library(readxl)
# There seem to be some multibyte problems here, it works
# better in a basic C locale than in the default en-UTF8
Sys.setlocale("LC_ALL","C")

root_folder="/data/Raw/For Supplementaries/Supplementary 9 Material comparison"

setwd(root_folder)

overview=as.data.frame(read_excel("overview_files_stress_sweeps_control_materials.xlsx"))



overview$start_line = as.numeric(overview$start_line)
overview$stop_line=as.numeric(overview$stop_line)




theColnames=c("t.en.s","t_seg.en.s","X.....en.Pas","f.en.Hz" , "file" ,"folder","polymer_conc_mgmL"
,"X..en.Pa","G..en.Pa","X.G...en.Pa.","X..en...1","X..en..","Polymer_concentration_adjustment","Dry_weight_measurement","Geometry","porosity","shape","size_sort","Material","overview_index")

overview$Gprime=NA


overview$purpose="Comparison to other materials"



for(ind in 1:(dim(overview)[1]))
{
    
    
    info=overview[ind,]
    
    current_data = read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=info$start_line-1,nrows=info$stop_line-info$start_line,sep="\t",comment.char="",blank.lines.skip=FALSE,quote="")
    
    
    if(dim(current_data)[2]==1)
    {
        current_data = read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=info$start_line-1,nrows=info$stop_line-info$start_line,sep=";",comment.char="",blank.lines.skip=FALSE,quote="")
        
    }
    
    
    current_data = current_data[(1+info$skip):(dim(current_data)[1]),]
    
    current_data$file=info$File
    current_data$folder=info$Folder
    current_data$polymer_conc_mgmL=info$polymer_conc_mgmL
    current_data$aspiration_pressure_cm_H2O = info$aspiration_pressure_cm_H2O
    current_data$correction_factor_M = info$correction_factor_M
    current_data$Polymer_concentration_adjustment=info$Polymer_concentration_adjustment
    current_data$Dry_weight_measurement=info$Dry_weight_measurement
    current_data$Geometry=info$Geometry
    current_data$porosity=info$porosity
    current_data$shape=info$shape
    current_data$size_sort=info$size_sort
    current_data$Material=info$Material
    
    current_data$overview_index=ind
    
    # Sometimes the Gprime character conversion is different
    if(!("X..en.Pa" %in% colnames(current_data)))
    {
        if("Tau.en.Pa" %in% colnames(current_data))
        {
            current_data$X..en.Pa = current_data[,"Tau.en.Pa"]
        }
    }
    
    if(!("X.G...en.Pa." %in% colnames(current_data)))
    {
        if("G..en.Pa.1" %in% colnames(current_data))
        {
            current_data[,"X.G...en.Pa."] = current_data[,"G..en.Pa.1"]
        }
    }
    
    # Sometimes the viscosity (irrelevant here) got forgotten
    if(!("X.....en.Pas" %in% colnames(current_data)))
    {
        current_data[,"X.....en.Pas"]=NA
    }
    
    if(!("X..en.." %in% colnames(current_data)))
    {
        if("Ga.en.." %in% colnames(current_data))
        {
            current_data$X..en.. = current_data[,"Ga.en.."]
        }
    }
    
    if(!("X..en...1" %in% colnames(current_data)))
    {
        if("Da.en.." %in% colnames(current_data))
        {
            current_data$X..en...1 = current_data[,"Da.en.."]
        } else
        {
            current_data$X..en...1=NA
        }
    }
    
    if(!("M.en..Nm"%in% colnames(current_data)))
    {
        current_data$M.en..Nm=NA
    }
    
    
    if(!("X..en.rad" %in% colnames(current_data)))
    {
        current_data$X..en.rad = NA
    }
    
    # Sometimes we have inversion of G' and G'' in the text file. This needs to be corrected because the
    # characters ' and '' are lost during saving and loading of the text files
    if(info$Gprime_and_Gprime_inverted_in_text_file==1)
    {
        z=current_data$G..en.Pa
        current_data$G..en.Pa=current_data$X.G...en.Pa.
        current_data$X.G...en.Pa.=z
        
    }
    
    # Once the chuck starts spinning after the liquefaction transition, artefacts are generated. Go only up to a
    # decrease of 1:1000 from the original G' value
    if(any(current_data$G..en.Pa<current_data$G..en.Pa[1]*1e-3))
    {
        
        spinning = min(which(current_data$G..en.Pa<current_data$G..en.Pa[1]*2e-3))
        spinning = min(c(spinning,dim(current_data)[1]))
        
        
        
        current_data = current_data[1:spinning,]
        
    }
    
    
    
    
    if(ind==1)
    {
        all_data = current_data[,theColnames]
        
        
    } else
    {
        all_data = rbind(all_data,current_data[,theColnames])
    }
    
    
    overview$Gprime[ind]=mean(current_data[1,"G..en.Pa"])
    
}




colnames(all_data)[colnames(all_data)=="X..en.Pa"]="tau_Pa"
colnames(all_data)[colnames(all_data)=="G..en.Pa"]="Gprime_Pa"
colnames(all_data)[colnames(all_data)=="X.G...en.Pa."]="Gprimeprime_Pa"
colnames(all_data)[colnames(all_data)=="X..en...1"]="Phase_angle_degrees"
colnames(all_data)[colnames(all_data)=="X..en.."]="Gamma_in_percent"




all_data$Phase_angle_degrees=atan(all_data$Gprimeprime_Pa/all_data$Gprime_Pa)/pi*180







stress_sweeps_comparison=all_data

overview_comparison = overview



numerical_cols_overview=c("Line","start_line" ,"stop_line","skip", "polymer_conc_mgmL",
"uniaxial_compression","Gprime")

for(theNumericalColumn in numerical_cols_overview)
{
    overview_comparison[,theNumericalColumn]=as.numeric(overview_comparison[,theNumericalColumn])
}


numerical_cols_sweeps=c("t.en.s","t_seg.en.s","X.....en.Pas","f.en.Hz"
,"polymer_conc_mgmL","tau_Pa","Gprime_Pa","Gprimeprime_Pa","Phase_angle_degrees","Gamma_in_percent")

for(theNumericalColumn in numerical_cols_sweeps)
{
    stress_sweeps_comparison[,theNumericalColumn]=as.numeric(stress_sweeps_comparison[,theNumericalColumn])
}




setwd("/results/Evaluation/For Supplementaries/Supplementary 9 Material comparison")

save(file="stress_sweeps_comparison.rda",list=c("stress_sweeps_comparison","overview_comparison"))



