library(readxl)


root_folder="/data/Raw/Particle Geometry/Particle Shape"

setwd(root_folder)

overview_particle_shape=as.data.frame(read_excel("/data/Raw/Particle Geometry/Particle Shape/particles_shape_quantification.xlsx"))


overview_particle_shape$Material = factor(overview_particle_shape$Material,levels=c("EPI","EPI_Alg","CMC_non_porous_irregular","Alg_non_porous_irregular"
    ,"Juvederm","cultisphere_s","CMC_non_porous_spherical","Alg_non_porous_spherical",
     "Sephacryl S200","cytodex"))


# Aggregate per image analyzed. This is to get the cutoff for the solidity and roundness parameters below
overview_particle_shape_per_image = aggregate(overview_particle_shape[,
c("Area","Circularity","Aspect_ratio","Roundness","Solidity")],by=overview_particle_shape[,c("Material","Folder","Image","Design_shape","Design_porosity","polymer")],FUN=mean)

# This is to get the cutoffs for solidity and roundness. It is an improved percentile function handling interpolation and values outside the domain covered
# (these outside values are handled with normal distribution joint to the interpolation at the edge of the interval covered by the values)
get_fraction_smaller_extrapolated<-function(x,vals)
{
    sort_vals=sort(vals)
    m=mean(vals)
    ret=x
    for(ind in 1:length(x))
    {
    n_smaller=sum(sort_vals<x[ind])
    if(n_smaller>0 & n_smaller<length(sort_vals))
    {
        # interpolate
        
        ret[ind]=n_smaller+(x[ind]-sort_vals[n_smaller])/(sort_vals[n_smaller+1]-sort_vals[n_smaller])
    } else {
        if(n_smaller==0) # this means we are below the first value
        {
           # at the mininum value in vals, ret should be 1, extrapolate with exp(-x2/2sd)
           
           ret[ind]=exp(-((x[ind]-m)/sd(vals))^2/2)/exp(-((sort_vals[1]-m)/sd(vals))^2/2)
           
        } else {
            ret[ind]=n_smaller +1-exp(-((x[ind]-m)/sd(vals))^2/2)/exp(-((sort_vals[length(sort_vals)]-m)/sd(vals))^2/2)
            
        }
    }
    
    }
    ret=ret/(length(sort_vals)+1)
    return(ret)
}

# Get the cutoff on the solidity by using known porous or non-porous partile design
# We put the cutoff where chances of misclassifying the two types of particles are equal
# df will be the aggregated data per image from above
cutoff.solidity <- function(df)
{
  
  
  solidity_quantile_delta<-function(x){get_fraction_smaller_extrapolated(x,df$Solidity[df$Design_porosity==0])-(1-get_fraction_smaller_extrapolated(x,df$Solidity[df$Design_porosity==1]))}


  solidity_cutoff=uniroot(solidity_quantile_delta,c(0,1))$root
  
  return(solidity_cutoff)
  
  
}

particle_shape_solidity_cutoff=cutoff.solidity(overview_particle_shape_per_image)


# Get the cutoff on the roundness by using the known irregularity/regularity of the particles
# We put the cutoff where chances of misclassifying the two types of particles are equal
# df will be the aggregated data per image from above
cutoff.roundness <- function(df)
{
  
  
  roundness_quantile_delta<-function(x){get_fraction_smaller_extrapolated(x,df$Roundness[df$Design_shape=="spherical"])-(1-get_fraction_smaller_extrapolated(x,df$Roundness[df$Design_shape=="irregular"]))}

  roundness_cutoff=uniroot(roundness_quantile_delta,c(0,1))$root
  
  return(roundness_cutoff)
  
  
}


particle_shape_roundness_cutoff=cutoff.roundness(overview_particle_shape_per_image)



save(file="/results/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda",list="overview_particle_shape","root_folder","particle_shape_solidity_cutoff","particle_shape_roundness_cutoff")
