library(readxl)


# Configure here the raw data path 

root_folder = "/data/Raw/Rheology/Creep recovery"


setwd(root_folder)


overview_data = as.data.frame(read_excel("overview_files_creep_recovery.xlsx"))


for(ind in 1:(dim(overview_data)[1]))
{

info=overview_data[ind,]


# First, load the strain rate sweep that directly gives the stress as a function of strain rate, but that does not extend to very low strain rates due to the inability of the rheostress apparatus to control very low strain rats.

creep_and_relaxation = read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=info$start_line_strain_rate_sweep-1,nrows=info$stop_line_strain_rate_sweep-info$start_line_strain_rate_sweep,sep="\t",comment.char="",blank.lines.skip=FALSE,quote="",fileEncoding="latin1")  # The first measurement is wrong due to the apparatus inability to control low strain rates

# Encoding issue, to make consistent with previous evaluation
    colnames(creep_and_relaxation)[colnames(creep_and_relaxation)=="Â.en.."]="X..en.."
    colnames(creep_and_relaxation)[colnames(creep_and_relaxation)=="ä.en.Pa"]="X..en.Pa"
    colnames(creep_and_relaxation)[colnames(creep_and_relaxation)=="Î.en.."]="X..en.."
    
    
# "X..en.Pa" was once tau en Pa (en = in in French), so this is the shear stress
# "X..en.." was once gamma en % , so this is the shear deformation in percent
    
theStress = creep_and_relaxation[,"X..en.Pa"]
theStrain = (creep_and_relaxation[,"X..en.."]-creep_and_relaxation[1,"X..en.."])*1e-2
theTime = round(creep_and_relaxation[,"t.en.s"])



if(ind==1)
{
    creep_recovery_experiments = data.frame(time=theTime,strain = theStrain, stress=theStress,File=info$File,Folder=info$Folder,polymer_conc_mgmL=info$polymer_conc_mgmL,target_pressure_step=info$target_pressure_step_Pa,
    pre_stress = info$pre_stress_Pa,Line=info$Line)
} else

{
    creep_recovery_experiments = rbind(creep_recovery_experiments,data.frame(time=theTime,strain = theStrain, stress=theStress,File=info$File,Folder=info$Folder,polymer_conc_mgmL=info$polymer_conc_mgmL,target_pressure_step=info$target_pressure_step_Pa,pre_stress = info$pre_stress_Pa,Line=info$Line))
    
}




}


creep_recovery_agg = aggregate(creep_recovery_experiments[,c("strain","stress")],by=creep_recovery_experiments[,c("time","target_pressure_step","pre_stress")],FUN=mean)
creep_recovery_agg_sd = aggregate(creep_recovery_experiments[,c("strain","stress")],by=creep_recovery_experiments[,c("time","target_pressure_step","pre_stress")],FUN=sd)

# Not all traces have the exact same length, so go by the shortest one

time_span = aggregate(data.frame(time=creep_recovery_experiments[,c("time")]),by=creep_recovery_experiments[,c("target_pressure_step","pre_stress","File")],FUN=max)

time_span = aggregate(data.frame(time=time_span$time),by=time_span[,c("target_pressure_step", "pre_stress")],FUN=min)

for(ind in 1:(dim(time_span)[1]))
{
    sel = !(creep_recovery_agg$target_pressure_step==time_span$target_pressure_step[ind] & creep_recovery_agg$pre_stress==time_span$pre_stress[ind]) |  creep_recovery_agg$time<=time_span$time[ind]
    
    
    creep_recovery_agg=creep_recovery_agg[sel,]
     creep_recovery_agg_sd=creep_recovery_agg_sd[sel,]
    
}



creep_recovery_agg$group=paste(creep_recovery_agg$target_pressure_step,creep_recovery_agg$pre_stress,sep="-")

overview_creep_recovery=overview_data

# Configure here the data evaluation path
save(file="/results/Evaluation/Rheology/Creep recovery/EPI/creep_recovery.rda",list=c("creep_recovery_agg","creep_recovery_agg_sd","overview_creep_recovery","creep_recovery_experiments"))


