library(readxl)



root_folder="/data/Raw/Rheology/Self healing"

setwd(root_folder)


overview=as.data.frame(read_excel("overview_files_self_healing_kinetics.xlsx"))




for(ind in 1:(dim(overview)[1]))
{
    
    info=overview[ind,]
    
    start_line = info$header_line
    
    stop_line = max(info[,c("header_line","baseline_stop","shear_stop","recovery_stop")])
    
    
    current_data = read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=start_line-1,nrows=stop_line-start_line,sep="\t",comment.char="",blank.lines.skip=FALSE,quote="",fileEncoding="latin1")
    
    
    if(dim(current_data)[2]==1)
    {
        current_data = read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=start_line-1,nrows=stop_line-start_line,sep=";",comment.char="",blank.lines.skip=FALSE,quote="",fileEncoding="latin1")
        
    }
    
    
    # Encoding issue, to make consistent with previous evaluation
    colnames(current_data)[colnames(current_data)=="M.en.\302\265Nm"]="M.en..Nm"
    
    
    # Assemble the desired Segments
    baseline_segment = current_data[(info$baseline_start-start_line):(info$baseline_stop-start_line),]
    baseline_segment$Segment="baseline"
    
    shear_segment = current_data[(info$shear_start-start_line):(info$shear_stop-start_line),]
    shear_segment$Segment="shear"
    
    recovery_segment = current_data[(info$recovery_start-start_line):(info$recovery_stop-start_line),]
    recovery_segment$Segment="recovery"
    
    current_data = rbind(baseline_segment,shear_segment,recovery_segment)
    
    current_data$overview_index = ind
    
    
    current_data$t_s_relative = current_data$t.en.s-min(current_data$t.en.s)
    
    
   
    
    if(ind==1)
    {
        all_data = current_data
        theColnames=colnames(all_data)
        
        
    } else
    {
        all_data = rbind(all_data,current_data[,theColnames])
    }
    
    overview$Tau_Pa[ind]=current_data[1,"Tau.en.Pa"]
    overview$f_Hz[ind]=current_data[1,"f.en.Hz"]
    
    
}









colnames(all_data)[colnames(all_data)=="G..en.Pa.1"]="Gprime_Pa"
colnames(all_data)[colnames(all_data)=="G..en.Pa"]="Gprimeprime_Pa"


self_healing_kinetics = all_data
overview_self_healing_kinetics = overview


start_point = aggregate(t_s_relative ~overview_index,self_healing_kinetics[self_healing_kinetics$Segment=="shear",],FUN=max)

self_healing_kinetics$t_s_relative=(self_healing_kinetics$t_s_relative-start_point$t_s_relative[match(self_healing_kinetics$overview_index,start_point$overview_index)])


self_healing_kinetics$t_s_relative_full_precision=self_healing_kinetics$t_s_relative



# We have the problem that measurement cycles are supposed to take 15s, but they don't exactly. So when aggregating, the various time points will not match exactly
# To deal with this problem, we rather count the number of measurement periods before and after t=0

self_healing_kinetics$t_s_theoretical=NA

for(ind in unique(self_healing_kinetics$overview_index))
{
    t_s = self_healing_kinetics$t_s_relative_full_precision[self_healing_kinetics$overview_index==ind]
    self_healing_kinetics$t_s_theoretical[self_healing_kinetics$overview_index==ind] = ((1:length(t_s))-which.min(abs(t_s)))*10
    

    
}

correction_coefficient=coefficients(lm(t_s_theoretical ~ t_s_relative_full_precision, self_healing_kinetics ))[["t_s_relative_full_precision"]]

self_healing_kinetics$t_s_theoretical=self_healing_kinetics$t_s_theoretical/correction_coefficient


self_healing_kinetics$t_s_relative=self_healing_kinetics$t_s_theoretical



self_healing_kinetics$Tau_Pa_nominal = overview_self_healing_kinetics$Tau_Pa[self_healing_kinetics$overview_index]

self_healing_kinetics_agg = aggregate(self_healing_kinetics[,c("Gprime_Pa","Gprimeprime_Pa","overview_index")],by= self_healing_kinetics[,c("Segment","t_s_relative","Tau_Pa_nominal")],FUN=mean)


self_healing_kinetics_agg_sd = aggregate(self_healing_kinetics[,c("Gprime_Pa","Gprimeprime_Pa","overview_index")],by= self_healing_kinetics[,c("Segment","t_s_relative","Tau_Pa_nominal")],FUN=sd)


# This is to exclude  time points where a smaller number of evaluations is available (this happens because spacing is not as regular as it is supposed to be

most_frequent_composition = aggregate(overview_index ~  Tau_Pa_nominal, self_healing_kinetics_agg, FUN=function(x){as.numeric(names(sort(table(c(x)),decreasing=TRUE)))[1]})

most_frequent_composition$overview_index = round(most_frequent_composition$overview_index*10)/10




corresponds_to_most_frequent_composition=round(self_healing_kinetics_agg$overview_index*10)/10==most_frequent_composition$overview_index[match(self_healing_kinetics_agg$Tau_Pa_nominal,most_frequent_composition$Tau_Pa_nominal)]


self_healing_kinetics_agg_constant_composition=self_healing_kinetics_agg[corresponds_to_most_frequent_composition,]


self_healing_kinetics_agg_constant_composition_sd=self_healing_kinetics_agg[corresponds_to_most_frequent_composition,]






# Configure here your data evaluation path
save(file="/results/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda",list=c(
"self_healing_kinetics","overview_self_healing_kinetics",
"self_healing_kinetics_agg","self_healing_kinetics_agg_sd",
"self_healing_kinetics_agg_constant_composition","self_healing_kinetics_agg_constant_composition_sd"))


