library(readxl)



root_folder="/data/Raw/Rheology/Stress Sweeps/EPI"


#root_folder="/Users/thomasbraschler/switchdrive/Mechanical_v2/Data/Raw Data/Rheology/Stress Sweeps/EPI"


#options(encoding="UTF-8-BOM")


setwd(root_folder)

overview1=as.data.frame(read_excel("overview_files_stress_sweep_EPI.xlsx"))


overview1$purpose = "Single sweep per concentration"


overview2=as.data.frame(read_excel("overview_files_stress_sweep_EPI.xlsx",sheet=2))

overview2$purpose="Additional plate-plate sweeps"

overview=rbind(overview1,overview2)

overview$start_line = as.numeric(overview$start_line)
overview$stop_line=as.numeric(overview$stop_line)




theColnames=c("t.en.s","t_seg.en.s","X.....en.Pas","f.en.Hz" , "file" ,"folder","polymer_conc_mgmL"
,"aspiration_pressure_cm_H2O","correction_factor_M","X..en.Pa","G..en.Pa","X.G...en.Pa.","X..en...1","X..en..","Polymer_concentration_adjustment","Dry_weight_measurement","Geometry","purpose","overview_index")

overview$Gprime=NA

for(ind in 1:(dim(overview)[1]))
{

    
    
    info=overview[ind,]

    
    current_data=read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=info$start_line-1,nrows=info$stop_line-info$start_line,sep="\t",comment.char="",blank.lines.skip=FALSE,quote="",fileEncoding="latin1")
    
    
    if(dim(current_data)[2]==1)
    {
    current_data=read.table(file=paste(info$Folder,info$File,sep="/"),header=TRUE,skip=info$start_line-1,nrows=info$stop_line-info$start_line,sep=";",comment.char="",blank.lines.skip=FALSE,quote="",fileEncoding="latin1")    
        
    }
    
    current_data = current_data[(1+info$skip):(dim(current_data)[1]),]
    
    current_data$file=info$File
    current_data$folder=info$Folder
    current_data$polymer_conc_mgmL=info$polymer_conc_mgmL
    current_data$aspiration_pressure_cm_H2O = info$aspiration_pressure_cm_H2O
    current_data$correction_factor_M = info$correction_factor_M
    current_data$Polymer_concentration_adjustment=info$Polymer_concentration_adjustment
    current_data$Dry_weight_measurement=info$Dry_weight_measurement
    current_data$Geometry=info$Geometry
    current_data$purpose=info$purpose
    current_data$overview_index = ind
    
    # Sometimes the Gprime character conversion is different,
    # these lines are to make it workable on different systems
    if(!("X..en.Pa" %in% colnames(current_data)))
    {
        if("Tau.en.Pa" %in% colnames(current_data))
        {
            current_data$X..en.Pa = current_data[,"Tau.en.Pa"]
        }
        if("â.en.Pa" %in% colnames(current_data))
        {
            current_data$X..en.Pa = current_data[,"â.en.Pa"]
        }
        
    }
    
    if(!("X.G...en.Pa." %in% colnames(current_data)))
    {
        if("G..en.Pa.1" %in% colnames(current_data))
        {
            current_data[,"X.G...en.Pa."] = current_data[,"G..en.Pa.1"]
        }
    }
    
    # Addressing encoding issues with the viscosity column name
    if(("X.Ä...en.Pas" %in% colnames(current_data)) &
      !("X.....en.Pas" %in% colnames(current_data)))
        {
        current_data[,"X.....en.Pas"]=current_data[,"X.Ä...en.Pas"]
    }
    
    # Sometimes the viscosity (irrelevant here) got forgotten
    if(!("X.....en.Pas" %in% colnames(current_data)))
    {
        current_data[,"X.....en.Pas"]=NA
    }
    
    if(!("X..en.." %in% colnames(current_data)))
    {
        if("Ga.en.." %in% colnames(current_data))
        {
            current_data$X..en.. = current_data[,"Ga.en.."]
        }
        if("å.en.." %in% colnames(current_data))
        {
            current_data$X..en.. = current_data[,"å.en.."]
        }
        if("Ì.en.." %in% colnames(current_data))
        {
            current_data$X..en.. = current_data[,"Ì.en.."]
        }
    }
    
    if(!("X..en...1" %in% colnames(current_data)))
    {
        if("Da.en.." %in% colnames(current_data))
        {
            current_data$X..en...1 = current_data[,"Da.en.."]
        } else
        {
            current_data$X..en...1=NA
        }
    }
    
    if(!("M.en..Nm"%in% colnames(current_data)))
    {
        current_data$M.en..Nm=NA
    }
    
    
    if(!("X..en.rad" %in% colnames(current_data)))
    {
        current_data$X..en.rad = NA
    }
    
    # Sometimes we have inversion of G' and G'' in the text file. This needs to be corrected because the
    # characters ' and '' are lost during saving and loading of the text files
    if(info$Gprime_and_Gprime_inverted_in_text_file==1)
    {
        z=current_data$G..en.Pa
        current_data$G..en.Pa=current_data$X.G...en.Pa.
        current_data$X.G...en.Pa.=z
        
    }
    
    # Once the chuck starts spinning after the liquefaction transition, artefacts are generated. Go only up to a
    # decrease of 1:1000 from the original G' value
    if(any(current_data$G..en.Pa<current_data$G..en.Pa[1]*1e-3))
    {
        
        spinning = min(which(current_data$G..en.Pa<current_data$G..en.Pa[1]*2e-3))
        spinning = min(c(spinning,dim(current_data)[1]))
        
        
        
        current_data = current_data[1:spinning,]
        
    }
    
    
    
    
    if(ind==1)
    {
        all_data = current_data[,theColnames]
        
        
    } else
    {
        all_data = rbind(all_data,current_data[,theColnames])
    }
    
    
    overview$Gprime[ind]=mean(current_data[1,"G..en.Pa"])/overview$correction_factor_M[ind]
    
}




colnames(all_data)[colnames(all_data)=="X..en.Pa"]="tau_Pa"
colnames(all_data)[colnames(all_data)=="G..en.Pa"]="Gprime_Pa"
colnames(all_data)[colnames(all_data)=="X.G...en.Pa."]="Gprimeprime_Pa"
colnames(all_data)[colnames(all_data)=="X..en...1"]="Phase_angle_degrees"
colnames(all_data)[colnames(all_data)=="X..en.."]="Gamma_in_percent"


all_data$Gprime_Pa = all_data$Gprime_Pa/all_data$correction_factor_M
all_data$Gprimeprime_Pa = all_data$Gprimeprime_Pa/all_data$correction_factor_M

all_data$Gamma_in_percent = all_data$Gamma_in_percent*all_data$correction_factor_M

all_data$Phase_angle_degrees=atan(all_data$Gprimeprime_Pa/all_data$Gprime_Pa)/pi*180



all_data=all_data[all_data$tau_Pa>=1 ,]

# Get the polymer content from the aspiration pressure

# Also needs the swelling curve for polymer concentration evaluation
# Configure here your raw data path (to unzipped contents of 07 Raw Hydrostatic pressure response.zip)

swelling_data_EPI = as.data.frame(read_excel("/data/Raw/Hydrostatic pressure response/EPI/Swelling Curve _ PB46 Paste Repeated.xlsx"))
# There are some issues with character conversion on the last two colnames, both on the codeocean system and locally on my mac. Make it the same (these are anyways irrelevant for the evaluation)
colnames(swelling_data_EPI)[colnames(swelling_data_EPI)=="...18"]="X__1"
colnames(swelling_data_EPI)[colnames(swelling_data_EPI)=="...19"]="X__2"


pressures_at_missing_polymer_conc = as.numeric(all_data$aspiration_pressure_cm_H2O[all_data$polymer_conc_mgmL=="NA"])*1e-2*9.81*1000

polmyer_conc_for_missing = approx(x=swelling_data_EPI$Stress_Pa,y=swelling_data_EPI$Current_concentration_mg_mL,xout=pressures_at_missing_polymer_conc)$y

all_data$polymer_conc_mgmL[all_data$polymer_conc_mgmL=="NA"]=polmyer_conc_for_missing

all_data$polymer_conc_mgmL = as.numeric(all_data$polymer_conc_mgmL)

pressures_at_missing_polymer_conc_overview = as.numeric(overview$aspiration_pressure_cm_H2O[overview$polymer_conc_mgmL=="NA"])*1e-2*9.81*1000

polmyer_conc_for_missing_overview = approx(x=swelling_data_EPI$Stress_Pa,y=swelling_data_EPI$Current_concentration_mg_mL,xout=pressures_at_missing_polymer_conc_overview)$y

overview$polymer_conc_mgmL[overview$polymer_conc_mgmL=="NA"]=polmyer_conc_for_missing_overview

overview$polymer_conc_mgmL=as.numeric(overview$polymer_conc_mgmL)









stress_sweeps_EPI=all_data

overview_EPI = overview
# Configure here your data evaluation path
setwd("/results/Evaluation/Rheology/Stress Sweeps/EPI")

save(file="stress_sweeps_EPI.rda",list=c("stress_sweeps_EPI","overview_EPI","swelling_data_EPI"))






