
library(particleShearEvaluation)

get_softening_point<-function(Strain_amplitude,Gprime_Pa,threshold_Gprime_Pa)
{
    
    ord=order(Strain_amplitude,decreasing=TRUE)
    
    Strain_amplitude=Strain_amplitude[ord]
    Gprime_Pa=Gprime_Pa[ord]
    
    
    ind_first_high=Inf
    if(any(Gprime_Pa>threshold_Gprime_Pa))
    {
        ind_first_high = min(which(Gprime_Pa>threshold_Gprime_Pa))
    }
    
    
    if(ind_first_high==1)
    {
        return(Strain_amplitude[ind_first_high])
        
    }
    if(ind_first_high==Inf)
    {
        return(NA)
    }
    if(ind_first_high>1)
    {
        difference_high=Gprime_Pa[ind_first_high]-threshold_Gprime_Pa
        difference_low=Gprime_Pa[ind_first_high-1]-threshold_Gprime_Pa
        
        difference_strain_amplitude = Strain_amplitude[ind_first_high]-Strain_amplitude[ind_first_high-1]
        
        # linear interpolation
        
        return(Strain_amplitude[ind_first_high-1]-difference_low/(difference_high-difference_low)*difference_strain_amplitude)
        
        
        
    }
    
    
    
}


sd_by_groups=function(x,n_agg=5)
{
    N=floor(length(x)/n_agg)
    
    sd_vector = vector(mode="numeric",length=N)
    for(ind_group in 1:N)
    {
        sd_vector[ind_group]=sd(x[(ind_group-1)*n_agg+(1:n_agg)],na.rm=TRUE)
        
    }
    return(mean(sd_vector,na.rm=TRUE))
}





root_folder = "/data/Evaluation/Simulation/Overview_data_files"

setwd(root_folder)

threshold_Gprime_Pa=2000

plateau_strain=0.001


load(file="overview_simulation_jumps_corrected.rda")

# Use the corrected version where available


overview_simulation$Gprime_Pa_original=overview_simulation$Gprime_Pa
overview_simulation$Gprimeprime_Pa_original=overview_simulation$Gprimeprime_Pa

overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]




to_aggregate=c("Gprime_Pa_surface_force","Gprimeprime_Pa_surface_force","Gprime_Pa","Gprimeprime_Pa","Stress")

by = c("Friction_coefficient","Strain_amplitude","Sample_type","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","remove_link_fraction")



# Restrict to a canonical set of conditions. There are some more conditions, but we do not explore these statistically in the present manuscript
common_conditions=overview_simulation$remove_link_fraction %in% c(0,0.2,0.4,0.6) & overview_simulation$cut_lines %in% c(0,5) & overview_simulation$Friction_coefficient %in% c(0,0.001,0.003,0.01, 0.03, 0.1)




overview_agg=aggregate(overview_simulation[
common_conditions,to_aggregate],by=overview_simulation[
common_conditions,by],FUN=mean,na.rm=TRUE)






unique_conditions=aggregate(overview_agg$Gprime_Pa,by=overview_agg[,c("Friction_coefficient","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","Sample_type","remove_link_fraction")],FUN=mean)


unique_conditions$yield_strain=NA
unique_conditions$softening_strain=NA
unique_conditions$plateau_Gprime_Pa=NA
unique_conditions$plateau_Gprime_Pa_sd=NA



unique_conditions$yield_strain_sd=NA
unique_conditions$softening_strain_sd=NA


N_draw = 500

bootstrap_draws_soft_plateau_strain=matrix(nrow=length(unique_conditions$yield_strain),ncol=N_draw*5)
bootstrap_draws_soft_plateau_Gprime=matrix(nrow=length(unique_conditions$yield_strain),ncol=N_draw*5)
bootstrap_draws_yield_strain=matrix(nrow=length(unique_conditions$yield_strain),ncol=N_draw*5)
bootstrap_draws_softening_strain=matrix(nrow=length(unique_conditions$yield_strain),ncol=N_draw*5)
bootstrap_draws_mid_softening_strain=matrix(nrow=length(unique_conditions$yield_strain),ncol=N_draw*5)


cat("Drawing bootstrap samples and evaluating overall characteristics\n")

for(ind in 1:length(unique_conditions$yield_strain))
{
    # Aggregated curve
    current_data =overview_agg[
    overview_agg$Friction_coefficient==unique_conditions$Friction_coefficient[ind] &
    overview_agg$packing_fraction==unique_conditions$packing_fraction[ind] &
    overview_agg$interface_reenforcement_central==unique_conditions$interface_reenforcement_central[ind] &
    overview_agg$Young_modulus_spheres==unique_conditions$Young_modulus_spheres[ind] &
    overview_agg$Sample_type==unique_conditions$Sample_type[ind] &
    overview_agg$remove_link_fraction==unique_conditions$remove_link_fraction[ind],]
    
    current_data = current_data[order(current_data$Strain_amplitude,decreasing=TRUE),]
    
    overview_subset = overview_simulation[common_conditions &
    overview_simulation$Friction_coefficient==unique_conditions$Friction_coefficient[ind] &
    overview_simulation$packing_fraction==unique_conditions$packing_fraction[ind] &
    overview_simulation$interface_reenforcement_central==unique_conditions$interface_reenforcement_central[ind] &
    overview_simulation$Young_modulus_spheres==unique_conditions$Young_modulus_spheres[ind]&
    overview_simulation$Sample_type==unique_conditions$Sample_type[ind] &
    overview_simulation$remove_link_fraction==unique_conditions$remove_link_fraction[ind],]
    
    
    unique_conditions$yield_strain[ind]=get_yield_point(
    current_data$Strain_amplitude,
    current_data$Gprime_Pa,
    current_data$Gprimeprime_Pa)
    
    
    unique_conditions$softening_strain[ind]=get_softening_point(
    current_data$Strain_amplitude,
    current_data$Gprime_Pa,
    threshold_Gprime_Pa)
    
    
    for(ind_draw in 1:N_draw)
    {
        
        overview_subset$to_use_1=FALSE
        overview_subset$to_use_2=FALSE
        overview_subset$to_use_3=FALSE
        overview_subset$to_use_4=FALSE
        overview_subset$to_use_5=FALSE
        
        
        for(theStrain in unique(overview_subset$Strain_amplitude))
        {
            overview_subset$to_use_1[overview_subset$Strain_amplitude==theStrain]=(runif(sum(overview_subset$Strain_amplitude==theStrain))>0.8)
            overview_subset$to_use_2[overview_subset$Strain_amplitude==theStrain]=(runif(sum(overview_subset$Strain_amplitude==theStrain))>0.8)
            overview_subset$to_use_3[overview_subset$Strain_amplitude==theStrain]=(runif(sum(overview_subset$Strain_amplitude==theStrain))>0.8)
            overview_subset$to_use_4[overview_subset$Strain_amplitude==theStrain]=(runif(sum(overview_subset$Strain_amplitude==theStrain))>0.8)
            overview_subset$to_use_5[overview_subset$Strain_amplitude==theStrain]=(runif(sum(overview_subset$Strain_amplitude==theStrain))>0.8)
        }
        
        
        
        overview_agg_1=aggregate(overview_subset[overview_subset$to_use_1,to_aggregate],by=overview_subset[overview_subset$to_use_1,by],FUN=mean,na.rm=TRUE)
        
        overview_agg_2=aggregate(overview_subset[overview_subset$to_use_2,to_aggregate],by=overview_subset[overview_subset$to_use_2,by],FUN=mean,na.rm=TRUE)
        
        overview_agg_3=aggregate(overview_subset[overview_subset$to_use_3,to_aggregate],by=overview_subset[overview_subset$to_use_3,by],FUN=mean,na.rm=TRUE)
        
        overview_agg_4=aggregate(overview_subset[overview_subset$to_use_4,to_aggregate],by=overview_subset[overview_subset$to_use_4,by],FUN=mean,na.rm=TRUE)
        
        overview_agg_5=aggregate(overview_subset[overview_subset$to_use_5,to_aggregate],by=overview_subset[overview_subset$to_use_5,by],FUN=mean,na.rm=TRUE)
        
        
        
        # Get the landmark values
        l1=evaluate_stress_curve(overview_agg_1$Strain_amplitude,
        overview_agg_1$Gprime_Pa,overview_agg_1$Gprimeprime_Pa)
        
        l2=evaluate_stress_curve(overview_agg_2$Strain_amplitude,
        overview_agg_2$Gprime_Pa,overview_agg_2$Gprimeprime_Pa)
        
        l3=evaluate_stress_curve(overview_agg_3$Strain_amplitude,
        overview_agg_3$Gprime_Pa,overview_agg_3$Gprimeprime_Pa)
        
        l4=evaluate_stress_curve(overview_agg_4$Strain_amplitude,
        overview_agg_4$Gprime_Pa,overview_agg_4$Gprimeprime_Pa)
        
        l5=evaluate_stress_curve(overview_agg_5$Strain_amplitude,
        overview_agg_5$Gprime_Pa,overview_agg_5$Gprimeprime_Pa)
        
        
        
        # From the largest strain, find first strain where Gprime is equal to or larger than Gprimeprime
        
        bootstrap_draws_yield_strain[ind,(ind_draw-1)*5+1]=l1["strain_evaluated","yield"]
        bootstrap_draws_yield_strain[ind,(ind_draw-1)*5+2]=l2["strain_evaluated","yield"]
        bootstrap_draws_yield_strain[ind,(ind_draw-1)*5+3]=l3["strain_evaluated","yield"]
        bootstrap_draws_yield_strain[ind,(ind_draw-1)*5+4]=l4["strain_evaluated","yield"]
        bootstrap_draws_yield_strain[ind,(ind_draw-1)*5+5]=l5["strain_evaluated","yield"]
        
        # Mid-softening strain
        
        bootstrap_draws_mid_softening_strain[ind,(ind_draw-1)*5+1]=l1["strain_evaluated","softening"]
        bootstrap_draws_mid_softening_strain[ind,(ind_draw-1)*5+2]=l2["strain_evaluated","softening"]
        bootstrap_draws_mid_softening_strain[ind,(ind_draw-1)*5+3]=l3["strain_evaluated","softening"]
        bootstrap_draws_mid_softening_strain[ind,(ind_draw-1)*5+4]=l4["strain_evaluated","softening"]
        bootstrap_draws_mid_softening_strain[ind,(ind_draw-1)*5+5]=l5["strain_evaluated","softening"]
        
        # Mid-soft plateau strain
        
        bootstrap_draws_soft_plateau_strain[ind,(ind_draw-1)*5+1]=l1["strain_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_strain[ind,(ind_draw-1)*5+2]=l2["strain_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_strain[ind,(ind_draw-1)*5+3]=l3["strain_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_strain[ind,(ind_draw-1)*5+4]=l4["strain_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_strain[ind,(ind_draw-1)*5+5]=l5["strain_evaluated","soft_plateau"]
        
        
        # Mid-soft plateau Gprime
        
        bootstrap_draws_soft_plateau_Gprime[ind,(ind_draw-1)*5+1]=l1["Gprime_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_Gprime[ind,(ind_draw-1)*5+2]=l2["Gprime_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_Gprime[ind,(ind_draw-1)*5+3]=l3["Gprime_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_Gprime[ind,(ind_draw-1)*5+4]=l4["Gprime_evaluated","soft_plateau"]
        bootstrap_draws_soft_plateau_Gprime[ind,(ind_draw-1)*5+5]=l5["Gprime_evaluated","soft_plateau"]
        
        
        
        
        # Get the softening point
        
        bootstrap_draws_softening_strain[ind,(ind_draw-1)*5+1]=get_softening_point(
        overview_agg_1$Strain_amplitude,
        overview_agg_1$Gprime_Pa,
        threshold_Gprime_Pa)
        
        bootstrap_draws_softening_strain[ind,(ind_draw-1)*5+2]=get_softening_point(
        overview_agg_2$Strain_amplitude,
        overview_agg_2$Gprime_Pa,
        threshold_Gprime_Pa)
        
        bootstrap_draws_softening_strain[ind,(ind_draw-1)*5+3]=get_softening_point(
        overview_agg_3$Strain_amplitude,
        overview_agg_3$Gprime_Pa,
        threshold_Gprime_Pa)
        
        bootstrap_draws_softening_strain[ind,(ind_draw-1)*5+4]=get_softening_point(
        overview_agg_4$Strain_amplitude,
        overview_agg_4$Gprime_Pa,
        threshold_Gprime_Pa)
        
        bootstrap_draws_softening_strain[ind,(ind_draw-1)*5+5]=get_softening_point(
        overview_agg_5$Strain_amplitude,
        overview_agg_5$Gprime_Pa,
        threshold_Gprime_Pa)
        
        
        
        
    }
    
    
    
    
    
    if(any(overview_subset$Strain_amplitude==plateau_strain))
    {
        
        unique_conditions$plateau_Gprime_Pa[ind]=mean(overview_subset$Gprime_Pa[overview_subset$Strain_amplitude==plateau_strain])
        unique_conditions$plateau_Gprime_Pa_sd[ind]=sd(overview_subset$Gprime_Pa[overview_subset$Strain_amplitude==plateau_strain],na.rm=TRUE)
    }
    
    
    cat(ind)
    cat(" out of ")
    cat(length(unique_conditions$yield_strain))
    cat("d one \n")
    
    
    
}


unique_conditions$softening_strain_sd=apply(bootstrap_draws_softening_strain,1,sd_by_groups,n_agg=5)
unique_conditions$yield_strain_sd=apply(bootstrap_draws_yield_strain,1,sd_by_groups,n_agg=5)


# Save results
save(file="/results/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda",
list=c("overview_simulation","overview_agg","bootstrap_draws_yield_strain",
"bootstrap_draws_softening_strain","unique_conditions","threshold_Gprime_Pa","plateau_strain",
"bootstrap_draws_soft_plateau_strain","bootstrap_draws_soft_plateau_Gprime","bootstrap_draws_mid_softening_strain"
))



