library(particleShearEvaluation)
library(stringr) # To ensure operating-system independent sorting

# This function allows to read and store the additional
# information regarding the non-monotoneous (plateau)
# force-distance laws analyzed in this dataset

complete_overview<-function(overview_simulation_force_law)
{
    
    
    overview_simulation_force_law$plateau_law = 0
    overview_simulation_force_law$plateau_begin = 0
    overview_simulation_force_law$plateau_end = 0
    overview_simulation_force_law$plateau_slope = 0
    
    
    for(ind in 1:(dim(overview_simulation_force_law)[1]))
    {
        info=overview_simulation_force_law[ind,]
        header = read_first_lines(paste(info$Folder,info$File,sep="/"))
        if(length(grep("Plateau law",header))>0)
        {
            overview_simulation_force_law$plateau_law[ind]=1
            
            pattern = "Compressive plateau begin = (?<capture>[0-9]*\\.?[0-9]*)"
            text_info=find_info_from_text(header,pattern)
            if(is.character(text_info))
            {
                overview_simulation_force_law$plateau_begin[ind]=as.numeric(text_info)
            } else {
                # Standard setting
                overview_simulation_force_law$plateau_begin[ind]=0.3
            }
            pattern = "Compressive plateau end = (?<capture>[0-9]*\\.?[0-9]*)"
            text_info=find_info_from_text(header,pattern)
            if(is.character(text_info))
            {
                overview_simulation_force_law$plateau_end[ind]=as.numeric(text_info)
            } else {
                # Standard setting if not provided in file
                overview_simulation_force_law$plateau_end[ind]=0.8
            }
            
            pattern = "Compressive plateau slope = (?<capture>[0-9]*\\.?[0-9]*)"
            text_info=find_info_from_text(header,pattern)
            
            if(is.character(text_info))
            {
                overview_simulation_force_law$plateau_slope[ind]=as.numeric(text_info)
            } else {
                # Standard setting if not provided in file
                overview_simulation_force_law$plateau_slope[ind]=0.1
            }
            
            
            
            
        }
        
    }
    
    return(overview_simulation_force_law)
    
}



root_folder = "/data/Raw/Simulation/nonlinear_force_law"


storage_folder="/results/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/01_initial"


path_and_file_information=data.frame(path=c(
"python_data",
"python_data2",
"python_data3",
"python_data4",
"python_data5",
"python_data8"    
),
variable_name = c(
"overview_simulation_force_law1",
"overview_simulation_force_law2",
"overview_simulation_force_law3",
"overview_simulation_force_law4",
"overview_simulation_force_law5",
"overview_simulation_force_law7"    
))

path_and_file_information$path=as.character(path_and_file_information$path)
path_and_file_information$variable_name=as.character(path_and_file_information$variable_name)

path_and_file_information$rda_file=paste(as.character(path_and_file_information$variable_name),".rda",sep="")



for(ind in 1:(dim(path_and_file_information)[1]))
{
    
    setwd(root_folder)
    
    cat(paste("Reading ", path_and_file_information$variable_name[ind],"\n",sep=""))
    theTable=file_information_table_from_folders(path_and_file_information$path[ind],min_file_size=1e3)
    
    theTable$Sample_type=factor(rep("uncrosslinked",dim(theTable)[1]),levels=c("bulk","uncrosslinked","particles"))
    
    theTable$Sample_type[theTable$do_permanent_links]="bulk"
    
    theTable$Sample_type[theTable$do_permanent_links & theTable$cut_lines>0]="particles"
    
    theTable$remove_link_fraction=as.numeric(theTable$remove_link_fraction)
    theTable$remove_link_fraction[!theTable$do_permanent_links]=0
    
    theTable=theTable[str_order(theTable$File,locale="C"),]
    # To have consistent ordering, file systems
    # give otherwise somewhat variable ordering and so it becomes
    # difficult to compare the resulting files
    
    theTable=complete_overview(theTable)
    
    assign(path_and_file_information$variable_name[ind],theTable)
    
    setwd(storage_folder)
    
    # Save to the corresponding rda file
    save(file=path_and_file_information$rda_file[ind],list=c(path_and_file_information$variable_name[ind]))
    
    
    
    
}












