library(particleShearEvaluation)

root_folder = "/data/Raw/Simulation/nonlinear_force_law"




initial_overview_folder="/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/01_initial"

storage_folder="/results/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/02_jumps_corrected"

report_folder=paste(storage_folder,"analysis_reports",sep="/")


path_and_file_information=data.frame(
variable_name = c(
"overview_simulation_force_law1",
"overview_simulation_force_law2",
"overview_simulation_force_law3",
"overview_simulation_force_law4",
"overview_simulation_force_law5",
"overview_simulation_force_law7"
))

path_and_file_information$variable_name=as.character(path_and_file_information$variable_name)

path_and_file_information$rda_file=paste(as.character(path_and_file_information$variable_name),".rda",sep="")



for(ind_information in 1:(dim(path_and_file_information)[1]))
{
    
    setwd(initial_overview_folder)
    
    env=new.env()
    
    load(file=path_and_file_information$rda_file[ind_information],envir=env)
    
    theTable = get(path_and_file_information$variable_name[ind_information],envir=env)
    
    to_read=theTable$Strain_amplitude<=0.1 # Analyze only the low strain, at high strain the discontinuity error is small
    
    # New columns to hold the corrected information
    
    theTable$Gprime_Pa_surface_force_jumps_corrected=NA
    theTable$Gprimeprime_Pa_surface_force_jumps_corrected=NA
    
    theTable$Gprime_Pa_jumps_corrected=NA
    theTable$Gprimeprime_Pa_jumps_corrected=NA
    
    cat(paste("Jump correction for ", path_and_file_information$variable_name[ind_information],"\n",sep=""))
    
    
    # Start a pdf file showing the plots of the corrected curves
    setwd(report_folder)
    
    pdf(paste(path_and_file_information$variable_name[ind_information],"_jump_correction.pdf",sep=""))
    
    setwd(storage_folder)
    
    for (ind in 1:(dim(theTable)[1]))
    {
        
        cat(paste("   Stress curve ",ind," of ",dim(theTable)[1],"\n",sep=""))
        
        
        setwd(root_folder)
        
        info = theTable[ind,]
        
        stress_filename =paste("stress_",gsub(".txt",".rda",info$File),sep="")
        stress_filename =gsub("header_","",stress_filename)
        
        pathRead=paste(info$Folder,stress_filename,sep="/")
        
        path =paste(info$Folder,info$File,sep="/")
        
        theStressCurve = read_stress_curve_from_rda_file(path=pathRead)
        
        theStressCurve$measurement=measurement_periods(
        theStressCurve,info$baseline_pre_periods,info$periods,info$Frequency)
        
        osc_measurement=theStressCurve[theStressCurve$measurement=="oscillatory_measurement",]
        
        min_t=min(osc_measurement$t)
        
        theStressCurve$t_rel = theStressCurve$t-min_t
        
        max_stress = max(c(max(theStressCurve$shear_stress_measured_at_surface),max(theStressCurve$shear_stress_from_internal_stress_tensor)))
        
        min_stress = min(c(min(theStressCurve$shear_stress_measured_at_surface),min(theStressCurve$shear_stress_from_internal_stress_tensor)))
        
        mid_point=(max_stress+min_stress)/2
        
        height_graph=4*(max_stress-min_stress)
        ylim=c(mid_point-height_graph/2,mid_point+height_graph/2)
        
        index_plotting = round(seq(from=1, to=dim(theStressCurve)[1],length.out=400))
        
        
        plot(shear_stress_measured_at_surface ~ t_rel, theStressCurve[index_plotting,],type="l",main=paste(info$Folder,stress_filename,sep="/\n"),ylim=ylim,col="red",xlab="Time [s]",ylab="Shear stress [Pa]")
        lines(shear_stress_from_internal_stress_tensor ~ t_rel, theStressCurve[index_plotting,],type="l",col="black")
        
        legend("topleft",legend=c("Stress: internally measured","    used for G'/G'' demodulation","Stress: by surface force","    used for G'/G'' demodulation"),lty=c("solid","solid","solid","solid"),col=c("black","black","red","red"),lwd=c(1,5,1,5))
        
        
        theStressCurveTensor=read_stress_tensor_data_from_rda_file(path=pathRead)
            
            theStressCurveTensor$measurement=measurement_periods(
            theStressCurveTensor,info$baseline_pre_periods,info$periods,info$Frequency)
            
            
            theTable$P[ind]=mean(theStressCurveTensor$stress_tensor_overall_00[theStressCurveTensor$measurement=="pre"]+theStressCurveTensor$stress_tensor_overall_11[theStressCurveTensor$measurement=="pre"])/2
        
        
        
        if(to_read[ind])
        {
        
        
        
        
        G=G_from_demodulation(t=osc_measurement$t,
        Frequency=info$Frequency,
        m=osc_measurement$shear_stress_measured_at_surface,
        Strain_amplitude=info$Strain_amplitude,
        relative_threshold=0.1,doPlot=TRUE,plot.new=FALSE,lty="solid",col="red",lwd=5)
        
        
        theTable$Gprime_Pa_surface_force_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]=G["Gprime"]
        
        theTable$Gprimeprime_Pa_surface_force_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]=G["Gprimeprime"]
        
        G_internal=G_from_demodulation(t=osc_measurement$t,
        Frequency=info$Frequency,
        m=osc_measurement$shear_stress_from_internal_stress_tensor,
        Strain_amplitude=info$Strain_amplitude,
        relative_threshold=0.1,doPlot=TRUE,plot.new=FALSE,lty="solid",col="black",lwd=5)
        
        
        theTable$Gprime_Pa_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]=G_internal["Gprime"]
        
        theTable$Gprimeprime_Pa_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]=G_internal["Gprimeprime"]
        
        
        } else {
            
            osc_measurement$t = osc_measurement$t-min(osc_measurement$t)
            
            lines(shear_stress_measured_at_surface ~ t, osc_measurement,type="l",col="red",lwd=5)
            lines(shear_stress_from_internal_stress_tensor ~ t, osc_measurement,type="l",col="black",lwd=5)
            
            
        }
        
        # Output an evaluation summary on a second page. This is a text output
        
        plot.new()
        
        plot.window(c(0,1),c(0,1))
        
        
        text(x=0,y=1,paste("Analysis of file\n",info$Folder,"/\n",stress_filename,sep=""),adj=c(0,1))
        
        text(x=0,y=0.8,"Shear moduli obtained in Python",adj=c(0,1))
        
        text(x=0,y=0.75,"G'",adj=c(0,1))
        text(x=0,y=0.7,"internal",adj=c(0,1))
        text(x=0.15,y=0.7,"surface",adj=c(0,1))
        
        text(x=0.4,y=0.75,"G''",adj=c(0,1))
        text(x=0.4,y=0.7,"internal",adj=c(0,1))
        text(x=0.55,y=0.7,"surface",adj=c(0,1))
        
        
        
        text(x=0,y=0.65,sprintf("%1.0f",theTable$Gprime_Pa[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
         text(x=0.15,y=0.65,sprintf("%1.0f",theTable$Gprime_Pa_surface_force[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        text(x=0.4,y=0.65,sprintf("%1.0f",theTable$Gprimeprime_Pa[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        text(x=0.55,y=0.65,sprintf("%1.0f",theTable$Gprimeprime_Pa_surface_force[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        if(to_read[ind])
        {
        text(x=0,y=0.5,"Shear moduli after jump-correction, R-cran",adj=c(0,1))
        
        
        
        
        
        
        
        
        } else {
           text(x=0,y=0.5,"Large strain (>0.1), no jump-correction",adj=c(0,1))
        }
        
        text(x=0,y=0.45,"G'",adj=c(0,1))
        text(x=0,y=0.4,"internal",adj=c(0,1))
        text(x=0.15,y=0.4,"surface",adj=c(0,1))
        
        text(x=0.4,y=0.45,"G''",adj=c(0,1))
        text(x=0.4,y=0.4,"internal",adj=c(0,1))
        text(x=0.55,y=0.4,"surface",adj=c(0,1))
        
        
        
        
        text(x=0,y=0.35,sprintf("%1.0f",theTable$Gprime_Pa_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        text(x=0.15,y=0.35,sprintf("%1.0f",theTable$Gprime_Pa_surface_force_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        text(x=0.4,y=0.35,sprintf("%1.0f",theTable$Gprimeprime_Pa_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        text(x=0.55,y=0.35,sprintf("%1.0f",theTable$Gprimeprime_Pa_surface_force_jumps_corrected[match(path,paste(theTable$Folder,theTable$File,sep="/"))]),adj=c(0,1))
        
        
        dev.flush()
        
        
        
    }
    
    
    # Draw overview graph
    
    
    
    
    to_aggregate=c("Gprime_Pa","Gprimeprime_Pa","Gprime_Pa_surface_force","Gprimeprime_Pa_surface_force",
    "Gprime_Pa_jumps_corrected","Gprimeprime_Pa_jumps_corrected",
    "Gprime_Pa_surface_force_jumps_corrected","Gprimeprime_Pa_surface_force_jumps_corrected",
    "Stress")
    
    by = c("Friction_coefficient","Strain_amplitude","Sample_type","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","remove_link_fraction")
    
   
    
    
    
    overview_agg=aggregate(theTable[,to_aggregate],by=theTable[,by],FUN=mean,na.rm=TRUE)
    
    
    
    unique_conditions=aggregate(overview_agg$Gprime_Pa,by=overview_agg[,c("Friction_coefficient","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","remove_link_fraction","Sample_type")],FUN=mean)
    
    for(ind_condition in 1:(dim(unique_conditions)[1]))
    {

        
        to_plot=overview_agg[
        overview_agg$Friction_coefficient==unique_conditions$Friction_coefficient[ind_condition] &
        overview_agg$packing_fraction==unique_conditions$packing_fraction[ind_condition] &
        overview_agg$interface_reenforcement_central==unique_conditions$interface_reenforcement_central[ind_condition] &
        overview_agg$Young_modulus_spheres==unique_conditions$Young_modulus_spheres[ind_condition] &
        overview_agg$remove_link_fraction==unique_conditions$remove_link_fraction[ind_condition] &
        overview_agg$Sample_type==unique_conditions$Sample_type[ind_condition]
        ,]
        
        
        
        assembly_types_title=c("Bulk","Spherical","Irregular compact particles")
        names(assembly_types_title)=c("bulk","uncrosslinked","particles")
        
        title=assembly_types_title[unique_conditions$Sample_type[ind_condition]]
        
        if(title=="Irregular compact particles" & unique_conditions$remove_link_fraction[ind_condition]>0)
        {
            title="Irregular porous particles"
        }
        
        title=paste(title," with parameters:\n","Packing=",unique_conditions$packing_fraction[ind_condition]," Friction=",unique_conditions$Friction_coefficient[ind_condition],sep="")
        if(unique_conditions$interface_reenforcement_central[ind_condition]!=1)
        {title=paste(title," Interface reeinforcement=",unique_conditions$interface_reenforcement_central[ind_condition],sep="")}
        title=paste(title,"\nYoung modulus E=",unique_conditions$Young_modulus_spheres[ind_condition],sep="")
        if(unique_conditions$remove_link_fraction[ind_condition]!=0)
        {title=paste(title," remove links=",unique_conditions$remove_link_fraction[ind_condition],
            sep="")}
        
        
        plot(to_plot$Strain_amplitude,to_plot$Gprime_Pa,
        ylab="G' and G''[Pa]",xlab="Strain",log="x",ylim=c(1,3000),xlim=c(1e-3,2),cex=1.5,main=title,type="b")
        
        lines(to_plot$Strain_amplitude,to_plot$Gprimeprime_Pa,cex=0.75,type="b")
        
        lines(to_plot$Strain_amplitude,to_plot$Gprime_Pa_jumps_corrected,col="red",type="b",cex=1.5)
        
        lines(to_plot$Strain_amplitude,to_plot$Gprimeprime_Pa_jumps_corrected,cex=0.75,col="red",type="b")
        
        legend("topright",legend=c("G'","G' continuity correction","G''","G'' continuity correction"),lty=rep(1,4),pch=rep(1,4),col=c("black","red","black","red"),pt.cex=c(1.5,1.5,0.75,0.75))
        
    }
    
    

    
    
    
    
    dev.off()
    
    
    
    
    assign(path_and_file_information$variable_name[ind_information],theTable)
    
    setwd(storage_folder)
    
    # Save to the corresponding rda file
    save(file=paste(path_and_file_information$variable_name[ind_information],"_jumps_corrected.rda",sep=""),list=c(path_and_file_information$variable_name[ind_information]))
    
    
    
    
    
    
    
    
    
    
    
    
   
    
    
}












