library(reproducibleCalculationTools)


cat("Comparison of data evaluation runs\n")
cat("This file compares the reference data evaluation uploaded to the \n")
cat("codeocean capsule (in /data/Evaluation and sub-folders) to the current analysis (in the Evaluation folder of the results section). \n\n\n")


all_validation_tests_passed=TRUE

cat("Evaluation of simulation data ===================================")
cat("\n   Comparison of the initial evaluations (reference in /data/Evaluation vs. current evaluation in /results/Evaluation)")

# There is a series of simulation overview files to compare, define them here
to_compare_simulation_overview=c(
    "overview_simulation_baseline",
    "overview_simulation_friction_young",
    "overview_simulation_friction_packing",
    "overview_simulation_spherical",
    "overview_simulation_crosslink",
    "overview_simulation_crosslink_pack_2",
    "overview_simulation_bulk",
    "overview_simulation_friction_low",
    "overview_simulation_friction_low_porous",
    "overview_simulation_packing_1",
    "overview_simulation_friction_low_spherical",
    "overview_simulation_completion",
    "overview_simulation_thomas_bulk",
    "overview_simulation_bulk_young",
    "overview_simulation_young_modulus_close",
    "overview_simulation_round_16_friction_high"
)

# Go through all of them for comparison
for(ind in 1:length(to_compare_simulation_overview))
    {
    # This is the simulation overview part to compare
    to_compare=to_compare_simulation_overview[ind] 
    		
    cat(paste("\n\nCompare evaluation of ",to_compare, ".rda, located in  Simulation/Overview_data_files/01_initial\n",sep=""))

    # This is the first rda file path: the reference evaluation
    path1=paste(
    "/data/Evaluation/Simulation/Overview_data_files/01_initial/",
    to_compare,".rda",sep="")

    # This is the second rda file path: the current evaluation
    path2=paste(
    "/results/Evaluation/Simulation/Overview_data_files/01_initial/",
    to_compare,".rda",sep="")
    
    # We should not compare files and folders, those are local
    exclude_variables=c(paste(to_compare,"File",sep="/"),paste(to_compare,"Folder",sep="/"))
	
current_test=compare_rda_contents(path1, path2,   exclude_variables=exclude_variables,numerical_tolerance=1e-12)
    
 

all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))
}

# Next: jump correction
cat("\n   Comparison of the evaluations corrected for continuity by removal of the jumps caused by spheres leaving and entering the measurement region (again, reference in /data/Evaluation vs. current evaluation in /results/Evaluation)")

# Go through all of them for comparison
for(ind in 1:length(to_compare_simulation_overview))
    {
    # This is the simulation overview part to compare
    to_compare=to_compare_simulation_overview[ind] 
    		
    
    
    cat(paste("\n\nCompare evaluation of ",to_compare, "_jumps_corrected.rda, located in  Simulation/Overview_data_files/02_jumps_corrected\n",sep=""))

    # This is the first rda file path: the reference evaluation
    path1=paste(
    "/data/Evaluation/Simulation/Overview_data_files/02_jumps_corrected/",
    to_compare,"_jumps_corrected.rda",sep="")

    # This is the second rda file path: the current evaluation
    path2=paste(
    "/results/Evaluation/Simulation/Overview_data_files/02_jumps_corrected/",
    to_compare,"_jumps_corrected.rda",sep="")
    
    # We should not compare files and folders, those are local
    exclude_variables=c(paste(to_compare,"File",sep="/"),paste(to_compare,"Folder",sep="/"))
	
current_test=compare_rda_contents(path1, path2,   exclude_variables=exclude_variables,numerical_tolerance=1e-11)
    
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))
}



cat(paste("\n\nCompare evaluation of overview_simulation_jumps_corrected_no_static_pressure.rda, located in  Simulation/Overview_data_files/02_jumps_corrected\n",sep=""))

    # This is the first rda file path: the reference evaluation
    path1=
    "/data/Evaluation/Simulation/Overview_data_files/02_jumps_corrected/overview_simulation_jumps_corrected_no_static_pressure.rda"

    # This is the second rda file path: the current evaluation
    path2=
    "/results/Evaluation/Simulation/Overview_data_files/02_jumps_corrected/overview_simulation_jumps_corrected_no_static_pressure.rda"
    
    # We should not compare files and folders, those are local
    exclude_variables=c("overview_simulation/File", "overview_simulation/Folder","root_folder")

current_test=compare_rda_contents(path1, path2,   exclude_variables=exclude_variables)
    
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nEvaluation of bootstrapping simulation overview files =========================")


# Bootstrapping
cat("\n\nCompare evaluation of overview_simulation_jumps_corrected_bootstrap.rda, located at Simulation/Overview_data_files\n")
cat("Bootstrapping is a random draw process, so the variables that are entirely or particle dependent on the bootstrapping process will nearly certainly not be equal from run to run: \"bootstrap_draws_mid_softening_strain\",\"bootstrap_draws_soft_plateau_Gprime\",\"bootstrap_draws_soft_plateau_strain\",\"bootstrap_draws_softening_strain\" and \"bootstrap_draws_yield_strain\". Further, the \"unique_conditions\" variable also contains some summary data depending on the bootstrapping.")


# The comparison of bootstrapping variables is a bit more complicated since 
# bootstrapping involves random resampling. We can still test some constant elements
# but not the actual bootstrapping process

exclude_variables=c("bootstrap_draws_mid_softening_strain","bootstrap_draws_soft_plateau_Gprime","bootstrap_draws_soft_plateau_strain","bootstrap_draws_softening_strain","bootstrap_draws_yield_strain","unique_conditions/x","unique_conditions/yield_strain","unique_conditions/softening_strain","unique_conditions/plateau_Gprime_Pa","unique_conditions/plateau_Gprime_Pa_sd","unique_conditions/yield_strain_sd","unique_conditions/softening_strain_sd","overview_simulation/Folder","overview_simulation/File")

current_test=compare_rda_contents("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda", "/results/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda",exclude_variables=exclude_variables)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nEvaluation of simulation data for nonlinear compression ============================================================")
cat("\n   Comparison of the initial evaluations (reference in /data/Evaluation vs. current evaluation in /results/Evaluation)")

# There is a series of simulation overview files to compare, define them here
to_compare_simulation_overview=c(
    "overview_simulation_force_law1",
    "overview_simulation_force_law2",
    "overview_simulation_force_law3",
    "overview_simulation_force_law4",
    "overview_simulation_force_law5",
    "overview_simulation_force_law7"
)

# Go through all of them for comparison
for(ind in 1:length(to_compare_simulation_overview))
    {
    # This is the simulation overview part to compare
    to_compare=to_compare_simulation_overview[ind] 
    
    
    
    cat(paste("\n\nCompare evaluation of ",to_compare, ".rda, located in  Simulation/Overview_data_files/nonlinear_force_law/01_initial\n",sep=""))

    # This is the first rda file path: the reference evaluation
    path1=paste(
    "/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/01_initial/",
    to_compare,".rda",sep="")

    # This is the second rda file path: the current evaluation
    path2=paste(
    "/results/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/01_initial/",
    to_compare,".rda",sep="")
    
    # We should not compare files and folders, those are local
    exclude_variables=c(paste(to_compare,"File",sep="/"),paste(to_compare,"Folder",sep="/"))
	
current_test=compare_rda_contents(path1, path2,   exclude_variables=exclude_variables)
    
 

all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))
}




# Next: jump correction
cat("\n   Nonlinear compression law simulations: Comparison of the evaluations corrected for continuity by removal of the jumps caused by spheres leaving and entering the measurement region (again, reference in /data/Evaluation vs. current evaluation in /results/Evaluation)")

# Go through all of them for comparison
for(ind in 1:length(to_compare_simulation_overview))
    {
    # This is the simulation overview part to compare
    to_compare=to_compare_simulation_overview[ind] 
    		
    
    
    cat(paste("\n\nCompare evaluation of ",to_compare, "_jumps_corrected.rda, located in  Simulation/Overview_data_files/nonlinear_force_law/02_jumps_corrected\n",sep=""))

    # This is the first rda file path: the reference evaluation
    path1=paste(
    "/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/02_jumps_corrected/",
    to_compare,"_jumps_corrected.rda",sep="")

    # This is the second rda file path: the current evaluation
    path2=paste(
    "/results/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/02_jumps_corrected/",
    to_compare,"_jumps_corrected.rda",sep="")
    
# We should not compare files and folders, those are local
    exclude_variables=c(paste(to_compare,"File",sep="/"),paste(to_compare,"Folder",sep="/"))
	
current_test=compare_rda_contents(path1, path2,   exclude_variables=exclude_variables,numerical_tolerance=1e-11)
    
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))
}

# The overall assembly was evaluated on CodeOcean, compare to 
# historical version (so identical folders and files as well)
cat("\n\nComparison of the overall assembly (nonlinear force law)")
current_test=compare_rda_contents("/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/overview_simulation_force_law_jumps_corrected.rda", "/results/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/overview_simulation_force_law_jumps_corrected.rda")

all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nEvaluation of example force law data")
current_test=compare_rda_contents("/data/Evaluation/Simulation/plateau_law/plateau_contact_law_fig_5e.rda","/results/Evaluation/Simulation/plateau_law/plateau_contact_law_fig_5e.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nEvaluation of ejection force data ===============================")
cat("\n\nCompare evaluation of ejection_force_data.rda, located in   Ejection Force/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Ejection Force/EPI/ejection_force_data.rda","/results/Evaluation/Ejection Force/EPI/ejection_force_data.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))

cat("\n\nCompare evaluation of ejection_force_data_bulk.rda, located in   Ejection Force/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Ejection Force/EPI/ejection_force_bulk.rda","/results/Evaluation/Ejection Force/EPI/ejection_force_bulk.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nCompare evaluation of ejection_force_data_aggregated.rda, located in   Ejection Force/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Ejection Force/EPI/ejection_force_data_aggregated.rda","/results/Evaluation/Ejection Force/EPI/ejection_force_data_aggregated.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nEvaluation of in vivo data ===============================")
cat("\n\nCompare evaluation of in_vivo_data.rda, located in the  \"In vivo\" folder\n")
current_test=compare_rda_contents("/data/Evaluation/In vivo/in_vivo_data.rda","/results/Evaluation/In vivo/in_vivo_data.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nEvaluation of in vivo degradation data ===============================")
cat("\n\nCompare evaluation of in_vivo_degradation.rda, located in the  \"In vivo\" folder\n")
current_test=compare_rda_contents("/data/Evaluation/In vivo/in_vivo_degradation.rda","/results/Evaluation/In vivo/in_vivo_degradation.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))







cat("\n\nEvaluation of porosity data ===============================")
cat("\nCompare evaluation of sephacryl_S200_porosity.rda, located at Porosity/Sephacryl_S200/Pore fraction\n")
cat("This dataset contains fitting data, requiring 1e-6 numerical precision")
current_test=compare_rda_contents("/data/Evaluation/Porosity/Sephacryl_S200/Pore fraction/sephacryl_S200_porosity.rda","/results/Evaluation/Porosity/Sephacryl_S200/Pore fraction/sephacryl_S200_porosity.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nCompare evaluation of pore_size_fitting_constants_sephacryl_S200.rda, located at Porosity/Sephacryl_S200/Pore size\n")
cat("This dataset contains fitting data, requiring 1e-6 numerical precision")
current_test=compare_rda_contents("/data/Evaluation/Porosity/Sephacryl_S200/Pore size/pore_size_fitting_constants_sephacryl_S200.rda","/results/Evaluation/Porosity/Sephacryl_S200/Pore size/pore_size_fitting_constants_sephacryl_S200.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\n\nCompare evaluation of EPI_porosity.rda, located at Porosity/EPI/Pore fraction\n")
cat("This dataset contains fitting data, requiring 1e-6 numerical precision")
current_test=compare_rda_contents("/data/Evaluation/Porosity/EPI/Pore fraction/EPI_porosity.rda","/results/Evaluation/Porosity/EPI/Pore fraction/EPI_porosity.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nCompare evaluation of pore_size_fitting_constants_EPI.rda, located at Porosity/EPI/Pore size\n")
cat("This dataset contains fitting data, requiring 1e-6 numerical precision")
current_test=compare_rda_contents("/data/Evaluation/Porosity/EPI/Pore size/pore_size_fitting_constants_EPI.rda","/results/Evaluation/Porosity/EPI/Pore size/pore_size_fitting_constants_EPI.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nCompare evaluation of EPI_intra_inter_particle_pore_space.rda, located at Porosity/EPI/inter_intra_particle_pore_space\n")
current_test=compare_rda_contents("/data/Evaluation/Porosity/EPI/inter_intra_particle_pore_space/EPI_intra_inter_particle_pore_space.rda","/results/Evaluation/Porosity/EPI/inter_intra_particle_pore_space/EPI_intra_inter_particle_pore_space.rda",exclude_variables="root_folder",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nEvaluation of rheology data ===============================")

cat("\n\nCompare evaluation of creep_recovery.rda, located at Rheology/Creep recovery/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Creep recovery/EPI/creep_recovery.rda","/results/Evaluation/Rheology/Creep recovery/EPI/creep_recovery.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\n\nCompare evaluation of stress_sweeps_injections.rda, located at Rheology/Injectability testing/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Injectability testing/EPI/stress_sweeps_injections.rda","/results/Evaluation/Rheology/Injectability testing/EPI/stress_sweeps_injections.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\n\nCompare evaluation of overview_files_self_healing_kinetics.rda, located at Rheology/Self healing\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda","/results/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))





cat("\n\nCompare evaluation of stress_sweeps_EPI.rda, located at Rheology/Stress Sweeps/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda","/results/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))

cat("\n\nCompare evaluation of stress_sweeps_EPI_neutralization.rda, located at Rheology/Stress Sweeps/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_neutralization.rda","/results/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_neutralization.rda",exclude_variables="root_folder",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))

cat("\n\nCompare evaluation of stress_sweeps_backbone_variation.rda, located at Rheology/Stress Sweeps/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/backbone_variation/stress_sweeps_backbone_variation.rda","/results/Evaluation/Rheology/Stress Sweeps/backbone_variation/stress_sweeps_backbone_variation.rda",exclude_variables="root_folder",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))

cat("\n\nCompare evaluation of stress_sweeps_cultisphere.rda, located at Rheology/Stress Sweeps/cultisphere\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/cultisphere/stress_sweeps_cultisphere.rda","/results/Evaluation/Rheology/Stress Sweeps/cultisphere/stress_sweeps_cultisphere.rda",exclude_variables="root_folder",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nCompare evaluation of stress_sweeps_coating.rda, located at Rheology/Stress Sweeps/EPI_coating\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/EPI_coating/stress_sweeps_coating.rda","/results/Evaluation/Rheology/Stress Sweeps/EPI_coating/stress_sweeps_coating.rda",exclude_variables="root_folder",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nCompare evaluation of stress_sweeps_EPI_all.rda, located at Rheology/Stress Sweeps/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda","/results/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\n\nCompare evaluation of polynomial_model_Gprime_EPI, located at Rheology/Stress Sweeps/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/EPI/polynomial_model_Gprime_EPI.rda", "/results/Evaluation/Rheology/Stress Sweeps/EPI/polynomial_model_Gprime_EPI.rda")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\nCompare evaluation of scaffold_rheology.rda, located at Rheology/Stress Sweeps/bulk\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/bulk/scaffold_rheology.rda","/results/Evaluation/Rheology/Stress Sweeps/bulk/scaffold_rheology.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\nCompare evaluation of stress_sweeps_juvederm.rda, located at Rheology/Stress Sweeps/Juvederm_Voluma\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda","/results/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\nCompare evaluation of stress_sweeps_sephacryl_S200.rda, located at Rheology/Stress Sweeps/Sephacryl_S200\n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda","/results/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda",numerical_tolerance=1e-13)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nCompare evaluation of polynomial_model_Gprime_Sephacryl_S200.rda, located at Rheology/Stress Sweeps/Sephacryl_S200\n")
cat("Evaluation here is to within numerical precision of 1e-6 since apparently there is slight divergence in implementation of least squares fitting algorithms")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/polynomial_model_Gprime_Sephacryl_S200.rda", "/results/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/polynomial_model_Gprime_Sephacryl_S200.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))





cat("\n\nCompare yield evaluation over all materials. This is yield_info_all_materials.rda, located at Rheology/Stress Sweeps  \n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda","/results/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda",exclude_variables="root_folder",numerical_tolerance=1e-15)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nCompare EPI flow curve evaluations. This is EPI_yield_stress.rda, located at Rheology/Flow curves/EPI   \n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Flow curves/EPI/EPI_yield_stress.rda","/results/Evaluation/Rheology/Flow curves/EPI/EPI_yield_stress.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nCompare Sephacryl S200 flow curve evaluations. This is sephacryl_S200_yield_stress.rda, located at Rheology/Flow curves/Sephacryl_S200   \n")
current_test=compare_rda_contents("/data/Evaluation/Rheology/Flow curves/Sephacryl_S200/sephacryl_S200_yield_stress.rda","/results/Evaluation/Rheology/Flow curves/Sephacryl_S200/sephacryl_S200_yield_stress.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\nEvaluation of uniaxial compression data ===============================")


cat("\nCompare evaluation of Compression_SelfHealing_Post_Injection.rda, located at Uniaxial compression/EPI\n")
current_test=compare_rda_contents("/data/Evaluation/Uniaxial compression/EPI/Compression_SelfHealing_Post_Injection.rda","/results/Evaluation/Uniaxial compression/EPI/Compression_SelfHealing_Post_Injection.rda",numerical_tolerance=1e-6)
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\nCompare evaluation of bulk_1_5_uniaxial_compression.rda, located at Uniaxial compression/bulk\n")
current_test=compare_rda_contents("/data/Evaluation/Uniaxial compression/bulk/bulk_1_5_uniaxial_compression.rda","/results/Evaluation/Uniaxial compression/bulk/bulk_1_5_uniaxial_compression.rda",numerical_tolerance=1e-7,exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))




cat("\n\nEvaluation of cell adherence data ===============================")


cat("\nCompare evaluation of adherence_assay.rda, located at in the cell \"Cell adherence\"folder\n")
current_test=compare_rda_contents("/data/Evaluation/Cell adherence/adherence_assay_OP9.rda","/results/Evaluation/Cell adherence/adherence_assay_OP9.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nEvaluation of particle size data ===============================")

cat("\nCompare evaluation of particle_size_overview_EPI.rda, located  in the  \"Particle Geometry/EPI\"folder\n")
current_test=compare_rda_contents("/data/Evaluation/Particle Geometry/EPI/particle_size_overview_EPI.rda","/results/Evaluation/Particle Geometry/EPI/particle_size_overview_EPI.rda",exclude_variables="root_folder")
all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))


cat("\n\nEvaluation of particle shape data ===============================")


cat("\nCompare evaluation of particle_shape.rda, located  in the  \"Particle Geometry/Particle Shape\"folder\n")
current_test=compare_rda_contents("/data/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda","/results/Evaluation/Particle Geometry/Particle Shape/particle_shape.rda",exclude_variables="root_folder")

all_validation_tests_passed=all_validation_tests_passed&current_test
cat(paste("\nOverall: ",current_test,sep=""))



cat("\n\n\n")
if(all_validation_tests_passed)
{
  cat("Overall validation: PASS")  
} else {
  cat("Overall validation: FAIL")  
    
}
    