


library(plot.counts)

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")



pdf("fig_2h.pdf")



# ==================== Begin evaluation ===================================


common_select=unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 & unique_conditions$Friction_coefficient %in% c(0.01)

sphere_select = common_select & unique_conditions$Sample_type %in% c("uncrosslinked")
particles_select = common_select  & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0
particles_loose_select = common_select & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4
bulk_select = common_select & unique_conditions$Sample_type %in% c("bulk") & unique_conditions$remove_link_fraction==0



selected_conditions_spheres=unique_conditions[ sphere_select,]

selected_conditions_particles=unique_conditions[ particles_select,]

selected_conditions_particles_loose=unique_conditions[particles_loose_select ,]






selected_conditions_bulk=unique_conditions[bulk_select ,]




for_barplot=data.frame(
spherical=selected_conditions_spheres$plateau_Gprime_Pa,
spherical_sd =selected_conditions_spheres$plateau_Gprime_Pa_sd,
particles=selected_conditions_particles$plateau_Gprime_Pa[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_particles$Young_modulus_spheres)],
particles_sd=selected_conditions_particles$plateau_Gprime_Pa_sd[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_particles$Young_modulus_spheres)],
particles_loose=selected_conditions_particles_loose$plateau_Gprime_Pa[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_particles_loose$Young_modulus_spheres)],
particles_loose_sd=selected_conditions_particles_loose$plateau_Gprime_Pa_sd[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_particles_loose$Young_modulus_spheres)],
bulk=selected_conditions_bulk$plateau_Gprime_Pa[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_bulk$Young_modulus_spheres)],
bulk_sd=selected_conditions_bulk$plateau_Gprime_Pa_sd[match(selected_conditions_spheres$Young_modulus_spheres,selected_conditions_bulk$Young_modulus_spheres)],
Young_modulus_spheres=selected_conditions_spheres$Young_modulus_spheres
)


# log matrix (because the softening strain is logarithmic; here, 0.001=0.1% will become 0, 1 will become three)

log_values=log(t(as.matrix(for_barplot[,c("spherical","particles_loose","particles","bulk")])),10)-2

# For the standard deviation: dlog 10 x = dlog x / log 10 = 1/x * dx / log(10)

sd_log_values=t(as.matrix(for_barplot[,c("spherical_sd","particles_loose_sd","particles_sd","bulk_sd")]))/t(as.matrix(for_barplot[,c("spherical","particles_loose","particles","bulk")]))/log(10)


barplot_with_errorbars(log_values,names.arg= for_barplot$Young_modulus_spheres/1e3,beside=TRUE,col=grey(c(1,0.8,0.4,0.25)),
sd_height=sd_log_values,xlab="Young modulus [kPa]",ylab="Plateau G' [kPa]",legend.text=c("spherical","irregular - porous","irregular - compact", "bulk"),
main="2h) Plateau G' vs. Young modulus",ylim=c(0,3),yaxt="n")

axis(at=log(c(1:9,(1:9)*10,(1:10)*100),10),side=2,labels=c(expression("0.1"),rep("",8),"1.0",rep("",8),"10",rep("",8),"100"),las=2)







select_young_modulus_low_strain=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(1e3,1e4,1e5) & ((overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction %in% c(0,0.4)) | overview_simulation$Sample_type %in% c("uncrosslinked")) & overview_simulation$Strain_amplitude==0.001
cat("Statistical reporting (Item 26)")
cat("\n====================")
cat("\nn (number of simulations per group)")
n=aggregate(Gprime_Pa ~ Young_modulus_spheres + Sample_type + remove_link_fraction, overview_simulation[select_young_modulus_low_strain,],FUN=length)
colnames(n)[colnames(n)=="Gprime_Pa"]="n"
n
cat("\nN (total number of simulations)")
sum(n$n)

cat("\nShapiro-Wilks for normality in linear model, prior to non-normality mitigation")
# Originally, we tried standard linear regression, but the residuals are non-normally distributed
linmod=lm(Gprime_Pa ~ Young_modulus_spheres + Sample_type + remove_link_fraction, overview_simulation[select_young_modulus_low_strain,])
shapiro.test(resid(linmod))

cat("\nShapiro-Wilks for normality in general linear model, used for non-normality mitigation (error structure with variance proportional to mu^2")


linmod=glm(Gprime_Pa ~ Young_modulus_spheres + Sample_type + remove_link_fraction, overview_simulation[select_young_modulus_low_strain,],family=quasi(link="identity",variance="mu^2"))

shapiro.test(resid(linmod))

cat("\nSummary of the linear model with Young modulus of the spheres, particle irregularity and porosity as explanatory factors (provides t-statistics and degrees of freedom of residuals)")
summary(linmod)


# Confidence intervals for the various slopes from the glm
cat("\nConfidence interval for the slope relating the G'0 to the Young modulus of the constituent spheres")
suppressMessages(confint(linmod,"Young_modulus_spheres"))
cat("\nConfidence interval for the slope relating the G'0 to the type of particles (irregular vs. spherical)")
suppressMessages(confint(linmod,"Sample_typeparticles"))
cat("\nConfidence interval for the slope relating the G'0 to the type of particles (per unit of crosslink removal probability)")
suppressMessages(confint(linmod,"remove_link_fraction"))



# For glm's, the r^2 is not given automatically, manual calculation:

s=summary(linmod)

deviance0 = s$null.deviance
# If we do the complete regression, the deviance becomes smaller
deviance_residual = s$deviance

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\nAdjusted R2 overall")

1 - (deviance_residual/deviance0) * s$df.null/s$df.residual

# Rsquared for each factor from single regression
linmod_Young=glm(Gprime_Pa ~ Young_modulus_spheres , overview_simulation[select_young_modulus_low_strain,],family=quasi(link="identity",variance="mu^2"))


s_Young=summary(linmod_Young)

deviance0 = s_Young$null.deviance
# If we do the complete regression, the deviance becomes smaller
deviance_residual = s_Young$deviance

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\nAdjusted R2 for Young modulus regression (single explanatory variable)")
1 - (deviance_residual/deviance0) * s_Young$df.null/s$df.residual


linmod_particle_type=glm(Gprime_Pa ~ Sample_type , overview_simulation[select_young_modulus_low_strain,],family=quasi(link="identity",variance="mu^2"))


s_particle_type=summary(linmod_particle_type)

deviance0 = s_particle_type$null.deviance
# If we do the complete regression, the deviance becomes smaller
deviance_residual = s_particle_type$deviance

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\nAdjusted R2 for sample type regression (single explanatory variable)")
1 - (deviance_residual/deviance0) * s_particle_type$df.null/s$df.residual


linmod_porosity=glm(Gprime_Pa ~ remove_link_fraction , overview_simulation[select_young_modulus_low_strain,],family=quasi(link="identity",variance="mu^2"))


s_porosity=summary(linmod_porosity)

deviance0 = s_porosity$null.deviance
# If we do the complete regression, the deviance becomes smaller
deviance_residual = s_porosity$deviance

# Rsquared is basically 1 - the relative remaining deviance. There is a correction for degrees
# of freedom, so overall

cat("\nAdjusted R2 for porosity regression (single explanatory variable)")
1 - (deviance_residual/deviance0) * s_porosity$df.null/s$df.residual





# The glm also doesn't give the overall F-statistic so we need to calculate it. This is done on the transformed, weighted valeus since this is the actual regression

# code modified from R's summary.lm
r <- linmod$residuals # difference between best fit and actual values
f <- linmod$fitted.values # total best fit values
w <- linmod$weights # adjusted by glm depending on the expected value
p <- linmod$rank # number of independent parameters including intercept
df.int <- if (attr(linmod$terms, "intercept")) 1L else 0L # is there a degree of freedom associated with the intercept
# mss is the sum of squares of the fitting (that is, sum(fitted values - mean fitted values)^2, weighted by the weights)
if (is.null(w)) {
    mss <- if (attr(linmod$terms, "intercept"))
    sum((f - mean(f))^2)
    else sum(f^2)
    rss <- sum(r^2)
} else {
    mss <- if (attr(linmod$terms, "intercept")) {
        m <- sum(w * f/sum(w))
        sum(w * (f - m)^2)
    } else sum(w * f^2)
    rss <- sum(w * r^2)
    r <- sqrt(w) * r
}
rdf <- linmod$df.residual
resvar <- rss/rdf

fstat=c(value = (mss/(p - df.int))/resvar,
numdf = p - df.int, dendf = rdf)
cat("\nOverall F-statistics")
fstat
cat("\nDegrees of freedom for overall F-statistics")
paste(fstat["numdf"],fstat["dendf"],sep="/")
cat("\nP-value for overall F-statistics")
pf(fstat["value"],fstat["numdf"],fstat["dendf"],lower.tail=FALSE)





dev.off()


