# Figure 3f shows selected rheological oscillatory stress sweeps for the EPI biomaterial at different polymer concentrtions. This script plots data stored in "stress_sweeps_EPI.rda". This script plots a selected subset

# Plotting library
library(plot.counts)


# Load the data
load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

# Start the device for saving the output graphics
pdf("fig_3f.pdf")





# For precision, use only sweeps with polymer concentrations measured by dry weight (and not via the swelling pressure, less precise)
to_use=stress_sweeps_EPI[stress_sweeps_EPI$Polymer_concentration_adjustment %in% (unique(stress_sweeps_EPI$Polymer_concentration_adjustment)[1:2]),]

# Exclude a sweep with 7 mg/mL where we stopped too early because we anticipated a yield point which did not occur (this sweep can still be used for low-strain G' values, but it is incomplete otherwise)

sweeps_7mgmL = to_use[round(to_use$polymer_conc_mgmL)==7,]

sweep_7mgmL_upper_pressure=aggregate(tau_Pa ~ file + folder, sweeps_7mgmL,FUN=max)

for(ind in 1:(dim(sweep_7mgmL_upper_pressure)[1]))
{
    if(sweep_7mgmL_upper_pressure$tau_Pa[ind] != max(sweep_7mgmL_upper_pressure$tau_Pa))
    {
        to_use = to_use[to_use$folder!=sweep_7mgmL_upper_pressure$folder[ind] | sweep_7mgmL_upper_pressure$file[ind]!=to_use$file,]
    }
    
}








# Aggregate where there are several curves with the same concentrations

data_agg=aggregate(to_use[,c("Gprime_Pa","Gprimeprime_Pa","Phase_angle_degrees")],by=data.frame(tau_Pa=to_use$tau_Pa,polymer_conc_mgmL=round(to_use$polymer_conc_mgmL)),FUN=mean)


# Selected concentrations

display_concentrations=c(7,15,23,32,54)

grps=plot_counts(data_agg$tau_Pa, data_agg$Gprime_Pa,log="xy",xlab="Shear stress [Pa]",ylab="Storage modulus G' [Pa]",main="3f) Elastic storage modulus",groups=data_agg$polymer_conc_mgmL,ylim=c(1,5e4),group_order=display_concentrations,bg=grey(c(1,0.9,0.75,0.6,0)),pch=21,col="black",xlim=c(0.1,1000),cex=0.75,xaxt="n",yaxt="n")

axis(side=1,at=c((1:9)*0.1,(1:9),(1:9)*10,(1:9)*100,1000),labels=c(expression(0.1),rep("",8),1,rep("",8),10,rep("",8),100,rep("",8),1000))

axis(side=2,at=c((1:9),(1:9)*10,(1:9)*100,(1:9)*1000,10000*(1:5)),labels=c(expression("1 Pa"),rep("",8),"10 Pa",rep("",8),"100 Pa",rep("",8),"1 kPa",rep("",8),"10 kPa",rep("",3),""),las=2)


sel_solid =data_agg$Gprime_Pa>=data_agg$Gprimeprime_Pa


grps=plot_counts(data_agg$tau_Pa[sel_solid], data_agg$Gprime_Pa[sel_solid],groups=data_agg$polymer_conc_mgmL[sel_solid],group_order=display_concentrations,bg=grey(c(1,0.9,0.75,0.6,0)),pch=21,col="black",xlim=c(0.1,1000),cex=2,plot.new=FALSE,type="p")


# To plot the labels at the right height
first_value=aggregate(Gprime_Pa ~ polymer_conc_mgmL, data_agg, FUN=function(x){x[1]} )

first_value = first_value[first_value$polymer_conc_mgmL %in% grps,]


text(x=rep(0.8, length(grps)),y=first_value$Gprime_Pa, labels=paste(first_value$polymer_conc_mgmL," mg/mL",sep=""),adj=1,cex=1.5)


# Group size reporting

N_reporting=aggregate(to_use[,c("Gprime_Pa","Gprimeprime_Pa","Phase_angle_degrees")],by=data.frame(tau_Pa=to_use$tau_Pa,polymer_conc_mgmL=round(to_use$polymer_conc_mgmL)),FUN=length)

# The figure is a selection to illustrate the behaviour at reasonably spaced polymer concentrations

N_reporting=N_reporting[N_reporting$polymer_conc_mgmL %in% display_concentrations,]

N_measurements=aggregate(Gprime_Pa ~ polymer_conc_mgmL,N_reporting,FUN=mean)

colnames(N_measurements)[2]="Measurements used"

cat("Statistical reporting (Item 28): Measurements shown\n")
N_measurements




cat("\nTotal measurements acquired")
length(unique(to_use$overview_index))





dev.off()







