# Figure 3f shows selected rheological oscillatory stress sweeps for the EPI biomaterial at different polymer concentrtions. This script plots data stored in "stress_sweeps_EPI.rda". This script is like R_script_Fig_3f.R, but plotting the complete set (for reference, the plot by itself is difficult to read)

# Plotting library
library(plot.counts)


# Load the data
load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

# Start the device for saving the output graphics
pdf("fig_3f_complete_set.pdf")





# Use the entire set
to_use=stress_sweeps_EPI


# Aggregate where there are several curves with the same concentrations

data_agg=aggregate(to_use[,c("Gprime_Pa","Gprimeprime_Pa","Phase_angle_degrees")],by=data.frame(tau_Pa=to_use$tau_Pa,polymer_conc_mgmL=round(to_use$polymer_conc_mgmL)),FUN=mean)


# All concentrations
bg=grey(1-(0:length(unique(data_agg$polymer_conc_mgmL)))/length(unique(data_agg$polymer_conc_mgmL)))

grps=plot_counts(data_agg$tau_Pa, data_agg$Gprime_Pa,log="xy",xlab="Shear stress [Pa]",ylab="Storage modulus G' [Pa]",main="3f) Elastic storage modulus, all curves",groups=data_agg$polymer_conc_mgmL,bg=bg,ylim=c(1,5e4),,pch=21,col="black",xlim=c(0.1,1000),cex=0.75,xaxt="n",yaxt="n")

axis(side=1,at=c((1:9)*0.1,(1:9),(1:9)*10,(1:9)*100,1000),labels=c(expression(0.1),rep("",8),1,rep("",8),10,rep("",8),100,rep("",8),1000))

axis(side=2,at=c((1:9),(1:9)*10,(1:9)*100,(1:9)*1000,10000*(1:5)),labels=c(expression("1 Pa"),rep("",8),"10 Pa",rep("",8),"100 Pa",rep("",8),"1 kPa",rep("",8),"10 kPa",rep("",3),""),las=2)


sel_solid =data_agg$Gprime_Pa>=data_agg$Gprimeprime_Pa


grps=plot_counts(data_agg$tau_Pa[sel_solid], data_agg$Gprime_Pa[sel_solid],groups=data_agg$polymer_conc_mgmL[sel_solid],bg=bg,pch=21,col="black",xlim=c(0.1,1000),cex=2,plot.new=FALSE,type="p")


# To plot the labels at the right height
first_value=aggregate(Gprime_Pa ~ polymer_conc_mgmL, data_agg, FUN=function(x){x[1]} )

first_value = first_value[first_value$polymer_conc_mgmL %in% grps,]


text(x=rep(0.8, length(grps)),y=first_value$Gprime_Pa, labels=paste(first_value$polymer_conc_mgmL," mg/mL",sep=""),adj=1,cex=1.5)


# Group size reporting

N_reporting=aggregate(to_use[,c("Gprime_Pa","Gprimeprime_Pa","Phase_angle_degrees")],by=data.frame(tau_Pa=to_use$tau_Pa,polymer_conc_mgmL=round(to_use$polymer_conc_mgmL)),FUN=length)

# The figure is a selection to illustrate the behaviour at reasonably spaced polymer concentrations

N_measurements=aggregate(Gprime_Pa ~ polymer_conc_mgmL,N_reporting,FUN=mean)

colnames(N_measurements)[2]="Measurements used"

N_measurements

dev.off()







