# Fig. 3g shows Juvederm compared to the EPI stress sweep. The data needed for this plot is in "stress_sweeps_EPI.rda" and "stress_sweeps_juvederm.rda". In the manuscript, we added a literature data plot for adipose tissue; the data for this addition can be found in Patel, P. N., Smith, C. K. & Patrick, C. W. Rheological and recovery properties of poly(ethylene glycol) diacrylate hydrogels and human adipose tissue. J Biomed Mater Res A 73a, 313-319, doi:10.1002/jbm.a.30291 (2005).
 

library("rheologyEvaluation")

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")



load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")


load(file="/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/adipose_tissue_rheology_data_patel.rda")


pdf("fig_3g.pdf")

xlim=c(0.01,1000)




to_use_EPI=stress_sweeps_EPI

# We use a concentration in the range for matching adipose tissue for this figure; also, because of issues withpast drying in the plate-geometry, reeinforce cup
to_use_EPI = stress_sweeps_EPI[round(stress_sweeps_EPI$polymer_conc_mgmL)==26 &stress_sweeps_EPI$Geometry=="cup",]


cex=1.5


# G' strain curve
plot(Gprime_Pa ~ Gamma_in_percent, to_use_EPI, log="xy",ylim=c(1,4e3),pch=21,type="b",cex=cex,bg="black",main="3g) Rheology EPI, HA control, adipose tissue from literature",xlim=xlim,
    ylab="G' [Pa]",xlab="Strain (Deformation)",xaxt="n",yaxt="n")



# Axes with logarithmic scale
axis(side=2,at=c(1:9,(1:9)*10,(1:9)*100,(1:10)*1000,20000),labels=c(expression("1 Pa"),rep("",8),"10 Pa",rep("",8),"100 Pa",rep("",8),"1 kPa",rep("",8),"10 kPa",""),las=2)


axis(side=1,at=c((1:9)*1e-2,(1:9)*1e-1,(1:9),(1:9)*10,(1:10)*100),labels=c(expression("0.01%"),rep("",8),"0.1%",rep("",8),"1.0%",rep("",8),"10%",rep("",8),"100%",rep("",8),"1000%"))




# G'' curves
lines(Gprimeprime_Pa ~ Gamma_in_percent, to_use_EPI, pch=21,type="b",cex=cex,bg="white")


# Juvederm

# Aggregate to obtain an averaged sweep
stress_sweeps_juvederm_agg = aggregate(stress_sweeps_juvederm[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent")],by=list(tau_Pa=stress_sweeps_juvederm$tau_Pa),FUN=mean)


# plot G''
lines(Gprimeprime_Pa ~ Gamma_in_percent, stress_sweeps_juvederm_agg,pch=24,type="b",cex=cex,bg="white")


# plot G'
lines(Gprime_Pa ~ Gamma_in_percent, stress_sweeps_juvederm_agg,bg="black",type="b",pch=24,cex=cex,col="black")





# Yield point characteristics for comparison
juvederm_yield=evaluateYield(stress_sweeps_juvederm_agg)
epi_yield=evaluateYield(to_use_EPI)

cat("Statistical reporting (Item 32)")

cat("\nEPI: n=",length(unique(to_use_EPI$file)))
cat("\nJuvederm: n=",sum(stress_sweeps_juvederm$tau_Pa==min(stress_sweeps_juvederm$tau_Pa)))

cat("\nYield point Juvederm\n")
juvederm_yield

cat("\nYield point EPI\n")
epi_yield



lines(G_star ~ strain_percent, adipose_tissue_rheology_data_patel,lwd=2)


# Legend for the graphics
legend("bottomleft",legend=c("EPI","HA ctl","Adipose tissue (Patel et al.)"),pch=c(21,24,-1),pt.bg=c("black","black","black"),cex=cex,pt.cex=cex,lwd=c(1,1,2))



dev.off()




