# Fig. 3i shows the relation between stiffness (low-strain G') and pore size for the EPI biomaterial and Sephacryl S200 reference material. It relies on a number of data files, listed below.

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/polynomial_model_Gprime_EPI.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/polynomial_model_Gprime_Sephacryl_S200.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")

load("/data/Evaluation/Porosity/EPI/Pore fraction/EPI_porosity.rda")

load("/data/Evaluation/Porosity/Sephacryl_S200/Pore fraction/sephacryl_S200_porosity.rda")

load("/data/Evaluation/Porosity/EPI/Pore size/pore_size_fitting_constants_EPI.rda")

load("/data/Evaluation/Porosity/Sephacryl_S200/Pore size/pore_size_fitting_constants_sephacryl_S200.rda")

library("rheologyEvaluation")

pdf("fig_3i.pdf")


# Use only cup geometry because Sephacryl is also with cup, and concentration is better defined (evaporation, necessary z-compression)
overview_EPI = overview_EPI[overview_EPI$Geometry=="cup",]


# The idea is to estimate the pore size from polymer concentration, we first convert polymer concentration
# to pore fraction using the fitted constants (Supplementary 4, eq. S4-4, solved for the wall fraction)
overview_EPI$pore_fraction=1-wall_fraction(
polymer_concentration=overview_EPI$polymer_conc_mgmL,
wall_concentration=EPI_wall_concentration,gamma=EPI_gamma) 

# This is the relative wall volume
overview_EPI$notional_phase_volume = 1-overview_EPI$pore_fraction


ylim=c(10,1000)


# For plotting the theoretical curves, we start from a concentration range
# Concentration range (mg/mL) for the theoretical curve
for_theory_x= exp(seq(from=log(5),to=log(75),length.out=200))
# Theoretical G' value from polynomial modelling specific to EPI
Gprime_theory=polynomial_model(for_theory_x,A_EPI,c0_EPI,m_EPI)

Gprime_desired = c(2000,3000) # Our target values; see manuscript for discussion

# Design values: What would be the concentration if polymer giving the right range of stiffness? Solve the polynomial model for the concentration

EPI_concentration = (Gprime_desired/(A_EPI*c0_EPI^m_EPI))^(1/m_EPI)*c0_EPI+c0_EPI

# and what the asociated pore fraction (use the wall fraction model for this, Supplementary 4, eq. S4-4, solved for the wall fraction)

EPI_pore_fraction = 1-wall_fraction(polymer_concentration=EPI_concentration,wall_concentration=EPI_wall_concentration,gamma=EPI_gamma)



# and associated pore size (Supplementary 8, eq. S8-6)

EPI_pore_size = Dwall_EPI*EPI_pore_fraction^(1/n_EPI)/(1-EPI_pore_fraction^(1/n_EPI))

# For the theory line, we convert the concentration range to pore fraction

for_theory_pore_fractiom_EPI=
1-wall_fraction(polymer_concentration=for_theory_x,wall_concentration=EPI_wall_concentration,gamma=EPI_gamma)

# and then pore diameter. This is the actual value to be plotted

for_theory_pore_diameter_EPI =Dwall_EPI*for_theory_pore_fractiom_EPI^(1/n_EPI)/(1-for_theory_pore_fractiom_EPI^(1/n_EPI))

# for the actual values, also report the pore size (this is only based on polymer concentration, we did
# not re-measure the pore size on the actual, sheared samples)
overview_EPI$pore_fraction = 
1-wall_fraction(polymer_concentration=overview_EPI$polymer_conc_mgmL,wall_concentration=EPI_wall_concentration,gamma=EPI_gamma)



overview_EPI$pore_diameter = Dwall_EPI*overview_EPI$pore_fraction^(1/n_EPI)/(1-overview_EPI$pore_fraction^(1/n_EPI))

# G' (measured) vs. pore diameter (estimated from polymer concentration)
plot(overview_EPI$Gprime,overview_EPI$pore_diameter,log="xy",ylab="Pore diameter [micrometer]",xlab="Gprime [Pa]",pch=21,bg="black",ylim=ylim,cex=1.5,main="3i) Storage modulus vs. pore diameter",xlim=c(100,2e4),yaxt="n",xaxt="n")

axis(side=1,at=c((1:9)*10,(1:9)*100,(1:10)*1000,20000,30000),labels=c(10,rep("",8),100,rep("",8),1000,rep("",8),10000,"",""),cex.axis=1.5,las=2)

axis(side=2,at=c((1:9)*10,(1:9)*100,1000),labels=c(expression(10),rep("",8),100,rep("",8),1000),cex.axis=1.5)


# Theoretical line for the EPI material
lines(Gprime_theory,for_theory_pore_diameter_EPI,type="l",lty=1)




# For Sephacryl, it's the same calculations but different constants and measurement data



for_theory_x= exp(seq(from=log(25),to=log(120),length.out=200))

for_theory_sephacryl_pore_fraction=
1-wall_fraction(for_theory_x,sephacryl_wall_concentration,sephacryl_gamma)

Gprime_theory=polynomial_model(for_theory_x,A_sephacryl_S200,c0_sephacryl_S200,m_sephacryl_S200)


overview_sephacryl_S200$pore_fraction=
1-wall_fraction(overview_sephacryl_S200$polymer_conc_mgmL,sephacryl_wall_concentration,sephacryl_gamma)


sephacryl_S200_concentration = (Gprime_desired/(A_sephacryl_S200*c0_sephacryl_S200^m_sephacryl_S200))^(1/m_sephacryl_S200)*c0_sephacryl_S200+c0_sephacryl_S200


sephacryl_S200_pore_fraction =
1-wall_fraction(sephacryl_S200_concentration,sephacryl_wall_concentration,sephacryl_gamma)


for_theory_pore_diameter_sephacryl =D_sephacryl*for_theory_sephacryl_pore_fraction^(1/n_sephacryl)/(1-for_theory_sephacryl_pore_fraction^(1/n_sephacryl))

overview_sephacryl_S200$pore_diameter = D_sephacryl*overview_sephacryl_S200$pore_fraction^(1/n_sephacryl)/(1-overview_sephacryl_S200$pore_fraction^(1/n_sephacryl))

lines( overview_sephacryl_S200$Gprime,overview_sephacryl_S200$pore_diameter,pch=1,col="black",type="p",cex=1.5)




lines(Gprime_theory,for_theory_pore_diameter_sephacryl,type="l",lty=2)



legend("topright",legend=c("EPI biomaterial","Sephacryl S200"),pch=c(21,21),col=rep("black",2),pt.bg=c("black","white"),cex=1.5,lty=c(1,2))






dev.off()
cat("Statistical reporting: Rheology (Item 30)")
cat("\nN curves used EPI")
dim(overview_EPI)[1]

cat("\nN curves used Sephacryl")
dim(overview_sephacryl_S200)[1]

cat("\n\nReporting: pore size (Item 31)")

cat("\nImages per sample EPI")
aggregate(File ~ Polymer_concentration,EPI_porosity[EPI_porosity$Polymer_concentration>0,],FUN=length)
cat("\nImages per sample Sephacryl S200")
aggregate(file ~ Polymer_concentration,sephacryl_S200_pore_size[sephacryl_S200_pore_size$Polymer_concentration>0,],FUN=length)






