# Fig. 3j: Comparison of ejection force for bulk and fragmented material

library(tolerance)
library(effsize)



load("/data/Evaluation/Ejection Force/EPI/ejection_force_bulk.rda")



overview_ejection_force_bulk$Mean_Force_Newton=NA
overview_ejection_force_bulk$Max_Force_Newton=NA


for(ind in 1:length(ejection_force_bulk))
{
    
    current_data = ejection_force_bulk[[ind]]
    
    
    start_index=min(which(current_data$Force>50))
    
    return_index = which.min(current_data$Distance)
    
    
    start_distance = current_data$Distance[start_index]
    return_distance = current_data$Distance[return_index]
    
    
    data_to_analyze = current_data[1:return_index,]
    
    data_to_analyze$Distance=current_data$Distance[start_index]-data_to_analyze$Distance
    
    data_to_analyze$Distance=data_to_analyze$Distance/max(data_to_analyze$Distance)*60
    
    
    overview_ejection_force_bulk$Mean_Force_Newton[ind] = mean(data_to_analyze$Force[data_to_analyze$Distance>=0.1*max(data_to_analyze$Distance)])*0.0098
    
    overview_ejection_force_bulk$Max_Force_Newton[ind] = max(data_to_analyze$Force[data_to_analyze$Distance>=0.1*max(data_to_analyze$Distance)])*0.0098
    
    
    
    
    # Plotting and comparison with the EPI material
    
    
    
    
    
    
    
}



speeds_to_plot=c(10)



# From Fig. 3j
load("/data/Evaluation/Ejection Force/EPI/20G/EPI_ejection_force_20G.rda")


overview_ejection_force_EPI_20G$Mean_Force_Newton=NA
overview_ejection_force_EPI_20G$Max_Force_Newton=NA


overview_ejection_force_EPI_20G$Mean_Force_Newton=NA
overview_ejection_force_EPI_20G$Max_Force_Newton=NA


for(theSpeed in speeds_to_plot)
{
    started=FALSE
    
    for(ind in 1:length(ejection_force_bulk))
    {
        
        
        
        
        if(overview_ejection_force_bulk$injection_speed_mm_sec[ind]==theSpeed)
        {
            
            
            current_data = ejection_force_bulk[[ind]]
            
            
            start_index=min(which(current_data$Force>50))
            
            return_index = which.min(current_data$Distance)
            
            
            start_distance = current_data$Distance[start_index]
            return_distance = current_data$Distance[return_index]
            
            
            data_to_analyze = current_data[1:return_index,]
            
            data_to_analyze$Distance=current_data$Distance[start_index]-data_to_analyze$Distance
            
            data_to_analyze$Distance=data_to_analyze$Distance/max(data_to_analyze$Distance)*60

            
            
            
            
            
            
            if(!started)
            {
                # Graphical device for the pdf of the plot
                pdf("fig_3j.pdf")
                
                plot(data_to_analyze$Distance, data_to_analyze$Force*0.0098,xlim=c(-10,65),ylim=c(-2,30),main=paste("Ejection rate ",theSpeed," mm/s"),xlab="Distance [mm]", ylab="Force [N]",col="#f5b908",type="l",lwd=2)
                started=TRUE
                
            } else {
                lines(data_to_analyze$Distance, data_to_analyze$Force*0.0098,col="#f5b908",lwd=2)
                
            }
            
            
            
        }
    }
    
    nominal_syringe_length=60
    
    for(ind in unique(EPI_ejection_force_20G$overview_index))
    {
        
        
        
        {
            current_data = EPI_ejection_force_20G[EPI_ejection_force_20G$overview_index==ind ,]
            
            
            lines(Force_N ~ Distance_normalized, current_data, col="#1286a8",lwd=2)
            
            
            overview_ejection_force_EPI_20G$Mean_Force_Newton[ind] = mean(current_data$Force_N[current_data$Distance>=0.1*nominal_syringe_length & current_data$Distance<=0.9*nominal_syringe_length])
            
            overview_ejection_force_EPI_20G$Max_Force_Newton[ind] = max(current_data$Force_N[current_data$Distance>=0.1*nominal_syringe_length & current_data$Distance<=0.9*nominal_syringe_length])
            




            
            


        }


    }
    
    
    
    
}

lines(c(-10,65),c(20,20))

lines(c(60,60),c(0,30),lty=2)

legend("topleft",col=c("#1286a8","#f5b908","black","black"),lty=c(1,1,1,2),legend=c("EPI","Bulk","Tolerance","Syringe limit"),lwd=c(2,2,1,1),cex=1.25)

dev.off()

EPI_maxima=overview_ejection_force_EPI_20G$Max_Force_Newton[overview_ejection_force_EPI_20G$injection_speed_mm_sec==10]
bulk_maxima=overview_ejection_force_bulk$Max_Force_Newton[overview_ejection_force_bulk$injection_speed_mm_sec==10]

# Bonferroni: 3 total tests (t-test between EPI and bulk, an tolerance interval tests for both EPI and bulk against 20N upper force limit
N_Bonferroni=3

cat("\nStatistical reporting (Item 74 and 75)")
cat("\nGroup sizes (number of injection trials at 20G, 10mm/s injection rate)")
cat("\nEPI:")
length(EPI_maxima)
cat("\nBulk:")
length(bulk_maxima)




cat("\nTesting difference between EPI and bulk (Item 74)")

t.test(bulk_maxima,EPI_maxima)


cat("\n\nNormality testing (Shapiro-Wilks")
cat("\nForce maxima for EPI")
shapiro.test(EPI_maxima)

cat("\n\nNormality testing (Shapiro-Wilks")
cat("\nForce maxima for bulk")
shapiro.test(bulk_maxima)

cat("\n\nEffect size (Hedge's g)")
cohen.d(bulk_maxima,EPI_maxima,hedges.correction=TRUE)

cat(paste("\n\nP-value, Bonferroni correction for ",N_Bonferroni, " tests",sep=""))
t.test(bulk_maxima,EPI_maxima)$p.val*N_Bonferroni



cat("\n\n\nTolerance interval analysis. Upper limit of force is 20N (Chen, M. H. et al. Methods To Assess Shear-Thinning Hydrogels for Application As Injectable Biomaterials. Acs Biomater Sci Eng 3, 3146-3160, doi:10.1021/acsbiomaterials.7b00734 (2017). Reporting for Item 75.\n")

tolerance_limit=20

mu_bulk_maxima=mean(bulk_maxima)
mu_EPI_maxima=mean(EPI_maxima)
sd_bulk_maxima=sd(bulk_maxima)
sd_EPI_maxima=sd(EPI_maxima)



cat("\nOne-sided K-factor: The lower force is uninteresting, physically this is bounded by 0, our requirements is that the maximum force remain below 20N. The one-sided K-value is therefore (20N-sample mean)/(sample sd)")
cat("\nEPI")
K_upper_EPI = (tolerance_limit-mu_EPI_maxima)/sd_EPI_maxima
K_upper_EPI

cat("\nBulk")
K_upper_bulk = (tolerance_limit-mu_bulk_maxima)/sd_bulk_maxima
K_upper_bulk







cat("\n\nTolerance interval, that 95% of the values are below the upper limit.")
cat("\n EPI: ")
cat(paste((normtol.int(x = EPI_maxima, alpha = 0.05, P = 0.95, side = 1))[["1-sided.upper"]],"N",sep=""))
cat("\n Bulk: ")
cat(paste((normtol.int(x = bulk_maxima, alpha = 0.05, P = 0.95, side = 1))[["1-sided.upper"]],"N",sep=""))


cat("\nDegrees of freedom: n")
cat("\nEPI:")
length(EPI_maxima)
cat("\nBulk:")
length(bulk_maxima)

# This is essentially from normtol.int of the tolerance package in R
# The goal is however to go the other way around: rather than obtaining the K-value to define the tolerance interval, as done in normtol.int,
# here, we try to match the experimentally observed K-value by finding the associated P-value
getAlphaNormtol<-function(x,P=0.95,upper=20)
{
    x.bar <- mean(x)
    s <- sd(x)
    n <- length(x)
    method="HE"
    K_observed=(upper-x.bar)/s
    m=50
    return(uniroot(function(y)invisible(K.factor(n = n, alpha = y, P = P, side = 1,
    method = method, m = m))-K_observed,c(0,1))$root)
    
}

cat("\nPosterior probability that less than 95% of the samples conform (i.e. more than 5% of the injection trials have >20N maxima)")

cat("\nEPI")
p_tolerance_EPI=getAlphaNormtol(EPI_maxima)
p_tolerance_EPI

cat("\nBulk")
p_tolerance_bulk=getAlphaNormtol(bulk_maxima)
p_tolerance_bulk

cat("Bonferroni-corrected")
cat("\nEPI")
p_tolerance_EPI_Bonferroni=p_tolerance_EPI*N_Bonferroni
if(p_tolerance_EPI_Bonferroni>1) {p_tolerance_EPI_Bonferroni=1}
p_tolerance_EPI_Bonferroni

cat("\nBulk")
p_tolerance_bulk_Bonferroni=p_tolerance_bulk*N_Bonferroni
if(p_tolerance_bulk_Bonferroni>1) {p_tolerance_bulk_Bonferroni=1}
p_tolerance_bulk_Bonferroni










