# Fig. 3k shows the uniaxial compression curve, initially, and after 1 and 2 consecutive simulated injections of an EPI biomaterial sample



load("/data/Evaluation/Uniaxial compression/EPI/Compression_SelfHealing_Post_Injection.rda")

#device for saving the output graphics as pdf
pdf("fig_3k.pdf")

# convert the compression data (compression_data_EPI), which is a list, to a dataframe for aggregation

for(ind in 1:(length(compression_data_EPI)))
{
    
    current_data = compression_data_EPI[[ind]]
    
    current_data$Trial = overview_compression_EPI$Trial[ind]
    current_data$Injections = overview_compression_EPI$Injections[ind]
    current_data$overview_index = ind
    
    if(ind==1)
    {
        all_compression_data_EPI=current_data
    } else
    {
        all_compression_data_EPI=rbind(all_compression_data_EPI,current_data)
    }
    
    
    
    
}


# Display: aggregate at round strain values to be able to align all curves

all_compression_data_EPI$strain_round = round(all_compression_data_EPI$strain*100)/100


all_compression_data_EPI_agg = aggregate(pressure ~ strain_round+Injections,all_compression_data_EPI,FUN=mean)

all_compression_data_EPI_agg_sd = aggregate(pressure ~ strain_round+Injections,all_compression_data_EPI,FUN=sd)

# We will display errorbars only at selected strain values, for clarity
all_compression_data_EPI_agg_sd$pressure[!(all_compression_data_EPI_agg_sd$strain_round %in% c(0,0.25,0.5))]=NA

# Plot first the last injection to have the initial curve on top
injection_nr = sort(unique(all_compression_data_EPI_agg$Injections),decreasing=TRUE)

started = FALSE

for(ind in 1:length(injection_nr))
{
    theInjectionNr=injection_nr[ind]
    
    current=all_compression_data_EPI_agg[all_compression_data_EPI_agg$Injections==theInjectionNr,]
    current_sd=all_compression_data_EPI_agg_sd[all_compression_data_EPI_agg_sd$Injections==theInjectionNr,]
    
    
    if(!started)
    {
        
        plot(current$strain_round, current$pressure,pch=21,type="p",bg=grey(c(0,0.6,1)[ind]),
        xlab="Compressive strain",ylab="Stress [Pa]",lwd=0.5,col="black",main="3k Injectability: Compression testing",cex=2)
        
        started=TRUE
        
        
    } else
    {
        lines(current$strain_round, current$pressure,pch=21,type="p",bg=grey(c(0,0.6,1)[ind]),
        lwd=0.5,col="black",cex=2)
        
    }
    
    arrows(x0=current$strain_round,y0=current$pressure-current_sd$pressure,x1=current$strain_round,y1=current$pressure+current_sd$pressure,angle=90,code=3)
    
    
    #,sd_y=all_compression_data_EPI_agg_sd$pressure
    
}


legend("topleft",c("Initial","Injection #1","Injection #2"),pch=rep(21,3),col=rep("black",3),pt.bg=grey(c(1,0.6,0)),cex=2)



# Report the number of samples (= number of curves, one sample per curve) used


all_compression_data_EPI_length = aggregate(overview_index ~ Injections,all_compression_data_EPI,FUN=function(x){length(unique(x))})

colnames(all_compression_data_EPI_length)[2]="N curves"

cat("Statistical reporting (Item 35)\n\n Compression data, group sizes\n")
all_compression_data_EPI_length

# Treatment of the compression data: we need to know the Young modulus, we get it from
# the slope of the stress strain diagram for compressions up to 10%

for(ind in 1:(length(compression_data_EPI)))
{
    
    
    
    
    overview_compression_EPI$E_down[ind]=coefficients(lm(pressure ~ strain, compression_data_EPI[[ind]][compression_data_EPI[[ind]]$strain<=0.1,]))[["strain"]]
    
    
    
}



linmod=lm(E_down ~ Injections, overview_compression_EPI)
cat("\nLinear model of Young modulus over consecutive injections, normality testing")
shapiro.test(resid(linmod))
cat("\nSummary of linear model of Young modulus over consecutive injections")
summary(linmod)
cat("\nConfidence interval for Young modulus change per injection round")
confint(linmod,"Injections")


dev.off()

