# Fig. 3l shows the kinetics of recovery of G' after a period of strong shear (as recommended in Chen, M. H. et al. Methods To Assess Shear-Thinning Hydrogels for Application As Injectable Biomaterials. Acs Biomater Sci Eng 3, 3146-3160, doi:10.1021/acsbiomaterials.7b00734 (2017).)


# Load the file overview_files_self_healing_kinetics.rda
# This file contains self-healing data as acquired by monitoring recovery of
# G' values after a short period of strong shear 

load("/data/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda")


# Start pdf device for the figure
pdf("fig_3l.pdf")
# =========================================


# There is a 15 minute baseline establishment period, show only the last part of this

to_plot=self_healing_kinetics_agg[self_healing_kinetics_agg$t_s_relative/60>=-2.5,]




# Show selected shear strains only, for clarity.

selected_shear = c(0.1,1,10,50)

cat("Statistical reporting: Item 37\n\nn per curve")
n=aggregate(f_Hz ~ Tau_Pa ,overview_self_healing_kinetics,FUN=length)
colnames(n)[colnames(n)=="f_Hz"]="n"
n[n$Tau_Pa %in% selected_shear,]

to_plot = to_plot[to_plot$Tau_Pa_nominal %in% selected_shear,]

N=length(selected_shear)

bg_scale=(0:(N-1))/N
bg=grey((0.25-(bg_scale-0.5)^2)+bg_scale)


started=FALSE
for(shearStressIndex in 1:length(unique(to_plot$Tau_Pa_nominal)))
{
    shearStress = sort(unique(to_plot$Tau_Pa_nominal))[shearStressIndex]
    
    current=to_plot[to_plot$Tau_Pa_nominal==shearStress,]
    if(!started)
    {
        
        
        
        plot(current$t_s_relative/60,current$Gprime_Pa,xlab="Time [min]",ylab="G' [Pa]",ylim=c(0,4500),col="black",main="3l Self-healing under oscillatory stress",yaxt="n",cex=1.5,type="l",lwd=shearStressIndex)
        started=TRUE
        
        
    } else
    {
        lines(current$t_s_relative/60,current$Gprime_Pa,xlab="Time [min]",ylab="G' [Pa]",col="black",
        yaxt="n",cex=1.5,type="l",lwd=shearStressIndex)
        
    }
    
    
}


axis(side=2,at=c(0,1000,2000,3000))


legend("topleft",lty=rep(1,length(unique(to_plot$Tau_Pa_nominal))),legend=paste(sort(unique(to_plot$Tau_Pa_nominal)),"Pa",sep=" "),lwd=1:length(unique(to_plot$Tau_Pa_nominal)))


dev.off()







