load("/data/Evaluation/In vivo/in_vivo_data.rda")



# For effect sizes, this script also needs the public R library effsize


library(effsize)

# plotting library
library(plot.counts)


# pdf device for plotting
pdf("fig_4d.pdf")

# Start evaluation
# ===================================================

# Reformat numerically
in_vivo_data$Length=as.numeric(in_vivo_data$Length)
in_vivo_data$Width=as.numeric(in_vivo_data$Width)
in_vivo_data$Height=as.numeric(in_vivo_data$Height)
in_vivo_data$Time_days=as.numeric(in_vivo_data$Time_days)

in_vivo_data$time_point_cat = 0

in_vivo_data$time_point_cat[in_vivo_data$Time_days==0 & in_vivo_data$Shaping==1 ]=1
in_vivo_data$time_point_cat[in_vivo_data$Time_days==3  ]=2
in_vivo_data$time_point_cat[in_vivo_data$Time_days==21  ]=3

in_vivo_data$Shaping=as.numeric(in_vivo_data$Shaping)

in_vivo_data$V_external = in_vivo_data$Length*in_vivo_data$Width*in_vivo_data$Height

in_vivo_data$aspect_ratio = (in_vivo_data$Width/in_vivo_data$Length)^(-1)


to_aggregate_cols=c("Length","Width","Height","V_external","Volume_injected_microliters","aspect_ratio")

by_cols=c("Time_days","Shaping","Product")

in_vivo_agg = aggregate(in_vivo_data[,to_aggregate_cols],by=in_vivo_data[,by_cols],FUN=mean)
in_vivo_agg_sd = aggregate(in_vivo_data[,to_aggregate_cols],by=in_vivo_data[,by_cols],FUN=sd)

in_vivo_agg$aspect_ratio_sd = in_vivo_agg_sd$aspect_ratio

in_vivo_agg$time_point_cat = 0

in_vivo_agg$time_point_cat[in_vivo_agg$Time_days==0 & in_vivo_agg$Shaping==1 ]=1
in_vivo_agg$time_point_cat[in_vivo_agg$Time_days==3  ]=2
in_vivo_agg$time_point_cat[in_vivo_agg$Time_days==21  ]=3



in_vivo_agg=in_vivo_agg[order(in_vivo_agg$Product,in_vivo_agg$time_point_cat),]








forbarplot=matrix(ncol=2,nrow=4)

colnames(forbarplot)=c("EPI","HA ctl")

rownames(forbarplot)=c("After injection","After shaping","3 days","21 days")



forbarplot_sd=forbarplot

forbarplot[,"EPI"]=in_vivo_agg$aspect_ratio[in_vivo_agg$Product=="EPI"]
forbarplot_sd[,"EPI"]=in_vivo_agg$aspect_ratio_sd[in_vivo_agg$Product=="EPI"]

# No after shaping data point because we could not shape without loosing a localized sample
forbarplot[c(1,3,4),"HA ctl"]=in_vivo_agg$aspect_ratio[in_vivo_agg$Product=="Juvederm"]
forbarplot_sd[c(1,3,4),"HA ctl"]=in_vivo_agg$aspect_ratio_sd[in_vivo_agg$Product=="Juvederm"]


forbarplot=t(forbarplot)
forbarplot_sd=t(forbarplot_sd)

xvals=barplot_with_errorbars(forbarplot,beside=TRUE,legend=TRUE,ylim=c(0,5),sd_height=forbarplot_sd,col=grey(c(0.4,0.75)))

# plot the individual measurements
# First bar: EPI, after injection


plot_dot_column<-function(x,y,y_threshold_for_shifting=0.1,lateral_shift=0.06,type="p",...){
    
    xplot=rep(x,length(y))
    
    for(ind in 1:(length(y)-1))
    {
        if(abs(y[ind]-y[ind+1])<y_threshold_for_shifting)
        {
            xplot[ind]=xplot[ind]-lateral_shift
            xplot[ind+1]=xplot[ind+1]+lateral_shift
        }
    }
    
    lines(xplot,y,type=type,...)
}

plot_dot_column(xvals[1],sort(in_vivo_data[in_vivo_data$Product=="EPI" & in_vivo_data$Shaping==0,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[2],sort(in_vivo_data[in_vivo_data$Product=="Juvederm" & in_vivo_data$Time_days==0 ,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[3],sort(in_vivo_data[in_vivo_data$Product=="EPI" & in_vivo_data$Shaping==1
& in_vivo_data$Time_days==0,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[5],sort(in_vivo_data[in_vivo_data$Product=="EPI" & in_vivo_data$Shaping==1
& in_vivo_data$Time_days==3,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[6],sort(in_vivo_data[in_vivo_data$Product=="Juvederm"
& in_vivo_data$Time_days==3,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[7],sort(in_vivo_data[in_vivo_data$Product=="EPI" & in_vivo_data$Shaping==1
& in_vivo_data$Time_days==21,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[8],sort(in_vivo_data[in_vivo_data$Product=="Juvederm"
& in_vivo_data$Time_days==21,"aspect_ratio"]),col="black",pch=21,bg="black",cex=1)





# Testing:

pvals=vector(mode="numeric",length=4)
names(pvals)=c("Injection, no shaping","Day 3","Day 21","Shaping procedure")

# Difference in aspect ratio after injection first tried with t-test, but normality problem

after_injection=in_vivo_data[in_vivo_data$Time_days==0 & in_vivo_data$Shaping==0 & !is.na(in_vivo_data$Shaping),]
cat("Statistical reporting: Test of aspect ratio after injection (no shaping yet, Item 43), group sizes")
n_injection=aggregate(aspect_ratio ~ Product, after_injection, FUN=length)
colnames(n_injection)[colnames(n_injection)=="aspect_ratio"]="n"
n_injection

#t_test=t.test(aspect_ratio ~ Product,after_injection)
#t_test
#cohen.d(aspect_ratio ~ Product,in_vivo_data[in_vivo_data$Time_days==0 & in_vivo_data$Shaping==0,])
# Non-normality: There is joint non-normality over all the residuals:
cat("\nNormality testing at 0 days\n")
shapiro.test(c(after_injection$aspect_ratio[after_injection$Product=="EPI"]-mean(after_injection$aspect_ratio[after_injection$Product=="EPI"]),after_injection$aspect_ratio[after_injection$Product=="Juvederm"]-mean(after_injection$aspect_ratio[after_injection$Product=="Juvederm"])))
# Technically, joint normality over all the residuals is not a requirement for a t-test with unequal variance, so let's look at the populations
# EPI is OK
cat("\nSince overall normality testing fails, consider the two products individually\n")
cat("\nNormality testing at day 0, individually for EPI\n")
shapiro.test(after_injection$aspect_ratio[after_injection$Product=="EPI"])
# but there is non-normality with the Juvederm
cat("\nNormality testing at day 0, individually for Juvderm\n")
shapiro.test(after_injection$aspect_ratio[after_injection$Product=="Juvederm"])

# Non-normality, so Wilcoxon test
after_injection$Product=as.factor(after_injection$Product)
wilcox.test(aspect_ratio ~ Product,data=after_injection,exact=FALSE,conf.int=TRUE)
P_wilcox=wilcox.test(aspect_ratio ~ Product,data=after_injection,exact=FALSE)$p.value
# Effect size from non-paramatric test, Fritz, C.O., P.E. Morris, and J.J. Richler, Effect size estimates: current use, calculations, and interpretation. J Exp Psychol Gen, 2012. 141(1): p. 2-18.
# First get Z value from P value (two-sided)
Z_wilcox=qnorm(0.5+(1-P_wilcox)/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/(dim(after_injection)[1])

cat("\nEffect size calculation for Wilcoxon test: r^2 according to Fritz, C.O., P.E. Morris, and J.J. Richler, Effect size estimates: current use, calculations, and interpretation. J Exp Psychol Gen, 2012. 141(1): p. 2-18: First, convert P-value to Z score using the cumulative distribution law, then r2=Z^2/N as explained in the Fritz et al. paper for non-parametric tests")
r2

# Testing of shaping itself

shaping = in_vivo_data[in_vivo_data$Time_days==0 & !is.na(in_vivo_data$Time_days) & in_vivo_data$Product=="EPI" ,]

cat("\n\nTest of the immediate influence of shaping on EPI (Item 44)")
cat("\nGroup sizes")
n_shaping=aggregate(aspect_ratio ~ Shaping, shaping, FUN=length)
colnames(n_shaping)[colnames(n_shaping)=="aspect_ratio"]="n"
n_shaping

cat("\nNormality testing for shaping\n")
shapiro.test(shaping$aspect_ratio[shaping$Shaping==1]-shaping$aspect_ratio[shaping$Shaping==0])


cat("\nt-test for shaping\n")
t.test(shaping$aspect_ratio[shaping$Shaping==1],shaping$aspect_ratio[shaping$Shaping==0],paired=TRUE)
cat("\nEffect size for shaping\n")
cohen.d(shaping$aspect_ratio[shaping$Shaping==1],shaping$aspect_ratio[shaping$Shaping==0],paired=TRUE)




# Difference in aspect ratio after 3 days

day3=in_vivo_data[in_vivo_data$Time_days==3 & !is.na(in_vivo_data$Time_days),]
cat("\n\nShape (aspect ratio) after 3 days (Item 45)")
n_day3=aggregate(aspect_ratio ~ Product, day3, FUN=length)
colnames(n_day3)[colnames(n_day3)=="aspect_ratio"]="n"
n_day3
cat("\nNormality testing 3 days\n")
shapiro.test(c(day3$aspect_ratio[day3$Product=="EPI"]-mean(day3$aspect_ratio[day3$Product=="EPI"]),day3$aspect_ratio[after_injection$Product=="Juvederm"]-mean(day3$aspect_ratio[day3$Product=="Juvederm"])))
cat("\n\nt-test 3 days\n")
t.test(aspect_ratio ~ Product,day3)
cat("\nEffect size 3 days\n")
cohen.d(aspect_ratio ~ Product,day3)


# Difference in aspect ratio after 21 days

day21=in_vivo_data[in_vivo_data$Time_days==21 & !is.na(in_vivo_data$Time_days),]
cat("\n\nShape (aspect ratio) after 21 days (Item 46)")
n_day21=aggregate(aspect_ratio ~ Product, day21, FUN=length)
colnames(n_day21)[colnames(n_day21)=="aspect_ratio"]="n"
n_day21
cat("Normality testing 21 days\n")
shapiro.test(c(day21$aspect_ratio[day21$Product=="EPI"]-mean(day21$aspect_ratio[day21$Product=="EPI"]),day21$aspect_ratio[after_injection$Product=="Juvederm"]-mean(day21$aspect_ratio[day21$Product=="Juvederm"])))
cat("t-test 21 days\n")
t.test(aspect_ratio ~ Product,day21)
cat("Effect size 21 days\n")
cohen.d(aspect_ratio ~ Product,day21)



dev.off()







