# Plotes immune cell counts

load("/data/Evaluation/In vivo/in_vivo_inflammation_encapsulation.rda")



# For effect sizes, this script also needs the public R library effsize


library(effsize)


# plotting library
library(plot.counts)


# pdf device for plotting
pdf("fig_4e.pdf")

# Start evaluation
# ===================================================


#Average data (from data point per field of view to data point per sample)

to_aggregate_cols=c("Lymphocytes","Macrophages","Giant_cells", "PMN_cells")
by_cols=c("Time_point_weeks","Shaped", "Material", "Sample")

in_vivo_agg = aggregate(in_vivo_inflammation_encapsulation[,to_aggregate_cols],by=in_vivo_inflammation_encapsulation[,by_cols],FUN=mean)
in_vivo_agg_sd = aggregate(in_vivo_inflammation_encapsulation[,to_aggregate_cols],by=in_vivo_inflammation_encapsulation[,by_cols],FUN=sd)


# Aggregation of the per sample data
to_aggregate_cols_2dim=c("Lymphocytes","Macrophages","Giant_cells", "PMN_cells")
by_cols_2dim=c("Time_point_weeks","Shaped", "Material")

in_vivo_agg_2dim= aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=mean)
in_vivo_agg_2dim_sd = aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=sd)

in_vivo_agg_2dim$Lymphocytes_sd = in_vivo_agg_2dim_sd$Lymphocytes
in_vivo_agg_2dim$Macrophages_sd = in_vivo_agg_2dim_sd$Macrophages
in_vivo_agg_2dim$Giant_cells_sd = in_vivo_agg_2dim_sd$Giant_cells
in_vivo_agg_2dim$PMN_cells_sd = in_vivo_agg_2dim_sd$PMN_cells



#Creating bar plots

forbarplot=matrix(ncol=8,nrow=4)

colnames(forbarplot)=c("E3N","E12N", "E3S", "E12S", "J3N","J12N", "J3S", "J12S")
rownames(forbarplot)=c("Lymphocytes", "Macrophages", "Giant cells", "PMN cells")

forbarplot_sd=forbarplot

forbarplot["Lymphocytes",]=in_vivo_agg_2dim$Lymphocytes
forbarplot_sd["Lymphocytes",]=in_vivo_agg_2dim$Lymphocytes_sd
forbarplot["Macrophages",]=in_vivo_agg_2dim$Macrophages
forbarplot_sd["Macrophages",]=in_vivo_agg_2dim$Macrophages_sd
forbarplot["Giant cells",]=in_vivo_agg_2dim$Giant_cells
forbarplot_sd["Giant cells",]=in_vivo_agg_2dim$Giant_cells_sd
forbarplot["PMN cells",]=in_vivo_agg_2dim$PMN_cells
forbarplot_sd["PMN cells",]=in_vivo_agg_2dim$PMN_cells_sd

forbarplot=t(forbarplot)
forbarplot_sd=t(forbarplot_sd)


non_shaped = forbarplot[c("E3N","E12N", "J3N","J12N"),]
colnames(non_shaped)=paste(colnames(non_shaped),"non-shaped",sep="\n")
non_shaped_sd = forbarplot_sd[c("E3N","E12N", "J3N","J12N"),]
colnames(non_shaped_sd)=paste(colnames(non_shaped_sd),"non-shaped",sep="\n")

shaped = forbarplot[c("E3S","E12S", "J3S","J12S"),]
colnames(shaped)=paste(colnames(shaped),"shaped",sep="\n")
shaped_sd = forbarplot_sd[c("E3S","E12S", "J3S","J12S"),]
colnames(shaped_sd)=paste(colnames(shaped_sd),"shaped",sep="\n")

barplot_arranged = cbind(non_shaped, shaped)
barplot_arranged_sd = cbind(non_shaped_sd, shaped_sd)

rownames(barplot_arranged)=c("Epi - 3weeks","Epi - 3months","HA ctl - 3weeks","HA ctl - 3months")

# Spectral palette from colorbrewer
col=c("#1286a8","#00399d","#fee98b" ,"#f5b908")

xvals=barplot_with_errorbars(barplot_arranged,beside=TRUE,legend=TRUE,ylim=c(0,20),sd_height=barplot_arranged_sd,col=col,ylab="Cells/observation field",las=2)



plot_dot_column(xvals[1],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[2],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[3],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[4],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)

plot_dot_column(xvals[17],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[18],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[19],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[20],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Lymphocytes"]),col="black",pch=21,bg="black",cex=1)

plot_dot_column(xvals[5],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[6],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[7],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[8],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[21],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[22],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[23],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Macrophages"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[24],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Macrophages"]),col="black",pch=21,bg="black",cex=1)

plot_dot_column(xvals[9],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[10],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[11],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[12],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)

plot_dot_column(xvals[25],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[26],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[27],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[28],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Giant_cells"]),col="black",pch=21,bg="black",cex=1)

plot_dot_column(xvals[13],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[14],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[15],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[16],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)



plot_dot_column(xvals[29],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[30],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[31],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[32],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "PMN_cells"]),col="black",pch=21,bg="black",cex=1)


# Sample size reporting

cat("Sample size reporting (for Items 47 to 49). \nPrimary aggregation: 5 field of views per sample")

in_vivo_agg_field_of_views = aggregate(in_vivo_inflammation_encapsulation[,to_aggregate_cols],by=in_vivo_inflammation_encapsulation[,by_cols],FUN=length)

cat("As there are 3 to 5 physical samples per condition, that makes a total of n=15 to n=25 of entries")

in_vivo_agg_2dim_n= aggregate(in_vivo_agg_field_of_views[,to_aggregate_cols_2dim],by=in_vivo_agg_field_of_views[,by_cols_2dim],FUN=sum)

in_vivo_agg_2dim_n

cat("N: the number of actual samples samples")

in_vivo_agg_2dim_N= aggregate(in_vivo_agg_field_of_views[,to_aggregate_cols_2dim],by=in_vivo_agg_field_of_views[,by_cols_2dim],FUN=length)

in_vivo_agg_2dim_N



# Statistical testing

# Overall inflammation analysis (4f)

# Overall inflammation score
# ISO-10993-6, Appendix E: Giant cells should be counted 2x compared to the others

in_vivo_agg$weighted_total_cells = in_vivo_agg$Lymphocytes + in_vivo_agg$Macrophages + 2*in_vivo_agg$Giant_cells + in_vivo_agg$PMN_cells
cat("\n\nStatistical reporting (items 47-49)")
cat("\nShapiro-Wilks testing of residuals for t-test: Implant material (Item 47)\n")
shapiro.test(resid(lm(weighted_total_cells ~ Material,in_vivo_agg)))

cat("\nShapiro-Wilks testing of residuals for t-test: Shaping (Item 48)\n")
shapiro.test(resid(lm(weighted_total_cells ~ Shaped,in_vivo_agg)))

cat("\nShapiro-Wilks testing of residuals for t-test: Time point (Item 49)\n")
shapiro.test(resid(lm(weighted_total_cells ~ Time_point_weeks,in_vivo_agg)))

N_Bonferroni = 3

cat("\nT-test for implant material (Item 47)")
t.test(weighted_total_cells ~ Material,in_vivo_agg)
cat("\nT-test for shaping (Item 48)")
t.test(weighted_total_cells ~ Shaped,in_vivo_agg)
cat("\nT-test for Time point (3 weeks, 3 months): Item 49")
t.test(weighted_total_cells ~ Time_point_weeks,in_vivo_agg)

Pvals=c(
    t.test(weighted_total_cells ~ Material,in_vivo_agg)$p.value,
    t.test(weighted_total_cells ~ Shaped,in_vivo_agg)$p.value,
    t.test(weighted_total_cells ~ Time_point_weeks,in_vivo_agg)$p.value
)

Pvals_Bonferroni = Pvals*N_Bonferroni
cat("\nP-values after Bonferroni adjustment\n")
Pvals_Bonferroni

cat("\nEffect size (overall inflammation score): Material (Item 47)")
cohen.d(weighted_total_cells ~ Material,in_vivo_agg)
cat("\nEffect size(overall inflammation score): Shaping (Item 48)")
cohen.d(weighted_total_cells ~ Shaped,in_vivo_agg)
cat("\nEffect size(overall inflammation score): Time-point (Item 49)")
cohen.d(weighted_total_cells ~ Time_point_weeks,in_vivo_agg)

dev.off()







