# Plots encapsulation data

load("/data/Evaluation/In vivo/in_vivo_inflammation_encapsulation.rda")



# For effect sizes, this script also needs the public R library effsize


library(effsize)

# plotting library
library(plot.counts)


# pdf device for plotting
pdf("fig_4f.pdf")

# Start evaluation
# ===================================================


#Aggregate by sample

to_aggregate_cols=c("Capsule_thickness_microns")
by_cols=c("Time_point_weeks","Shaped", "Material", "Sample")

in_vivo_agg = aggregate(in_vivo_inflammation_encapsulation[,to_aggregate_cols],by=in_vivo_inflammation_encapsulation[,by_cols],FUN=mean)
in_vivo_agg_sd = aggregate(in_vivo_inflammation_encapsulation[,to_aggregate_cols],by=in_vivo_inflammation_encapsulation[,by_cols],FUN=sd)

colnames(in_vivo_agg)[colnames(in_vivo_agg)=="x"] <- "Capsule_thickness_microns"
colnames(in_vivo_agg_sd)[colnames(in_vivo_agg)=="x"] <- "Capsule_thickness_microns_sd"


#Aggregate by condition for bar plotting

to_aggregate_cols_2dim=c("Capsule_thickness_microns")
by_cols_2dim=c("Time_point_weeks","Shaped", "Material")

in_vivo_agg_2dim= aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=mean)
in_vivo_agg_2dim_sd = aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=sd)

in_vivo_agg_2dim$Capsule_thickness_microns_sd = in_vivo_agg_2dim_sd$Capsule_thickness_microns

colnames(in_vivo_agg_2dim)[colnames(in_vivo_agg_2dim)=="x"] <- "Capsule_thickness_microns_2dim"
colnames(in_vivo_agg_2dim_sd)[colnames(in_vivo_agg_2dim_sd)=="x"] <- "Capsule_thickness_microns_2dim_sd"

#Bar plotting

forbarplot=matrix(ncol=2,nrow=4)

colnames(forbarplot)=c("EPI", "HA ctl")
rownames(forbarplot)=c("3 weeks, non-shaped", "3 weeks, shaped", "12 weeks, non-shaped", "12 weeks, shaped")


forbarplot_sd=forbarplot

# EPI

forbarplot["3 weeks, non-shaped","EPI"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="EPI" & in_vivo_agg_2dim$Time_point_weeks==3 & in_vivo_agg_2dim$Shaped==0]

forbarplot["3 weeks, shaped","EPI"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="EPI" & in_vivo_agg_2dim$Time_point_weeks==3 & in_vivo_agg_2dim$Shaped==1]

forbarplot["12 weeks, non-shaped","EPI"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="EPI" & in_vivo_agg_2dim$Time_point_weeks==12 & in_vivo_agg_2dim$Shaped==0]

forbarplot["12 weeks, shaped","EPI"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="EPI" & in_vivo_agg_2dim$Time_point_weeks==12 & in_vivo_agg_2dim$Shaped==1]

# Juvederm

forbarplot["3 weeks, non-shaped","HA ctl"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="Juvederm" & in_vivo_agg_2dim$Time_point_weeks==3 & in_vivo_agg_2dim$Shaped==0]

forbarplot["3 weeks, shaped","HA ctl"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="Juvederm" & in_vivo_agg_2dim$Time_point_weeks==3 & in_vivo_agg_2dim$Shaped==1]

forbarplot["12 weeks, non-shaped","HA ctl"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="Juvederm" & in_vivo_agg_2dim$Time_point_weeks==12 & in_vivo_agg_2dim$Shaped==0]

forbarplot["12 weeks, shaped","HA ctl"]=in_vivo_agg_2dim$Capsule_thickness_microns_2dim[in_vivo_agg_2dim$Material=="Juvederm" & in_vivo_agg_2dim$Time_point_weeks==12 & in_vivo_agg_2dim$Shaped==1]


# Standard deviation

# EPI

forbarplot_sd["3 weeks, non-shaped","EPI"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="EPI" & in_vivo_agg_2dim_sd$Time_point_weeks==3 & in_vivo_agg_2dim_sd$Shaped==0]

forbarplot_sd["3 weeks, shaped","EPI"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="EPI" & in_vivo_agg_2dim_sd$Time_point_weeks==3 & in_vivo_agg_2dim_sd$Shaped==1]

forbarplot_sd["12 weeks, non-shaped","EPI"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="EPI" & in_vivo_agg_2dim_sd$Time_point_weeks==12 & in_vivo_agg_2dim_sd$Shaped==0]

forbarplot_sd["12 weeks, shaped","EPI"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="EPI" & in_vivo_agg_2dim_sd$Time_point_weeks==12 & in_vivo_agg_2dim_sd$Shaped==1]

# Juvederm

forbarplot_sd["3 weeks, non-shaped","HA ctl"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="Juvederm" & in_vivo_agg_2dim_sd$Time_point_weeks==3 & in_vivo_agg_2dim_sd$Shaped==0]

forbarplot_sd["3 weeks, shaped","HA ctl"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="Juvederm" & in_vivo_agg_2dim_sd$Time_point_weeks==3 & in_vivo_agg_2dim_sd$Shaped==1]

forbarplot_sd["12 weeks, non-shaped","HA ctl"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="Juvederm" & in_vivo_agg_2dim_sd$Time_point_weeks==12 & in_vivo_agg_2dim_sd$Shaped==0]

forbarplot_sd["12 weeks, shaped","HA ctl"]=in_vivo_agg_2dim_sd$Capsule_thickness_microns_2dim[in_vivo_agg_2dim_sd$Material=="Juvederm" & in_vivo_agg_2dim_sd$Time_point_weeks==12 & in_vivo_agg_2dim_sd$Shaped==1]


forbarplot=t(forbarplot)
forbarplot_sd=t(forbarplot_sd)



colnames(forbarplot)=gsub(",",",\n",colnames(forbarplot))

forbarplot=forbarplot[,c(1,3,2,4)] # Rearrange, first non-shaped, then shaped
forbarplot_sd=forbarplot_sd[,c(1,3,2,4)]




xvals=barplot_with_errorbars(forbarplot,beside=TRUE,legend=TRUE,ylim=c(0,200),sd_height=forbarplot_sd,col=grey(c(0.2,0.8)),las=3,ylab="Capsule thickness [um]")


plot_dot_column(xvals[1],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[2],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==3, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[3],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[4],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==0 & in_vivo_agg$Time_point_weeks==12, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)


plot_dot_column(xvals[5],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[6],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==3, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[7],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[8],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Shaped==1 & in_vivo_agg$Time_point_weeks==12, "Capsule_thickness_microns"]),col="black",pch=21,bg="black",cex=1)
cat("Statistical test reporting: Item 51\n\n")
cat("Sample size: n=total fields of view counted per condition  (material, shaping, timepoint)")
n_capsule_size=aggregate(Capsule_thickness_microns~Material + Shaped+Time_point_weeks,in_vivo_inflammation_encapsulation,FUN=length)
colnames(n_capsule_size)[colnames(n_capsule_size)=="Capsule_thickness_microns"]="n"
n_capsule_size

cat("\nStatistical reporting (Item 51)\n\nSample size: N=biologicial sample per condition  (material, shaping, timepoint)")
N_capsule_size=aggregate(Capsule_thickness_microns~Material + Shaped+Time_point_weeks,in_vivo_agg,FUN=length)
colnames(N_capsule_size)[colnames(N_capsule_size)=="Capsule_thickness_microns"]="N"
N_capsule_size

# Testing: Influence of the time-point, shaping and material on encapsulation
# Linear model with the three parameters
linmod=lm(Capsule_thickness_microns ~ Time_point_weeks + Shaped + Material, in_vivo_agg)
cat("\nOverall normality testing for linear model with effects for Time point, shaping and material")
shapiro.test(resid(linmod))
cat("\nResults of the linear regression")
summary(linmod)
cat("\nConfidence intervals for the slopes")
confint(linmod)

cat("\nSummaries of single regressions for the adjusted R2 squared values for individual regressors (effect size)")
cat("\n\tTime point")
summary(lm(Capsule_thickness_microns ~ Time_point_weeks , in_vivo_agg))
cat("\n\tShaping")
summary(lm(Capsule_thickness_microns ~ Shaped , in_vivo_agg))
cat("\n\tMaterial")
summary(lm(Capsule_thickness_microns ~ Material , in_vivo_agg))

cat("\nBonferroni correction for 3 individual tests regarding encapsulation")
coefficients(summary(linmod))[-1,"Pr(>|t|)"]*3




dev.off()







