# Cellular colonization over time, EPI vs. Juvederm 

load("/data/Evaluation/In vivo/in_vivo_colonization_vascularization.rda")



# For effect sizes, this script also needs the public R library effsize


library(effsize)

# plotting library
library(plot.counts)


# pdf device for plotting
 pdf("fig_4g.pdf")

# Start evaluation
# ===================================================



#Aggregate by sample

to_aggregate_cols=c("area_fraction_occupied_by_cells_percent")
by_cols=c("Time_point_month", "Material", "Sample")

in_vivo_agg = aggregate(in_vivo_colonization_vascularization[,to_aggregate_cols],by=in_vivo_colonization_vascularization[,by_cols],FUN=mean)
in_vivo_agg_sd = aggregate(in_vivo_colonization_vascularization[,to_aggregate_cols],by=in_vivo_colonization_vascularization[,by_cols],FUN=sd)

colnames(in_vivo_agg)[colnames(in_vivo_agg)=="x"] <- "area_fraction_occupied_by_cells_percent"
colnames(in_vivo_agg_sd)[colnames(in_vivo_agg)=="x"] <- "area_fraction_occupied_by_cells_percent_sd"


#Aggregate by condition for bar plotting

to_aggregate_cols_2dim=c("area_fraction_occupied_by_cells_percent")
by_cols_2dim=c("Time_point_month", "Material")

in_vivo_agg_2dim= aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=mean)
in_vivo_agg_2dim_sd = aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=sd)

in_vivo_agg_2dim$area_fraction_occupied_by_cells_percent_sd = in_vivo_agg_2dim_sd$area_fraction_occupied_by_cells_percent

colnames(in_vivo_agg_2dim)[colnames(in_vivo_agg_2dim)=="x"] <- "area_fraction_occupied_by_cells_percent_2dim"
colnames(in_vivo_agg_2dim_sd)[colnames(in_vivo_agg_2dim_sd)=="x"] <- "area_fraction_occupied_by_cells_percent_2dim_sd"

#Bar plotting

forbarplot=matrix(ncol=2,nrow=4)

colnames(forbarplot)=c("EPI", "HA ctl")
rownames(forbarplot)=c("3 weeks", "3 month", "6 months", "12 months")


forbarplot_sd=forbarplot

forbarplot[,"EPI"]=in_vivo_agg_2dim$area_fraction_occupied_by_cells_percent_2dim[in_vivo_agg_2dim$Material=="EPI"]
forbarplot_sd[,"EPI"]=in_vivo_agg_2dim_sd$area_fraction_occupied_by_cells_percent_2dim_sd[in_vivo_agg_2dim$Material=="EPI"]
forbarplot[,"HA ctl"]=in_vivo_agg_2dim$area_fraction_occupied_by_cells_percent_2dim[in_vivo_agg_2dim$Material=="Juvederm"]
forbarplot_sd[,"HA ctl"]=in_vivo_agg_2dim_sd$area_fraction_occupied_by_cells_percent_2dim_sd[in_vivo_agg_2dim$Material=="Juvederm"]

forbarplot=t(forbarplot)
forbarplot_sd=t(forbarplot_sd)

xvals=barplot_with_errorbars(forbarplot,beside=TRUE,legend=TRUE,ylim=c(0,200),sd_height=forbarplot_sd,col=grey(c(0.2,0.8)),ylab="Colonization [%]")

# plot the individual measurements


plot_dot_column<-function(x,y,y_threshold_for_shifting=0.06,lateral_shift=0.06,type="p",...){
    
    xplot=rep(x,length(y))
    
    for(ind in 1:(length(y)-1))
    {
        if(abs(y[ind]-y[ind+1])<y_threshold_for_shifting)
        {
            xplot[ind]=xplot[ind]-lateral_shift
            xplot[ind+1]=xplot[ind+1]+lateral_shift
        }
    }
    
    lines(xplot,y,type=type,...)
}


plot_dot_column(xvals[1],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==0.75,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[2],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Time_point_month==0.75,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[3],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==3,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[4],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Time_point_month==3,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[5],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==6,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[7],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==12,"area_fraction_occupied_by_cells_percent"]),col="black",pch=21,bg="black",cex=1)

#Juvederm degraded at 6 months, so no more plotting here


# Testing and reporting
cat("\nStatistical reporting: Item 52")
# Sample size reporting
cat("\nTechnical sample size (n): Fields of view counted per material and time point")
aggregate(area_fraction_occupied_by_cells_percent ~ Material + Time_point_months, in_vivo_colonization_vascularization[!is.na(in_vivo_colonization_vascularization$area_fraction_occupied_by_cells_percent),], FUN=length)

cat("\nEffective (biological) sample size: Number of samples")
aggregate(Sample ~ Material + Time_point_months, in_vivo_colonization_vascularization[!is.na(in_vivo_colonization_vascularization$area_fraction_occupied_by_cells_percent),], FUN=function(x){length(unique(x))})


# Testing via linear modelling (2 independent varialbes: Material and time-point)

linmod=lm(area_fraction_occupied_by_cells_percent ~Material+Time_point_month, in_vivo_agg)
cat("\nNormality testing for the residuals of the linear model using Material (EPI vs. Juvéderm) and time point as explanatory variables for the colonization")
shapiro.test(resid(linmod))

cat("\nSummary of the linear model with relevant test statistics")
summary(linmod)

cat("\nConfidence intervals")
confint(linmod)

cat("\nEffect size: Overall, see adjusted R2 in the linear model summary above")
cat("\nEffect size of the individual variables: in separate, individual linear regression. ")
cat("\n\tMaterial")
summary(lm(area_fraction_occupied_by_cells_percent ~Material, in_vivo_agg))
cat("\n\tTime-point")
summary(lm(area_fraction_occupied_by_cells_percent ~Time_point_month, in_vivo_agg))


dev.off()







