# Vascularization EPI vs. Juvederm over time

load("/data/Evaluation/In vivo/in_vivo_colonization_vascularization.rda")



# For effect sizes, this script also needs the public R library effsize


library(effsize)

# plotting library
library(plot.counts)


# pdf device for plotting
pdf("fig_4h.pdf")

# Start evaluation
# ===================================================

#Aggregate by sample

to_aggregate_cols=c("vessels_per_field_of_view")
by_cols=c("Time_point_month", "Material", "Sample")

in_vivo_agg = aggregate(in_vivo_colonization_vascularization[,to_aggregate_cols],by=in_vivo_colonization_vascularization[,by_cols],FUN=mean)
in_vivo_agg_sd = aggregate(in_vivo_colonization_vascularization[,to_aggregate_cols],by=in_vivo_colonization_vascularization[,by_cols],FUN=sd)

colnames(in_vivo_agg)[colnames(in_vivo_agg)=="x"] <- "vessels_per_field_of_view"
colnames(in_vivo_agg_sd)[colnames(in_vivo_agg)=="x"] <- "vessels_per_field_of_view_sd"


#Aggregate by condition for bar plotting

to_aggregate_cols_2dim=c("vessels_per_field_of_view")
by_cols_2dim=c("Time_point_month", "Material")

in_vivo_agg_2dim= aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=mean)
in_vivo_agg_2dim_sd = aggregate(in_vivo_agg[,to_aggregate_cols_2dim],by=in_vivo_agg[,by_cols_2dim],FUN=sd)

in_vivo_agg_2dim$vessels_per_field_of_view_sd = in_vivo_agg_2dim_sd$vessels_per_field_of_view

colnames(in_vivo_agg_2dim)[colnames(in_vivo_agg_2dim)=="x"] <- "vessels_per_field_of_view_2dim"
colnames(in_vivo_agg_2dim_sd)[colnames(in_vivo_agg_2dim_sd)=="x"] <- "vessels_per_field_of_view_2dim_sd"

#Bar plotting

forbarplot=matrix(ncol=2,nrow=4)

colnames(forbarplot)=c("EPI", "HA ctl")
rownames(forbarplot)=c("3 weeks", "3 month", "6 months", "12 months")


forbarplot_sd=forbarplot

forbarplot[,"EPI"]=in_vivo_agg_2dim$vessels_per_field_of_view_2dim[in_vivo_agg_2dim$Material=="EPI"]
forbarplot_sd[,"EPI"]=in_vivo_agg_2dim_sd$vessels_per_field_of_view_2dim_sd[in_vivo_agg_2dim$Material=="EPI"]
forbarplot[,"HA ctl"]=in_vivo_agg_2dim$vessels_per_field_of_view_2dim[in_vivo_agg_2dim$Material=="Juvederm"]
forbarplot_sd[,"HA ctl"]=in_vivo_agg_2dim_sd$vessels_per_field_of_view_2dim_sd[in_vivo_agg_2dim$Material=="Juvederm"]

forbarplot=t(forbarplot)
forbarplot_sd=t(forbarplot_sd)

xvals=barplot_with_errorbars(forbarplot,beside=TRUE,legend=TRUE,ylim=c(0,20),sd_height=forbarplot_sd,col=grey(c(0.2,0.8)),ylab="Vessels/field of view")

# plot the individual measurements


plot_dot_column<-function(x,y,y_threshold_for_shifting=0.06,lateral_shift=0.06,type="p",...){
    
    xplot=rep(x,length(y))
    
    for(ind in 1:(length(y)-1))
    {
        if(abs(y[ind]-y[ind+1])<y_threshold_for_shifting)
        {
            xplot[ind]=xplot[ind]-lateral_shift
            xplot[ind+1]=xplot[ind+1]+lateral_shift
        }
    }
    
    lines(xplot,y,type=type,...)
}


plot_dot_column(xvals[1],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==0.75,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[2],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Time_point_month==0.75,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[3],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==3,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[4],sort(in_vivo_agg[in_vivo_agg$Material=="Juvederm" & in_vivo_agg$Time_point_month==3,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[5],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==6,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)
plot_dot_column(xvals[7],sort(in_vivo_agg[in_vivo_agg$Material=="EPI" & in_vivo_agg$Time_point_month==12,"vessels_per_field_of_view"]),col="black",pch=21,bg="black",cex=1)

#Juvederm degraded at 6 months

# Sample size reporting
cat("Sample size reporting (for items 53 and 54)")
cat("\n\nTechnical sample size (n): Fields of view counted per material and time point")
aggregate(vessels_per_field_of_view ~ Material + Time_point_months, in_vivo_colonization_vascularization[!is.na(in_vivo_colonization_vascularization$vessels_per_field_of_view),], FUN=length)

cat("\nEffective (biological) sample size: Number of samples")
aggregate(Sample ~ Material + Time_point_months, in_vivo_colonization_vascularization[!is.na(in_vivo_colonization_vascularization$area_fraction_occupied_by_cells_percent),], FUN=function(x){length(unique(x))})

cat("\nReporting on statistical testing of vascularization as a  binary variable (absence/presence) as function of time-point and implant material (Item 53)")
# First attempt at statistical testing: Linear modelling
cat("\nFirst attempt: Linear model for vascularization with material and time-point as explanatory variables")
linmod=lm(vessels_per_field_of_view ~Material+Time_point_month, in_vivo_agg)

cat("This linear model fails normality testing of the residuals")
shapiro.test(resid(linmod))

cat("Since the Juvederm Voluma values are all zero (no vasuclarization),")
cat("the glm model with variance proportional to the expected value does not converge and so we ")
cat("are effectively unable to analyze jointly the effect of in-vivo time and material")

cat("So we need to address the effects separately")
cat("We cannot use a t-test since we cannot assess normality for the Juvederm group as all values are zero")

cat("Also Juvederm data goes only up to 3 months due to degradation, so compare only the")
cat(" 3 weeks and 3 months time points")
up_to_3_months=in_vivo_agg[in_vivo_agg$Time_point_month<=3,]

# The idea here is to test for probability of detecting vascularization per sample, as a function
# of the biomaterial implanted. This is stratified by the timepoints, which therefore 
# is a covariate without interest for primary statistical testing for the analysis
# of presence and absence of vascularization


# Estimation of the overall vascularization probability at timepoints of interest
p_time_points = data.frame(Time_point_month=sort(unique(up_to_3_months$Time_point_month)),p_vascularization=NA,n=NA)

for(theT in p_time_points$Time_point_month)
{
    p_time_points$p_vascularization[p_time_points$Time_point_month==theT]=sum(up_to_3_months$vessels_per_field_of_view[up_to_3_months$Time_point_month==theT]>0)/length(up_to_3_months$vessels_per_field_of_view[up_to_3_months$Time_point_month==theT])
    p_time_points$n[p_time_points$Time_point_month==theT]=length(up_to_3_months$vessels_per_field_of_view[up_to_3_months$Time_point_month==theT])
    
}


# Preparation for the contingency table: gather the materials
materials=sort(unique(up_to_3_months$Material))

# Make the dataframe with the counts
time_points_double = vector(mode="numeric",length=0)

for(tp in p_time_points$Time_point_month)
{
    time_points_double=c(time_points_double,rep(tp,2))
}

Time_point_month_vector = rep(time_points_double,2)

Material_vector=vector(mode="character",length=0)

for(theMaterial in unique(materials))
{
    Material_vector=c(Material_vector,rep(theMaterial,length(time_points_double)))
    
}



contingency_table=data.frame(Time_point_month=Time_point_month_vector,Material=Material_vector,Vascularized=rep(c(FALSE,TRUE),length(Time_point_month_vector)/2),n_observed=NA,n_expected=NA)

for(ind in 1:(dim(contingency_table)[1]))
{
    contingency_table$n_observed[ind]=sum(up_to_3_months$Time_point_month==contingency_table$Time_point_month[ind] & up_to_3_months$Material==contingency_table$Material[ind] & (up_to_3_months$vessels_per_field_of_view>0)==contingency_table$Vascularized[ind])
}






# For estimating the n's under the assumption of equal probabilities for EPI and Juvéderm
# total df from the number of entries in the contingency table

df_total = dim(contingency_table)[1]

# For the equal propbability model between EPI and Juvederm, with stratification
# by the time-points, we need to know:

# A) the global probabilites of being vascularized at each time point, this
# removes a corresponding number of degrees of freedom

df=df_total - dim(p_time_points)[1]

# B) The totals for each product at each time point (which is then split into 
# vascularized and non-vascularized samples). This also removes a corresponding number of degrees of freedom

df=df - dim(p_time_points)[1]*length(materials)



# With this information, we can calculate the expected values

for(ind in 1:(dim(contingency_table)[1]))
{
    p=p_time_points$p_vascularization[p_time_points$Time_point_month==contingency_table$Time_point_month[ind]]
    if(!(contingency_table$Vascularized[ind]))
    {
        p=1-p
        
    }
    contingency_table$n_expected[ind]=sum(up_to_3_months$Time_point_month==contingency_table$Time_point_month[ind] & up_to_3_months$Material==contingency_table$Material[ind])*p
}


cat("\nContingency table for presence (TRUE) and absence (FALSE) of vascularization, with ")
cat("expected and observed counts")

contingency_table


cat("\nCohen's h: delta of arcsine transformed values of estimated proportions")
n_tot = aggregate(n_observed ~ Time_point_month+Material,contingency_table, FUN=sum)
n_success = contingency_table[contingency_table$Vascularized,]
n_success$n_tot = n_tot$n_observed[match(paste(n_tot$Material,n_tot$Time_point_month),paste(n_success$Material,n_success$Time_point_month))]
n_success$estimated_vascularization_proportion=n_success$n_observed/n_success$n_tot

cohen_h=aggregate(asin(estimated_vascularization_proportion)~Material,n_success,FUN=mean)
cohen_h=cohen_h$"asin(estimated_vascularization_proportion)"[cohen_h$Material=="EPI"]-cohen_h$"asin(estimated_vascularization_proportion)"[cohen_h$Material=="Juvederm"]
cohen_h

# Chisquare. The groups are individually a bit small (N=5) and so apply Yates
# continuity correction, which is to subtract 0.5 from each of the |Oi-Ei| values.
chisq = sum((abs(contingency_table$n_observed-contingency_table$n_expected)-0.5)^2/contingency_table$n_expected)

cat("Chi-square value")
chisq

cat("P-value for equal vascularization probability between Juvederm and EPI")
pchisq(chisq,df,lower.tail=FALSE)


# Confidence interval: chi-square with Yates continuity correction, as detailed by
#Newcombe, R. G. (1998), Interval estimation for the difference between independent proportions: comparison of eleven methods. Statist. Med., 17: 873-890. doi:10.1002/(SICI)1097-0258(19980430)17:8<873::AID-SIM779>3.0.CO;2-I
# p. 875, method 2

# This method is in principle for only two TRUE/FALSE groups, and not four. To adapt
# it to more groups, one can note that it is based on the idea that counts, at worst, are precise only to within 0.5 and so

continuity_error_table = data.frame(Time_point_month=time_points_double, Material=rep(materials,length(time_points_double)/length(materials)),continuity_error_absolute=0.5,n=NA)

for(ind in 1:(dim(continuity_error_table)[1]))
{
   continuity_error_table$n[ind]=sum(contingency_table$n_observed[contingency_table$Material==continuity_error_table$Material[ind] & contingency_table$Time_point_month==continuity_error_table$Time_point_month[ind]])     
}

continuity_error_material = vector(mode="numeric",length=length(materials))
names(continuity_error_material)=materials

for(theMaterial in materials)
{
     continuity_error_material[theMaterial]=sum(continuity_error_table$continuity_error_absolute[continuity_error_table$Material==theMaterial])/sum(continuity_error_table$n[continuity_error_table$Material==theMaterial]) 
}

continuity_error = sum(continuity_error_material)

p_estimate_material = vector(mode="numeric",length=length(materials))
names(p_estimate_material)=materials

ntotal_material = vector(mode="numeric",length=length(materials))
names(ntotal_material)=materials

for(theMaterial in materials)
{
     p_estimate_material[theMaterial]=sum(contingency_table$n_observed[contingency_table$Material==theMaterial & contingency_table$Vascularized])/sum(contingency_table$n_observed[contingency_table$Material==theMaterial]) 
    
    ntotal_material[theMaterial]=sum(contingency_table$n_observed[contingency_table$Material==theMaterial]) 
}

delta_p = p_estimate_material["EPI"]-p_estimate_material["Juvederm"]

conf_lower = max(0,delta_p - qnorm(0.975)*sqrt(p_estimate_material["EPI"]*(1-p_estimate_material["EPI"])/ntotal_material["EPI"]+p_estimate_material["Juvederm"]*(1-p_estimate_material["Juvederm"])/ntotal_material["Juvederm"])-continuity_error)

conf_upper = min(1,delta_p + qnorm(0.975)*sqrt(p_estimate_material["EPI"]*(1-p_estimate_material["EPI"])/ntotal_material["EPI"]+p_estimate_material["Juvederm"]*(1-p_estimate_material["Juvederm"])/ntotal_material["Juvederm"])+continuity_error)

cat("Confidence interval for the delta of vascularization probability EPI vs. Juvederm")

c(conf_lower,conf_upper)



cat("\n\nLinear model for vascularization in the EPI material over time (Item 54)")
EPI_only = in_vivo_agg[in_vivo_agg$Material=="EPI",]
linmod=lm(vessels_per_field_of_view ~Time_point_month, EPI_only)
cat("\nNormality testing within the EPI material dataset")
shapiro.test(resid(linmod))
cat("\nSummary of the linear model within the EPI data")
summary(linmod)
cat("\nConfidence intervals")
confint(linmod)



dev.off()







