# Plot longterm in-vivo scaffold degradation data

library(plot.counts)
library(mvtnorm)


load(file="/data/Evaluation/In vivo/in_vivo_degradation.rda")
cat("\nStatistical reporting (Item 63)\n")
summary(lm(CMC_concentration_walls_g_L ~ Days, in_vivo_degradation_data_per_mouse))

shapiro.test(resid(lm(CMC_concentration_walls_g_L ~ Days, in_vivo_degradation_data_per_mouse)))

in_vivo_degradation_data_per_mouse$months_trimester=round(in_vivo_degradation_data_per_mouse$Days/90)*3


in_vivo_degradation_data_per_mouse$months_trimester=round(in_vivo_degradation_data_per_mouse$Days/90)*3

in_vivo_degradation_data_per_mouse_agg=aggregate(CMC_concentration_walls_g_L~months_trimester,in_vivo_degradation_data_per_mouse,FUN=mean)

in_vivo_degradation_data_per_mouse_agg_sd=aggregate(CMC_concentration_walls_g_L~months_trimester,in_vivo_degradation_data_per_mouse,FUN=sd)

names_to_show=data.frame(months_trimester=c(0,3,6,9,12),labels=c("<=3 weeks","3 months","6 months","9 months","12 months"))

in_vivo_degradation_data_per_mouse$labels=names_to_show$labels[match(in_vivo_degradation_data_per_mouse$months_trimester,names_to_show$months_trimester)]
in_vivo_degradation_data_per_mouse$labels=factor(in_vivo_degradation_data_per_mouse$labels,levels=names_to_show$labels)

pdf("fig_4m.pdf")

xlim=c(0,13)

plot(in_vivo_degradation_data_per_mouse$Days/30,in_vivo_degradation_data_per_mouse$CMC_concentration_walls_g_L,cex=2,bg="black",pch=21,lwd=2,xlab="Duration implantation",ylab="CMC concentration in walls [g/L]",ylim=c(0,150),xlim=xlim)


linmod = lm(CMC_concentration_walls_g_L~Days,in_vivo_degradation_data_per_mouse)

coeffs=coefficients(linmod)

lines(xlim,coeffs[["(Intercept)"]]+coeffs[["Days"]]*xlim*30,col="red",lwd=2)

cat("\nSample size")
dim(in_vivo_degradation_data_per_mouse)[1]

cat("\n\nShapiro-Wilks test for normality of residuals")
shapiro.test(resid(linmod))

cat("\nLinear regression degradation vs. Days of implantation")
summary(linmod)

cat("\nConfidence interval for the slope")
confint(linmod)




cat("\n\nEstimation of degradation time: Zero x-intercept for the linear regression")

cat("This calculation is from the reply to a Stack Exchange question: https://stats.stackexchange.com/questions/221630/how-to-calculate-the-confidence-interval-of-the-x-intercept-in-a-linear-regressi")
cat("\nThe stack exchange question concerned precisely the calculation of an x-axis intercept confidence interval in linear regression and was posted by 'Marc in the box'")
cat("\nThe answer used is the one from Adrien Renaud, using thee CAPITANI-POLLASTRI method")
cat("\nThis implies further use of code from the paper 'The R-code for computing the cdf and the df o f the ratio of two correlated Normal rv', by De Capitani L and Pollastri A, available at https://boa.unimib.it/retrieve/handle/10281/43053/64388/DECAPITANI_Pollastri.pdf ")


a=coeffs[["(Intercept)"]]
b=coeffs[["Days"]]

covariance_matrix_coefficients = vcov(linmod)
sigma_a=sqrt(covariance_matrix_coefficients["(Intercept)","(Intercept)"])

covariance_matrix_coefficients = vcov(linmod)
sigma_b=sqrt(covariance_matrix_coefficients["Days","Days"])

sigma_ab=covariance_matrix_coefficients["Days","(Intercept)"]

rho=sigma_ab/sigma_a/sigma_b

mu_a = a
mu_b = b
# Copied as is from https://boa.unimib.it/retrieve/handle/10281/43053/64388/DECAPITANI_Pollastri.pdf
F_Wl <- function(w, mu_X, mu_Y, sigma_X, sigma_Y, rho)             {
    #definition of the quantities in expression (2)
    a      <-  (1/(1-rho^2))^0.5 * (mu_Y/sigma_Y-rho*mu_X/sigma_X)
    b      <-   mu_X/sigma_X
    t_w   <-  (1/(1-rho^2))^0.5*(sigma_X/sigma_Y*w-rho)
    #introduction of auxialiry variables
    A    <-  (a-b*t_w)/((1+t_w^2)^0.5)
    B  <-  -b
    C    <-  t_w/((1+t_w^2)^0.5)
    #definition of the two addends in expression (1)
    Mcor<-matrix(c(1,C,C,1),2,2)
    A1<-pmvnorm(lower=c(A,B),upper=Inf, corr=Mcor)
    A2<-pmvnorm(lower=c(-A,-B),upper=Inf, corr=Mcor)
    #computation of the cdf
    res<-A1+A2
    return(res)
}


w=0:1000

F_Wl_vector <- function(w, mu_X, mu_Y, sigma_X, sigma_Y, rho)
{
    res=w
    res[]=0
    for(ind in 1:length(res))
    {
        res[ind]=F_Wl(w[ind],mu_X, mu_Y, sigma_X, sigma_Y, rho)
    }
    return(res)
    
}

P_intercept <- function(x, intercept_Y, slope, sigma_intercept_Y,sigma_slope, rho)
{
    return(1-F_Wl_vector(-x,slope,intercept_Y,sigma_slope,sigma_intercept_Y,rho))
}


Quantile_P_intercept <- function(P,intercept_Y, slope, sigma_intercept_Y,sigma_slope, rho,lower=0,upper=2000){
    q=P
    q[]=0
    
    for(ind in 1:length(P))
    {
        q[ind]= uniroot( function(q) P_intercept(q,intercept_Y, slope, sigma_intercept_Y,sigma_slope, rho) - P[ind],lower=lower,upper=upper)[[1]]
    }
    
    
    return(q)
}


cat("0.025%, median, and 0.975% quantile for the x-intercept, in days")
Quantile_P_intercept(c(0.025,0.5,0.975),a,b,sigma_a,sigma_b,rho)



dev.off()















