# Fig. 5a: Overview over the yield point of the different materials
# analysed. x-coordinate: relative yield stress, describing the 
# balance between injectability and possible strength. y-coordinate
# yield strain

library(plot.counts)



load("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda")


# Point symbols for drawing
pch_CMC = 21
pch_HA=22
pch_other=23


# xy limits for drawing
xlim=c(0,0.4)
ylim=c(0,2)

# This figure has both ellipses for visualization and 
# dots for the individual measurements

pdf("fig_5b.pdf")
plot.new()
plot.window(xlim,ylim)
box(col="black")
Axis(side=1)
Axis(side=2)
title(xlab="Relative yield stress",ylab="Yield strain")

col_irreg_porous = "#083045"
col_irreg_non_porous = "#b44336"
col_spherical_non_porous="#f5b908"
col_spherical_porous = "#ffffff"



col_irreg_porous_border = "#083045"
col_irreg_non_porous_border = "#b44336"
col_spherical_non_porous_border="#f5b908"
col_spherical_porous_border = "#aaaaaa"

col_irreg_porous_interior = "#1286a8"
col_irreg_non_porous_interior = "#e3a7a0"
col_spherical_non_porous_interior="#fadc84"
col_spherical_porous_interior = "#dddddd"





cols_border=c(rep(col_irreg_porous_border,3),rep(col_irreg_non_porous_border,2),rep(col_spherical_non_porous_border,2),col_spherical_porous_border)
names(cols_border)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")


cols_interior=c(rep(col_irreg_porous_interior,3),rep(col_irreg_non_porous_interior,2),rep(col_spherical_non_porous_interior,2),col_spherical_porous_interior)
names(cols_interior)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")




for(theMaterial in unique(yield_info_all_materials$material))
{
    current_data = yield_info_all_materials[yield_info_all_materials$material==theMaterial,c("tau_rel","strain")]
    current_data$tau_rel = current_data$tau_rel/max(xlim)
    current_data$strain = current_data$strain/max(ylim)
    
    var_cov=cov(current_data)
    ev = eigen(var_cov)
    mean_tau_rel = mean(current_data$tau_rel)
    mean_strain = mean(current_data$strain)
    
    angle_values=seq(from=0,to=2*pi,length.out=100)
    
    major_axis_contribution_x=max(xlim)*ev$vectors[1,1]*sqrt(ev$values[1])*cos(angle_values)
    major_axis_contribution_y=max(ylim)*ev$vectors[2,1]*sqrt(ev$values[1])*cos(angle_values)
    
    minor_axis_contribution_x=max(xlim)*ev$vectors[1,2]*sqrt(ev$values[2])*sin(angle_values)
    minor_axis_contribution_y=max(ylim)*ev$vectors[2,2]*sqrt(ev$values[2])*sin(angle_values)
    
    col_border=cols_border[theMaterial]
    col_interior=cols_interior[theMaterial]
    
    polygon(max(xlim)*mean_tau_rel+major_axis_contribution_x+minor_axis_contribution_x,
    max(ylim)*mean_strain+major_axis_contribution_y+minor_axis_contribution_y,border=col_border,col=col_interior,lwd=3)
    
    
}

plot_counts(yield_info_all_materials$tau_rel, yield_info_all_materials$strain, groups=yield_info_all_materials$material,type="p",cex=3.5,ylim=ylim,xlim=xlim,
group_order=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere"),pch=c(pch_CMC,pch_other,pch_HA,pch_CMC,pch_HA,pch_other,pch_CMC,pch_other),col="black",bg=c(rep(col_irreg_porous,3),rep(col_irreg_non_porous,2),rep(col_spherical_non_porous,2),col_spherical_porous),
plot.new=FALSE,lwd=3)

lines(xlim,xlim,col="red",lty=2)
lines(xlim,c(0.5,0.5),col="black")


# For defining the target relative yield stress: At least 1kPa low-strain modulus for the same
# absolute yield stress (in Pa) than Juvederm => allows to define required relative yield stress as
# the ratio between Juvederm yield stress in Pa divided by 1kPa

target_G0prime=c(1000)

yield_info_agg=aggregate(yield_info_all_materials[,c("strain","tau_rel")],by=list(material=yield_info_all_materials$material),FUN=mean)

load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")


target_tau_rel = yield_info_agg$tau_rel[yield_info_agg$material=="Juvederm"]*mean(stress_sweeps_juvederm$Gprime_Pa[stress_sweeps_juvederm$tau_Pa<5])/target_G0prime

# Draw this target line
lines(rep(target_tau_rel,2),c(0.005,2),col="black")

dev.off()




