
library(plot.counts)
library(rheologyEvaluation)
library(Hotelling)
library(SpatialNP)
library(methods)
library(plotfunctions)



load("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda")


#These functions are to replace the part of the library MVN that we did not manage to install
source("/code/Data analysis/Figure_5/multivariate_normal_helper_functions.R")


# Point symbols for drawing
pch_CMC = 21
pch_HA=22
pch_other=23


col_irreg_porous = "#083045"
col_irreg_non_porous = "#b44336"
col_spherical_non_porous="#f5b908"
col_spherical_porous = "#ffffff"






# Clustering analysis
# ===============================================================================================


# Analysis between the materials with the Hotelling test

materials_ordered = c("EPI - CMC","EPI - Hyaluronic_acid","EPI - Alginate","Juvederm","CMC_non_porous_irregular","Sephacryl S200","CMC_spherical_small","cultisphere")


yield_info_all_materials_new = yield_info_all_materials[yield_info_all_materials$material==materials_ordered[1],]
for(ind in 2:length(materials_ordered))
{
    yield_info_all_materials_new=rbind(yield_info_all_materials_new,yield_info_all_materials[yield_info_all_materials$material==materials_ordered[ind],])
}

# Reporting of the group sizes
# For legends conformal with nomencature in paper: Juvederm is labelled HA ctl
yield_info_all_materials_new$material=as.character(yield_info_all_materials_new$material)
yield_info_all_materials_new$material[yield_info_all_materials_new$material=="Juvederm"]="HA ctl"

materials_ordered = c("EPI - CMC","EPI - Hyaluronic_acid","EPI - Alginate","HA ctl","CMC_non_porous_irregular","Sephacryl S200","CMC_spherical_small","cultisphere")
yield_info_all_materials_new$material=factor(yield_info_all_materials_new$material,levels=materials_ordered)


yield_info_all_materials=yield_info_all_materials_new
n_group = aggregate(Gprime_Pa_0~material,yield_info_all_materials,FUN=length)
colnames(n_group)[colnames(n_group)=="Gprime_Pa_0"]="n"

cat("\nStatistical reporting (Item 59: Multivariate distance testing)\n\n")

cat("\nGroup sizes per material:")
n_group

cat("\nTotal measurements:")
sum(n_group$n)






# initialization of the various test statistic matrices
material_difference_P = matrix(nrow=length(unique(yield_info_all_materials$material)),ncol=length(unique(yield_info_all_materials$material)))
rownames(material_difference_P)=unique(yield_info_all_materials$material)
colnames(material_difference_P)=unique(yield_info_all_materials$material)



material_royston_P = material_difference_P
material_difference_P_non_parameteric=material_difference_P #P-value of the non-parametric spatial rank sum test
material_difference_Q2_non_parameteric=material_difference_P # Chisquare test statistic of the non-parametric spatial rank sum test
material_difference_df_non_parameteric=material_difference_P
material_Hotelling_T2 = material_difference_P # Parametric test, distance
material_Hotelling_nx = material_difference_P # Parametric test, n1
material_Hotelling_ny = material_difference_P # Parametric test, n2
material_Hotelling_n_effective = material_difference_P # Parametric test, n effective from n1 and n2
material_effect_size = material_difference_P # Parametric test, n2
material_Hotelling_P = material_difference_P # Hotelling test  P-value

#Confidence_intervals for the Mahalanobis distance according to Reiser, B. CONFIDENCE INTERVALS FOR THE MAHALANOBIS DISTANCE. Communications in Statistics - Simulation and Computation 30, 37-45, doi:10.1081/SAC-100001856 (2001).
confidence_mahalanobis_lower_reiser=material_difference_P
confidence_mahalanobis_upper_reiser=material_difference_P

confidence_mahalanobis_lower_reiser_Bonferroni=material_difference_P
confidence_mahalanobis_upper_reiser_Bonferroni=material_difference_P


# Common covariance matrix for calculating the effect size
cov_matrix_all=0

for(theMaterial in unique(yield_info_all_materials$material))
{
    
    cov_matrix = var(yield_info_all_materials[yield_info_all_materials$material==theMaterial, c("strain","tau_rel")])
    
    cov_matrix_all = cov_matrix/length(unique(yield_info_all_materials$material)) + cov_matrix_all #Averaging over all the materials
}

cov_matrix=cov_matrix_all

cov_matrix_inverse = solve(cov_matrix)




for(mat1 in rownames(material_difference_P))
{
    for(mat2 in colnames(material_difference_P))
    {
        data1=yield_info_all_materials[yield_info_all_materials$material==mat1,c("strain","tau_rel")]
        data2=yield_info_all_materials[yield_info_all_materials$material==mat2,c("strain","tau_rel")]
        
        test_info=hotelling.test(x=data1,y=data2)
        material_difference_P[mat1,mat2]=test_info$pval
        
        
        data1_centered=data1-as.data.frame(t(as.matrix(apply(data1,2,mean)))[rep(1, dim(data1)[1]), ])
        data2_centered=data2-as.data.frame(t(as.matrix(apply(data2,2,mean)))[rep(1, dim(data2)[1]), ])
        if(mat1==mat2)
        {
            data_centered=data1_centered
            
        } else
        {
            data_centered=rbind(data1_centered,data2_centered)
        }
        if(dim(data_centered)[1]<=3)
        {
            material_royston_P[mat1,mat2]=1
        } else {
            material_royston_P[mat1,mat2]=attributes(roystonTest(data_centered))$p.value
        }
        
        spatial_rank_sum_test =sr.loc.test(data1,data2,score="rank")
        material_difference_P_non_parameteric[mat1,mat2]=spatial_rank_sum_test$p.value
        material_difference_Q2_non_parameteric[mat1,mat2]=spatial_rank_sum_test$statistic
        material_difference_df_non_parameteric[mat1,mat2]=spatial_rank_sum_test$param
        
        
        material_Hotelling_P[mat1,mat2]=material_difference_P[mat1,mat2]
        material_Hotelling_T2[mat1,mat2]=test_info$stats$statistic
        material_Hotelling_nx[mat1,mat2] = test_info$stats$nx
        material_Hotelling_ny[mat1,mat2] = test_info$stats$ny
        
        n_effective = test_info$stats$nx*test_info$stats$ny/(test_info$stats$nx+test_info$stats$ny)
        
        material_Hotelling_n_effective[mat1,mat2]=n_effective
        
        mean_vector_1 = as.vector(apply(data1,2,mean))
        mean_vector_2 = as.vector(apply(data2,2,mean))
        
        delta = as.matrix(mean_vector_1-mean_vector_2)
        
        material_effect_size[mat1,mat2]=sqrt(t(delta)%*%cov_matrix_inverse%*%delta)
        
        
        
        
    }
}




cat("\nRoyston test: Is the pairwise data compatible with multivariate normality?")
material_royston_P

# For Bonferroni correction (later):

N_Bonferroni = (dim(material_difference_P)[1])*(dim(material_difference_P)[2]-1)/2
# Number of distinct comparisons (symmetry: A vs. B = B vs. A). Also +2 for the clustering tests







for(mat1 in rownames(material_difference_P))
{
    for(mat2 in colnames(material_difference_P))
    {
        
        
        # Using the notation in the above paper
        p=2 # We always have two values, yield strain and relative yield stress
        m=n_group$n[n_group$material==mat1]
        n=n_group$n[n_group$material==mat2]
        d2=material_effect_size[mat1,mat2]^2*m*n/(m+n) #observed distance scaled for following an F-distribution
        
        
        alpha=0.05
        
        F_intervals=F_confint_Reiser(d2,p,m+n-p-1,alpha)
        d2_upper=F_intervals[2]
        d2_lower=F_intervals[1]
        confidence_mahalanobis_upper_reiser[mat1,mat2]=sqrt((m+n)/m/n*d2_upper)
        confidence_mahalanobis_lower_reiser[mat1,mat2]=sqrt((m+n)/m/n*d2_lower)
        
        
        
        alpha=0.05/N_Bonferroni
        
        F_intervals=F_confint_Reiser(d2,p,m+n-p-1,alpha)
        d2_upper=F_intervals[2]
        d2_lower=F_intervals[1]
        confidence_mahalanobis_upper_reiser_Bonferroni[mat1,mat2]=sqrt((m+n)/m/n*d2_upper)
        confidence_mahalanobis_lower_reiser_Bonferroni[mat1,mat2]=sqrt((m+n)/m/n*d2_lower)
        
        
        
    }
}






confidence_interval_text=confidence_mahalanobis_lower_reiser
confidence_interval_text[]=paste(round(confidence_mahalanobis_lower_reiser*100)/100,round(confidence_mahalanobis_upper_reiser*100)/100,sep="-")

diag(confidence_interval_text)="NA"

cat("\nConfidence intervals for the Mahalanobis distance (i.e. distance/sd, multivariate version with common variance-covariance matrix). These intervals are calculated using an effective sample size n_effective=n1*n2/(n1+n2), with  normal distribution with sd=1/n_effective, centered on observed Mahalanobis distance.")
noquote(confidence_interval_text)

cat("\nConfidence intervals with Bonferroni correction")

confidence_interval_text=confidence_mahalanobis_lower_reiser_Bonferroni
confidence_interval_text[]=paste(round(confidence_mahalanobis_lower_reiser_Bonferroni*100)/100,round(confidence_mahalanobis_upper_reiser_Bonferroni*100)/100,sep="-")

diag(confidence_interval_text)="NA"
noquote(confidence_interval_text)

cat("\nEffect size: Mahalanobis distance (i.e. distance/sd, multivariate version)")
material_effect_size

cat("\nHotelling test: T2. Only applicable if Royston test non-significant")
material_Hotelling_T2

cat("\nHotelling test: First degree of freedom (nx), only applicable if Royston test non-significant")
material_Hotelling_nx

cat("\nHotelling test: Second degree of freedom (ny), only applicable if Royston test non-significant")
material_Hotelling_ny

cat("\nHotelling test: Overall effective n")
material_Hotelling_n_effective


cat("\nSpatial rank sum test: Chisquared. Used when Royston test significant (non-normality)")
material_difference_Q2_non_parameteric

cat("\nSpatial rank sum test: Degree of freedom. Used when Royston test significant (non-normality)")
material_difference_df_non_parameteric




material_difference_P[material_royston_P<0.05]=material_difference_P_non_parameteric[material_royston_P<0.05]

cat("\nOverall P-values (Hotelling if Royston non-significant, spatial rank sum test otherwise)")
material_difference_P




material_difference_P_Bonferroni=material_difference_P*N_Bonferroni

material_difference_P_Bonferroni[material_difference_P_Bonferroni>1]=1

cat("\nNumber of tests for Bonferroni correction")
N_Bonferroni

cat("\nOverall P-values, with Bonferroni correction (Hotelling if Royston non-significant, spatial rank sum test otherwise)")
material_difference_P_Bonferroni




left_margin=10
top_margin=10




for_heatmap = material_effect_size

pdf("fig_5c.pdf",width=9,height=7) # unit: inches


max_effect_size_heatmap=6 # Effect size is difference vs. standard deviaton. A difference of more than
# 2 standard deviations is already very clear as usually single measurements won't overlap, with 6 standard
# deviations materials can be distinguished with very high probability in single measurements, so let's
# use this as the upper limit


# margins: Lower, Left, Top, Right
par(mai=c(0.2,3,2,1.2),xpd=NA)
image(t(for_heatmap[(dim(for_heatmap)[1]):1,]),col=grey(seq(from=0,to=100,length.out=200)/100),zlim=c(0,max_effect_size_heatmap),xaxt="n",yaxt="n")
axis(side=3,at=(0:(dim(for_heatmap)[1]-1))/(dim(for_heatmap)[1]-1),labels=FALSE)
axis(side=2,at=(0:(dim(for_heatmap)[2]-1))/(dim(for_heatmap)[2]-1),labels=rownames(for_heatmap)[(dim(for_heatmap)[1]):1],las=2,mgp=c(3,3,0))



for(ind1 in 1:(dim(for_heatmap)[1]))
{
    for(ind2 in 1:(dim(for_heatmap)[2]))
    {
        
        text(x=(ind1-1)/(dim(for_heatmap)[1]-1),
        y=1-(ind2-1)/(dim(for_heatmap)[1]-1),
        label=significance_labels(material_difference_P_Bonferroni[ind1,ind2],codes=c("","*","**","***")),cex=2.5,col="black")
        
        
    }
    
}

cex_legend=4

lines(0/(dim(for_heatmap)[1]-1),1.15,pch=pch_CMC,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-CMC
lines(1/(dim(for_heatmap)[1]-1),1.15,pch=pch_HA,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-HA
lines(2/(dim(for_heatmap)[1]-1),1.15,pch=pch_other,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-Alginate
lines(3/(dim(for_heatmap)[1]-1),1.15,pch=pch_HA,bg=col_irreg_non_porous,type="p",cex=cex_legend) # Juvederm
lines(4/(dim(for_heatmap)[1]-1),1.15,pch=pch_CMC,bg=col_irreg_non_porous,type="p",cex=cex_legend) # CMC irr non-porous
lines(5/(dim(for_heatmap)[1]-1),1.15,pch=pch_other,bg=col_spherical_non_porous,type="p",cex=cex_legend) # Sephacryl
lines(6/(dim(for_heatmap)[1]-1),1.15,pch=pch_CMC,bg=col_spherical_non_porous,type="p",cex=cex_legend) # CMC spherical
lines(7/(dim(for_heatmap)[1]-1),1.15,pch=pch_other,bg=col_spherical_porous,type="p",cex=cex_legend) # Cultisphere


lines(-0.15,1-0/(dim(for_heatmap)[1]-1),pch=pch_CMC,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-CMC
lines(-0.15,1-1/(dim(for_heatmap)[1]-1),pch=pch_HA,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-HA
lines(-0.15,1-2/(dim(for_heatmap)[1]-1),pch=pch_other,bg=col_irreg_porous,type="p",cex=cex_legend) # EPI-Alginate
lines(-0.15,1-3/(dim(for_heatmap)[1]-1),pch=pch_HA,bg=col_irreg_non_porous,type="p",cex=cex_legend) # Juvederm
lines(-0.15,1-4/(dim(for_heatmap)[1]-1),pch=pch_CMC,bg=col_irreg_non_porous,type="p",cex=cex_legend) # CMC irr non-porous
lines(-0.15,1-5/(dim(for_heatmap)[1]-1),pch=pch_other,bg=col_spherical_non_porous,type="p",cex=cex_legend) # Sephacryl
lines(-0.15,1-6/(dim(for_heatmap)[1]-1),pch=pch_CMC,bg=col_spherical_non_porous,type="p",cex=cex_legend) # CMC spherical
lines(-0.15,1-7/(dim(for_heatmap)[1]-1),pch=pch_other,bg=col_spherical_porous,type="p",cex=cex_legend) # Cultisphere




for_clustering = log(material_effect_size)


graphical_offset = 0.5 # This doesn't change the clustering diagram per se but provides
# better graphical display as it avoids intersection with the point symbols


d<-for_clustering[lower.tri(for_clustering)]+graphical_offset
attr(d,"Size")=dim(for_clustering)[1]
attr(d,"Labels")=rownames(for_clustering)
attr(d,"Diag")=FALSE
attr(d,"Upper")=FALSE
attr(d,"Method")="mahalanobis"
attr(d,"call")="d<-for_clustering"
attr(d,"class")="dist"

hc<-hclust(d,method="ward.D")

hc$order=1:(dim(for_clustering)[1])

x<-hc
merge <- x$merge
n1 <- nrow(merge)
n <- n1 + 1L
height <- as.double(x$height)
ord<-order(x$order)
labels<-x$labels




xlim=c(0,1)

xpos_leafs = xlim[1]+(xlim[2]-xlim[1])/n1*(0:(length(height)))

pos_nodes = data.frame(index=vector(mode="numeric",length=0),xpos=vector(mode="numeric",length=0),ypos=vector(mode="numeric",length=0))

ylim=c(1.2,1.5)

total_height=max(height)



done=vector(mode="numeric",length=0)

# Find the height in the diagram where the difference between average groups is beyond the 5% significance level
# even for single measurement comparison
offset_95p_difference =qnorm(1-0.05/2/N_Bonferroni,sd=sqrt(2))

# Transform this into a y-coordinate for the graph by doing the same transformations as for the diagram drawing
offset_95p_difference_y_position=ylim[1]+(ylim[2]-ylim[1])/total_height*(log(offset_95p_difference)+graphical_offset)




lines(xlim,rep(offset_95p_difference_y_position,2),lty=2)

while(dim(merge)[1]-length(done)>0)
{
    ind_to_do = which.min(height)
    
    
    
    xpos=vector(mode="numeric",length=length(merge[ind_to_do,]))
    ypos=vector(mode="numeric",length=length(merge[ind_to_do,]))
    
    for(ind in 1:length(merge[ind_to_do,]))
    {
        if(merge[ind_to_do,ind]<0) # Leaf node
        {
            xpos[ind]=xpos_leafs[-merge[ind_to_do,ind]]
            ypos[ind]=ylim[1]
        } else { # Intermediate node
            xpos[ind]=pos_nodes$xpos[match(merge[ind_to_do,ind],pos_nodes$index)]
            ypos[ind]=pos_nodes$ypos[match(merge[ind_to_do,ind],pos_nodes$index)]
        }
    }
    
    node_height=ylim[1]+(ylim[2]-ylim[1])/total_height*height[ind_to_do]
    
    lines(c(rep(xpos[1],2),rep(xpos[2],2)),c(ypos[1],node_height,node_height,ypos[2]),type="l")
    
    pos_nodes=rbind(pos_nodes,data.frame(index=ind_to_do,xpos=mean(xpos),ypos=node_height))
    
    
    done=c(done,ind_to_do)
    
    height[ind_to_do]=NA
    
    
    
    
}




# Legend: Effect size scale

# Position coding is left,bottom,right,top

gradientLegend(c(0,max_effect_size_heatmap),pos=c(1.05,0,1.15,1),color=grey((0:255)/255),n.seg=4)


text(x=1.2,y=1.2,labels="Effect size\ndelta/sd")


# Statistical analysis of the clustering

cat("\n\n\nStatistical analysis of the clustering in terms of variance explained (Item 60)")
cat("\nGroup sizes: n=N=total measurements=")
dim(yield_info_all_materials)[1]
# Make the groupings obtained above available as factors for analysis of variance
groupings_from_clustering=cutree(hc,h=log(offset_95p_difference)+graphical_offset)
yield_info_all_materials$cluster=as.factor(groupings_from_clustering [match(yield_info_all_materials$material, names(groupings_from_clustering))])

# Normality testing: This turns out to be not so simple

linmod_cluster_simple=lm(cbind(strain,tau_rel) ~ cluster, yield_info_all_materials)
linmod_0_simple = update(linmod_cluster_simple, ~1)

cat("\nNormality testing: M1 is the complete model with clustering as an explanatory variable, M0 the control without explanatory variables (intercept only). Both models with bivariate response, namely strain and relative yield stress")
cat("\nM1:")
shapiro.test(resid(linmod_cluster_simple))
cat("\nM0:")
shapiro.test(resid(linmod_0_simple))


# Deeper analysis shows that the problem comes from the tau_rel values
# that have quite different variance depending on their magnitude (larger when value is larger)
# After some trial, we can state that the sqrt transform is not useful; the log-transform is to some extent by
# correctly scaling the higher tau_rel values that also have larger variance, however it also "draws out" low values
# so we end up using a log + c transform, taking the minimum observed tau_rel value as the starting point

min_tau_rel = min(yield_info_all_materials$tau_rel)

linmod_cluster=lm(cbind(strain,log(tau_rel+min_tau_rel)) ~ cluster, yield_info_all_materials)
linmod_0 = update(linmod_cluster, ~1)

cat("\nMitigation for non-normality: The relative yield stress variable is the problem, it shows increasing variance with increaing absolute value. The log transform is much better, but introduces a new problem at very low values since it stretches out the distribution there. Compromise: use log+c transform on relative yield stress; choice: offset c=min(relative yield stress).")
cat("\nM1 after mitigation:")
shapiro.test(resid(linmod_cluster))
cat("\nM0 after mitigation:")
shapiro.test(resid(linmod_0))

cat("\nSummary of the comparative ANOVA, with and without inclusion of the material structure clusters, to explain the strain and relative yield stress characteristics")

anova(linmod_cluster,linmod_0,test="Wilks")






# For the confidence interval
cat("\nConfidence interval for Wilk's lambda")

w=wilks_confint(linmod_cluster,linmod_0)
c(w[2],w[1])

cat("\nEffect size: r^2=1-Wilk's lambda")
1-anova(linmod_cluster,linmod_0,test="Wilks")$Wilks[2]

cat("\nP-value")
pf(anova(linmod_cluster,linmod_0,test="Wilks")$"approx F"[2],
anova(linmod_cluster,linmod_0,test="Wilks")$"num Df"[2],
anova(linmod_cluster,linmod_0,test="Wilks")$"den Df"[2],lower.tail=FALSE)

cat("\nP-value after Bonferroni correction")
pf(anova(linmod_cluster,linmod_0,test="Wilks")$"approx F"[2],
anova(linmod_cluster,linmod_0,test="Wilks")$"num Df"[2],
anova(linmod_cluster,linmod_0,test="Wilks")$"den Df"[2],lower.tail=FALSE)*2



