library(plot.counts)
library(rheologyEvaluation)



load(file="/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_neutralization.rda")

load(file="/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")


# Here, we compare absolute values rather than master curves, so it is
# important to use only a narrow range of concentrations. Also, limit
# to the plate-plate geometry
EPI_to_use = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 24 & stress_sweeps_EPI_all$polymer_conc_mgmL<=28 & stress_sweeps_EPI_all$Geometry=="plate"  ,]


EPI_to_use$Neutralization_percentage = 0
EPI_to_use$overview_index = NA
EPI_to_use$Gprime_normalization = EPI_to_use$Gprime_Pa_0
EPI_to_use$Gprime_rel = EPI_to_use$Gprime_Pa/EPI_to_use$Gprime_normalization
EPI_to_use$Gprimeprime_rel = EPI_to_use$Gprimeprime_Pa/EPI_to_use$Gprime_normalization
EPI_to_use$tau_rel = EPI_to_use$tau_Pa/EPI_to_use$Gprime_normalization



# Provide a unique ID

stress_sweeps_EPI_neutralization$ID=paste("Neutralization",stress_sweeps_EPI_neutralization$overview_index,sep="_")

# Exclude duplicates since we will assemble later on

stress_sweeps_EPI_neutralization=stress_sweeps_EPI_neutralization[!(stress_sweeps_EPI_neutralization$ID %in% unique(EPI_to_use$ID)),]



stress_sweeps_EPI_neutralization=stress_sweeps_EPI_neutralization[stress_sweeps_EPI_neutralization$polymer_conc_mgmL==27,]

stress_sweeps_EPI_neutralization$Gprime_normalization = overview_EPI_neutralization$Gprime[stress_sweeps_EPI_neutralization$overview_index]

stress_sweeps_EPI_neutralization$Gprime_rel = stress_sweeps_EPI_neutralization$Gprime_Pa/stress_sweeps_EPI_neutralization$Gprime_normalization

stress_sweeps_EPI_neutralization$Gprimeprime_rel = stress_sweeps_EPI_neutralization$Gprimeprime_Pa/stress_sweeps_EPI_neutralization$Gprime_normalization


stress_sweeps_EPI_neutralization$tau_rel = stress_sweeps_EPI_neutralization$tau_Pa/stress_sweeps_EPI_neutralization$Gprime_normalization


common_colnames = colnames(stress_sweeps_EPI_neutralization)[colnames(stress_sweeps_EPI_neutralization) %in% colnames(EPI_to_use)]

EPI_to_use$ID=paste(EPI_to_use$file, EPI_to_use$folder) # There are some instances
# where the samples were prepared from a common bulk, without separate readjustment
# of humidity (although the samples by themselves are independent, the bulk is the same). Here, the absolute values are particularly important, and so
# contrary to the master curve, these samples should be counted as 1. This is achieved
# by using the file rather than the measurement ID

stress_sweeps_EPI_neutralization=rbind(stress_sweeps_EPI_neutralization[,common_colnames],EPI_to_use[,common_colnames])



log_factor = 10 # For averaging in log intervals of the relative shear stress

cex_Gprime = 2 # Character expansion for G' curve

cex_Gprimeprime = 1 # Character expansion for G'' curve

stress_sweeps_EPI_neutralization$tau_Pa_round=exp(round(log(stress_sweeps_EPI_neutralization$tau_Pa)*log_factor)/log_factor)

stress_sweeps_EPI_neutralization_agg = aggregate(stress_sweeps_EPI_neutralization[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa")],by=stress_sweeps_EPI_neutralization[,c("Neutralization_percentage","tau_Pa_round","ID")],FUN=mean)

started=FALSE
for(theNeutralization in unique(stress_sweeps_EPI_neutralization_agg$Neutralization_percentage))
{
    
    to_complete =stress_sweeps_EPI_neutralization_agg[stress_sweeps_EPI_neutralization_agg$Neutralization_percentage==theNeutralization,]
    if(!started)
    {
        completed_sweeps = complete_sweeps(to_complete,abscissa="tau_Pa_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa"),sweep_identifier_column="ID")
        started=TRUE
    } else
    {
        completed_sweeps = rbind(completed_sweeps,complete_sweeps(to_complete,abscissa="tau_Pa_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa"),sweep_identifier_column="ID"))
        
    }
}

sweeps_agg = aggregate(completed_sweeps[,c("tau_Pa","Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa")],by=completed_sweeps[,c("Neutralization_percentage","tau_Pa_round")],FUN=mean)

sweeps_agg_len =aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa")],by=completed_sweeps[,c("Neutralization_percentage","tau_Pa_round")],FUN=length)

sweeps_agg_sd = aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel","tau_Pa")],by=completed_sweeps[,c("Neutralization_percentage","tau_Pa_round")],FUN=sd)

to_show_sd=aggregate(Gprime_rel ~ Neutralization_percentage, sweeps_agg,FUN=function(x){which.min(abs(x-0.8))})

for(theNeutralization in unique(sweeps_agg_sd$Neutralization_percentage))
{
    
    current_data = sweeps_agg_sd[sweeps_agg_sd$Neutralization==theNeutralization ,]
    
    current_data[-to_show_sd$Gprime_rel[to_show_sd$Neutralization_percentage==theNeutralization ],c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA
    sweeps_agg_sd[sweeps_agg_sd$Neutralization_percentage==theNeutralization ,]=current_data
    
    
}

solid_part = sweeps_agg[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa,]
solid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa,]


liquid_part = sweeps_agg[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa,]
liquid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa,]


before_yield=aggregate(tau_Pa ~ Neutralization_percentage,solid_part, FUN=which.max)
after_yield=aggregate(tau_Pa ~ Neutralization_percentage,liquid_part, FUN=which.min)

started=FALSE

for(ind in 1:(dim(before_yield)[1]))
{
    if(!started)
    {
        transition=solid_part[solid_part$Neutralization_percentage==before_yield$Neutralization_percentage[ind],][before_yield$tau_Pa[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,solid_part[solid_part$Neutralization_percentage==before_yield$Neutralization_percentage[ind],][before_yield$tau_Pa[ind],])
        
        
    }
}

for(ind in 1:(dim(after_yield)[1]))
{
    if(!started)
    {
        transition=liquid_part[liquid_part$Neutralization_percentage==after_yield$Neutralization_percentage[ind],][after_yield$tau_Pa[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,liquid_part[liquid_part$Neutralization_percentage==after_yield$Neutralization_percentage[ind],][after_yield$tau_Pa[ind],])
        
        
    }
}

pdf("fig_5d.pdf")



plot_counts(liquid_part$tau_Pa,liquid_part$Gprime_Pa,groups=liquid_part$Neutralization_percentage,sd_y=liquid_part_sd$Gprime_Pa,log="xy",xlab="Shear stress [Pa]",ylab="Modulus [Pa]",type="b",pch=21,bg=grey((6:0)/6),col="black",cex=cex_Gprimeprime,ylim=c(1,1e4),xaxt="n",yaxt="n",main="Neutralization and EPI rheology",group_order=c(90,75,50,25,10,5,0),xlim=c(0.5,1e3))


plot_counts(transition$tau_Pa,transition$Gprime_Pa,groups=transition$Neutralization_percentage,sd_y=transition$Gprime_Pa,type="b",pch=21,bg=grey((6:0)/6),col="black",cex=cex_Gprimeprime,group_order=c(90,75,50,25,10,5,0),plot.new=FALSE)


plot_counts(solid_part$tau_Pa,solid_part$Gprime_Pa,groups=solid_part$Neutralization_percentage,sd_y=solid_part_sd$Gprime_Pa,type="b",pch=21,bg=grey((6:0)/6),col="black",cex=cex_Gprime,group_order=c(90,75,50,25,10,5,0),plot.new=FALSE)






axis(side=1,at=c((5:9)*1e-1,(1:9),(1:9)*1e1,(1:9)*1e2,1e3),labels=c(rep("",5),expression(1),rep("",8),10,rep("",8),100,rep("",8),1000))

axis(side=2,at=c((1:9),(1:9)*1e1,(1:9)*100,(1:10)*1000),labels=c(expression(1),rep("",8),10,rep("",8),100,rep("",8),1000,rep("",8),10000))



legend("topright",legend=c("0%","5%","10%","25%","50%","75%","90%"),pt.bg=grey((0:6)/6),pch=rep(21,6),pt.cex=2)





dev.off()

cat("\nSample size reporting (Item 61)")

cat("\nn for the neutralization experiment")
n_neutralization=aggregate( overview_index ~ Neutralization_percentage,stress_sweeps_EPI_neutralization,function(x){length(unique(x))})
colnames(n_neutralization)[colnames(n_neutralization)=="overview_index"]="n"

n_neutralization=rbind(data.frame(Neutralization_percentage=0,n=length(unique(EPI_to_use$ID))),n_neutralization)
n_neutralization

cat("\nTotal N")
sum(n_neutralization$n)










