library(plot.counts)
library(rheologyEvaluation)

# There are additional sweeps, but for consistency, we report only the ones where we also have cell adhesion data

log_factor = 10 # For averaging in log intervals of the relative shear stress

cex_Gprime = 2 # Character expansion for G' curve

cex_Gprimeprime = 1 # Character expansion for G'' curve

load(file="/data/Evaluation/Rheology/Stress Sweeps/EPI_coating/stress_sweeps_coating.rda")


log_factor = 10 # For averaging in log intervals of the relative shear stress

cex_Gprime = 2 # Character expansion for G' curve

cex_Gprimeprime = 1 # Character expansion for G'' curve


started=FALSE

G0 = aggregate(Gprime_Pa ~ file, stress_sweeps_coating, function(x){x[1]})

stress_sweeps_coating$G0=G0$Gprime_Pa[match(stress_sweeps_coating$file,G0$file)]
stress_sweeps_coating$tau_rel=stress_sweeps_coating$tau_Pa/stress_sweeps_coating$G0
stress_sweeps_coating$tau_rel_round=exp(round(log(stress_sweeps_coating$tau_Pa/stress_sweeps_coating$G0)*log_factor)/log_factor)
stress_sweeps_coating$Gprime_rel=stress_sweeps_coating$Gprime_Pa/stress_sweeps_coating$G0
stress_sweeps_coating$Gprimeprime_rel=stress_sweeps_coating$Gprimeprime_Pa/stress_sweeps_coating$G0

stress_sweeps_coating_agg = aggregate(stress_sweeps_coating[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=stress_sweeps_coating[,c("Coating","Mass_fraction_coating","tau_rel_round","file")],FUN=mean)

for(theCoating in unique(paste(stress_sweeps_coating_agg$Coating,stress_sweeps_coating_agg$Mass_fraction_coating)))
{
    
    to_complete =stress_sweeps_coating_agg[paste(stress_sweeps_coating_agg$Coating,stress_sweeps_coating_agg$Mass_fraction_coating)==theCoating,]
    if(!started)
    {
       completed_sweeps = complete_sweeps(to_complete,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel"))
       started=TRUE
    } else
    {
        completed_sweeps = rbind(completed_sweeps,complete_sweeps(to_complete,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel")))
        
    }
}

sweeps_agg = aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps[,c("Coating","Mass_fraction_coating","tau_rel_round")],FUN=mean)

sweeps_agg_sd = aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps[,c("Coating","Mass_fraction_coating","tau_rel_round")],FUN=sd)

to_show_sd=aggregate(Gprime_rel ~ Coating + Mass_fraction_coating, sweeps_agg,FUN=function(x){which.min(abs(x-0.5))})

for(theCoating in unique(sweeps_agg_sd$Coating))
{
    for(theMassFraction in unique(sweeps_agg_sd$Mass_fraction_coating[sweeps_agg_sd$Coating==theCoating]))
    {
       current_data = sweeps_agg_sd[sweeps_agg_sd$Coating==theCoating & sweeps_agg_sd$Mass_fraction_coating==theMassFraction,]
       
       current_data[-to_show_sd$Gprime_rel[to_show_sd$Coating==theCoating & to_show_sd$Mass_fraction_coating==theMassFraction],c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA
       sweeps_agg_sd[sweeps_agg_sd$Coating==theCoating & sweeps_agg_sd$Mass_fraction_coating==theMassFraction,]=current_data
       
    }
}


solid_part = sweeps_agg[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]
solid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]


liquid_part = sweeps_agg[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]
liquid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]


before_yield=aggregate(tau_rel_round ~ Mass_fraction_coating,solid_part, FUN=which.max)
after_yield=aggregate(tau_rel_round ~ Mass_fraction_coating,liquid_part, FUN=which.min)

started=FALSE

for(ind in 1:(dim(before_yield)[1]))
{
    if(!started)
    {
        transition=solid_part[solid_part$Mass_fraction_coating==before_yield$Mass_fraction_coating[ind],][before_yield$tau_rel_round[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,solid_part[solid_part$Mass_fraction_coating==before_yield$Mass_fraction_coating[ind],][before_yield$tau_rel_round[ind],])
        
        
    }
}

for(ind in 1:(dim(after_yield)[1]))
{
    if(!started)
    {
        transition=liquid_part[liquid_part$Mass_fraction_coating==after_yield$Mass_fraction_coating[ind],][after_yield$tau_rel_round[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,liquid_part[liquid_part$Mass_fraction_coating==after_yield$Mass_fraction_coating[ind],][after_yield$tau_rel_round[ind],])
        
        
    }
}


ylim=c(1e-3,1)


pdf("fig_5e.pdf")

plot_counts(liquid_part$tau_rel_round,liquid_part$Gprime_rel,groups=paste(liquid_part$Coating,liquid_part$Mass_fraction_coating),log="xy",xlab="Normalized shear stress",ylab="Normalized modulus ",type="b",pch=21,bg=grey(c(0.5,0.8,1)),col="black",group_order=c("Collagen 0.01","Collagen 0.03","Collagen 0.1"),cex=cex_Gprimeprime,ylim=ylim,xlim=c(1e-4,0.3),xaxt="n",yaxt="n",main="Coating and EPI rheology")

plot_counts(transition$tau_rel_round,transition$Gprime_rel,groups=paste(transition$Coating,transition$Mass_fraction_coating),type="b",pch=21,bg=grey(c(0.5,0.8,1)),col="black",group_order=c("Collagen 0.01","Collagen 0.03","Collagen 0.1"),cex=cex_Gprimeprime,plot.new=FALSE)

plot_counts(solid_part$tau_rel_round,solid_part$Gprime_rel,groups=paste(solid_part$Coating,solid_part$Mass_fraction_coating),sd_y=solid_part_sd$Gprime_rel,type="b",pch=21,bg=grey(c(0.5,0.8,1)),col="black",group_order=c("Collagen 0.01","Collagen 0.03","Collagen 0.1"),cex=cex_Gprime,plot.new=FALSE)


axis(side=1,at=c((1:9)*1e-4,(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-4),rep("",8),1e-3,rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))

axis(side=2,at=c(c(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-3),rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))


# Too many curves to also plot the G''

#plot_counts(sweeps_agg$tau_rel_round,sweeps_agg$Gprimeprime_rel,groups=paste(sweeps_agg$Coating,sweeps_agg$Mass_fraction_coating),sd_y=sweeps_agg_sd$Gprimeprime_rel,type="b",pch=21,bg=grey(c(0.5,0.8,1)),col="black",group_order=c("Collagen 0.01","Collagen 0.03","Collagen 0.1"),cex=cex_Gprimeprime,plot.new=FALSE)








load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")



# We collected EPI sweeps in quite extreme variations of concentrations. Focus here on the more relevant ones around 20-30 mg/mL. Also, there is one file where there are multiple sweeps in a single file, which we need to treat separately (below)

EPI_control = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 24 & stress_sweeps_EPI_all$polymer_conc_mgmL<=28 & stress_sweeps_EPI_all$Geometry=="plate"  ,]



EPI_control$tau_rel = EPI_control$tau_Pa/EPI_control$Gprime_Pa_0
EPI_control$tau_rel_round=exp(round(log(EPI_control$tau_rel)*log_factor)/log_factor)

EPI_control$Gprime_rel = EPI_control$Gprime_Pa/EPI_control$Gprime_Pa_0
EPI_control$Gprimeprime_rel = EPI_control$Gprimeprime_Pa/EPI_control$Gprime_Pa_0





sweeps_EPI_agg_per_ID = aggregate(EPI_control[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=EPI_control[,c("tau_rel_round","file","ID")],FUN=mean)


completed_sweeps_EPI = complete_sweeps(sweeps_EPI_agg_per_ID,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel"),sweep_identifier_column="ID")

sweeps_EPI_agg_per_file = aggregate(completed_sweeps_EPI[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps_EPI[,c("tau_rel_round","file")],FUN=mean)



sweeps_EPI_agg = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=mean)

sweeps_EPI_agg_sd = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=sd)

sweeps_EPI_agg_sd[-which.min(abs(sweeps_EPI_agg$Gprime_rel-0.5)),c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA



solid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]
solid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]


liquid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]
liquid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]

transition_EPI = rbind(solid_part_EPI[which.max(solid_part_EPI$tau_rel_round),],liquid_part_EPI[which.min(liquid_part_EPI$tau_rel_round),])








plot_counts(liquid_part_EPI$tau_rel_round, liquid_part_EPI$Gprime_rel   ,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprimeprime)

plot_counts(transition_EPI$tau_rel_round, transition_EPI$Gprimeprime_rel  ,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprimeprime)

plot_counts(solid_part_EPI$tau_rel_round, solid_part_EPI$Gprime_rel , sd_y=solid_part_EPI_sd$Gprime_rel,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprime)








load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")


current_start=1


segments=c(35,34,33)
started=FALSE

for(ind in 1:length(segments))
{
    
    current_data =stress_sweeps_juvederm[(current_start):(current_start+segments[ind]-1),]
    
    G0 = mean(current_data$Gprime_Pa[current_data$tau_Pa<5])
    current_data$tau_rel = current_data$tau_Pa/G0
    
    current_start=current_start+segments[ind]
    material = paste("Juvederm",sep="")
    
    
    
    current_data$logGamma = log(current_data$Gamma_in_percent)
    current_data$logGprime_Pa = log(current_data$Gprime_Pa)
    current_data$logGprimeprime_Pa = log(current_data$Gprimeprime_Pa)
    
    yield_strain=exp(evaluateYield(current_data,
    Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma"))[["logGamma"]]/100
    
    current_data$tau_rel = current_data$tau_Pa/current_data$Gprime_Pa[1]
    
    yield_tau_rel=evaluateYield(current_data,         Gprime_column="Gprime_Pa",Gprimeprime_column="Gprimeprime_Pa",abscissa="logGamma",additional_columns_to_be_interpolated="tau_rel")[["tau_rel"]]
    
    if(!started)
    {
        yield_info_juvederm=data.frame(material=material,strain=yield_strain,tau_rel=yield_tau_rel)
        started=TRUE
        
    } else
    {
        yield_info_juvederm=rbind(yield_info_juvederm,
        data.frame(material=material,strain=yield_strain,tau_rel=yield_tau_rel))
        
    }
    
    
    
    
    
    
}


target_G0prime=c(1000)

target_tau_rel = mean(yield_info_juvederm$tau_rel)*mean(stress_sweeps_juvederm$Gprime_Pa[stress_sweeps_juvederm$tau_Pa<5])/target_G0prime

lines(x=rep(target_tau_rel,2),y=ylim,col="red")


# Add the simulations

load("/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/overview_simulation_force_law_jumps_corrected.rda")

overview_simulation_force_law$Gprime_Pa[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]

overview_simulation_force_law$Gprimeprime_Pa[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]

overview_plateau_particles=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01 &  overview_simulation_force_law$Friction_coefficient %in% c(0.01,0.8) ,]



# For normalization in this case we take the plateau which is clearly established in the frictional case


overview_plateau_particles_high_friction=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01 &  overview_simulation_force_law$Friction_coefficient %in% c(1) ,]

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected.rda")

overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]

particle_sel =
overview_simulation$packing_fraction==1.5 &
overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres==10000 &
overview_simulation$Friction_coefficient==0.01 &
overview_simulation$remove_link_fraction %in% c(0.4) &
overview_simulation$Sample_type=="particles"


G0prime_simulation = mean(c(overview_simulation$Gprime_Pa[ overview_simulation$Strain_amplitude<=0.005 & particle_sel],overview_plateau_particles_high_friction$Gprime_Pa[overview_plateau_particles_high_friction$Strain_amplitude<=0.005]))


overview_plateau_particles$G_Pa = sqrt(overview_plateau_particles$Gprime_Pa^2+overview_plateau_particles$Gprimeprime_Pa^2)

overview_plateau_particles_agg=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=mean)

overview_plateau_particles_agg_sd=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=sd)


upper_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa + qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

upper_stress = overview_plateau_particles_agg$Stress + qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude

lower_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa - qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

lower_stress = overview_plateau_particles_agg$Stress - qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude



overview_plateau_particles_agg_solid = overview_plateau_particles_agg[overview_plateau_particles_agg$Gprime_Pa>=overview_plateau_particles_agg$Gprimeprime_Pa,]

grps=plot_counts(overview_plateau_particles_agg$Stress/G0prime_simulation,overview_plateau_particles_agg$Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg$Sample_type,"r"=overview_plateau_particles_agg$remove_link_fraction,"p=",overview_plateau_particles_agg$plateau_law,"s=",overview_plateau_particles_agg$plateau_slope,"f=",overview_plateau_particles_agg$relative_frequency,"F=",overview_plateau_particles_agg$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=21,col=c("blue","red","green","yellow","purple","black","grey"),type="l",lwd=1,lty=2)

grps=plot_counts(upper_stress/G0prime_simulation,upper_Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg$Sample_type,"r"=overview_plateau_particles_agg$remove_link_fraction,"p=",overview_plateau_particles_agg$plateau_law,"s=",overview_plateau_particles_agg$plateau_slope,"f=",overview_plateau_particles_agg$relative_frequency,"F=",overview_plateau_particles_agg$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=21,col=c("blue","red","green","yellow","purple","black","grey"),type="l",lwd=1,lty=1)

grps=plot_counts(lower_stress/G0prime_simulation,lower_Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg$Sample_type,"r"=overview_plateau_particles_agg$remove_link_fraction,"p=",overview_plateau_particles_agg$plateau_law,"s=",overview_plateau_particles_agg$plateau_slope,"f=",overview_plateau_particles_agg$relative_frequency,"F=",overview_plateau_particles_agg$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=21,col=c("blue","red","green","yellow","purple","black","grey"),type="l",lwd=1,lty=1)


grps=plot_counts(overview_plateau_particles_agg_solid$Stress/G0prime_simulation,overview_plateau_particles_agg_solid$Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg_solid$Sample_type,"r"=overview_plateau_particles_agg_solid$remove_link_fraction,"p=",overview_plateau_particles_agg_solid$plateau_law,"s=",overview_plateau_particles_agg_solid$plateau_slope,"f=",overview_plateau_particles_agg_solid$relative_frequency,"F=",overview_plateau_particles_agg_solid$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=-1,col=c("blue","red","green","yellow","purple","black","grey"),cex=2,type="l",lwd=4)


legend("bottomleft",pch=c(rep(21,4),-1,-1),lty=c(rep(-1,4),1,1),pt.bg=grey(c(1,0.8,0.5,0,0,0)),col=c(rep("black",4),"blue","red"),legend=c("Collagen 0.1","Collagen 0.03","Collagen 0.01","uncoated","Simulation: High porosity","Simulation: High porosity \n  + High friction"),cex=1.5)



dev.off()

# Reporting

cat("Group size reporting (Item 62)")
cat("\nuncoated EPI")
cat("\n",length(unique(EPI_control$ID)), "sweeps",sep=" ")

cat("\nSweeps with collagen-coated EPI")
n_coating=aggregate(overview_index ~ Mass_fraction_coating, stress_sweeps_coating[stress_sweeps_coating$Coating %in% c("None","Collagen") & stress_sweeps_coating$Mass_fraction_coating %in% c(0.01,0.03,0.1),],FUN=function(x){length(unique(x))})
colnames(n_coating)[colnames(n_coating)=="overview_index"]="n"
n_coating


cat("\nSimulations")
nsim=aggregate(Gprime_Pa~Strain_amplitude+Friction_coefficient,overview_plateau_particles,FUN=length)
colnames(nsim)[colnames(nsim)=="Gprime_Pa"]="n"
nsim
cat("\nTotal simulations per friction coefficient")
aggregate(n~Friction_coefficient,nsim,FUN=sum)






















