
library(plot.counts)
library(rheologyEvaluation)
library(effsize)


load(file="/data/Evaluation/Rheology/Stress Sweeps/EPI_coating/stress_sweeps_coating.rda")


load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")




# Here, we compare absolute values rather than master curves, so it is
# important to use only a narrow range of concentrations. Also, limit
# to the plate-plate geometry
EPI_to_use = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 24 & stress_sweeps_EPI_all$polymer_conc_mgmL<=28 & stress_sweeps_EPI_all$Geometry=="plate"  ,]


EPI_to_use$Coating = "None"
EPI_to_use$Mass_fraction_coating = 0
EPI_to_use$overview_index = NA
EPI_to_use$Gprime_normalization = EPI_to_use$Gprime_Pa_0
EPI_to_use$Gprime_rel = EPI_to_use$Gprime_Pa/EPI_to_use$Gprime_normalization
EPI_to_use$Gprimeprime_rel = EPI_to_use$Gprimeprime_Pa/EPI_to_use$Gprime_normalization
EPI_to_use$tau_rel = EPI_to_use$tau_Pa/EPI_to_use$Gprime_normalization



# Provide a unique ID

stress_sweeps_coating$ID=paste("coating",stress_sweeps_coating$overview_index,sep="_")

# Exclude duplicates since we will assemble later on

stress_sweeps_coating=stress_sweeps_coating[!(stress_sweeps_coating$ID %in% unique(EPI_to_use$ID)),]




stress_sweeps_coating$Gprime_normalization = overview_coating$Gprime[stress_sweeps_coating$overview_index]

stress_sweeps_coating$Gprime_rel = stress_sweeps_coating$Gprime_Pa/stress_sweeps_coating$Gprime_normalization

stress_sweeps_coating$Gprimeprime_rel = stress_sweeps_coating$Gprimeprime_Pa/stress_sweeps_coating$Gprime_normalization


stress_sweeps_coating$tau_rel = stress_sweeps_coating$tau_Pa/stress_sweeps_coating$Gprime_normalization


common_colnames = colnames(stress_sweeps_coating)[colnames(stress_sweeps_coating) %in% colnames(EPI_to_use)]

EPI_to_use$ID=paste(EPI_to_use$file, EPI_to_use$folder) # There are some instances
# where the samples were prepared from a common bulk, without separate readjustment
# of humidity (although the samples by themselves are independent, the bulk is the same). Here, the absolute values are particularly important, and so
# contrary to the master curve, these samples should be counted as 1. This is achieved
# by using the file rather than the measurement ID

stress_sweeps_coating=rbind(stress_sweeps_coating[,common_colnames],EPI_to_use[,common_colnames])


# Limit here to the collagen coating case

stress_sweeps_coating=stress_sweeps_coating[stress_sweeps_coating$Coating %in% c("Collagen","None"),]

# Also, only the coating fractions where we also have cell adhesion data

stress_sweeps_coating=stress_sweeps_coating[stress_sweeps_coating$Mass_fraction_coating %in% c(0,0.01,0.03,0.1),]





# To have the structure, the value of the yield stress tau_Pa will be changed below

yield_info=aggregate(tau_Pa ~ ID + Mass_fraction_coating,stress_sweeps_coating,FUN=max)

yield_info$tau_Pa = NA

yield_info$Gprime_0=NA
yield_info$strain = NA

for(theID in yield_info$ID)
{
    yield_info$Gprime_0[yield_info$ID==theID]=mean(stress_sweeps_coating$Gprime_Pa[stress_sweeps_coating$ID==theID & stress_sweeps_coating$tau_Pa < 2])
    
    theSweep = stress_sweeps_coating[stress_sweeps_coating$ID==theID,]
    theSweep$logGamma = log(theSweep$Gamma_in_percent)
    
    yield_info$strain[yield_info$ID==theID] = exp(evaluateYield(theSweep,abscissa="logGamma"))[["logGamma"]]/100
    
    yield_info$tau_Pa[yield_info$ID==theID] = evaluateYield(theSweep,abscissa="logGamma",additional_columns_to_be_interpolated="tau_Pa")[["tau_Pa"]]
    
    
}

yield_info$tau_rel = yield_info$tau_Pa/yield_info$Gprime_0

yield_info_agg=aggregate(yield_info[,c("tau_Pa","Gprime_0","strain","tau_rel")],by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=mean)


yield_info_agg_sd=aggregate(yield_info[,c("tau_Pa","Gprime_0","strain","tau_rel")],by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=sd)

yield_info_agg_n=aggregate(yield_info[,c("tau_Pa","Gprime_0","strain","tau_rel")],by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=length)





# Primary evaluation of the P-values: t-test
pvals_tau_rel=get_t_test_matrix(treatment_factor=yield_info$Mass_fraction_coating,data=yield_info$tau_rel)

# Check: For the groups that do follow normal distribution, we need to use non-parametric test
pvals_shapiro_tau_rel=aggregate(yield_info[,c("tau_rel")],by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=function(x){shapiro.test(x)$p.value})

coating_groups_not_normal_tau_rel = pvals_shapiro_tau_rel$Mass_fraction_coating[pvals_shapiro_tau_rel$x<0.05]

# For all tests against a non-normally distributed group, we need wilcoxon testing (non-parametric)
if(length(coating_groups_not_normal_tau_rel)>0)
{
    for(group1 in coating_groups_not_normal_tau_rel)
    {
        for(group2 in as.numeric(rownames(pvals_tau_rel)))
        {
            if(group1 != group2 )
            {
                pvals_tau_rel[as.character(group1),as.character(group2)]= wilcox.test(yield_info$tau_rel[yield_info$Mass_fraction_coating==group1],yield_info$tau_rel[yield_info$Mass_fraction_coating==group2])$p.value
                
                pvals_tau_rel[as.character(group2),as.character(group1)]= wilcox.test(yield_info$tau_rel[yield_info$Mass_fraction_coating==group1],yield_info$tau_rel[yield_info$Mass_fraction_coating==group2])$p.value
                
            }
        }
    }
    
    
}





# Primary evaluation of the P-values: t-test
pvals_strain=get_t_test_matrix(treatment_factor=yield_info$Mass_fraction_coating,data=yield_info$strain)

# Check: For the groups that do follow normal distribution, we need to use non-parametric test
pvals_shapiro_strain=aggregate(yield_info[,c("strain")],by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=function(x){shapiro.test(x)$p.value})

coating_groups_not_normal_strain = pvals_shapiro_strain$Mass_fraction_coating[pvals_shapiro_strain$x<0.05]

# For all tests against a non-normally distributed group, we need wilcoxon testing (non-parametric)
if(length(coating_groups_not_normal_strain)>0)
{
    for(group1 in coating_groups_not_normal_strain)
    {
        for(group2 in as.numeric(rownames(pvals_strain)))
        {
            if(group1 != group2 )
            {
                pvals_strain[as.character(group1),as.character(group2)]= wilcox.test(yield_info$strain[yield_info$Mass_fraction_coating==group1],yield_info$strain[yield_info$Mass_fraction_coating==group2])$p.value
                
                pvals_strain[as.character(group2),as.character(group1)]= wilcox.test(yield_info$strain[yield_info$Mass_fraction_coating==group1],yield_info$strain[yield_info$Mass_fraction_coating==group2])$p.value
                
            }
        }
    }
    
    
}









Bonferroni_factor = 3

pdf(file="fig_5f_and_5g.pdf")

par(mfrow=c(2,1),mai = c(0.2, 1, 0.2, 0.1))







xpos=barplot_with_errorbars(yield_info_agg$tau_rel,sd_height=yield_info_agg_sd$tau_rel,sig_codes=significance_labels(pvals_tau_rel[1,]*Bonferroni_factor,codes = c("",
"*", "**", "***")),names.arg=yield_info_agg$Mass_fraction_coating*100,
ylab="Relative yield stress",sig.cex=3)

for(ind in 1:length(sort(unique(yield_info_agg$Mass_fraction_coating))))
{
    to_plot = yield_info[yield_info$Mass_fraction_coating==sort(unique(yield_info_agg$Mass_fraction_coating))[ind],]
    plot_dot_column(rep(xpos[ind],length(to_plot$tau_rel)),to_plot$tau_rel,cex=2,lateral_shift=0.025,y_threshold_for_shifting=0.01,pch=21,bg="black")
}



load("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda")


# For defining the target relative yield stress: At least 1kPa low-strain modulus for the same
# absolute yield stress (in Pa) than Juvederm => allows to define required relative yield stress as
# the ratio between Juvederm yield stress in Pa divided by 1kPa

target_G0prime=c(1000)

yield_info_for_limit_agg=aggregate(yield_info_all_materials[,c("strain","tau_rel")],by=list(material=yield_info_all_materials$material),FUN=mean)

load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")


target_tau_rel = yield_info_for_limit_agg$tau_rel[yield_info_for_limit_agg$material=="Juvederm"]*mean(stress_sweeps_juvederm$Gprime_Pa[stress_sweeps_juvederm$tau_Pa<5])/target_G0prime


lines(c(min(xpos),max(xpos)),rep(target_tau_rel,2),lty=2,lwd=2)


par(mai = c(0.8, 1, 0.05, 0.1))

xpos=barplot_with_errorbars(yield_info_agg$strain,sd_height=yield_info_agg_sd$strain,sig_codes=significance_labels(pvals_strain[1,]*Bonferroni_factor,codes = c("",
"*", "**", "***")),names.arg=yield_info_agg$Mass_fraction_coating*100,
xlab="Mass fraction Collagen [%]",ylab="Yield strain",sig.cex=3)

for(ind in 1:length(sort(unique(yield_info_agg$Mass_fraction_coating))))
{
    to_plot = yield_info[yield_info$Mass_fraction_coating==sort(unique(yield_info_agg$Mass_fraction_coating))[ind],]
    plot_dot_column(rep(xpos[ind],length(to_plot$strain)),to_plot$strain,cex=2,lateral_shift=0.1,y_threshold_for_shifting=0.1,pch=21,bg="black")
}


# Here, the desired minimum is 0.5 for physiological movement
lines(c(min(xpos),max(xpos)),rep(0.5,2),lty=2,lwd=2)





dev.off()

# Reporting: Normal distribution testing. This needs to be done for all concentrations and points


cat("\n\nGroup sizes (applies to both 5f and 5g, e.g. Items 64 and 65)")

aggregate(list(N=yield_info[,c("strain")]),by=list(Mass_fraction_coating=yield_info$Mass_fraction_coating),FUN=length)

cat("\n\nShapiro-Wilks normality testing per group (Coating percentage)")
cat("\nRelative shear stress (5f, item 64)\n")
colnames(pvals_shapiro_tau_rel)[colnames(pvals_shapiro_tau_rel)=="x"]="P"
pvals_shapiro_tau_rel



cat("\n\nFor the P-values smaller than 0.05 we used Wilcoxon testing for the pairwise tests involved, for the other t-tests")

cat("\n5f (t-tests only")
group1=0
      for(group2 in as.numeric(rownames(pvals_tau_rel)))
        {
            if(group1 != group2 )
            {
                cat(paste("\nComparing collagen ",group1," to collagen ",group2,sep=""))
                print(t.test(yield_info$tau_rel[yield_info$Mass_fraction_coating==group2],yield_info$tau_rel[yield_info$Mass_fraction_coating==group1]))
                
            }
        }


cat("\n5f Effect size (Hedge's g)")
group1=0
for(group2 in as.numeric(rownames(pvals_tau_rel)))
{
    if(group1 != group2 )
    {
        cat(paste("\nComparing collagen ",group1," to collagen ",group2,sep=""))
        print(cohen.d(yield_info$tau_rel[yield_info$Mass_fraction_coating==group2],yield_info$tau_rel[yield_info$Mass_fraction_coating==group1],hedges.correction=TRUE))
        
    }
}

cat("\n5f P-vals after Bonferroni correction")
p_vals_tau_rel_Bonferroni=pvals_tau_rel[1,]*Bonferroni_factor
p_vals_tau_rel_Bonferroni[p_vals_tau_rel_Bonferroni>1]=1
p_vals_tau_rel_Bonferroni




cat("\n\nShapiro-Wilks normality testing per group (Coating percentage)")
cat("\nShear strain (5g, item 65)")
colnames(pvals_shapiro_strain)[colnames(pvals_shapiro_strain)=="x"]="P"
pvals_shapiro_strain


cat("\n5g (t-tests if normality satisfied, Wilcox (aka Mann-Whitney u)")
group1=0
for(group2 in as.numeric(rownames(pvals_tau_rel)))
{
    if(group1 != group2 )
    {
        if(pvals_shapiro_strain$P[pvals_shapiro_strain$Mass_fraction_coating==group1]>0.05 &pvals_shapiro_strain$P[pvals_shapiro_strain$Mass_fraction_coating==group2]>0.05)
        {
        cat(paste("\nComparing collagen ",group1," to collagen ",group2,sep=""))
        print(t.test(yield_info$strain[yield_info$Mass_fraction_coating==group2],yield_info$strain[yield_info$Mass_fraction_coating==group1]))
        } else {
          print(wilcox.test(yield_info$strain[yield_info$Mass_fraction_coating==group2],yield_info$strain[yield_info$Mass_fraction_coating==group1],conf.int=TRUE))
        }
        
    }
}

cat("\n5g effect size (Hedge's g if normality satisfied, otherwise r^2=Z/n from Wilcoxon testing")
group1=0
for(group2 in as.numeric(rownames(pvals_tau_rel)))
{
    if(group1 != group2 )
    {
        if(pvals_shapiro_strain$P[pvals_shapiro_strain$Mass_fraction_coating==group1]>0.05 &pvals_shapiro_strain$P[pvals_shapiro_strain$Mass_fraction_coating==group2]>0.05)
        {
            cat(paste("\nEffect size collagen ",group1," to collagen ",group2,", Cohen's d",sep=""))
            print(cohen.d(yield_info$strain[yield_info$Mass_fraction_coating==group2],yield_info$strain[yield_info$Mass_fraction_coating==group1],hedges.correction=TRUE))
        } else {
            cat(paste("\nEffect size collagen ",group1," to collagen ",group2,", r2 from P-value of Wilcoxon test",sep=""))
            Z_wilcox=qnorm(0.5+(1-wilcox.test(yield_info$strain[yield_info$Mass_fraction_coating==group2],yield_info$strain[yield_info$Mass_fraction_coating==group1])$p.val)/2)
            # Then convert to R-squared using the Fritz. et al. formula
            r2=Z_wilcox^2/(length(yield_info$strain[yield_info$Mass_fraction_coating==group2])+length(yield_info$strain[yield_info$Mass_fraction_coating==group1]))

            
            
            print(r2)
        }
        
    }
}

cat("\n5g P-vals after Bonferroni correction")
p_vals_strain_Bonferroni=pvals_strain[1,]*Bonferroni_factor
p_vals_strain_Bonferroni[p_vals_strain_Bonferroni>1]=1
p_vals_strain_Bonferroni




