# The functions kurtosis (package moments, hidden), sf.test (package nortest, hidden), roystonTest (package MVN) are copied from their respective libraries. The reasons for copying these
# functions rather than installing the libraries is that
# MVN somehow does not install. There are indeed some
# some issues with installing this package in Ubuntu
# (the underlying car package seems difficult to install), but fortunately, the roystonTest function is dependent on only this
# handful of function + the class definition of royston


# Kurtosis. From package moments, used getAnywhere to get the source code
kurtosis<-function (x, na.rm = FALSE)
{
    if (is.matrix(x))
    apply(x, 2, kurtosis, na.rm = na.rm)
    else if (is.vector(x)) {
        if (na.rm)
        x <- x[!is.na(x)]
        n <- length(x)
        n * sum((x - mean(x))^4)/(sum((x - mean(x))^2)^2)
    }
    else if (is.data.frame(x))
    sapply(x, kurtosis, na.rm = na.rm)
    else kurtosis(as.vector(x), na.rm = na.rm)
}
# sf.test function from package nortest. This function is hidden, used getAnywhere to get the source code
sf.test<-function (x)
{
    DNAME <- deparse(substitute(x))
    x <- sort(x[complete.cases(x)])
    n <- length(x)
    if ((n < 5 || n > 5000))
    stop("sample size must be between 5 and 5000")
    y <- qnorm(ppoints(n, a = 3/8))
    W <- cor(x, y)^2
    u <- log(n)
    v <- log(u)
    mu <- -1.2725 + 1.0521 * (v - u)
    sig <- 1.0308 - 0.26758 * (v + 2/u)
    z <- (log(1 - W) - mu)/sig
    pval <- pnorm(z, lower.tail = FALSE)
    RVAL <- list(statistic = c(W = W), p.value = pval, method = "Shapiro-Francia normality test",
    data.name = DNAME)
    class(RVAL) <- "htest"
    return(RVAL)
}

# Class definition for Royston test, from 
setClass("royston", slots=list(H="numeric",p.value="numeric", dname="character", dataframe="data.frame"))

# from R package MVN
roystonTest<-function (data, qqplot = FALSE)
{
    if (dim(data)[2] < 2 || is.null(dim(data))) {
        stop("number of variables must be equal or greater than 2")
    }
    if (!is.data.frame(data) && !is.matrix(data))
    stop("Input must be one of classes \"data frame\" or \"matrix\"")
    dataframe = as.data.frame(data)
    dname <- deparse(substitute(data))
    data <- data[complete.cases(data), ]
    data <- as.matrix(data)
    p <- dim(data)[2]
    n <- dim(data)[1]
    z <- matrix(nrow <- p, ncol = 1)
    z <- as.data.frame(z)
    w <- matrix(nrow <- p, ncol = 1)
    w <- as.data.frame(w)
    data.org <- data
    if (n <= 3) {
        stop("n must be greater than 3")
    }
    else if (n >= 4 || n <= 11) {
        x <- n
        g <- -2.273 + 0.459 * x
        m <- 0.544 - 0.39978 * x + 0.025054 * x^2 - 0.0006714 *
        x^3
        s <- exp(1.3822 - 0.77857 * x + 0.062767 * x^2 - 0.0020322 *
        x^3)
        for (i in 1:p) {
            a2 <- data[, i]
            {
                if (kurtosis(a2) > 3) {
                    w <- sf.test(a2)$statistic
                }
                else {
                    w <- shapiro.test(a2)$statistic
                }
            }
            z[i, 1] <- (-log(g - (log(1 - w))) - m)/s
        }
    }
    if (n > 2000) {
        stop("n must be less than 2000")
    }
    else if (n >= 12 || n <= 2000) {
        x <- log(n)
        g <- 0
        m <- -1.5861 - 0.31082 * x - 0.083751 * x^2 + 0.0038915 *
        x^3
        s <- exp(-0.4803 - 0.082676 * x + 0.0030302 * x^2)
        for (i in 1:p) {
            a2 <- data[, i]
            {
                if (kurtosis(a2) > 3) {
                    w <- sf.test(a2)$statistic
                }
                else {
                    w <- shapiro.test(a2)$statistic
                }
            }
            z[i, 1] <- ((log(1 - w)) + g - m)/s
        }
    }
    else {
        stop("n is not in the proper range")
    }
    u <- 0.715
    v <- 0.21364 + 0.015124 * (log(n))^2 - 0.0018034 * (log(n))^3
    l <- 5
    C <- cor(data)
    NC <- (C^l) * (1 - (u * (1 - C)^u)/v)
    T <- sum(sum(NC)) - p
    mC <- T/(p^2 - p)
    edf <- p/(1 + (p - 1) * mC)
    Res <- matrix(nrow = p, ncol = 1)
    Res <- as.data.frame(Res)
    for (i in 1:p) {
        Res <- (qnorm((pnorm(-z[, ]))/2))^2
    }
    data <- scale(data, scale = FALSE)
    Sa <- cov(data)
    D <- data %*% solve(Sa) %*% t(data)
    if (qqplot) {
        d <- diag(D)
        r <- rank(d)
        chi2q <- qchisq((r - 0.5)/n, p)
        plot(d, chi2q, pch = 19, main = "Chi-Square Q-Q Plot",
        xlab = "Squared Mahalanobis Distance", ylab = "Chi-Square Quantile")
        abline(0, 1, lwd = 2, col = "black")
    }
    RH <- (edf * (sum(Res)))/p
    pv <- pchisq(RH, edf, lower.tail = FALSE)
    result <- new("royston", H = RH, p.value = pv, dname = dname,
    dataframe = dataframe)
    result
}





# Helper function for the f confidence intervals using the non-centrality parameter
F_confint<-function(F,df1,df2,alpha)
{
    
    
    # The here is that the F-value measured is the median, such that
    # pf(F,df1,df2,ncp)=0.5
    
    if(pf(F,df1,df2,0)<=0.5)
    {
       ncp=0
        
    } else {
    ncp = uniroot(function(x){pf(F,df1,df2,x)}-0.5,c(0,F*100*df1))$root
    }
    
    
    return(qf(c(alpha/2,1-alpha/2),df1,df2,ncp))
    
    
    
    
    
}

# anova comparison of multiple multi-output variable linear models in R can be done by using the function anova. This launches the dedicated method "anova.mlmlist", in package stats. This function is 
#normally hidden from direct access, but is visible through stats:::anova.mlmlist. We used the Wilks statistic in this function, since r^2 can be derived from this by 1-Wilk's lambda
# Here, we extend this functionality a bit by also calculating the confidence interval for Wilk's lambda from the underlying F statistics
# The source code itself is mostly reworked from stats:::anova.mlmlist and stats:::Wilks
wilks_confint<-function(complete_model,control_model)
{

# Some reverse engineering for getting the Wilks relation (from stats:::anova.mlmlist); the idea is to reconstitute the function linking the Wilks statistics to the F value, so that we can calculate back
# the confidence interval for the Wilk statistics
 p <- ncol(SSD(complete_model)$SSD)
objects=list(complete_model,control_model)
resdf <- as.numeric(lapply(objects, df.residual))
df <- c(NA, diff(resdf))
nmodels <- length(objects)
resssd <- lapply(objects, SSD)
deltassd <- mapply(function(x, y) y$SSD - x$SSD, resssd[-nmodels],
resssd[-1L], SIMPLIFY = FALSE)

i=2
sg <- (df[i] > 0) - (df[i] < 0)
bigmodel <- order(resdf)[1L]

q=sg * df[i]
df.res=resdf[bigmodel]

# From stats:::Wilks
test <- anova(complete_model,control_model,test="Wilks")$Wilks[2]
p <- 2 # This is because we happen to have two indepently contributing responses, strain and relative stress
tmp1 <- df.res - 0.5 * (p - q + 1)
tmp2 <- (p * q - 2)/4
tmp3 <- p^2 + q^2 - 5
tmp3 <- if (tmp3 > 0)
sqrt(((p * q)^2 - 4)/tmp3) else 1
dfnum=p * q
dfden=tmp1 * tmp3 - 2 * tmp2

# This is the actually observed F
F=anova(complete_model,control_model,test="Wilks")$"approx F"[2]
# Get the associated F confidence interval
F_interval<-F_confint(F,dfnum,dfden,0.05)

# and so we basically have the reverse function as
test=(1+F_interval*p*q/(tmp1 * tmp3 - 2 * tmp2))^(-tmp3)

return(test)



}



# Confidence intervals for Mahalanobis distance: This is outlined in Reiser, B. CONFIDENCE INTERVALS FOR THE MAHALANOBIS DISTANCE. Communications in Statistics - Simulation and Computation 30, 37-45, doi:10.1081/SAC-100001856 (2001).


# Helper function for the f confidence intervals (also from the above paper)
F_confint_Reiser<-function(F,df1,df2,alpha)
{


if(F==0)
{
    # Cannot not calculate much with F=0
    return(rep(NA,2))
    
    
} else
{
    upper=NA
    lower=NA
    
    
    if(pf(F,df1,df2)<alpha/2)
    {
        upper=0
    } else
    {
        
        upper = uniroot(function(x){qf(alpha/2,df1,df2,x)}-F,c(0,F*100*df1))$root
    }
    
    if(pf(F,df1,df2)<1-alpha/2)
    {
        lower=0
    } else
    {
        
        lower = uniroot(function(x){qf(1-alpha/2,df1,df2,x)}-F,c(0,F*100))$root
        
    }
    
    return(c(lower,upper))
}


}







