library(plot.counts)
library(effsize)


pdf("Fig_C11.pdf")

load("/data/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda")

start_point = aggregate(t_s_relative ~overview_index,self_healing_kinetics[self_healing_kinetics$Segment=="shear",],FUN=max)

self_healing_kinetics$t_s_relative=self_healing_kinetics$t_s_relative-start_point$t_s_relative[match(self_healing_kinetics$overview_index,start_point$overview_index)]-5


baseline_Gprime=aggregate(Gprime_Pa ~ overview_index, self_healing_kinetics[self_healing_kinetics$Segment=="baseline",],FUN=function(x){x[length(x)]})

overview_self_healing_kinetics$Gprime_Pa_baseline = baseline_Gprime$Gprime_Pa[match(1:(dim(overview_self_healing_kinetics)[1]),baseline_Gprime$overview_index)]




overview_self_healing_kinetics$Gprime_Pa_30s=0
overview_self_healing_kinetics$Gprime_Pa_15min=0


for(ind in 1:(dim(overview_self_healing_kinetics)[1]))
{
    recovery_segment = self_healing_kinetics[self_healing_kinetics$overview_index==ind & self_healing_kinetics$Segment=="recovery",]
    
    ind_15min = which.min(abs(recovery_segment$t_s_relative-15*60))
    
    ind_30s = which.min(abs(recovery_segment$t_s_relative-30))
    
    overview_self_healing_kinetics$Gprime_Pa_15min[ind]=recovery_segment$Gprime_Pa[ind_15min]
    overview_self_healing_kinetics$Gprime_Pa_30s[ind]=recovery_segment$Gprime_Pa[ind_30s]
   
    
    
}








selected_probe_stress=c(0.2,0.5,2,5,20,50)

selected_stress_overview = overview_self_healing_kinetics[overview_self_healing_kinetics$Tau_Pa%in%selected_probe_stress,]

selected_stress_overview$change_ratio = selected_stress_overview$Gprime_Pa_15min/selected_stress_overview$Gprime_Pa_30s

selected_stress_overview_agg = aggregate(change_ratio ~ Tau_Pa,selected_stress_overview,FUN=mean)
selected_stress_overview_agg_sd = aggregate(change_ratio ~ Tau_Pa,selected_stress_overview,FUN=sd)
selected_stress_overview_agg_n = aggregate(change_ratio ~ Tau_Pa,selected_stress_overview,FUN=length)

colnames(selected_stress_overview_agg_n)[colnames(selected_stress_overview_agg_n)=="change_ratio"]="n"

tm=get_t_test_matrix(treatment_factor=selected_stress_overview$Tau_Pa, data=selected_stress_overview$change_ratio,paired=TRUE)



pvals=(tm["0.2",])*(length(tm["0.2",])-1) # Bonferroni correction, self-testing of the 0.2Pa recovery against itself excluded


pvals_normality=vector(mode="numeric",length=length(pvals))

pvals_normality[]=NA

for(ind in 1:length(pvals_normality))
{
    x=selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==selected_probe_stress[ind]]-selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==0.2]
    if(any(x!=0))
    {
        pvals_normality[ind]=shapiro.test(x)[["p.value"]]
    }
    
}

barplot_with_errorbars((selected_stress_overview_agg$change_ratio-1)*100,sd_height=selected_stress_overview_agg_sd$change_ratio*100,names.arg=selected_stress_overview_agg$Tau_Pa,
sig_codes=significance_labels(pvals),ylim=c(0,70),sig.cex=2.5,main="G' recovery",xlab="Probing stress [Pa]",ylab="Increase G' from 30s to 15min [%]")


# Reporting

cat("\nStatistical reporting: Slow recovery percentage, different probing stresses against 0.2Pa (Item 41)")

cat("\nSample size per probing stress level")
selected_stress_overview_agg_n


for(theProbeStress in selected_probe_stress[2:length(selected_probe_stress)])
{
cat(paste("\nNormality testing: Shapiro-Wilks on pooled residuals, probe stress ",theProbeStress,"Pa vs. 0.2Pa",sep=""))
print(shapiro.test(c(selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==theProbeStress]-mean(selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==theProbeStress]),selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==0.2]-mean(selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==0.2]))))
}

# For reporting, individual t-tests

for(theProbeStress in selected_probe_stress[2:length(selected_probe_stress)])
{
    cat(paste("\nT-tests for probe stress ",theProbeStress,"Pa vs. 0.2Pa",sep=""))
print(t.test(
selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==theProbeStress],
selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa==0.2],paired=TRUE))

}

for(theProbeStress in selected_probe_stress[2:length(selected_probe_stress)])
{
    cat(paste("\nEffect size for probe stress ",theProbeStress,"Pa vs. 0.2Pa",sep=""))
print(cohen.d(selected_stress_overview$change_ratio[selected_stress_overview$Tau_Pa %in% c(0.2,theProbeStress)],
as.factor(selected_stress_overview$Tau_Pa[selected_stress_overview$Tau_Pa %in% c(0.2,theProbeStress)]),paired=TRUE))

}

cat("\nP-values after Bonferroni correction")
pvals




dev.off()



