library(textureAnalyzerGels)
library(plot.counts)

load(file="/data/Evaluation/Simulation/plateau_law/plateau_contact_law_fig_5e.rda")

load(file="/data/Evaluation/Uniaxial compression/bulk/bulk_1_5_uniaxial_compression.rda")

# Load Python-generated force file

pdf("Fig_C12.pdf")

# Use the textureAnalyzerGels library to do automated interpretation and evaluation of the curves
comparison_analysis=foam_mechanical_analysis_list(overview_bulk_compression,compression_data_bulk)

# Transform results to dataframe for easier handling
comparison_analysis_dataframe = analysis_list_to_dataframe(overview_bulk_compression,comparison_analysis)
comparison_analysis_dataframe[ comparison_analysis_dataframe$point=="elastic" & comparison_analysis_dataframe$measurement=="E" & comparison_analysis_dataframe$direction=="down" ,]



cat(paste("E=",mean(comparison_analysis_dataframe[comparison_analysis_dataframe$measurement=="E" & comparison_analysis_dataframe$point=="elastic" & comparison_analysis_dataframe$direction=="down" ,"value"])),
"+/-",sd(comparison_analysis_dataframe[comparison_analysis_dataframe$measurement=="E" & comparison_analysis_dataframe$point=="elastic" & comparison_analysis_dataframe$direction=="down" ,"value"]))

cat(paste("Eplateau=",mean(comparison_analysis_dataframe[comparison_analysis_dataframe$measurement=="E" & comparison_analysis_dataframe$point=="plateau" & comparison_analysis_dataframe$direction=="down" ,"value"])),
"+/-",sd(comparison_analysis_dataframe[comparison_analysis_dataframe$measurement=="E" & comparison_analysis_dataframe$point=="plateau" & comparison_analysis_dataframe$direction=="down" ,"value"]))


to_aggregate=c("pressure","pressureSlope")

by_cols=c("Strain_round","direction")


for(ind in 1:(length(compression_data_bulk)))
{
    compression_data_bulk[[ind]]$Strain=(compression_data_bulk[[ind]]$Distance-mean(comparison_analysis[[ind]]$Distance[,"touchpoint"]))/comparison_analysis[[ind]]$gel_height
    
    compression_data_bulk[[ind]]$Strain_round=round(compression_data_bulk[[ind]]$Strain*200)/200
    
    compression_agg=aggregate(compression_data_bulk[[ind]][,to_aggregate],by= compression_data_bulk[[ind]][,by_cols],FUN=mean)
    
    compression_agg$overview_index=ind
    
    compression_agg$pressureSlope = compression_agg$pressureSlope*comparison_analysis[[ind]]$gel_height
    
    if(ind==1)
    {
        
        compression_agg_all = compression_agg
    } else
    {
        compression_agg_all=rbind(compression_agg_all, compression_agg)
    }
    
    
}

compression_single_curve = aggregate(compression_agg_all[,to_aggregate],by= compression_agg_all[,by_cols], FUN=mean)

compression_single_curve$pressure_sd = aggregate(compression_agg_all[,to_aggregate],by= compression_agg_all[,by_cols], FUN=sd)$pressure

compression_single_curve_N =aggregate(pressure ~ Strain_round + direction, compression_agg_all, FUN=length)

compression_single_curve=compression_single_curve[compression_single_curve_N$pressure == max(compression_single_curve_N$pressure),]

part_up=compression_single_curve[compression_single_curve$direction=="up",]
ord=order(part_up$Strain_round,decreasing=TRUE)

compression_single_curve[compression_single_curve$direction=="up",]=part_up[ord,]



compression_single_curve$Distance=compression_single_curve$Strain_round

compression_single_curve$Force=compression_single_curve$pressure

landmarks=find_landmarks_gel_compression(compression_single_curve, approximate_gel_touch_point=0)

foam_analysis=foam_mechanical_analysis(compression_single_curve,NULL,landmarks=landmarks,gel_thickness=1)

for_sd = compression_single_curve[compression_single_curve$direction=="down",]
for_sd = for_sd[which.min(abs(for_sd$Strain_round-0.5)),]

for_sd_up = compression_single_curve[compression_single_curve$direction=="up",]
for_sd_up = for_sd_up[which.min(abs(for_sd_up$Strain_round-0.5)),]








plot(compression_single_curve$Strain_round*100,compression_single_curve$pressure/1000 ,type="l",xlab="Compressive strain [%]",ylab="Stress [kPa]",las=1,cex.lab=2,cex.axis=2,main="Contact laws",xlim=c(0,100))

lines(compression_single_curve[compression_single_curve$direction=="down",]$Strain_round*100,compression_single_curve[compression_single_curve$direction=="down",]$pressure/1000  ,lwd=3)


plot_counts(for_sd$Strain_round*100,for_sd$pressure/1000,for_sd$pressure_sd/1000,plot.new=FALSE,type="l")


plot_counts(for_sd_up$Strain_round*100,for_sd_up$pressure/1000,for_sd_up$pressure_sd/1000,plot.new=FALSE,type="l")

legend("topleft",lwd=c(3,1,2,1,1),lty=c(1,1,1,2,1),col=c("black","black","red","red","red"),legend=c("Compression (Meas.)","Relaxation (Meas.)","Plateau law","Reeinforcement only","Linear"),cex=1.5)


lines(plateau_contact_law_fig_5e$Strain*100, plateau_contact_law_fig_5e$Force/1000,col="red",lwd=2)
lines(plateau_contact_law_fig_5e$Strain*100, plateau_contact_law_fig_5e$Force_plateau/1000,lty=2,col="red")
lines(plateau_contact_law_fig_5e$Strain*100,plateau_contact_law_fig_5e$Strain*2.5,col="red")



dev.off()







