
library(plot.counts)
library(rheologyEvaluation)




pdf("Fig_C13.pdf")



ylim=c(1e-3,1)

log_factor = 10 # For averaging in log intervals of the relative shear stress

cex_Gprime = 2 # Character expansion for G' curve

cex_Gprimeprime = 1 # Character expansion for G'' curve







load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")



# We collected EPI sweeps in quite extreme variations of concentrations. Focus here on the more relevant ones around 20-30 mg/mL. Also, there is one file where there are multiple sweeps in a single file, which we need to treat separately (below)

EPI_control = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 24 & stress_sweeps_EPI_all$polymer_conc_mgmL<=28 & stress_sweeps_EPI_all$Geometry=="plate"  ,]



EPI_control$tau_rel = EPI_control$tau_Pa/EPI_control$Gprime_Pa_0
EPI_control$tau_rel_round=exp(round(log(EPI_control$tau_rel)*log_factor)/log_factor)

EPI_control$Gprime_rel = EPI_control$Gprime_Pa/EPI_control$Gprime_Pa_0
EPI_control$Gprimeprime_rel = EPI_control$Gprimeprime_Pa/EPI_control$Gprime_Pa_0





sweeps_EPI_agg_per_ID = aggregate(EPI_control[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=EPI_control[,c("tau_rel_round","file","ID")],FUN=mean)


completed_sweeps_EPI = complete_sweeps(sweeps_EPI_agg_per_ID,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel"),sweep_identifier_column="ID")

sweeps_EPI_agg_per_file = aggregate(completed_sweeps_EPI[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps_EPI[,c("tau_rel_round","file")],FUN=mean)



sweeps_EPI_agg = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=mean)

sweeps_EPI_agg_sd = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=sd)

sweeps_EPI_agg_sd[-which.min(abs(sweeps_EPI_agg$Gprime_rel-0.5)),c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA



solid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]
solid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]


liquid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]
liquid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]

transition_EPI = rbind(solid_part_EPI[which.max(solid_part_EPI$tau_rel_round),],liquid_part_EPI[which.min(liquid_part_EPI$tau_rel_round),])



plot_counts(liquid_part_EPI$tau_rel_round,liquid_part_EPI$Gprime_rel,log="xy",xlab="Normalized shear stress",ylab="Normalized modulus ",type="b",pch=21,bg="black",col="black",cex=cex_Gprimeprime,ylim=ylim,xlim=c(1e-4,0.3),xaxt="n",yaxt="n",main="Simulation and EPI master curves")


axis(side=1,at=c((1:9)*1e-4,(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-4),rep("",8),1e-3,rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))

axis(side=2,at=c(c(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-3),rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))





plot_counts(transition_EPI$tau_rel_round, transition_EPI$Gprimeprime_rel  ,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprimeprime)

plot_counts(solid_part_EPI$tau_rel_round, solid_part_EPI$Gprime_rel , sd_y=solid_part_EPI_sd$Gprime_rel,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprime)












load("/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/overview_simulation_force_law_jumps_corrected.rda")

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected.rda")


overview_simulation_force_law$Gprime_Pa[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]

overview_simulation_force_law$Gprimeprime_Pa[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]

overview_plateau_particles=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01 &  overview_simulation_force_law$Friction_coefficient %in% c(0.01) ,]




overview_plateau_particles$G_Pa = sqrt(overview_plateau_particles$Gprime_Pa^2+overview_plateau_particles$Gprimeprime_Pa^2)

overview_plateau_particles_agg=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=mean)

overview_plateau_particles_agg_sd=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=sd)



overview_simulation_force_law$Gprime_Pa[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]

overview_regular_particles=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==0 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$Friction_coefficient %in% c(0.01) ,]

overview_plateau_particles_high_friction=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01 &  overview_simulation_force_law$Friction_coefficient %in% c(1) ,]


overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]




# Here, we are specifically interested in the partially crosslinked particles with internal friction surfaces (emulating opposing pore walls that can enter into friction in the actual EPI biomaterial)

particle_sel =
overview_simulation$packing_fraction==1.5 &
overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres==10000 &
overview_simulation$Friction_coefficient==0.01 &
overview_simulation$remove_link_fraction %in% c(0.4) &
overview_simulation$Sample_type=="particles"





upper_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa + qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

upper_stress = overview_plateau_particles_agg$Stress + qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude

lower_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa - qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

lower_stress = overview_plateau_particles_agg$Stress - qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude



overview_plateau_particles_agg_solid = overview_plateau_particles_agg[overview_plateau_particles_agg$Gprime_Pa>=overview_plateau_particles_agg$Gprimeprime_Pa,]

# This is assembled from both regular particles and plateau law, high friction particles which both have a nice plateau. The idea is to have a fixed reference value here, in Fig. S10-3, and also in Fig. 5e, 5f and 5g
G0prime_simulation = mean(c(overview_simulation$Gprime_Pa[ overview_simulation$Strain_amplitude<=0.005 & particle_sel],overview_plateau_particles_high_friction$Gprime_Pa[overview_plateau_particles_high_friction$Strain_amplitude<=0.005]))

lines(overview_plateau_particles_agg$Stress/G0prime_simulation,overview_plateau_particles_agg$Gprime_Pa/G0prime_simulation,pch=21,col=c("blue"),type="l",lwd=1,lty=1)
lines(overview_plateau_particles_agg_solid$Stress/G0prime_simulation,overview_plateau_particles_agg_solid$Gprime_Pa/G0prime_simulation,pch=21,col=c("blue"),type="l",lwd=4,lty=1)

lines(lower_stress/G0prime_simulation,lower_Gprime_Pa/G0prime_simulation,pch=21,col=c("blue"),type="l",lwd=1,lty=2)
lines(upper_stress/G0prime_simulation,upper_Gprime_Pa/G0prime_simulation,pch=21,col=c("blue"),type="l",lwd=1,lty=2)









overview_standard_particles=rbind(overview_regular_particles[,colnames(overview_simulation)],overview_simulation[particle_sel,])


overview_standard_particles$G_Pa = sqrt(overview_standard_particles$Gprime_Pa^2+overview_standard_particles$Gprimeprime_Pa^2)

overview_standard_particles_agg=aggregate(overview_standard_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=list(Strain_amplitude=overview_standard_particles[,c("Strain_amplitude")]),FUN=mean)

overview_standard_particles_agg_sd=aggregate(overview_standard_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=list(Strain_amplitude=overview_standard_particles[,c("Strain_amplitude")]),FUN=sd)

overview_standard_particles_agg_solid=overview_standard_particles_agg[overview_standard_particles_agg$Gprime_Pa>=overview_standard_particles_agg$Gprimeprime_Pa,]


upper_Gprime_Pa = overview_standard_particles_agg$Gprime_Pa + qnorm(0.975)*overview_standard_particles_agg_sd$Gprime_Pa

upper_stress = overview_standard_particles_agg$Stress + qnorm(0.975)*overview_standard_particles_agg_sd$G_Pa*overview_standard_particles_agg$Strain_amplitude

lower_Gprime_Pa = overview_standard_particles_agg$Gprime_Pa - qnorm(0.975)*overview_standard_particles_agg_sd$Gprime_Pa

lower_stress = overview_standard_particles_agg$Stress - qnorm(0.975)*overview_standard_particles_agg_sd$G_Pa*overview_standard_particles_agg$Strain_amplitude



G0prime_simulation = mean(c(overview_simulation$Gprime_Pa[ overview_simulation$Strain_amplitude<=0.005 & particle_sel],overview_plateau_particles_high_friction$Gprime_Pa[overview_plateau_particles_high_friction$Strain_amplitude<=0.005]))





lines(overview_standard_particles_agg$Stress/G0prime_simulation,overview_standard_particles_agg$Gprime_Pa/G0prime_simulation,pch=21,col=c("red"),type="l",lwd=1,lty=1)

lines(overview_standard_particles_agg_solid$Stress/G0prime_simulation,overview_standard_particles_agg_solid$Gprime_Pa/G0prime_simulation,pch=21,col=c("red"),type="l",lwd=4,lty=1)




lines(lower_stress/G0prime_simulation,lower_Gprime_Pa/G0prime_simulation,pch=21,col=c("red"),type="l",lwd=1,lty=2)
lines(upper_stress/G0prime_simulation,upper_Gprime_Pa/G0prime_simulation,pch=21,col=c("red"),type="l",lwd=1,lty=2)



legend("bottomleft",pch=c(rep(21,1),-1,-1),lty=c(rep(-1,1),1,1),pt.bg=grey(c(0,0,0)),col=c(rep("black",1),"blue","red"),legend=c("EPI","Simulation: High porosity","Simulation: Simple"),cex=1.5)

standard_shear_stress_0_05=overview_standard_particles$Gprime_Pa[overview_standard_particles$Stress>0.045*G0prime_simulation & overview_standard_particles$Stress<0.055*G0prime_simulation]/G0prime_simulation

measured_shear_stress_0_05 = EPI_control[EPI_control$tau_rel>0.045 &EPI_control$tau_rel<0.055,]
measured_shear_stress_0_05_agg = aggregate(Gprime_rel ~ ID, measured_shear_stress_0_05,FUN=mean)$Gprime_rel


plateau_shear_stress_0_05=overview_plateau_particles$Gprime_Pa[overview_plateau_particles$Stress>0.045*G0prime_simulation & overview_plateau_particles$Stress<0.055*G0prime_simulation]/G0prime_simulation



N_Bonferroni=2
cat("\nStatistical reporting: Test of second plateau different simulations against measured (Item 76)")
cat("\nGroup sizes")
cat("\nEPI, measured G'/G0' at relative shear stress (tau/G0') between 0.045 and 0.055: n=")
length(measured_shear_stress_0_05_agg)
cat("\nSimulation of G'/G0', regular contact law, at relative shear stress (tau/G0') between 0.045 and 0.055: n=")
length(standard_shear_stress_0_05)
cat("\nSimulation of G'/G0', plateau contact law for emulation of large porosity, at relative shear stress (tau/G0') between 0.045 and 0.055: n=")
length(plateau_shear_stress_0_05)


cat("\nNormality testing within each group")
cat("\nEPI, measured")
shapiro.test(measured_shear_stress_0_05_agg)
cat("\nSimulation, regular contact law")
shapiro.test(standard_shear_stress_0_05)
cat("\nSimulation, plateau contact law")
shapiro.test(plateau_shear_stress_0_05)

cat("\nWilcoxon ranksum test, EPI measured vs. simulation regular")
wilcox.test(measured_shear_stress_0_05_agg,standard_shear_stress_0_05)
cat("\nWilcoxon ranksum test, EPI measured vs. simulation plateau")
wilcox.test(measured_shear_stress_0_05_agg,plateau_shear_stress_0_05)

cat("\nNon-parametric confidence intervals from Wilcoxon test: EPI vs. standard simulation")
wilcox.test(measured_shear_stress_0_05_agg,standard_shear_stress_0_05,conf.int=TRUE,exact=FALSE)$conf.int
cat("\nNon-parametric confidence intervals from Wilcoxon test: EPI vs. plateau law simulation")
wilcox.test(measured_shear_stress_0_05_agg,plateau_shear_stress_0_05,conf.int=TRUE,exact=FALSE)$conf.int


cat("\nNon-parametric effect size: Z^2/n from P-value")
cat("EPI vs. standard simulation: r2=")
Z_wilcox=qnorm(0.5+(1-wilcox.test(measured_shear_stress_0_05_agg,standard_shear_stress_0_05)$p.val)/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/(length(measured_shear_stress_0_05_agg)+length(standard_shear_stress_0_05))
r2
cat("EPI vs. plateau law simulation: r2=")
Z_wilcox=qnorm(0.5+(1-wilcox.test(measured_shear_stress_0_05_agg,plateau_shear_stress_0_05)$p.val)/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/(length(measured_shear_stress_0_05_agg)+length(standard_shear_stress_0_05))
r2



cat("\n\nP-values with Bonferroni correction")
cat("\nSimple vs. empirical")
wilcox.test(measured_shear_stress_0_05_agg,standard_shear_stress_0_05)$p.val*N_Bonferroni
cat("\nPlateau vs. empirical")
wilcox.test(measured_shear_stress_0_05_agg,plateau_shear_stress_0_05)$p.val*N_Bonferroni

dev.off()

