library(plot.counts)
library(particleShearEvaluation)
library(mblm)








load(file="/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")





# Young modulus

pdf("Fig_C1.pdf")

common_select= unique_conditions$Friction_coefficient==0.01 & unique_conditions$packing_fraction %in% c(1,1.5,2) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000)


sphere_select = common_select & unique_conditions$Sample_type %in% c("uncrosslinked")
particles_select = common_select  & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0
particles_loose_select = common_select & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4


selected_conditions_spheres= unique_conditions[common_select & unique_conditions$Sample_type %in% c("uncrosslinked"),]

selected_conditions_particles=unique_conditions[ common_select & unique_conditions$Sample_type %in% c("particles") &unique_conditions$remove_link_fraction%in%c(0),]


selected_conditions_particles_loose=
unique_conditions[ common_select & unique_conditions$Sample_type %in% c("particles") &unique_conditions$remove_link_fraction%in%c(0.4),]

selected_conditions_bulk=
unique_conditions[ common_select & unique_conditions$Sample_type %in% c("bulk") &unique_conditions$remove_link_fraction%in%c(0),]



for_barplot=data.frame(
spherical=selected_conditions_spheres$plateau_Gprime_Pa[match(selected_conditions_particles$packing_fraction,selected_conditions_spheres$packing_fraction)],
spherical_sd =selected_conditions_spheres$plateau_Gprime_Pa_sd[match(selected_conditions_particles$packing_fraction,selected_conditions_spheres$packing_fraction)],
particles=selected_conditions_particles$plateau_Gprime_Pa[match(selected_conditions_particles$packing_fraction,selected_conditions_particles$packing_fraction)],
particles_sd=selected_conditions_particles$plateau_Gprime_Pa_sd[match(selected_conditions_particles$packing_fraction,selected_conditions_particles$packing_fraction)],
particles_loose=selected_conditions_particles_loose$plateau_Gprime_Pa[match(selected_conditions_particles$packing_fraction,selected_conditions_particles_loose$packing_fraction)],
particles_loose_sd=selected_conditions_particles_loose$plateau_Gprime_Pa_sd[match(selected_conditions_particles$packing_fraction,selected_conditions_particles_loose$packing_fraction)],
bulk=selected_conditions_bulk$plateau_Gprime_Pa[match(selected_conditions_particles$packing_fraction,selected_conditions_bulk$packing_fraction)],
bulk_sd=selected_conditions_bulk$plateau_Gprime_Pa_sd[match(selected_conditions_particles$packing_fraction,selected_conditions_bulk$packing_fraction)],
packing_fraction=selected_conditions_particles$packing_fraction
)



barplot_with_errorbars(t(as.matrix(for_barplot[,c("spherical","particles_loose","particles","bulk")])),names.arg= (for_barplot$packing_fraction),beside=TRUE,col=grey(c(1,0.8,0.4,0.25)),
sd_height=t(as.matrix(for_barplot[,c("spherical_sd","particles_loose_sd","particles_sd","bulk_sd")])),legend=TRUE,xlab="Packing density",ylab="Plateau G' [Pa]",legend.text=c("spherical","irregular - porous","irregular - compact","bulk"),main="Plateau G' vs. packing density",ylim=c(0,4000))



common_select_overview_simulation=overview_simulation$Friction_coefficient==0.01 & overview_simulation$packing_fraction %in% c(1,1.5,2) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Strain_amplitude==0.001

for_linmod_spheres = overview_simulation[common_select_overview_simulation & overview_simulation$Sample_type %in% c("uncrosslinked") ,]

linmod_spheres=lm(Gprime_Pa ~ packing_fraction, for_linmod_spheres )

# Shapiro-Wilks is significant (see below), so this is not valid. Use non-parametric linear regression instead (the problem comes from variable simulation instability with packing density and thus variable variance, this is not easy to corrcect for with glm functions. So use the Siegel non-parametric regression from the R package mblm (i.e. method based on Siegel, A.F. (1982). Robust Regression Using Repeated Medians. Biometrika, 69, 1, 242-244.)

linmod_spheres_nonparametric =mblm(Gprime_Pa ~ packing_fraction, for_linmod_spheres )


pval_spheres=coefficients(summary(linmod_spheres_nonparametric))["packing_fraction","Pr(>|V|)"]


for_linmod_particles = overview_simulation[common_select_overview_simulation & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0  ,]

linmod_particles=lm(Gprime_Pa ~ packing_fraction, for_linmod_particles)

# Shapiro-Wilks is not significant, so this is OK

pval_particles=coefficients(summary(linmod_particles))["packing_fraction","Pr(>|t|)"]


for_linmod_particles_loose = overview_simulation[common_select_overview_simulation & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4  ,]

linmod_particle_porous=lm(Gprime_Pa ~ packing_fraction, for_linmod_particles_loose)

# Here too, Shapiro-Wilks is OK

pval_particles_loose=coefficients(summary(linmod_particle_porous))["packing_fraction","Pr(>|t|)"]

for_linmod_bulk = overview_simulation[common_select_overview_simulation & overview_simulation$Sample_type %in% c("bulk")   ,]
linmod_bulk=lm(Gprime_Pa ~ packing_fraction, for_linmod_bulk)

# Shapiro-Wilks is significant, so again, we need to use the non-parametric version
linmod_bulk_nonparametric=mblm(Gprime_Pa ~ packing_fraction, for_linmod_bulk )

pval_bulk=coefficients(summary(linmod_bulk_nonparametric))["packing_fraction","Pr(>|V|)"]






pvals_packing_fraction=p.adjust(c(pval_spheres,pval_particles,pval_particles_loose,pval_bulk),method="bonferroni")

names(pvals_packing_fraction)=c("spherical","compact","porous","bulk")





dev.off()

# reporting

cat("\nStatistical reporting: linear regression for each particle shape (Item 67)")

cat("\nGroup sizes")
for_reporting=overview_simulation[common_select_overview_simulation & overview_simulation$remove_link_fraction %in% c(0,0.4) & !(overview_simulation$remove_link_fraction==0.4 & overview_simulation$Sample_type=="bulk") ,]

n_sim=aggregate(Gprime_Pa ~ packing_fraction+Sample_type + remove_link_fraction,for_reporting,FUN=length)
colnames(n_sim)[colnames(n_sim)=="Gprime_Pa"]="n"

n_sim

cat("\nTotal simulations used")
sum(n_sim$n)

cat("\nNormality testing spherical particles")
shapiro.test(resid(linmod_spheres))

cat("\nNormality testing irregular porous particles")
shapiro.test(resid(linmod_particle_porous))

cat("\nNormality testing irregular compact particles")
shapiro.test(resid(linmod_particles))

cat("\nNormality testing non-porous bulk")
shapiro.test(resid(linmod_bulk))


cat("\n\nLinear regression and non-parametric Siegel regression (mblm function in mblm R package, implementing Siegel, A.F. (1982). Robust Regression Using Repeated Medians. Biometrika, 69, 1, 242-244)")

cat("\nSpherical particles: Siegel regression")
summary(linmod_spheres_nonparametric)

cat("\nIrregular porous: ordinary linear regression")
summary(linmod_particle_porous)

cat("\nIrregular compact: ordinary linear regression")
summary(linmod_particles)

cat("\nBulk: Siegel regression")
summary(linmod_bulk_nonparametric)

cat("\n\nConfidence intervals for the slopes")
cat("\nSpherical")
confint(linmod_spheres_nonparametric)
cat("\nIrregular porous:")
confint(linmod_particle_porous)
cat("\nIrregular compact:")
confint(linmod_particles)
cat("\nBulk:")
confint(linmod_bulk_nonparametric)

cat("\nEffect size")
cat("\nSpherical: R2 from Z^2/n")
Z=-qnorm(coefficients(summary(linmod_spheres_nonparametric))["packing_fraction","Pr(>|V|)"]/2)
Z^2/length(linmod_spheres_nonparametric$slopes)
cat("\nIrregular porous: Adjusted R2 in summary of linear regression above")
cat("\nIrregular compact: Adjusted R2 in summary of linear regression above")
cat("\nBulk: R2 from Z^2/n")
Z=-qnorm(coefficients(summary(linmod_bulk_nonparametric))["packing_fraction","Pr(>|V|)"]/2)
Z^2/length(linmod_bulk_nonparametric$slopes)

cat("\nDegrees of freedom")
cat("\nSpherical: n slopes evaluated")
length(linmod_spheres_nonparametric$slopes)
cat("\nIrregular porous: DF in summary of linear regression above")
cat("\nIrregular compact: DF in summary of linear regression above")
cat("\nBulk: n slopes evaluated")
length(linmod_bulk_nonparametric$slopes)

cat("\n\nP-values, with Bonferroni adjustment")
pvals_packing_fraction
cat("\nSignificance")
significance_labels(pvals_packing_fraction)





