library(plot.counts)
library(particleShearEvaluation)
library(mblm)

load(file="/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")

pdf("Fig_C2.pdf")


# packing density

common_select=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1,1.5,2) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("uncrosslinked","particles")

sphere_select = common_select & unique_conditions$Sample_type %in% c("uncrosslinked")
particles_select = common_select  & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0
particles_loose_select = common_select & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4

complete_select=sphere_select | particles_select | particles_loose_select

selected_conditions_spheres=unique_conditions[sphere_select,]
selected_conditions_particles=unique_conditions[particles_select,]
selected_conditions_particles_loose=unique_conditions[particles_loose_select,]







for_barplot=data.frame(
spherical=selected_conditions_spheres$yield_strain,
spherical_sd =selected_conditions_spheres$yield_strain_sd,
particles=selected_conditions_particles$yield_strain[match(selected_conditions_spheres$packing_fraction,selected_conditions_particles$packing_fraction)],
particles_sd=selected_conditions_particles$yield_strain_sd[match(selected_conditions_spheres$packing_fraction,selected_conditions_particles$packing_fraction)],
particles_loose=selected_conditions_particles_loose$yield_strain[match(selected_conditions_spheres$packing_fraction,selected_conditions_particles_loose$packing_fraction)],
particles_loose_sd=selected_conditions_particles_loose$yield_strain_sd[match(selected_conditions_spheres$packing_fraction,selected_conditions_particles_loose$packing_fraction)],
packing_fraction=selected_conditions_spheres$packing_fraction
)






barplot_with_errorbars(t(as.matrix(for_barplot[,c("spherical","particles_loose","particles")]))*100,names.arg= for_barplot$packing_fraction,beside=TRUE,col=grey(c(1,0.75,0.25)),
sd_height=t(as.matrix(for_barplot[,c("spherical_sd","particles_loose_sd","particles_sd")]))*100,legend=TRUE,xlab="Packing fraction",ylab="Yield strain [%]",legend.text=c("spherical","irregular - porous","irregular - compact"),main="Packing density")



pval_spheres=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[sphere_select],y=bootstrap_draws_yield_strain[sphere_select,])


pval_particles=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[particles_select],y=bootstrap_draws_yield_strain[particles_select,])


pval_particles_loose=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[particles_loose_select],y=bootstrap_draws_yield_strain[particles_loose_select,])

pvals_packing_fraction_pre_Bonferroni=c(pval_spheres,pval_particles_loose,pval_particles)
names(pvals_packing_fraction_pre_Bonferroni)=c("spherical","porous","compact")
pvals_packing_fraction=p.adjust(pvals_packing_fraction_pre_Bonferroni,method="bonferroni")



# Reporting of sample size


select_packing_density_entire_curve=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1,1.5,2) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & ((overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction %in% c(0,0.4)) | overview_simulation$Sample_type %in% c("uncrosslinked"))


dev.off()


# reporting
cat("\nStatistical reporting: Yield strain as a function of packing density for each particle shape (Item 68)")

cat("\nGroup sizes here: n=5 in bootstrapping mode. Indication on the total number of simulations used")

for_reporting=overview_simulation[select_packing_density_entire_curve,]

n_sim=aggregate(Gprime_Pa ~ packing_fraction+Sample_type + remove_link_fraction,for_reporting,FUN=length)
colnames(n_sim)[colnames(n_sim)=="Gprime_Pa"]="n"
n_sim
cat("\nTotal simulations used")
sum(n_sim$n)

cat("\nNormality testing spherical particles via Shapiro-Wilks. P=")
attr(pval_spheres,"p_shapiro")

cat("\nNormality testing irregular porous particles")
attr(pval_particles_loose,"p_shapiro")

cat("\nNormality testing irregular compact particles")
attr(pval_particles,"p_shapiro")


cat("\n\nF-Statistic for regression of yield strain as a function of packing density (i.e. increase of yield strain for one unit of increase of packing density, as in from 1 to 2)")
cat("\nSpherical particles")
attr(pval_spheres,"F")
cat("\nIrregular porous particles")
attr(pval_particles_loose,"F")
cat("\nIrregular compact particles")
attr(pval_particles,"F")


cat("\n\nConfidence intervals for the slope of yield strain as a function of packing density (i.e. increase of yield strain for one unit of increase of packing density, as in from 1 to 2)")
cat("\nSpherical particles")
attr(pval_spheres,"confint")
cat("\nIrregular porous particles")
attr(pval_particles_loose,"confint")
cat("\nIrregular compact particles")
attr(pval_particles,"confint")


cat("\n\nEffect size (adjusted R2)")
cat("\nSpherical particles")
attr(pval_spheres,"adj.r.squared")
cat("\nIrregular porous particles")
attr(pval_particles_loose,"adj.r.squared")
cat("\nIrregular compact particles")
attr(pval_particles,"adj.r.squared")


cat("\n\nDegrees of freedom (for F-statistic)")
cat("\nSpherical particles")
cat(paste(attr(pval_spheres,"DF1"),attr(pval_spheres,"DF2"),sep="/"))
cat("\nIrregular porous particles")
cat(paste(attr(pval_particles_loose,"DF1"),attr(pval_particles_loose,"DF2"),sep="/"))
cat("\nIrregular compact particles")
cat(paste(attr(pval_particles,"DF1"),attr(pval_particles,"DF2"),sep="/"))




cat("\n\nP-values, before adjustment for multiple testing")
pvals_packing_fraction_pre_Bonferroni
cat("\n\nP-values with Bonferroni correction")
pvals_packing_fraction
cat("\nSignificance")
significance_labels(pvals_packing_fraction)



