library(rheologyEvaluation)

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")


# Use only cup data (there are problems with drying and the necessity to partially compress the scaffold with the plate-plate geometry)



to_use=stress_sweeps_EPI[stress_sweeps_EPI$Geometry=="cup",]

overview_EPI=overview_EPI[overview_EPI$Geometry=="cup",]




to_use$Full_File=paste(to_use$folder,to_use$file,sep="/")





yield = data.frame(Full_File = sort(unique(to_use$Full_File)), polymer_conc_mgmL=NA,yield_strain=NA,yield_stress=NA)


to_use$log_Gprime_Pa=log(to_use$Gprime_Pa)
to_use$log_Gprimeprime_Pa=log(to_use$Gprimeprime_Pa)
to_use$log_Gamma_in_percent=log(to_use$Gamma_in_percent)
to_use$log_tau_Pa=log(to_use$tau_Pa)



for(theFile in to_use$Full_File)
{
    sweep=to_use[to_use$Full_File==theFile,]
    
    use_first = FALSE
    
    if(max(sweep$Gprime_Pa)<10) # These are difficult cases since with so soft materials, the random
    # fluctuations are important
    {
        
        
        # To start with, establish where the
        solid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]
        liquid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa<sweep$Gprimeprime_Pa]
        
        if(1 %in% liquid_regime)
        {
            use_first=TRUE
        } else
        {
            
            
            
            # first transition: we have some liquid regime above the solid regime
            if(any(liquid_regime>min(solid_regime)))
            {
                first_liquid = min(liquid_regime[liquid_regime>min(solid_regime)])
                
                last_solid = first_liquid-1
                
                while(last_solid %in% liquid_regime)
                {
                    last_solid=last_solid-1
                }
                
                while(last_solid %in% solid_regime)
                {
                    last_solid=last_solid-1
                }
                
                last_solid=last_solid+1
                
                last_solid = max(last_solid,1)
                
                sweep=sweep[last_solid:first_liquid,]
            } else
            {
                # We can't do much, just leave it for evaluation as is
            }
            
            
        }
        
        
    }
    
    
    
    
    yield$polymer_conc_mgmL[theFile==yield$Full_File]=to_use[to_use$Full_File==theFile,"polymer_conc_mgmL"][1]
    
    
    if(use_first)
    {
        yield$yield_strain[theFile==yield$Full_File]=sweep$Gamma_in_percent[1]
        yield$yield_stress[theFile==yield$Full_File]=sweep$tau_Pa[1]
        
    } else {
        
        if(any(sweep$log_Gamma_in_percent[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]<min(sweep$log_Gamma_in_percent[sweep$Gprime_Pa<sweep$Gprimeprime_Pa])))
        {
            
            yield$yield_strain[theFile==yield$Full_File]=
            exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
            Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_Gamma_in_percent"))["log_Gamma_in_percent"]
            
        }
        
        
        yield$yield_stress[theFile==yield$Full_File]=
        exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
        Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_tau_Pa"))["log_tau_Pa"]
        
        
    }
    
}






xlim=c(0,100)








load("/data/Evaluation/Rheology/Flow curves/EPI/EPI_yield_stress.rda")


pdf("Fig_C4a.pdf")



plot(yield$polymer_conc_mgmL,yield$yield_stress,type="p",cex=2,pch=21,bg="black",ylim=c(1,1000),xlim=xlim,log="y",xlab="Polymer concentration [mg/mL]",ylab="Yield stress [Pa]")

lines(overview_EPI_yield_stress$Polymer_concentration*1000,overview_EPI_yield_stress$yield_stress,pch=21,cex=2,bg="white",type="p")


dev.off()
