library(plot.counts)
library(rheologyEvaluation)
library(mblm)



# To calculate the notional phase volume


load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")


# Use only cup data (there are problems with drying and the necessity to partially compress the scaffold with the plate-plate geometry)



to_use=stress_sweeps_EPI[stress_sweeps_EPI$Geometry=="cup",]

overview_EPI=overview_EPI[overview_EPI$Geometry=="cup",]




to_use$Full_File=paste(to_use$folder,to_use$file,sep="/")





yield = data.frame(Full_File = sort(unique(to_use$Full_File)), polymer_conc_mgmL=NA,yield_strain=NA,yield_stress=NA)


to_use$log_Gprime_Pa=log(to_use$Gprime_Pa)
to_use$log_Gprimeprime_Pa=log(to_use$Gprimeprime_Pa)
to_use$log_Gamma_in_percent=log(to_use$Gamma_in_percent)
to_use$log_tau_Pa=log(to_use$tau_Pa)



for(theFile in to_use$Full_File)
{
    sweep=to_use[to_use$Full_File==theFile,]
    
    use_first = FALSE
    
    if(max(sweep$Gprime_Pa)<10) # These are difficult cases since with so soft materials, the random
    # fluctuations are important
    {
        
        
        # To start with, establish where the
        solid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]
        liquid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa<sweep$Gprimeprime_Pa]
        
        if(1 %in% liquid_regime)
        {
            use_first=TRUE
        } else
        {
            
            
            
            # first transition: we have some liquid regime above the solid regime
            if(any(liquid_regime>min(solid_regime)))
            {
                first_liquid = min(liquid_regime[liquid_regime>min(solid_regime)])
                
                last_solid = first_liquid-1
                
                while(last_solid %in% liquid_regime)
                {
                    last_solid=last_solid-1
                }
                
                while(last_solid %in% solid_regime)
                {
                    last_solid=last_solid-1
                }
                
                last_solid=last_solid+1
                
                last_solid = max(last_solid,1)
                
                sweep=sweep[last_solid:first_liquid,]
            } else
            {
                # We can't do much, just leave it for evaluation as is
                

            }
            
            
        }
        
        
    }
    
    
    
    
    yield$polymer_conc_mgmL[theFile==yield$Full_File]=to_use[to_use$Full_File==theFile,"polymer_conc_mgmL"][1]
    
    
    if(use_first)
    {
        yield$yield_strain[theFile==yield$Full_File]=sweep$Gamma_in_percent[1]
        yield$yield_stress[theFile==yield$Full_File]=sweep$tau_Pa[1]
        
    } else {
        
        if(any(sweep$log_Gamma_in_percent[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]<min(sweep$log_Gamma_in_percent[sweep$Gprime_Pa<sweep$Gprimeprime_Pa])))
        {
            
            yield$yield_strain[theFile==yield$Full_File]=
            exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
            Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_Gamma_in_percent"))["log_Gamma_in_percent"]
            
        }
        
        
        yield$yield_stress[theFile==yield$Full_File]=
        exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
        Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_tau_Pa"))["log_tau_Pa"]
        
        
    }
    
}








xlim=c(0,100)








load("/data/Evaluation/Rheology/Flow curves/EPI/EPI_yield_stress.rda")





# Direct comparison with t-test

yield$yield_from_flow = overview_EPI_yield_stress$yield_stress[match(round(yield$polymer_conc_mgmL*10)/10,round(overview_EPI_yield_stress$Polymer_concentration*10000)/10)]


yield_EPI = yield







load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")






# Use only cup data (there are problems with drying and the necessity to partially compress the scaffold with the plate-plate geometry)



to_use=stress_sweeps_sephacryl_S200[stress_sweeps_sephacryl_S200$Geometry=="cup",]

overview_sephacryl_S200=overview_sephacryl_S200[overview_sephacryl_S200$Geometry=="cup",]




to_use$Full_File=paste(to_use$folder,to_use$file,sep="/")





yield = data.frame(Full_File = sort(unique(to_use$Full_File)), polymer_conc_mgmL=NA,yield_strain=NA,yield_stress=NA)


to_use$log_Gprime_Pa=log(to_use$Gprime_Pa)
to_use$log_Gprimeprime_Pa=log(to_use$Gprimeprime_Pa)
to_use$log_Gamma_in_percent=log(to_use$Gamma_in_percent)
to_use$log_tau_Pa=log(to_use$tau_Pa)



for(theFile in to_use$Full_File)
{
    sweep=to_use[to_use$Full_File==theFile,]
    
    use_first = FALSE
    
    if(max(sweep$Gprime_Pa)<10) # These are difficult cases since with so soft materials, the random
    # fluctuations are important
    {
        
        
        # To start with, establish where the
        solid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]
        liquid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa<sweep$Gprimeprime_Pa]
        
        if(1 %in% liquid_regime)
        {
            use_first=TRUE
        } else
        {
            
            
            
            # first transition: we have some liquid regime above the solid regime
            if(any(liquid_regime>min(solid_regime)))
            {
                first_liquid = min(liquid_regime[liquid_regime>min(solid_regime)])
                
                last_solid = first_liquid-1
                
                while(last_solid %in% liquid_regime)
                {
                    last_solid=last_solid-1
                }
                
                while(last_solid %in% solid_regime)
                {
                    last_solid=last_solid-1
                }
                
                last_solid=last_solid+1
                
                last_solid = max(last_solid,1)
                
                sweep=sweep[last_solid:first_liquid,]
            } else
            {
                # We can't do much, just leave it for evaluation as is
                            }
            
            
        }
        
        
    }
    
    
    
    
    yield$polymer_conc_mgmL[theFile==yield$Full_File]=to_use[to_use$Full_File==theFile,"polymer_conc_mgmL"][1]
    
    
    if(use_first)
    {
        yield$yield_strain[theFile==yield$Full_File]=sweep$Gamma_in_percent[1]
        yield$yield_stress[theFile==yield$Full_File]=sweep$tau_Pa[1]
        
    } else {
        
        if(any(sweep$log_Gamma_in_percent[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]<min(sweep$log_Gamma_in_percent[sweep$Gprime_Pa<sweep$Gprimeprime_Pa])))
        {
            
            yield$yield_strain[theFile==yield$Full_File]=
            exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
            Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_Gamma_in_percent"))["log_Gamma_in_percent"]
            
        }
        
        
        yield$yield_stress[theFile==yield$Full_File]=
        exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
        Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_tau_Pa"))["log_tau_Pa"]
        
        
    }
    
}














load("/data/Evaluation/Rheology/Flow curves/Sephacryl_S200/sephacryl_S200_yield_stress.rda")



yield$yield_from_flow = overview_sephacryl_S200_yield_stress$yield_stress[match(round(yield$polymer_conc_mgmL*10)/10,round(overview_sephacryl_S200_yield_stress$Polymer_concentration*10000)/10)]

yield_sephacryl_S200 = yield

limits=c(1,2000)

pdf("Fig_C5.pdf")
plot(yield_stress ~ yield_from_flow, yield_sephacryl_S200,log="xy",xlim=limits,ylim=limits,cex=1.5,xlab="Yield stress from flow curves [Pa]",ylab="Yield stress from G' / G'' [Pa]",xaxt="n",yaxt="n")

lines(yield_stress ~ yield_from_flow, yield_EPI,type="p",pch=21,bg="black",cex=1.5)

lines(limits,limits,col="red",type="l")

axis(side=2,at=c(1:9,(1:9)*10,(1:10)*100,2000),labels=c(expression(1),rep("",8),10,rep("",8),100,rep("",8),1000,""),las=2)

axis(side=1,at=c(1:9,(1:9)*10,(1:10)*100,2000),labels=c(expression(1),rep("",8),10,rep("",8),100,rep("",8),1000,""),las=2)

legend("topleft",legend=c("EPI","Sephacryl S200"),pch=c(21,21),pt.bg=c("black","white"))

yield_EPI$material="EPI"
yield_sephacryl_S200$material="Sephacryl S200"

yield_EPI$log_delta=log(yield_EPI$yield_stress/yield_EPI$yield_from_flow)

yield_sephacryl_S200$log_delta=log(yield_sephacryl_S200$yield_stress/yield_sephacryl_S200$yield_from_flow)



all_yield=rbind(yield_EPI[,c("yield_stress","yield_from_flow","material","log_delta")],yield_sephacryl_S200[,c("yield_stress","yield_from_flow","material","log_delta")])

all_yield = all_yield[!is.na(all_yield$yield_stress) & !is.na(all_yield$yield_from_flow),]

all_yield$log_yield_stress=log(all_yield$yield_stress)
all_yield$log_yield_from_flow=log(all_yield$yield_from_flow)

linmod_slope=lm(log_yield_stress~log_yield_from_flow,all_yield)
linmod_slope_deviation_from_1=lm(log_delta~log_yield_from_flow,all_yield)

linmod_slope_non_parametric=mblm(log_yield_stress~log_yield_from_flow,all_yield)
linmod_slope_deviation_from_1_non_parametric=mblm(log_delta~log_yield_from_flow,all_yield)

coeffs=coefficients(linmod_slope_non_parametric)
lines(limits,exp(coeffs[["(Intercept)"]]+coeffs[["log_yield_from_flow"]]*log(limits)),type="l",lty=2,col="red")

dev.off()

#reporting
cat("\nReporting for the linear regression of yield stress by G'/G'' crossing vs. yield stress by flow curve (Item 69)")
cat("\nGroup sizes")
n=aggregate(yield_stress ~ material, all_yield,FUN=length)
colnames(n)[colnames(n)=="yield_stress"]="n"
n
cat("\nTotal n for linear regression")
sum(n$n)
cat("\nWe do this linear regression on log scale since otherwise the high yield stress values are completely dominating as this covers 3 orders of magnitude of yield stresses: log(yield stress from G'/G'') vs. log(yield stress from flow curves)")
cat("\nNormality testing (Shapiro-Wilks on residuals)")
shapiro.test(resid(linmod_slope))
cat("\nThe non-normality seems to be due to individual outliers at the lower and upper end of the curve (where measurement is particularly challenging due to very dry or very humid material). This is is not easily addressed with an adapted error structure since there is no particular tendency in the errors, so resorting to non-parametric technique")

cat("\n\nFor non-parametric linear regression, we use the Siegel regression (Siegel, A.F. (1982). Robust Regression Using Repeated Medians. Biometrika, 69, 1, 242-244)), as implemented in the mblm function in the mblm R package. This is the dashed line shown in the graphic")

cat("\nSummary of the non-parametric (Siegel) regression")
summary(linmod_slope_non_parametric)

cat("\nThe slope is significant, but the primary question is not whether it is significantly different from 0, but whether it is significantly different from 1; assess this question by regression of the delta to identity, aka log(yield stress(G'/G'')-log(yield stress(flow) as a function of log(yield stress (flow).")
summary(linmod_slope_deviation_from_1_non_parametric)

cat("\nBy construction, this shares the intercept with the direct regression, and so there are three distinct tests: slope with null hypothesis slope=0; slope with null hypothesis slope=1; and intercept with null hyopthesis intercept = 0 => N Bonferroni=3")
N_Bonferroni=3

cat("\n\nConfidence intervals")
confint(linmod_slope_non_parametric)


cat("\nEffect size: Delta from slope=0")
cat("\nSpherical: R2 from Z^2/n")
Z=-qnorm(coefficients(summary(linmod_slope_non_parametric))["log_yield_from_flow","Pr(>|V|)"]/2)
Z^2/length(linmod_slope_non_parametric$slopes)


cat("\nEffect size: Delta from slope=1")
cat("\nSpherical: R2 from Z^2/n")
Z=-qnorm(coefficients(summary(linmod_slope_deviation_from_1_non_parametric))["log_yield_from_flow","Pr(>|V|)"]/2)
Z^2/length(linmod_slope_deviation_from_1_non_parametric$slopes)



cat("\nDegrees of freedom (n for Wilcoxon V used internally by the mblm)")
length(linmod_slope_non_parametric$slopes)

Pvals=c(coefficients(summary(linmod_slope_non_parametric))["(Intercept)","Pr(>|V|)"],
coefficients(summary(linmod_slope_non_parametric))["log_yield_from_flow","Pr(>|V|)"],
coefficients(summary(linmod_slope_deviation_from_1_non_parametric))["log_yield_from_flow","Pr(>|V|)"])

names(Pvals)=c("Intercept","Slope=0","Slope=1")

Pvals_Bonferroni=Pvals*N_Bonferroni
Pvals_Bonferroni[Pvals_Bonferroni>1]=1

cat("\n\nP-values before multiple testing correction")
Pvals
cat("\nP-values with Bonferroni correction")
Pvals_Bonferroni
cat("\nSignificance")
significance_labels(Pvals_Bonferroni,codes=c("",
"*", "**", "***"))













