library(plot.counts)


pdf("Fig_C9a.pdf")

load("/data/Evaluation/Rheology/Self healing/overview_files_self_healing_kinetics.rda")

start_point = aggregate(t_s_relative ~overview_index,self_healing_kinetics[self_healing_kinetics$Segment=="shear",],FUN=max)

self_healing_kinetics$t_s_relative=self_healing_kinetics$t_s_relative-start_point$t_s_relative[match(self_healing_kinetics$overview_index,start_point$overview_index)]-5


baseline_Gprime=aggregate(Gprime_Pa ~ overview_index, self_healing_kinetics[self_healing_kinetics$Segment=="baseline",],FUN=function(x){x[length(x)]})

overview_self_healing_kinetics$Gprime_Pa_baseline = baseline_Gprime$Gprime_Pa[match(1:(dim(overview_self_healing_kinetics)[1]),baseline_Gprime$overview_index)]



overview_self_healing_kinetics$Gprime_Pa_15s=0
overview_self_healing_kinetics$Gprime_Pa_30s=0
overview_self_healing_kinetics$Gprime_Pa_15min=0
overview_self_healing_kinetics$Gprime_Pa_shear=0

for(ind in 1:(dim(overview_self_healing_kinetics)[1]))
{
    recovery_segment = self_healing_kinetics[self_healing_kinetics$overview_index==ind & self_healing_kinetics$Segment=="recovery",]
    
    ind_15min = which.min(abs(recovery_segment$t_s_relative-15*60))
    ind_15s = which.min(abs(recovery_segment$t_s_relative-15))
    ind_30s = which.min(abs(recovery_segment$t_s_relative-30))
    
    overview_self_healing_kinetics$Gprime_Pa_15min[ind]=recovery_segment$Gprime_Pa[ind_15min]
    overview_self_healing_kinetics$Gprime_Pa_30s[ind]=recovery_segment$Gprime_Pa[ind_30s]
    overview_self_healing_kinetics$Gprime_Pa_15s[ind]=recovery_segment$Gprime_Pa[ind_15s]
    
    shear_segment = self_healing_kinetics[self_healing_kinetics$overview_index==ind & self_healing_kinetics$Segment=="shear",]
    
    overview_self_healing_kinetics$Gprime_Pa_shear[ind]=shear_segment$Gprime_Pa[length(shear_segment$Gprime_Pa)]
    
}

sample1 = overview_self_healing_kinetics[overview_self_healing_kinetics$File=="PB51_T10_recovery_sweep.txt",]

sample2_run_1 = overview_self_healing_kinetics[overview_self_healing_kinetics$File=="PB51_T10_recovery_sweep_WEEKEND4.txt" & overview_self_healing_kinetics$baseline_start<=12105,]

sample2_run_2 = overview_self_healing_kinetics[overview_self_healing_kinetics$File=="PB51_T10_recovery_sweep_WEEKEND4.txt" & overview_self_healing_kinetics$baseline_start>12105,]

lim=c(0,3e3)

# Associate matching points (same nominal stress applied during recovery)
first_run_15min=sample2_run_1$Gprime_Pa_15min
second_run_15min=sample2_run_2$Gprime_Pa_15min[match(sample2_run_1$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_30s=sample2_run_1$Gprime_Pa_30s
second_run_30s=sample2_run_2$Gprime_Pa_30s[match(sample2_run_1$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_15s=sample2_run_1$Gprime_Pa_15s
second_run_15s=sample2_run_2$Gprime_Pa_15s[match(sample2_run_1$Tau_Pa,sample2_run_2$Tau_Pa)]


# Lower part of the curve only because variance changes so mutch
sample2_run_1_low=sample2_run_1[sample2_run_1$Gprime_Pa_baseline<1500,]

first_run_15min_low=sample2_run_1_low$Gprime_Pa_15min
second_run_15min_low=sample2_run_2$Gprime_Pa_15min[match(sample2_run_1_low$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_30s_low=sample2_run_1_low$Gprime_Pa_30s
second_run_30s_low=sample2_run_2$Gprime_Pa_30s[match(sample2_run_1_low$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_15s_low=sample2_run_1_low$Gprime_Pa_15s
second_run_15s_low=sample2_run_2$Gprime_Pa_15s[match(sample2_run_1_low$Tau_Pa,sample2_run_2$Tau_Pa)]



# Upper part of the curve only because variance changes so mutch
sample2_run_1_high=sample2_run_1[sample2_run_1$Gprime_Pa_baseline>=1500,]

first_run_15min_high=sample2_run_1_high$Gprime_Pa_15min
second_run_15min_high=sample2_run_2$Gprime_Pa_15min[match(sample2_run_1_high$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_30s_high=sample2_run_1_high$Gprime_Pa_30s
second_run_30s_high=sample2_run_2$Gprime_Pa_30s[match(sample2_run_1_high$Tau_Pa,sample2_run_2$Tau_Pa)]

first_run_15s_high=sample2_run_1_high$Gprime_Pa_15s
second_run_15s_high=sample2_run_2$Gprime_Pa_15s[match(sample2_run_1_high$Tau_Pa,sample2_run_2$Tau_Pa)]


plot(first_run_15min,second_run_15min,pch=21,bg="#000000",ylim=lim,xlim=lim,cex=1.5,xlab="G' recovered during 1st run [Pa]",ylab="G' recovered during 2nd run [Pa]",main="Self-Healing: Repeatability")
lines(first_run_30s,second_run_30s,pch=21,bg="#BBBBBB",type="p",cex=1.5)
lines(first_run_15s,second_run_15s,pch=21,bg="#FFFFFF",type="p",cex=1.5)
lines(lim,lim,type="l",col="red")


legend("topleft",pch=c(rep(21,3),-1,-1),pt.bg=c("#FFFFFF","#BBBBBB","#000000","#000000","#000000"),lty=c(-1,-1,-1,1,2),
col=c("black","black","black","red","black"),
legend=c("15s","30s","15min","Equality","Regression"),cex=1.5)

dev.off()


# Bland and Altman plot
pdf("Fig_C9b.pdf")
plot((first_run_15min_low+second_run_15min_low)/2, second_run_15min_low-first_run_15min_low,pch=21,bg="#000000",xlim=c(0,1200),
ylim=c(-30,30),cex=1.5,xlab="Average G' [Pa]",ylab="Delta G' [Pa]",main="Self-Healing: Repeatability")
lines(lim,c(0,0),type="l",col="red")




altman_sum=(first_run_15min_low+second_run_15min_low)/2


altman_difference=second_run_15min_low-first_run_15min_low


lm_altman=lm(altman_difference ~ altman_sum)


coeffs=coefficients(lm_altman)




lines(c(0,1200),coeffs[["(Intercept)"]]+coeffs[["altman_sum"]]*c(0,1200),type="l",lty=2)


legend("topleft",pch=c(rep(21,1),-1,-1),pt.bg=c("#000000","#000000","#000000"),lty=c(-1,1,2),
col=c("black","red","black"),
legend=c("15min","Equality","Regression"),cex=1.5)


# For reporting: Too high non-normality for the full dataset
altman_sum_all=(first_run_15min+second_run_15min)/2


altman_difference_all=second_run_15min-first_run_15min


cat("\nAltmann regression (differences vs. sum): Item 39")

cat("\nn: Total datapoints")
length(altman_sum_all)
cat("\nn: Used for parametric testing (linear regression)")
length(altman_sum)

cat("\nNormality testing: First attempt with all datapoints")
shapiro.test(resid(lm(altman_difference_all~altman_sum_all)))
cat("\nSince we get strong non-normality, limit to G'0 at baseline (before self-healing) to <=1500 to have similar variance (n=12 instead of n=19). Normality testing under these conditions")
shapiro.test(resid(lm_altman))

cat("\nNow, two different analyis possible. Non-parametric on the whole dataset is the first option:")


# Non-parametric test over the entire dataset
wilcox.test(second_run_15min-first_run_15min)

cat("\nThe second option, persued mainly, is to restrict ourselves to the segment where normality is respected. In this case, the linear regression gives:")

summary(lm_altman)

cat("\n with confidence intervals for the intercept and slope")
confint(lm_altman,"(Intercept)")
confint(lm_altman,"altman_sum")


dev.off()



