
library(plot.counts)
library(rheologyEvaluation)

pdf("Fig_S10c.pdf")

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/polynomial_model_Gprime_EPI.rda")

load("/data/Evaluation/Porosity/EPI/Pore fraction/EPI_porosity.rda")

# Use only cup data (there are problems with drying and the necessity to partially compress the scaffold with the plate-plate geometry)
overview_EPI=overview_EPI[overview_EPI$Geometry=="cup",]


overview_EPI = overview_EPI[order(overview_EPI$polymer_conc_mgmL),]

overview_EPI = overview_EPI[!is.na(overview_EPI$polymer_conc_mgmL),]




overview_EPI$pore_fraction= EPI_pore_fraction_gamma(overview_EPI$polymer_conc_mgmL)

overview_EPI$notional_phase_volume = 1-overview_EPI$pore_fraction




xlim=c(10,1000)


for_theory_x= exp(seq(from=log(5),to=log(75),length.out=200))

Gprime_theory=polynomial_model(for_theory_x,A_EPI,c0_EPI,m_EPI)

Gprime_desired = c(2000,3000)

EPI_concentration = (Gprime_desired/(A_EPI*c0_EPI^m_EPI))^(1/m_EPI)*c0_EPI+c0_EPI

EPI_pore_fraction = EPI_pore_fraction_gamma(EPI_concentration)




# for conversion of pore fraction to pore size

load("/data/Evaluation/Porosity/EPI/Pore size/pore_size_fitting_constants_EPI.rda")


EPI_pore_size = Dwall_EPI*EPI_pore_fraction^(1/n_EPI)/(1-EPI_pore_fraction^(1/n_EPI))


for_theory_pore_fraction_EPI=EPI_pore_fraction_gamma(for_theory_x)

for_theory_pore_diameter_EPI =Dwall_EPI*for_theory_pore_fraction_EPI^(1/n_EPI)/(1-for_theory_pore_fraction_EPI^(1/n_EPI))


overview_EPI$pore_fraction = EPI_pore_fraction_gamma(overview_EPI$polymer_conc_mgmL)

overview_EPI$pore_diameter = Dwall_EPI*overview_EPI$pore_fraction^(1/n_EPI)/(1-overview_EPI$pore_fraction^(1/n_EPI))

plot(overview_EPI$pore_diameter,overview_EPI$Gprime,log="xy",xlab="Pore diameter [micrometer]",ylab="Gprime [Pa]",pch=21,bg="black",xlim=xlim,cex=1.5,main="C) Storage modulus vs. pore diameter",ylim=c(10,3e4),yaxt="n",xaxt="n")

axis(side=2,at=c((1:9)*10,(1:9)*100,(1:10)*1000,20000,30000),labels=c(10,rep("",8),100,rep("",8),1000,rep("",8),10000,"",""),cex.axis=1.5,las=2)

axis(side=1,at=c((1:9)*10,(1:9)*100,1000),labels=c(expression(10),rep("",8),100,rep("",8),1000),cex.axis=1.5)



lines(for_theory_pore_diameter_EPI,Gprime_theory,type="l",lty=1)











EPI_pore_fraction


load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")
load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/polynomial_model_Gprime_Sephacryl_S200.rda")

load("/data/Evaluation/Porosity/Sephacryl_S200/Pore fraction/sephacryl_S200_porosity.rda")




for_theory_x= exp(seq(from=log(25),to=log(120),length.out=200))

for_theory_sephacryl_pore_fraction=sephacryl_pore_fraction_gamma(for_theory_x)


Gprime_theory=polynomial_model(for_theory_x,A_sephacryl_S200,c0_sephacryl_S200,m_sephacryl_S200)


overview_sephacryl_S200$pore_fraction= sephacryl_pore_fraction_gamma(overview_sephacryl_S200$polymer_conc_mgmL)

sephacryl_S200_concentration = (Gprime_desired/(A_sephacryl_S200*c0_sephacryl_S200^m_sephacryl_S200))^(1/m_sephacryl_S200)*c0_sephacryl_S200+c0_sephacryl_S200


sephacryl_S200_pore_fraction = sephacryl_pore_fraction_gamma(sephacryl_S200_concentration)



load("/data/Evaluation/Porosity/Sephacryl_S200/Pore size/pore_size_fitting_constants_sephacryl_S200.rda")

for_theory_pore_diameter_sephacryl =D_sephacryl*for_theory_sephacryl_pore_fraction^(1/n_sephacryl)/(1-for_theory_sephacryl_pore_fraction^(1/n_sephacryl))

overview_sephacryl_S200$pore_diameter = D_sephacryl*overview_sephacryl_S200$pore_fraction^(1/n_sephacryl)/(1-overview_sephacryl_S200$pore_fraction^(1/n_sephacryl))

lines(overview_sephacryl_S200$pore_diameter, overview_sephacryl_S200$Gprime,pch=1,col="black",type="p",cex=1.5)




lines(for_theory_pore_diameter_sephacryl,Gprime_theory,type="l",lty=2)



legend("topright",legend=c("EPI biomaterial","Sephacryl S200"),pch=c(21,21),col=rep("black",2),pt.bg=c("black","white"),cex=1.5,lty=c(1,2))




sephacryl_pore_size = D_sephacryl*sephacryl_S200_pore_fraction^(1/n_sephacryl)/(1-sephacryl_S200_pore_fraction^(1/n_sephacryl))



dev.off()


