
library(plot.counts)

library(rheologyEvaluation)

library(effsize)







# Utility function to get yield point characteristics
get_yield_from_stress_sweep<-function(sweeps,threshold_plateau)
{
    
    
    yield = data.frame(Full_File = sort(unique(sweeps$Full_File)), polymer_conc_mgmL=NA,yield_strain=NA,yield_stress=NA,yield_strain_last_measured=NA,
    yield_stress_last_measured=NA,yield_strain_evaluation_possible=FALSE)
    
    
    sweeps$log_Gprime_Pa=log(sweeps$Gprime_Pa)
    sweeps$log_Gprimeprime_Pa=log(sweeps$Gprimeprime_Pa)
    sweeps$log_Gamma_in_percent=log(sweeps$Gamma_in_percent)
    sweeps$log_tau_Pa=log(sweeps$tau_Pa)
    
    
    
    for(theFile in unique(sweeps$Full_File))
    {
        sweep=sweeps[sweeps$Full_File==theFile,]
        
        yield$polymer_conc_mgmL[theFile==yield$Full_File]=sweeps[sweeps$Full_File==theFile,"polymer_conc_mgmL"][1]
        
        
        use_first = FALSE
        
        if(max(sweep$Gprime_Pa)<10) # These are difficult cases since with so soft materials, the random
        # fluctuations are important
        {
            
            
            # To start with, establish where the
            solid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]
            liquid_regime=(1:length(sweep$Gprime_Pa))[sweep$Gprime_Pa<sweep$Gprimeprime_Pa]
            
            if(1 %in% liquid_regime)
            {
                use_first=TRUE
            } else
            {
                
                
                
                # first transition: we have some liquid regime above the solid regime
                if(any(liquid_regime>min(solid_regime)))
                {
                    first_liquid = min(liquid_regime[liquid_regime>min(solid_regime)])
                    
                    last_solid = first_liquid-1
                    
                    while(last_solid %in% liquid_regime)
                    {
                        last_solid=last_solid-1
                    }
                    
                    while(last_solid %in% solid_regime)
                    {
                        last_solid=last_solid-1
                    }
                    
                    last_solid=last_solid+1
                    
                    last_solid = max(last_solid,1)
                    
                    sweep=sweep[last_solid:first_liquid,]
                } else
                {
                    # We can't do much, just leave it for evaluation as is
                }
                
                
            }
            
            
        }
        
        
        
        
        yield$polymer_conc_mgmL[theFile==yield$Full_File]=sweeps[sweeps$Full_File==theFile,"polymer_conc_mgmL"][1]
        
        
        if(use_first)
        {
            yield$yield_strain[theFile==yield$Full_File]=sweep$Gamma_in_percent[1]
            yield$yield_stress[theFile==yield$Full_File]=sweep$tau_Pa[1]
            
        } else {
            
            if(any(sweep$log_Gamma_in_percent[sweep$Gprime_Pa>=sweep$Gprimeprime_Pa]<min(sweep$log_Gamma_in_percent[sweep$Gprime_Pa<sweep$Gprimeprime_Pa])))
            {
                
                yield$yield_strain[theFile==yield$Full_File]=
                exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
                Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_Gamma_in_percent"))["log_Gamma_in_percent"]
                
            }
            
            
            
            
            yield$yield_stress[theFile==yield$Full_File]=
            exp(evaluateYield(sweep,Gprime_column="log_Gprime_Pa",
            Gprimeprime_column="log_Gprimeprime_Pa",abscissa="log_tau_Pa"))["log_tau_Pa"]
            
        }
        
        
        
        
        
        yield$yield_stress_last_measured[theFile==yield$Full_File]=max(sweep$tau_Pa[sweep$tau_Pa<yield$yield_stress[theFile==yield$Full_File]])
        
        yield$yield_strain_last_measured[theFile==yield$Full_File]=max(sweep$Gamma_in_percent[sweep$tau_Pa<yield$yield_stress[theFile==yield$Full_File]])
        
        yield$yield_strain_evaluation_possible[theFile==yield$Full_File]=!is.na(yield$yield_strain[theFile==yield$Full_File])
        
        
        
        
        
        
        
        
    }
    
    
    return(yield)
    
    
    
    
    
    
    
    
}



load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")


stress_sweeps_EPI$Full_File=paste(stress_sweeps_EPI$folder,stress_sweeps_EPI$file,sep="/")

Gprime_low_strain = aggregate(Gprime_Pa ~ Full_File, stress_sweeps_EPI, function(x){x[1]})



# Use cup geometry only. The sephacryl control material was measured in cup geometry

EPI_yield=get_yield_from_stress_sweep(stress_sweeps_EPI[stress_sweeps_EPI$Geometry=="cup",],threshold_plateau)

EPI_yield$reason_of_exclusion="NA"


# If no G' / G'' crossing is found, the get_yield_from_stress_sweep will already return NA for the yield strain, and FALSE for the possibility to evaluate. Associate this with the proper reason

EPI_yield$reason_of_exclusion[!EPI_yield$yield_strain_evaluation_possible]="No G'/G'' crossing"


# Manual exclusions after looking manually through all the curves
# This concerns essentially too dilute samples which are in the sweep collection, but do not have proper yielding behaviour. This is particularly problematic with strain, which can assume randomly high values


EPI_yield$yield_strain_evaluation_possible["PasteDilutions_CupGeometry_DIH2O/200pct_StressSweep.txt"==EPI_yield$Full_File]=FALSE
EPI_yield$yield_strain["PasteDilutions_CupGeometry_DIH2O/200pct_StressSweep.txt"==EPI_yield$Full_File]=NA
EPI_yield$yield_stress["PasteDilutions_CupGeometry_DIH2O/200pct_StressSweep.txt"==EPI_yield$Full_File]=NA
EPI_yield$reason_of_exclusion["PasteDilutions_CupGeometry_DIH2O/200pct_StressSweep.txt"==EPI_yield$Full_File]="Low concentration, no proper yielding behaviour"


EPI_yield$yield_strain_evaluation_possible["PasteDilutions_CupGeometry_DIH2O/400pct_StressSweep_ForGPrimeValue.txt"==EPI_yield$Full_File]=FALSE
EPI_yield$yield_strain["PasteDilutions_CupGeometry_DIH2O/400pct_StressSweep_ForGPrimeValue.txt"==EPI_yield$Full_File]=NA
EPI_yield$yield_stress["PasteDilutions_CupGeometry_DIH2O/400pct_StressSweep_ForGPrimeValue.txt"==EPI_yield$Full_File]=NA
EPI_yield$reason_of_exclusion["PasteDilutions_CupGeometry_DIH2O/400pct_StressSweep_ForGPrimeValue.txt"==EPI_yield$Full_File]="Low concentration, no proper yielding behaviour"







load("/data/Evaluation/Rheology/Stress Sweeps/Sephacryl_S200/stress_sweeps_sephacryl_S200.rda")


stress_sweeps_sephacryl_S200=stress_sweeps_sephacryl_S200[stress_sweeps_sephacryl_S200$Geometry=="cup",] # Impose cup geometry; currently, there are anyways only cup measurements

stress_sweeps_sephacryl_S200$Full_File=paste(stress_sweeps_sephacryl_S200$folder,stress_sweeps_sephacryl_S200$file,sep="/")


Gprime_low_strain = aggregate(Gprime_Pa ~ Full_File, stress_sweeps_sephacryl_S200, function(x){x[1]})




sephacryl_S200_yield=get_yield_from_stress_sweep(stress_sweeps_sephacryl_S200,threshold_plateau)


sephacryl_S200_yield$reason_of_exclusion="NA"


# If no G' / G'' crossing is found, the get_yield_from_stress_sweep will already return NA for the yield strain, and FALSE for the possibility to evaluate. Associate this with the proper reason

sephacryl_S200_yield$reason_of_exclusion[!sephacryl_S200_yield$yield_strain_evaluation_possible]="No G'/G'' crossing"




# Multiple G' / G'' crossings detected by looking through the curves prior to analysis
sephacryl_S200_yield$yield_strain_evaluation_possible["control_sephacryl_S200/Sephacryl S200_rheometry/full stress sweep/07_30_stress_sweep_cylinder_F9.txt"==sephacryl_S200_yield$Full_File]=FALSE
sephacryl_S200_yield$yield_strain["control_sephacryl_S200/Sephacryl S200_rheometry/full stress sweep/07_30_stress_sweep_cylinder_F9.txt"==sephacryl_S200_yield$Full_File]=NA
sephacryl_S200_yield$yield_stress["control_sephacryl_S200/Sephacryl S200_rheometry/full stress sweep/07_30_stress_sweep_cylinder_F9.txt"==sephacryl_S200_yield$Full_File]=NA
sephacryl_S200_yield$reason_of_exclusion["control_sephacryl_S200/Sephacryl S200_rheometry/full stress sweep/07_30_stress_sweep_cylinder_F9.txt"==sephacryl_S200_yield$Full_File]="Low concentration, no proper yielding behaviour"



pdf("Fig_S12b.pdf")

xlim=c(0,80)

#strain_acceptance_factor = 3 # Factor of how close we have to be with the last measurement to the interpolated
# yield point for the strain to be valid. 0 = no selection





EPI_difference_to_last_solid_state_point_OK = !((EPI_yield$yield_strain/EPI_yield$yield_strain_last_measured)>3)


mean(EPI_yield$yield_strain/EPI_yield$yield_strain_last_measured,na.rm=TRUE)

plot(yield_strain ~ polymer_conc_mgmL,EPI_yield[EPI_difference_to_last_solid_state_point_OK,],pch=21,cex=2,bg="black",ylim=c(0,110),xlim=xlim)


sephacryl_S200_difference_to_last_solid_state_point_OK = !((sephacryl_S200_yield$yield_strain/sephacryl_S200_yield$yield_strain_last_measured)>3)


mean(sephacryl_S200_yield$yield_strain/sephacryl_S200_yield$yield_strain_last_measured,na.rm=TRUE)


lines(yield_strain ~ polymer_conc_mgmL,sephacryl_S200_yield[sephacryl_S200_difference_to_last_solid_state_point_OK,],pch=21,cex=2,bg="white",ylim=c(0,110),xlim=xlim,type="p")

legend("topleft",legend=c("EPI","Sephacryl S200"),pch=c(21,21),pt.bg=c("black","white"),cex=2)


sephacryl_S200_yield$sample="Sephacryl S200"
EPI_yield$sample="EPI"

regression_dataset=rbind(sephacryl_S200_yield[sephacryl_S200_difference_to_last_solid_state_point_OK,],EPI_yield[EPI_difference_to_last_solid_state_point_OK,])

linmod=lm(yield_strain ~ polymer_conc_mgmL+sample,regression_dataset)

n_S6_4b=aggregate(yield_strain ~ sample,regression_dataset,FUN=length)

cat("\nStatistical reporting Item 27")
cat("\n\nReporting Fig. S12b =======================")
cat("\nGroup size")
n_S6_4b

cat("\nTesting of residuals for linearity")
shapiro.test(resid(linmod))

cat("\n\nLinear model Fig. S6-4b: Influence of polymer concentration and material identity on yield strain\n")
summary(linmod)

cat("\nConfidence intervals linear model Fig. S6-4b")
confint(linmod)


pvals=coefficients(summary(linmod))[,"Pr(>|t|)"]
pvals=pvals[2:length(pvals)] # no interest in intercept
cat("\nIndividual P-values with Bonferroni correction")
p.adjust(pvals,method="bonferroni")




dev.off()

pdf("Fig_S12a.pdf")

plate_sweeps=stress_sweeps_EPI[stress_sweeps_EPI$Geometry=="plate",]

# We need to do some disambiguation, because there are several sweeps in a single file



xcoords=barplot(c(EPI_yield$yield_strain/EPI_yield$yield_strain_last_measured,sephacryl_S200_yield$yield_strain/sephacryl_S200_yield$yield_strain_last_measured),names.arg=c(rep("EPI",dim(EPI_yield)[1]),rep("S200",dim(sephacryl_S200_yield)[1])),las=2)


lines(c(min(xcoords),max(xcoords)),rep(3,2),type="l",lty=2)


dev.off()
pdf("Fig_S12c.pdf")


# Comparison to Juvederm





load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")

# Juvederm has multiple sweeps in one file, so we need to make them unique:

stress_sweeps_juvederm$trial=1


stress_sweeps_juvederm$Full_File=paste(stress_sweeps_juvederm$folder,stress_sweeps_juvederm$file,sep="/")

stress_sweeps_juvederm$trial=1

for(theFile in unique(stress_sweeps_juvederm$Full_File))
{
    current_data = stress_sweeps_juvederm[stress_sweeps_juvederm$Full_File==theFile,]
    
    t_s=current_data$t.en.s[1]
    
    
    trial=1
    
    for(ind in 1:length(current_data$t.en.s))
    {
        if(current_data$t.en.s[ind]<t_s)
        {
            trial=trial+1
        }
        t_s = current_data$t.en.s[ind]
        current_data$trial[ind]=trial
    }
    
    stress_sweeps_juvederm[stress_sweeps_juvederm$Full_File==theFile,]=current_data
    
}

stress_sweeps_juvederm$Full_File=paste(stress_sweeps_juvederm$Full_File,stress_sweeps_juvederm$trial,sep="_trial_")


juvederm_yield=get_yield_from_stress_sweep(stress_sweeps_juvederm,threshold_plateau)


juvederm_difference_to_last_solid_state_point_OK = !((juvederm_yield$yield_strain/juvederm_yield$yield_strain_last_measured)>3)



mean_yield_strain_EPI=mean(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK],na.rm=TRUE)
mean_yield_strain_EPI
sd_yield_strain_EPI=sd(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK],na.rm=TRUE)
sd_yield_strain_EPI

mean_yield_strain_sephacryl_S200=mean(sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK],na.rm=TRUE)
mean_yield_strain_sephacryl_S200
sd_yield_strain_sephacryl_S200=sd(sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK],na.rm=TRUE)
sd_yield_strain_sephacryl_S200



mean_yield_strain_juvederm=mean(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK])
sd_yield_strain_juvederm=sd(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK])


barplot_with_errorbars(
c(mean_yield_strain_sephacryl_S200,mean_yield_strain_juvederm,mean_yield_strain_EPI)
,sd_height=c(sd_yield_strain_sephacryl_S200,sd_yield_strain_juvederm,sd_yield_strain_EPI
),names.arg=c("Sephacryl\nS200","HA control","EPI"))


dev.off()


cat("\n\nReporting for Fig. S12c  ======================")
# T tests:

# P1: Sephacryl Juvéderm
# P2: Sephacryl EPI
# P3: Juvederm EPI

cat("\nSample size")
cat("\n\tEPI: ")
for_n_EPI=EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK]

sum(!is.na(for_n_EPI))

cat("\n\tSephacryl S200: ")

for_n_Sephacryl=sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]
sum(!is.na(for_n_Sephacryl))
cat("\n\tJuvederm Voluma: ")
for_n_Juvederm=juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK]
sum(!is.na(for_n_Juvederm))



pvals=rep(NA,3)

names(pvals)=c("S200 - Juv", "S200 - EPI", "Juv - EPI")



t_S200_Juv=t.test(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK],sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK])

pvals["S200 - Juv"]=t_S200_Juv[["p.value"]]







t_S200_EPI=t.test(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK],sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK])

pvals["S200 - EPI"]=t_S200_EPI[["p.value"]]

t_Juv_EPI=t.test(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK],juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK])

pvals["Juv - EPI"]=t_Juv_EPI[["p.value"]]

pvals[]=p.adjust(pvals, method="bonferroni")



# Normality test: Sephacryl - Juvederm
cat("\n4c:Normality test: Sephacryl - Juvederm")

shapiro.test(c(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK]-mean_yield_strain_juvederm,sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]-mean_yield_strain_sephacryl_S200))


# Sephacryl - EPI
cat("\nS12c:Normality test: Sephacryl - EPI")
shapiro.test(c(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK]-mean_yield_strain_EPI,sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]-mean_yield_strain_sephacryl_S200))

# And Juvederm - EPI
cat("\nS12c:Normality test: Juvederm - EPI")

shapiro.test(c(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK]-mean_yield_strain_EPI,juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK]-mean_yield_strain_juvederm))


cat("\nS12c T-tests for differences between materials")
cat("\n\tT-test details: Sephacryl - Juvederm")
t_S200_Juv
cat("\n\tT-test details: Sephacryl - EPI")
t_S200_EPI
cat("\n\tT-test details: Juvederm - EPI")
t_Juv_EPI






# Effect size


cat("\nS12c Effect size (Hedge's with delta/sd, sd being from pooled a priori unequal variance)")




# Juvederm vs. Sephacryl
dataframe_for_cohen_d = data.frame(yield_strain=
c(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK],
sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]), material=c(rep("Juv",length(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK])),rep("Sephacryl S200",length(sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]))))

cat("\n\tHedge's g: Sephacryl - Juvederm")
cohen.d(yield_strain ~ material, dataframe_for_cohen_d,hedges.correction=TRUE)


# EPI vs. Sephacryl
dataframe_for_cohen_d = data.frame(yield_strain=
c(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK],
sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]), material=c(rep("EPI",length(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK])),rep("Sephacryl S200",length(sephacryl_S200_yield$yield_strain[sephacryl_S200_difference_to_last_solid_state_point_OK]))))

cat("\n\tHedge's g: Sephacryl - EPI")
cohen.d(yield_strain ~ material, dataframe_for_cohen_d,hedges.correction=TRUE)






# EPI vs. Juvederm

dataframe_for_cohen_d = data.frame(yield_strain=
c(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK],
EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK]),
material=c(rep("Juv",length(juvederm_yield$yield_strain[juvederm_difference_to_last_solid_state_point_OK])),rep("Sephacryl EPI",length(EPI_yield$yield_strain[EPI_difference_to_last_solid_state_point_OK]))))

cat("\n\tHedge's g: Juvederm - EPI")
cohen.d(yield_strain ~ material, dataframe_for_cohen_d,hedges.correction=TRUE)


cat("\n\nFig. S12c: Bonferroni-corrected P-values")
pvals

