
# Plotting library
library(plot.counts)
library(mblm)
library(effsize)



pdf("Fig_S13a.pdf")


load("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda")

IDs=unique(sweeps_all_materials$ID)





Design_shape=c(rep("irregular",3),rep("irregular",2),rep("spherical",2),"spherical")
names(Design_shape)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")

Design_porosity=c(rep(1,3),rep(0,2),rep(0,2),1)
names(Design_porosity)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")

# CMC is 21, HA is 22, Alginate and others 23. Like in Fig. 5b and Fig. 5c
pchs = c(21,23,22,21,23,23,21,23)
names(pchs)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")



col_irreg_porous = "#083045"
col_irreg_non_porous = "#b44336"
col_spherical_non_porous="#f5b908"
col_spherical_porous = "#ffffff"



col_irreg_porous_border = "#78cce5ff"
col_irreg_non_porous_border = "#b44336"
col_spherical_non_porous_border="#f5b908"
col_spherical_porous_border = "#aaaaaa"

col_irreg_porous_interior = "#6ed2efff"
col_irreg_non_porous_interior = "#e3a7a0"
col_spherical_non_porous_interior="#fadc84"
col_spherical_porous_interior = "#dddddd"

col_irreg_porous_interior_yield = "#1286a8"
col_irreg_non_porous_interior_yield = "#98382dff"
col_spherical_non_porous_interior_yield="#ffbe01ff"
col_spherical_porous_interior_yield = "#999999"



cols_border=c(rep(col_irreg_porous_border,3),rep(col_irreg_non_porous_border,2),rep(col_spherical_non_porous_border,2),col_spherical_porous_border)
names(cols_border)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")


cols_interior=c(rep(col_irreg_porous_interior,3),rep(col_irreg_non_porous_interior,2),rep(col_spherical_non_porous_interior,2),col_spherical_porous_interior)
names(cols_interior)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")

cols_interior_yield=c(rep(col_irreg_porous_interior_yield,3),rep(col_irreg_non_porous_interior_yield,2),rep(col_spherical_non_porous_interior_yield,2),col_spherical_porous_interior_yield)
names(cols_interior_yield)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")





xlim=c(0.5,2000)
ylim=c(1,20000)

cex=0.8


plot.new()
plot.window(xlim,ylim,log="xy")
box(col="black")
Axis(side=1)
Axis(side=2)
title(xlab="Shear stress tau [Pa]",ylab="G' [Pa]",main="Suspensions of porous particles")

# make a materials list
material_list= yield_info_all_materials$material[match(IDs,yield_info_all_materials$ID)]
names(material_list)=IDs

IDs=c(sample(IDs[Design_shape[material_list[IDs]]=="irregular"]),sample(IDs[Design_shape[material_list[IDs]]=="spherical"]))

for(theID in IDs)
{

current_sweep = sweeps_all_materials[sweeps_all_materials$ID==theID,]
theMaterial = current_sweep$Material[1]
if(Design_porosity[theMaterial]==1)
{
col_border=cols_border[theMaterial]
col_interior=cols_interior[theMaterial]
pch=pchs[theMaterial]
current_sweep_pre_yield=current_sweep[current_sweep$Gprime_Pa>current_sweep$Gprimeprime_Pa,]
yield_line=current_sweep_pre_yield[dim(current_sweep_pre_yield)[1],]
yield_line$tau_Pa=yield_info_all_materials[yield_info_all_materials$ID==theID,"tau_Pa"]
yield_line$Gprime_Pa=yield_info_all_materials[yield_info_all_materials$ID==theID,"Gprime_Pa"]
yield_line$Gprimeprime_Pa=yield_info_all_materials[yield_info_all_materials$ID==theID,"Gprime_Pa"]
yield_line$Gprimeprime_Pa=yield_info_all_materials[yield_info_all_materials$ID==theID,"Gprime_Pa"]
yield_line$Gamma_in_percent=yield_info_all_materials[yield_info_all_materials$ID==theID,"strain"]*100
current_sweep_pre_yield=rbind(current_sweep_pre_yield,yield_line)
lines(current_sweep_pre_yield$tau_Pa, current_sweep_pre_yield$Gprime_Pa, pch=pch,col=col_border,bg=col_interior,type="b",cex=cex)
}
}


for(theID in IDs)
{

current_sweep = sweeps_all_materials[sweeps_all_materials$ID==theID,]
theMaterial = current_sweep$Material[1]
if(Design_porosity[theMaterial]==1)
{
col_border=cols_border[theMaterial]
col_interior_yield=cols_interior_yield[theMaterial]
pch=pchs[theMaterial]

lines(yield_info_all_materials[yield_info_all_materials$ID==theID,"tau_Pa"], yield_info_all_materials[yield_info_all_materials$ID==theID,"Gprime_Pa"], pch=pch,col="black",bg=col_interior_yield,type="b",cex=2)
}
}

porous_materials=names(Design_porosity)[Design_porosity==1]
legend("bottomleft",legend=porous_materials,pch=pchs[porous_materials],col=cols_border[porous_materials],pt.bg=cols_interior[porous_materials])


polymer=c("CMC","Alginate","HA","CMC","HA","Dextran","CMC","Gelatin")
names(polymer)=c("EPI - CMC","EPI - Alginate","EPI - Hyaluronic_acid","CMC_non_porous_irregular", "Juvederm", "Sephacryl S200", "CMC_spherical_small", "cultisphere")

yield_info_all_materials$logGprime_Pa=log(yield_info_all_materials$Gprime_Pa)
yield_info_all_materials$logtau_Pa=log(yield_info_all_materials$tau_Pa)

yield_info_all_materials$Design_shape=Design_shape[yield_info_all_materials$material]
yield_info_all_materials$polymer=polymer[yield_info_all_materials$material]

yield_info_all_materials$Design_porosity=Design_porosity[yield_info_all_materials$material]

yield_info_porous = yield_info_all_materials[Design_porosity[yield_info_all_materials$material]==1,]







# The overall shapiro test for a linear regression is significant
shapiro.test(resid(lm(logGprime_Pa ~ logtau_Pa+Design_shape,yield_info_porous)))
# The irregular particles are fine
shapiro.test(resid(lm(logGprime_Pa ~ logtau_Pa,yield_info_porous[yield_info_porous$Design_shape=="irregular",])))

# but the spherical ones are not
shapiro.test(resid(lm(logGprime_Pa ~ logtau_Pa,yield_info_porous[yield_info_porous$Design_shape=="spherical",])))

# So we can address the slope in the irregular particles via linear regression
summary(lm(logGprime_Pa ~ logtau_Pa,yield_info_porous[yield_info_porous$Design_shape=="irregular",]))


linmod_non_parametric=mblm(logGprime_Pa ~ logtau_Pa,yield_info_porous )

# With the realization that both slopes are about 1, we can do a t-test

shapiro.test((yield_info_porous$logGprime_Pa-yield_info_porous$logtau_Pa)[yield_info_porous$Design_shape=="spherical"])



cat("\nStatistical reporting (Item 89)\n\n")

cat("\n\nSpherical:N=n=",length(yield_info_porous$logGprime_Pa[yield_info_porous$Design_shape=="spherical"]))
cat("\nIrregular:N=n=",length(yield_info_porous$logGprime_Pa[yield_info_porous$Design_shape=="irregular"]))
cat("\n\nNormality in the spherical group")
shapiro.test((yield_info_porous$logGprime_Pa-yield_info_porous$logtau_Pa)[yield_info_porous$Design_shape=="spherical"])
cat("\n\nNormality in the irregular group")
shapiro.test((yield_info_porous$logGprime_Pa-yield_info_porous$logtau_Pa)[yield_info_porous$Design_shape=="irregular"])

t.test((-logGprime_Pa+logtau_Pa)~Design_shape,yield_info_porous)

cohen.d((-logGprime_Pa+logtau_Pa)~Design_shape,yield_info_porous)


dev.off()
