

library(plot.counts)
library(effsize)

pdf("Fig_S13c.pdf")


load("/data/Evaluation/Rheology/Stress Sweeps/yield_info_all_materials.rda")



yield_info_all_materials$material=factor(yield_info_all_materials$material,levels=c("EPI - CMC","EPI - Hyaluronic_acid","EPI - Alginate","CMC_non_porous_irregular","Juvederm","CMC_spherical_small",                                "Sephacryl S200","cultisphere"
))

# To have the numerical values per material
yield_info_aggregated = aggregate(yield_info_all_materials[,c("strain","tau_rel")], by=list(material=yield_info_all_materials$material),FUN=mean)

yield_info_aggregated_sd = aggregate(yield_info_all_materials[,c("strain","tau_rel")], by=list(material=yield_info_all_materials$material),FUN=sd)


# Statistics

pvals_strain=get_t_test_matrix(treatment_factor=yield_info_all_materials$material, data=yield_info_all_materials$strain)[1,]
t_vals = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
function(x){t.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$statistic})
w_vals = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
function(x){wilcox.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$statistic})

degrees_of_freedom_t = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=function(x){t.test(x,yield_info_all_materials$Solidity[yield_info_all_materials$material=="EPI - CMC"])$parameter})


shapiro_strain = aggregate(strain ~ material,yield_info_all_materials,FUN=function(x){shapiro.test(x)$p.val} )

shapiro_control = shapiro_strain$strain[shapiro_strain$material=="EPI - CMC"]

confidence_lower_bound_t = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
    function(x){t.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$conf.int[1]})
confidence_upper_bound_t = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
    function(x){t.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$conf.int[2]})
confidence_lower_bound_w = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
    function(x){wilcox.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"],conf.int = TRUE)$conf.int[1]})
confidence_upper_bound_w = aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
    function(x){wilcox.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"],conf.int = TRUE)$conf.int[2]})

cohen_distance=aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
function(x){cohen.d(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$estimate})

r2_from_wilcox=aggregate(yield_info_all_materials$strain, by=list(material=yield_info_all_materials$material),FUN=
function(x){
    pval=wilcox.test(x,yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])$p.value
    Zval=qnorm(pval/2)
    return(Zval^2/(length(x)+length(yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"])))
})



confidence_lower_bound=confidence_lower_bound_t
confidence_upper_bound=confidence_upper_bound_t

non_parametric=shapiro_strain$strain<=0.05 | shapiro_control<=0.05

confidence_lower_bound$x[non_parametric]=confidence_lower_bound_w$x[non_parametric]
confidence_upper_bound$x[non_parametric]=confidence_upper_bound_w$x[non_parametric]




# If the shapiro Wilks test for normality indicates departure from normality, use Wilcoxon instead
for(m in names(pvals_strain))
{
    if(shapiro_strain[match("EPI - CMC", shapiro_strain$material),"strain"] <= 0.05 |
    shapiro_strain[match(m, shapiro_strain$material),"strain"] <= 0.05)
    {
        pvals_strain[m]=wilcox.test(yield_info_all_materials$strain[yield_info_all_materials$material=="EPI - CMC"],yield_info_all_materials$strain[yield_info_all_materials$material==m])$p.val
    }
}



# Bonferroni adjustment

pvals_strain_Bonferroni=pvals_strain*(length(pvals_strain)-1) # Test EPI-EPI does not count
pvals_strain_Bonferroni[pvals_strain_Bonferroni>1]=1


# Output statistical values to Console
cat("\nStatistical reporting (Item 91)")
cat("\nN=n: number of rheological sweeps analyzed = ", dim(yield_info_all_materials)[1]  )
cat("\nNumber of groups (materials) = ", length(unique(yield_info_all_materials$material)))
cat("\nBonferroni testing: ",length(pvals_strain)-1," tests")
cat("\n\nShapiro-Wilks for strain: normality for each material")
shapiro_strain
cat("\n\nConfidence intervals: Delta from EPI to material at hand. Lower bounds:\n")
confidence_lower_bound
cat("\nConfidence intervals: Delta from EPI to material at hand. Upper bounds:\n")
confidence_upper_bound

statistic=t_vals
statistic$x=paste("t=",statistic$x,sep="")
statistic$x[non_parametric]=paste("W=",w_vals$x,sep="")[non_parametric]

cat("\n\nStatistic: depends on Shapiro-Wilks value, either t-test (t-value) or Wilcox test (W-value)")
statistic

cat("\n\nDegrees of freedom (t statistics only)")
degrees_of_freedom_t$x[non_parametric]="NA"
degrees_of_freedom_t


cat("\n\nEffect size: depends on Shapiro-Wilks value, either cohen's d with normality or otherwise r^2 from Z^2/N:")
effect_size=cohen_distance
effect_size$x=paste("Cohen's d=",effect_size$x,sep="")
effect_size$x[non_parametric]=paste("r2=",r2_from_wilcox$x,sep="")[non_parametric]
effect_size



cat("\nP-values strain, EPI vs.\n")
pvals_strain
cat("\n\nP-values strain, Bonferroni correction EPI vs.\n")
pvals_strain_Bonferroni



cat("\n\n\n For Shapiro-Wilks P-values below 0.05, Wilcoxon testing was used, t-tests otherwise")

# Plotting the graphs



xvals=barplot_dots(treatment=yield_info_all_materials$material,data=yield_info_all_materials[,c("strain")],pch=21,cex=2,bg="black",lateral_shift=0.05,y_threshold_for_shifting=0.02,ylab="strain",sig_codes=significance_labels(pvals_strain_Bonferroni),sig.cex=5,las=2,main="Yield strain material collection")


dev.off()




