library(plot.counts)




load("/data/Evaluation/Ejection Force/EPI/ejection_force_data_aggregated.rda")

all_data=ejection_force_data_as_dataframe


pdf("Fig_S15a.pdf")

for_max = aggregate(Force_N ~ injection_speed_mm_sec+batch+File,all_data,FUN=max)





max_agg = aggregate(Force_N ~ injection_speed_mm_sec+batch,for_max,FUN=mean)
max_agg_sd = aggregate(Force_N ~ injection_speed_mm_sec+batch,for_max,FUN=sd)
max_agg_length = aggregate(Force_N ~ injection_speed_mm_sec+batch,for_max,FUN=length)
colnames(max_agg_length)[colnames(max_agg_length)=="Force_N"]="n"

cat("Reporting: Sample sizes per condition")
max_agg_length
cat("\nTotals per material (AIR_NO_CANNULA not in supplementary 7)")
aggregate(n ~ batch,max_agg_length,FUN=sum)


to_plot=max_agg[max_agg$batch=="PB46" | max_agg$batch=="DI" | max_agg$batch=="AIR",]
to_plot_sd = max_agg_sd[max_agg_sd$batch=="PB46" | max_agg$batch=="DI" | max_agg$batch=="AIR",]

plot_counts(to_plot$injection_speed_mm_sec,to_plot$Force_N,sd_y=to_plot_sd$Force_N,xlab="Injection rate [mm/s]",ylab="Maximum Force [N]",groups=to_plot$batch,log="x",ylim=c(0,16),pch=c(2,1,21),bg=c("white","white","black"),col="black",main="B) Maximum force",cex=2,xaxt="n")

axis(side=1,at=c((1:9)*0.1,1:9,(1:5)*10),labels=c(expression("0.1"),rep("",8),"1.0",rep("",8),"10",rep("",3),"50"))


legend("topleft",legend=c("Elastic porous injectable","DI water","Air"),pch=c(21,1,2),col=c("black","black","black"),pt.bg=c("black","white","white"),cex=2,lty=c(1,1,1))



dev.off()
pdf("Fig_S15b.pdf")

comparison=to_plot[to_plot$injection_speed_mm_sec>0.5 &to_plot$batch %in% c("PB46","DI"),]
comparison_sd=to_plot_sd[to_plot_sd$injection_speed_mm_sec>0.5 & to_plot$batch %in% c("PB46","DI"),]

plot_counts(comparison$injection_speed_mm_sec,comparison$Force_N,sd_y=comparison_sd$Force_N,xlab="Injection rate [mm/s]",ylab="Maximum Force [N]",groups=comparison$batch,ylim=c(0,16),pch=c(1,21),bg=c("white","black"),col="black",main="B) Maximum force",cex=2,type="p")






linmod_comparison=lm(Force_N ~ injection_speed_mm_sec*batch, comparison)
cat("\n\nReporting for the linear model in Fig. S15b and its analysis in Table S7-1. This dataset concerns higher injection rates (>=1mm/s) and compares EPI and DI. Item 33")
cat("\nNormality testing of the residuals of the linear model (Force as a function of injection rate and material (DI vs. EPI) + interaction")
shapiro.test(resid(linmod_comparison))


for_theory=c(0,40)


lines(for_theory,predict(linmod_comparison,newdata=data.frame(injection_speed_mm_sec=for_theory,batch="PB46")),col="red")
lines(for_theory,predict(linmod_comparison,newdata=data.frame(injection_speed_mm_sec=for_theory,batch="DI")),col="red")



dev.off()


cat("\nOverall F-statistics and degrees of freedom")
summary(linmod_comparison)$fstatistic
cat("\nAnova analysis of the linear model with interaction")
anova(linmod_comparison)
cat("\nEffect size measure: Adjusted R2")
summary(linmod_comparison)$adj.r.squared
cat("\nOverall P-value")
pf(summary(linmod_comparison)$fstatistic["value"],df1=summary(linmod_comparison)$fstatistic["numdf"],df2=summary(linmod_comparison)$fstatistic["dendf"],lower.tail=FALSE)
cat("\nP-vals for individual terms after Bonferroni correction")
pvals_anova=anova(linmod_comparison)$"Pr(>F)"
pvals_anova=pvals_anova[1:(length(pvals_anova)-1)]
p.adjust(pvals_anova,method="bonferroni")



cat("\nMinimal force to move piston with water (Global Y-intercept):")
confint(linmod_comparison,"(Intercept)")
cat("\nAdditional minimal contribution of EPI scaffold (yielding):")
confint(linmod_comparison,"batchPB46")

cat("\nFraction of variance explained by individual terms")
ssq=anova(linmod_comparison)[,"Sum Sq"]
names(ssq)=rownames(anova(linmod_comparison))
ssq=ssq/sum(ssq)
ssq
