library(plot.counts)

library(rheologyEvaluation)

# Load data files, both literature and measured
load(file="/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/stress_sweeps_adipose_tissue_mouse.rda")

load(file="/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/adipose_tissue_rheology_data_patel.rda")

load(file="/data/Evaluation/For Supplementaries/Supplementary 9 Material comparison/adipose_tissue_rheology_data_yoo.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI.rda")

load("/data/Evaluation/Rheology/Stress Sweeps/Juvederm_Voluma/stress_sweeps_juvederm.rda")

# Aggregate with reasonable logarithmic strain steps
stress_sweeps_adipose_tissue_mouse$Gamma_in_percent_discrete=10^(round(log(stress_sweeps_adipose_tissue_mouse$Gamma_in_percent,10)*5)/5)

# First per sweep to give each sweep the same weight
aggregated_per_sweep = aggregate(stress_sweeps_adipose_tissue_mouse[,c("tau_Pa","Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent")],by=stress_sweeps_adipose_tissue_mouse[,c("Gamma_in_percent_discrete","Material","overview_index")],FUN=mean)



all_aggregated=aggregate(aggregated_per_sweep[,c("tau_Pa","Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent")],by=aggregated_per_sweep[,c("Gamma_in_percent_discrete","Material")],FUN=mean)

all_aggregated$n=aggregate(aggregated_per_sweep[,c("tau_Pa","Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent")],by=aggregated_per_sweep[,c("Gamma_in_percent_discrete","Material")],FUN=length)$tau_Pa

max_n = aggregate(n ~ Material, all_aggregated, FUN=max)

all_aggregated=all_aggregated[all_aggregated$n==max_n$n[match(all_aggregated$Material,max_n$Material)],]

cex=1.5

xlim=c(0.01,500)
pdf("Fig_S17.pdf")

plot_counts(all_aggregated$Gamma_in_percent,all_aggregated$Gprime_Pa, log="xy",groups=all_aggregated$Material,ylim=c(30,4e3),main="S9-3. Comparison to adipose tissues",xlim=xlim,ylab="G' [Pa]",xlab="Strain (Deformation) [%]",xaxt="n",yaxt="n",col="black",pch=c(3,5))

# Axes with logarithmic scale
axis(side=2,at=c((1:9)*10,(1:9)*100,(1:10)*1000,20000),labels=c(expression("10 Pa"),rep("",8),"100 Pa",rep("",8),"1 kPa",rep("",8),"10 kPa",""),las=2)


axis(side=1,at=c((1:9)*1e-2,(1:9)*1e-1,(1:9),(1:9)*10,100,200,300),labels=c(expression("0.01%"),rep("",8),"0.1%",rep("",8),"1.0%",rep("",8),"10%",rep("",8),"100%","",""))


to_use_EPI=stress_sweeps_EPI

# Same curve as in Fig. 3f for comparison
to_use_EPI = stress_sweeps_EPI[round(stress_sweeps_EPI$polymer_conc_mgmL)==26 &stress_sweeps_EPI$Geometry=="cup",]


lines(to_use_EPI$Gamma_in_percent,to_use_EPI$Gprime_Pa,pch=21,type="b",cex=cex,bg="black")

# Here as well, same curve as in Fig. 3f

stress_sweeps_juvederm_agg = aggregate(stress_sweeps_juvederm[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent")],by=list(tau_Pa=stress_sweeps_juvederm$tau_Pa),FUN=mean)


# plot G''
lines(Gprime_Pa ~ Gamma_in_percent, stress_sweeps_juvederm_agg,pch=24,type="b",cex=cex,bg="white")



lines(adipose_tissue_rheology_data_patel$strain_percent,adipose_tissue_rheology_data_patel$G_star,type="b",col="black",pch=4)

lines(adipose_tissue_rheology_data_yoo$strain_percent,adipose_tissue_rheology_data_yoo$G_prime_Pa,type="l",col="black")



legend("bottomleft",legend=c("EPI - 26mg/mL (measured)","HA ctl (measured)","Adipose tissues","  Bovine retroorbital (Yoo et al.)","  Human subcutaneous abdominal (Patel et al.)","  Mouse subcutaneous (measured)","  Mouse visceral (measured)"),cex=1,pch=c(21,24,-1,-1,4,5,3),pt.cex=c(cex,cex,1,1,1,1,1),pt.bg=c("black",rep("white",6)),lty=c(1,1,-1,1,1,1,1))

dev.off()
