library(plot.counts)
library(rheologyEvaluation)

pdf("Fig_S18.pdf")


log_factor = 10 # For averaging in log intervals of the relative shear stress

cex_Gprime = 2 # Character expansion for G' curve

cex_Gprimeprime = 1 # Character expansion for G'' curve

load(file="/data/Evaluation/Rheology/Stress Sweeps/EPI_coating/stress_sweeps_coating.rda")

started=FALSE

G0 = aggregate(Gprime_Pa ~ file, stress_sweeps_coating, function(x){x[1]})

stress_sweeps_coating$G0=G0$Gprime_Pa[match(stress_sweeps_coating$file,G0$file)]
stress_sweeps_coating$tau_rel=stress_sweeps_coating$tau_Pa/stress_sweeps_coating$G0
stress_sweeps_coating$tau_rel_round=exp(round(log(stress_sweeps_coating$tau_Pa/stress_sweeps_coating$G0)*log_factor)/log_factor)
stress_sweeps_coating$Gprime_rel=stress_sweeps_coating$Gprime_Pa/stress_sweeps_coating$G0
stress_sweeps_coating$Gprimeprime_rel=stress_sweeps_coating$Gprimeprime_Pa/stress_sweeps_coating$G0

stress_sweeps_coating_agg = aggregate(stress_sweeps_coating[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=stress_sweeps_coating[,c("Coating","Mass_fraction_coating","tau_rel_round","file")],FUN=mean)

for(theCoating in unique(paste(stress_sweeps_coating_agg$Coating,stress_sweeps_coating_agg$Mass_fraction_coating)))
{
    
    to_complete =stress_sweeps_coating_agg[paste(stress_sweeps_coating_agg$Coating,stress_sweeps_coating_agg$Mass_fraction_coating)==theCoating,]
    if(!started)
    {
       completed_sweeps = complete_sweeps(to_complete,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel"))
       started=TRUE
    } else
    {
        completed_sweeps = rbind(completed_sweeps,complete_sweeps(to_complete,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel")))
        
    }
}

sweeps_agg = aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps[,c("Coating","Mass_fraction_coating","tau_rel_round")],FUN=mean)

sweeps_agg_sd = aggregate(completed_sweeps[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps[,c("Coating","Mass_fraction_coating","tau_rel_round")],FUN=sd)

to_show_sd=aggregate(Gprime_rel ~ Coating + Mass_fraction_coating, sweeps_agg,FUN=function(x){which.min(abs(x-0.5))})

for(theCoating in unique(sweeps_agg_sd$Coating))
{
    for(theMassFraction in unique(sweeps_agg_sd$Mass_fraction_coating[sweeps_agg_sd$Coating==theCoating]))
    {
       current_data = sweeps_agg_sd[sweeps_agg_sd$Coating==theCoating & sweeps_agg_sd$Mass_fraction_coating==theMassFraction,]
       
       current_data[-to_show_sd$Gprime_rel[to_show_sd$Coating==theCoating & to_show_sd$Mass_fraction_coating==theMassFraction],c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA
       sweeps_agg_sd[sweeps_agg_sd$Coating==theCoating & sweeps_agg_sd$Mass_fraction_coating==theMassFraction,]=current_data
       
    }
}


solid_part = sweeps_agg[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]
solid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa>=sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]


liquid_part = sweeps_agg[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]
liquid_part_sd = sweeps_agg_sd[sweeps_agg$Gprime_Pa<sweeps_agg$Gprimeprime_Pa & sweeps_agg$Coating %in% c("Collagen","None"),]


before_yield=aggregate(tau_rel_round ~ Mass_fraction_coating,solid_part, FUN=which.max)
after_yield=aggregate(tau_rel_round ~ Mass_fraction_coating,liquid_part, FUN=which.min)

started=FALSE

for(ind in 1:(dim(before_yield)[1]))
{
    if(!started)
    {
        transition=solid_part[solid_part$Mass_fraction_coating==before_yield$Mass_fraction_coating[ind],][before_yield$tau_rel_round[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,solid_part[solid_part$Mass_fraction_coating==before_yield$Mass_fraction_coating[ind],][before_yield$tau_rel_round[ind],])
        
        
    }
}

for(ind in 1:(dim(after_yield)[1]))
{
    if(!started)
    {
        transition=liquid_part[liquid_part$Mass_fraction_coating==after_yield$Mass_fraction_coating[ind],][after_yield$tau_rel_round[ind],]
        started=TRUE
    } else
    {
        transition=rbind(transition,liquid_part[liquid_part$Mass_fraction_coating==after_yield$Mass_fraction_coating[ind],][after_yield$tau_rel_round[ind],])
        
        
    }
}


ylim=c(1e-3,1)




plot_counts(liquid_part$tau_rel_round,liquid_part$Gprime_rel,groups=paste(liquid_part$Coating,liquid_part$Mass_fraction_coating),log="xy",xlab="Normalized shear stress",ylab="Normalized modulus ",type="b",pch=21,bg=grey(c(1)),col="black",group_order=c("Collagen 0.1"),cex=cex_Gprimeprime,ylim=ylim,xlim=c(1e-4,0.3),xaxt="n",yaxt="n",main="Friction and EPI rheology")

plot_counts(transition$tau_rel_round,transition$Gprime_rel,groups=paste(transition$Coating,transition$Mass_fraction_coating),type="b",pch=21,bg=grey(c(1)),col="black",group_order=c("Collagen 0.1"),cex=cex_Gprimeprime,plot.new=FALSE)

plot_counts(solid_part$tau_rel_round,solid_part$Gprime_rel,groups=paste(solid_part$Coating,solid_part$Mass_fraction_coating),sd_y=solid_part_sd$Gprime_rel,type="b",pch=21,bg=grey(c(1)),col="black",group_order=c("Collagen 0.1"),cex=cex_Gprime,plot.new=FALSE)


axis(side=1,at=c((1:9)*1e-4,(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-4),rep("",8),1e-3,rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))

axis(side=2,at=c(c(1:9)*1e-3,(1:9)*1e-2,(1:9)*1e-1,1),labels=c(expression(1e-3),rep("",8),1e-2,rep("",8),1e-1,rep("",8),1))










load("/data/Evaluation/Rheology/Stress Sweeps/EPI/stress_sweeps_EPI_all.rda")




EPI_control = stress_sweeps_EPI_all[ stress_sweeps_EPI_all$polymer_conc_mgmL>= 24 & stress_sweeps_EPI_all$polymer_conc_mgmL<=28 & stress_sweeps_EPI_all$Geometry=="plate"  ,]



EPI_control$tau_rel = EPI_control$tau_Pa/EPI_control$Gprime_Pa_0
EPI_control$tau_rel_round=exp(round(log(EPI_control$tau_rel)*log_factor)/log_factor)

EPI_control$Gprime_rel = EPI_control$Gprime_Pa/EPI_control$Gprime_Pa_0
EPI_control$Gprimeprime_rel = EPI_control$Gprimeprime_Pa/EPI_control$Gprime_Pa_0





sweeps_EPI_agg_per_ID = aggregate(EPI_control[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=EPI_control[,c("tau_rel_round","file","ID")],FUN=mean)


completed_sweeps_EPI = complete_sweeps(sweeps_EPI_agg_per_ID,abscissa="tau_rel_round",columns_to_complete = c("Gprime_Pa", "Gprimeprime_Pa", "Gamma_in_percent","Gprime_rel","Gprimeprime_rel"),sweep_identifier_column="ID")

sweeps_EPI_agg_per_file = aggregate(completed_sweeps_EPI[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=completed_sweeps_EPI[,c("tau_rel_round","file")],FUN=mean)



sweeps_EPI_agg = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=mean)

sweeps_EPI_agg_sd = aggregate(sweeps_EPI_agg_per_file[,c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")],by=list(tau_rel_round=sweeps_EPI_agg_per_file[,c("tau_rel_round")]),FUN=sd)

sweeps_EPI_agg_sd[-which.min(abs(sweeps_EPI_agg$Gprime_rel-0.5)),c("Gprime_Pa","Gprimeprime_Pa","Gamma_in_percent","Gprime_rel","Gprimeprime_rel")]=NA



solid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]
solid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa>=sweeps_EPI_agg$Gprimeprime_Pa,]


liquid_part_EPI = sweeps_EPI_agg[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]
liquid_part_EPI_sd = sweeps_EPI_agg_sd[sweeps_EPI_agg$Gprime_Pa<sweeps_EPI_agg$Gprimeprime_Pa,]

transition_EPI = rbind(solid_part_EPI[which.max(solid_part_EPI$tau_rel_round),],liquid_part_EPI[which.min(liquid_part_EPI$tau_rel_round),])







plot_counts(liquid_part_EPI$tau_rel_round, liquid_part_EPI$Gprime_rel   ,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprimeprime)

plot_counts(transition_EPI$tau_rel_round, transition_EPI$Gprimeprime_rel  ,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprimeprime)

plot_counts(solid_part_EPI$tau_rel_round, solid_part_EPI$Gprime_rel , sd_y=solid_part_EPI_sd$Gprime_rel,col="black",bg="black",lwd=1,type="b",plot.new=FALSE,pch=21,cex=cex_Gprime)






load("/data/Evaluation/Simulation/Overview_data_files/nonlinear_force_law/overview_simulation_force_law_jumps_corrected.rda")

overview_simulation_force_law$Gprime_Pa[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprime_Pa_jumps_corrected)]

overview_simulation_force_law$Gprimeprime_Pa[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]=overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation_force_law$Gprimeprime_Pa_jumps_corrected)]

overview_plateau_particles=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01  ,]




overview_plateau_particles$G_Pa = sqrt(overview_plateau_particles$Gprime_Pa^2+overview_plateau_particles$Gprimeprime_Pa^2)

overview_plateau_particles_agg=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=mean)

overview_plateau_particles_agg_sd=aggregate(overview_plateau_particles[,c("Stress","Gprime_Pa","Gprimeprime_Pa","G_Pa")], by=overview_plateau_particles[,c("Strain_amplitude","Sample_type","plateau_law","remove_link_fraction","plateau_slope","relative_frequency","Friction_coefficient")],FUN=sd)


upper_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa + qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

upper_stress = overview_plateau_particles_agg$Stress + qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude

lower_Gprime_Pa = overview_plateau_particles_agg$Gprime_Pa - qnorm(0.975)*overview_plateau_particles_agg_sd$Gprime_Pa

lower_stress = overview_plateau_particles_agg$Stress - qnorm(0.975)*overview_plateau_particles_agg_sd$G_Pa*overview_plateau_particles_agg$Strain_amplitude


# To have the same normalization as in Fig. S10-2 and Fig. 5e
overview_plateau_particles_agg_solid = overview_plateau_particles_agg[overview_plateau_particles_agg$Gprime_Pa>=overview_plateau_particles_agg$Gprimeprime_Pa,]

load("/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected.rda")


overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]




# Here, we are specifically interested in the partially crosslinked particles with internal friction surfaces (emulating opposing pore walls that can enter into friction in the actual EPI biomaterial)

particle_sel =
overview_simulation$packing_fraction==1.5 &
overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres==10000 &
overview_simulation$Friction_coefficient==0.01 &
overview_simulation$remove_link_fraction %in% c(0.4) &
overview_simulation$Sample_type=="particles"

overview_plateau_particles_high_friction=overview_simulation_force_law[overview_simulation_force_law$Sample_type=="particles" & overview_simulation_force_law$plateau_law==1 & overview_simulation_force_law$plateau_slope==0.1 & overview_simulation_force_law$remove_link_fraction %in% c(0.4) & overview_simulation_force_law$relative_frequency==0.01 &  overview_simulation_force_law$Friction_coefficient %in% c(1) ,]


G0prime_simulation = mean(c(overview_simulation$Gprime_Pa[ overview_simulation$Strain_amplitude<=0.005 & particle_sel],overview_plateau_particles_high_friction$Gprime_Pa[overview_plateau_particles_high_friction$Strain_amplitude<=0.005]))


grps=plot_counts(overview_plateau_particles_agg$Stress/G0prime_simulation,overview_plateau_particles_agg$Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg$Sample_type,"r"=overview_plateau_particles_agg$remove_link_fraction,"p=",overview_plateau_particles_agg$plateau_law,"s=",overview_plateau_particles_agg$plateau_slope,"f=",overview_plateau_particles_agg$relative_frequency,"F=",overview_plateau_particles_agg$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=21,col=grey(c(0,0.4,0.5,0.6,0.7,0.8,0.85)),type="l",lwd=1,lty=2)



grps=plot_counts(overview_plateau_particles_agg_solid$Stress/G0prime_simulation,overview_plateau_particles_agg_solid$Gprime_Pa/G0prime_simulation,log="xy",xlab="Relative shear stress",ylab="Relative modulus",groups=paste(overview_plateau_particles_agg_solid$Sample_type,"r"=overview_plateau_particles_agg_solid$remove_link_fraction,"p=",overview_plateau_particles_agg_solid$plateau_law,"s=",overview_plateau_particles_agg_solid$plateau_slope,"f=",overview_plateau_particles_agg_solid$relative_frequency,"F=",overview_plateau_particles_agg_solid$Friction_coefficient),ylim=c(1e-3,1),plot.new=FALSE,pch=-1,col=grey(c(0,0.4,0.5,0.6,0.7,0.8,0.85)),cex=2,type="l",lwd=4)





legend("bottomleft",pch=c(rep(21,2),rep(-1,7)),lty=c(rep(-1,2),rep(1,7)),pt.bg=grey(c(1,0,rep(0,7))),col=c(rep("black",2),grey(c(0,0.4,0.5,0.6,0.7,0.8,0.85))),legend=c("Collagen 10%","uncoated",paste("mu=",c(0.01,0.1,0.3,0.5,0.6,0.8,1),sep="")),cex=1.5,lwd=c(1,1,rep(4,7)))

dev.off()


