library(plot.counts)

load(file="/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected.rda")

# Use the corrected stuff where available

overview_simulation$Gprime_Pa[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]=
overview_simulation$Gprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprime_Pa_jumps_corrected)]

overview_simulation$Gprimeprime_Pa[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]=
overview_simulation$Gprimeprime_Pa_jumps_corrected[!is.na(overview_simulation$Gprimeprime_Pa_jumps_corrected)]





to_aggregate=c("Gprime_Pa","Gprimeprime_Pa","Stress","actual_remove_link_fraction")

by = c("Friction_coefficient","Strain_amplitude","Sample_type","packing_fraction","interface_reenforcement_central","Young_modulus_spheres","remove_link_fraction")

use=overview_simulation$cut_lines %in% c(0,5)



overview_agg=aggregate(overview_simulation[,to_aggregate],by=overview_simulation[,by],FUN=mean,na.rm=TRUE)
overview_agg_sd=aggregate(overview_simulation[,to_aggregate],by=overview_simulation[,by],FUN=sd_mean,na.rm=TRUE)


removal_agg = aggregate(actual_remove_link_fraction ~ remove_link_fraction + Friction_coefficient +  Sample_type +  packing_fraction + interface_reenforcement_central+ Young_modulus_spheres, overview_agg, FUN=mean )


common_conditions=
overview_agg$packing_fraction==1.5 &
overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres==10000

particle_sel =
common_conditions &
overview_agg$Friction_coefficient==0.01 &
overview_agg$remove_link_fraction %in% c(0.4) &
overview_agg$Sample_type=="particles"


particle_no_friction_sel =
common_conditions &
overview_agg$Friction_coefficient==0.0 &
overview_agg$remove_link_fraction %in% c(0.4) &
overview_agg$Sample_type=="particles"

particle_full_no_friction_sel =
common_conditions &
overview_agg$Friction_coefficient==0 &
overview_agg$remove_link_fraction %in% c(0) &
overview_agg$Sample_type=="particles"

particle_full_sel =
common_conditions &
overview_agg$Friction_coefficient==0.01 &
overview_agg$remove_link_fraction %in% c(0) &
overview_agg$Sample_type=="particles"


sphere_sel =
common_conditions&
overview_agg$Friction_coefficient==0.01 &
overview_agg$Sample_type=="uncrosslinked"

sphere_no_friction_sel =
common_conditions&
overview_agg$Friction_coefficient==0 &
overview_agg$Sample_type=="uncrosslinked"

bulk_sel =
common_conditions&
overview_agg$Friction_coefficient==0.01 &
overview_agg$Sample_type=="bulk" &
overview_agg$remove_link_fraction %in% c(0)




# Get the yield strain

for_yield_strain=overview_agg[common_conditions & overview_agg$Friction_coefficient %in% c(0,0.01),]


unique_conditions=aggregate(for_yield_strain$Gprime_Pa,by=for_yield_strain[,c("Friction_coefficient","Sample_type","remove_link_fraction")],FUN=mean)

unique_conditions$yield_strain=NA

for(ind in 1:length(unique_conditions$yield_strain))
{
    current_data =for_yield_strain[for_yield_strain$Friction_coefficient==unique_conditions$Friction_coefficient[ind] & for_yield_strain$Sample_type==unique_conditions$Sample_type[ind] &
    for_yield_strain$remove_link_fraction==unique_conditions$remove_link_fraction[ind],]
    
    current_data = current_data[order(current_data$Strain_amplitude,decreasing=TRUE),]
    
    
    # From the largest strain, find first strain where Gprime is equal to or larger than Gprimeprime
    
    ind_first_solid = min(which(current_data$Gprime_Pa>current_data$Gprimeprime_Pa))
    
    if(ind_first_solid==1)
    {
        unique_conditions$yield_strain[ind]=current_data$Strain_amplitude[ind_first_solid]
        
    }
    if(ind_first_solid==Inf)
    {
        unique_conditions$yield_strain[ind]=NA
    }
    if(ind_first_solid>1)
    {
        difference_solid=current_data$Gprime_Pa[ind_first_solid]-current_data$Gprimeprime_Pa[ind_first_solid]
        difference_liquid=current_data$Gprime_Pa[ind_first_solid-1]-current_data$Gprimeprime_Pa[ind_first_solid-1]
        
        difference_strain_amplitude = current_data$Strain_amplitude[ind_first_solid]-current_data$Strain_amplitude[ind_first_solid-1]
        
        # linear interpolation
        
        unique_conditions$yield_strain[ind]=current_data$Strain_amplitude[ind_first_solid-1]-difference_liquid/(difference_solid-difference_liquid)*difference_strain_amplitude
        
        
        
    }
}


# Common graphical parameters

ylim=c(1,2500)
xlim=c(0.1,100)
cex=2
pch=21






# Porous
pdf("Fig_S1c.pdf")


to_plot = overview_agg[particle_sel,]

to_plot_sd = overview_agg_sd[particle_sel,]

to_plot_sd$Gprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0
to_plot_sd$Gprimeprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0

to_plot_sd$Gprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0
to_plot_sd$Gprimeprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0


plot_counts(to_plot$Strain_amplitude*100,to_plot$Gprime_Pa,groups=to_plot$Sample_type,
sd_y=to_plot_sd$Gprime_Pa,
ylab="G', G''[Pa]",xlab="Strain [%]",log="x",ylim=ylim,xlim=xlim,cex=cex,pch=pch,bg="black",main="Porous",xaxt="n")

axis(side=1,at=c((1:9)*0.1,(1:9),(1:10)*10),labels=c(expression(0.1),rep("",8),1,rep("",8),10,rep("",8),100))


plot_counts(to_plot$Strain_amplitude*100,to_plot$Gprimeprime_Pa,groups=to_plot$Sample_type,
sd_y=to_plot_sd$Gprime_Pa,
pch=pch,bg="white",cex=2,plot.new=FALSE)


yield_strain = unique_conditions$yield_strain[ unique_conditions$Sample_type=="particles" & unique_conditions$Friction_coefficient==0.01 & unique_conditions$remove_link_fraction==0.4]

#lines(rep(yield_strain*100,2),ylim,lty=2)

#text(x=yield_strain*100,y=ylim[2]*0.8,labels=paste(round(yield_strain*1000)/10,"%",sep=""),adj=0)

yield_strain


to_plot = overview_agg[particle_no_friction_sel,]

to_plot_sd = overview_agg_sd[particle_no_friction_sel,]

to_plot_sd$Gprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0
to_plot_sd$Gprimeprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0

to_plot_sd$Gprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0
to_plot_sd$Gprimeprime_Pa[!(to_plot_sd$Strain_amplitude %in% c(1e-3,1e-2,1e-1,1))]=0


plot_counts(to_plot$Strain_amplitude*100,to_plot$Gprime_Pa,groups=to_plot$Sample_type,
sd_y=to_plot_sd$Gprime_Pa,
cex=cex,pch=24,bg="black",plot.new=FALSE)

plot_counts(to_plot$Strain_amplitude*100,to_plot$Gprimeprime_Pa,groups=to_plot$Sample_type,
sd_y=to_plot_sd$Gprime_Pa,
pch=24,bg="white",cex=2,plot.new=FALSE)


yield_strain = unique_conditions$yield_strain[ unique_conditions$Sample_type=="particles" & unique_conditions$Friction_coefficient==0.01 & unique_conditions$remove_link_fraction==0.4]

#lines(rep(yield_strain*100,2),ylim,lty=2)

#text(x=yield_strain*100,y=ylim[2]*0.8,labels=paste(round(yield_strain*1000)/10,"%",sep=""),adj=0)

dev.off()

