library(plot.counts)
library(particleShearEvaluation)



load(file="/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")

# Reference select

reference_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4


reference_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4

reference_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


reference_evaluation=evaluate_stress_curve(overview_agg$Strain_amplitude[reference_select],overview_agg$Gprime_Pa[reference_select],overview_agg$Gprimeprime_Pa[reference_select])


pdf("Fig_S2.pdf")

par(mfrow=c(2,3))

# Change in Young modulus

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(12500) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4

comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(12500) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(12500) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4

comparison_evaluation=evaluate_stress_curve(overview_agg$Strain_amplitude[comparison_select],overview_agg$Gprime_Pa[comparison_select],overview_agg$Gprimeprime_Pa[comparison_select])

other_side_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(7500,1000,1e5) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

other_side_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(7500,1e3,1e5) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4


all_select=comparison_select_unique | reference_select_unique | other_side_select_unique



pvals_Young=vector(mode="numeric",length=5)
names(pvals_Young)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

pvals_Young["softening_strain"]=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])


pvals_Young["soft_plateau_strain"]=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])

pvals_Young["soft_plateau_Gprime"]=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])

pvals_Young["yield"]=linear_regression_p_bootstrap(x=unique_conditions$Young_modulus_spheres[all_select],y=bootstrap_draws_yield_strain[all_select,])

pvals_Young["low_strain_plateau"]=coefficients(summary(lm(Gprime_Pa ~ Young_modulus_spheres,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,])))["Young_modulus_spheres","Pr(>|t|)"]





plot(Gprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],log="x",type="b",pch=21,bg="white",cex=2,ylim=c(0,3000), main="Young modulus")
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],type="b",pch=21,bg="white",cex=0.75)
lines(Gprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="black",cex=2)
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="black",cex=0.75)





# Change in packing density

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(2) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(2) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(2) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4




other_side_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001

other_side_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4



plot(Gprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],log="x",type="b",pch=21,bg="white",cex=2,ylim=c(0,3000), main="Packing density")
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],type="b",pch=21,bg="white",cex=0.75)
lines(Gprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="black",cex=2)
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="black",cex=0.75)


all_select=comparison_select_unique | reference_select_unique | other_side_select_unique

pvals_packing=vector(mode="numeric",length=5)
names(pvals_packing)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

pvals_packing["softening_strain"]=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])


pvals_packing["soft_plateau_strain"]=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])

pvals_packing["soft_plateau_Gprime"]=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])

pvals_packing["yield"]=linear_regression_p_bootstrap(x=unique_conditions$packing_fraction[all_select],y=bootstrap_draws_yield_strain[all_select,])

pvals_packing["low_strain_plateau"]=coefficients(summary(lm(Gprime_Pa ~ packing_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation | other_side_select_simulation,])))["packing_fraction","Pr(>|t|)"]





# Change in firction coefficient

comparison_select=overview_agg$Friction_coefficient %in% c(0.003) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0.4



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.003) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0.4 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.003) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4






plot(Gprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],log="x",type="b",pch=21,bg="black",cex=2,ylim=c(0,3000), main="Friction")
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],type="b",pch=21,bg="black",cex=0.75)
lines(Gprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=2)
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=0.75)


all_select=comparison_select_unique | reference_select_unique

pvals_friction=vector(mode="numeric",length=5)
names(pvals_friction)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

pvals_friction["softening_strain"]=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])


pvals_friction["soft_plateau_strain"]=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])

pvals_friction["soft_plateau_Gprime"]=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])

pvals_friction["yield"]=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[all_select],y=bootstrap_draws_yield_strain[all_select,])

pvals_friction["low_strain_plateau"]=coefficients(summary(lm(Gprime_Pa ~ Friction_coefficient,overview_simulation[comparison_select_simulation | reference_select_simulation ,])))["Friction_coefficient","Pr(>|t|)"]





# Change in porosity

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("particles") & overview_agg$remove_link_fraction==0



comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("particles") & overview_simulation$remove_link_fraction==0 & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0



plot(Gprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],log="x",type="b",pch=21,bg="black",cex=2,ylim=c(0,3000), main="Porosity")
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],type="b",pch=21,bg="black",cex=0.75)
lines(Gprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=2)
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=0.75)

all_select=comparison_select_unique | reference_select_unique

pvals_porosity=vector(mode="numeric",length=5)
names(pvals_porosity)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

pvals_porosity["softening_strain"]=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_mid_softening_strain[all_select,])


pvals_porosity["soft_plateau_strain"]=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_soft_plateau_strain[all_select,])

pvals_porosity["soft_plateau_Gprime"]=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_soft_plateau_Gprime[all_select,])

pvals_porosity["yield"]=linear_regression_p_bootstrap(x=unique_conditions$remove_link_fraction[all_select],y=bootstrap_draws_yield_strain[all_select,])

pvals_porosity["low_strain_plateau"]=coefficients(summary(lm(Gprime_Pa ~ remove_link_fraction,overview_simulation[comparison_select_simulation | reference_select_simulation,])))["remove_link_fraction","Pr(>|t|)"]



# Change in particle shape

comparison_select=overview_agg$Friction_coefficient %in% c(0.01) & overview_agg$packing_fraction %in% c(1.5) & overview_agg$interface_reenforcement_central==1 &
overview_agg$Young_modulus_spheres %in% c(10000) & overview_agg$Sample_type %in% c("uncrosslinked")

comparison_select_simulation=overview_simulation$Friction_coefficient %in% c(0.01) & overview_simulation$packing_fraction %in% c(1.5) & overview_simulation$interface_reenforcement_central==1 &
overview_simulation$Young_modulus_spheres %in% c(10000) & overview_simulation$Sample_type %in% c("uncrosslinked") & overview_simulation$Strain_amplitude==0.001


comparison_select_unique=unique_conditions$Friction_coefficient %in% c(0.01) & unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000) & unique_conditions$Sample_type %in% c("uncrosslinked")



plot(Gprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],log="x",type="b",pch=21,bg="black",cex=2,ylim=c(0,3000), main="Shape")
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[reference_select,],type="b",pch=21,bg="black",cex=0.75)
lines(Gprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=2)
lines(Gprimeprime_Pa ~ Strain_amplitude, overview_agg[comparison_select,],type="b",pch=21,bg="white",cex=0.75)

all_select=comparison_select_unique | reference_select_unique

pvals_shape=vector(mode="numeric",length=5)
names(pvals_shape)=c("low_strain_plateau","softening_strain","soft_plateau_strain","soft_plateau_Gprime","yield")

pvals_shape["softening_strain"]=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_mid_softening_strain[all_select,])


pvals_shape["soft_plateau_strain"]=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_soft_plateau_strain[all_select,])

pvals_shape["soft_plateau_Gprime"]=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_soft_plateau_Gprime[all_select,])

pvals_shape["yield"]=linear_regression_p_bootstrap(x=as.numeric(unique_conditions$Sample_type[all_select]),y=bootstrap_draws_yield_strain[all_select,])

pvals_shape["low_strain_plateau"]=coefficients(summary(lm(Gprime_Pa ~ Sample_type,overview_simulation[comparison_select_simulation | reference_select_simulation,])))["Sample_typeparticles","Pr(>|t|)"]



dev.off()





pvals=rbind(pvals_Young,pvals_packing,pvals_friction,pvals_porosity,pvals_shape)


colnames(pvals)=c("G' low plateau","Softening strain","Strain on soft plateau","G' on soft plateau","Yield strain")

rownames(pvals)=c("Young modulus","Packing density","Friction coefficient","Porosity","Shape")

pvals[]=p.adjust(pvals)

sig_labs=significance_labels(pvals,levels=c(0.05, 0.01, 0.001),codes=c(
"*", "**", "***"))

sig_labs


