library(plot.counts)
library(particleShearEvaluation)

load(file="/data/Evaluation/Simulation/Overview_data_files/overview_simulation_jumps_corrected_bootstrap.rda")

# Friction coefficient

pdf("Fig_S3.pdf")

common_select=unique_conditions$packing_fraction %in% c(1.5) & unique_conditions$interface_reenforcement_central==1 &
unique_conditions$Young_modulus_spheres %in% c(10000)

sphere_select = common_select & unique_conditions$Sample_type %in% c("uncrosslinked")
particles_select = common_select  & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0
particles_loose_select = common_select & unique_conditions$Sample_type %in% c("particles") & unique_conditions$remove_link_fraction==0.4


selected_conditions_spheres=unique_conditions[ sphere_select,]

selected_conditions_particles=unique_conditions[ particles_select,]

selected_conditions_particles_loose=unique_conditions[ particles_loose_select,]



for_barplot=data.frame(
spherical=selected_conditions_spheres$yield_strain,
spherical_sd =selected_conditions_spheres$yield_strain_sd,
particles=selected_conditions_particles$yield_strain[match(selected_conditions_spheres$Friction_coefficient,selected_conditions_particles$Friction_coefficient)],
particles_sd=selected_conditions_particles$yield_strain_sd[match(selected_conditions_spheres$Friction_coefficient,selected_conditions_particles$Friction_coefficient)],
particles_loose=selected_conditions_particles_loose$yield_strain[match(selected_conditions_spheres$Friction_coefficient,selected_conditions_particles_loose$Friction_coefficient)],
particles_loose_sd=selected_conditions_particles_loose$yield_strain_sd[match(selected_conditions_spheres$Friction_coefficient,selected_conditions_particles_loose$Friction_coefficient)],
Friction_coefficient=selected_conditions_spheres$Friction_coefficient
)



barplot_with_errorbars(t(as.matrix(for_barplot[,c("spherical","particles_loose","particles")]))*100,names.arg= for_barplot$Friction_coefficient,beside=TRUE,col=grey(c(1,0.75,0.25)),
sd_height=t(as.matrix(for_barplot[,c("spherical_sd","particles_loose_sd","particles_sd")]))*100,legend=TRUE,xlab="Friction coefficient",ylab="Yield strain [%]",legend.text=c("spherical","irregular - porous","irregular - compact"),main="Friction coefficient")



pval_spheres=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[sphere_select],y=bootstrap_draws_yield_strain[sphere_select,])


pval_particles=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[particles_select],y=bootstrap_draws_yield_strain[particles_select,])


pval_particles_loose=linear_regression_p_bootstrap(x=unique_conditions$Friction_coefficient[particles_loose_select],y=bootstrap_draws_yield_strain[particles_loose_select,])

pvals_Friction_coefficient=p.adjust(c(pval_spheres,pval_particles,pval_particles_loose),method="bonferroni")

names(pvals_Friction_coefficient)=c("spherical","compact","porous")



# Reporting statistics details
cat("\nStatistical reporting: Influence of friction coefficient on yield strain for different particle geometry (Item 17)\n")
n_spheres=sum(   overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1  & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="uncrosslinked")


n_particles_loose=sum(  overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 &
overview_simulation $remove_link_fraction==0.4 & overview_simulation $interface_reenforcement_central==1 &
overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")


n_particles=sum(  overview_simulation$do_permanent_links & overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1 &
overview_simulation $remove_link_fraction==0 & overview_simulation $interface_reenforcement_central==1 &
overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="particles")

n_overall=n_spheres+n_particles_loose+n_particles



cat("\nReporting Spherical particles (Influence of an extended range of friction coefficients on the yield strain)")
cat("\n=============================")

cat("\n\tn per group: 5 (bootstrapping)")
cat("\n\tN total simulations")
n_spheres=sum(   overview_simulation$packing_fraction == 1.5 & overview_simulation$relative_transversal_link_strength==1  & overview_simulation $interface_reenforcement_central==1 & overview_simulation$Young_modulus_sphere ==1e4 & overview_simulation$Sample_type=="uncrosslinked")
n_spheres
cat("\n\t\tNormality testing (linear model)")
attr(pval_spheres,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(pval_spheres,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the yield strain")
attr(pval_spheres,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(pval_spheres,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(pval_spheres,"DF1"),attr(pval_spheres,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
as.numeric(pval_spheres)

cat("\nReporting Irregular porous particles (Influence of an extended range of friction coefficients on the yield strain)")
cat("\n=============================")


cat("\n\tn per group: 5 (bootstrapping)")
cat("\n\tN total simulations")
n_particles_loose

cat("\n\t\tNormality testing (linear model)")
attr(pval_particles_loose,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(pval_particles_loose,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the yield strain")
attr(pval_particles_loose,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(pval_particles_loose,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(pval_particles_loose,"DF1"),attr(pval_particles_loose,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
as.numeric(pval_particles_loose)


cat("\nReporting Irregular compact particles (Influence of an extended range of friction coefficients on the yield strain)")
cat("\n=============================")


cat("\n\tn per group: 5 (bootstrapping)")
cat("\n\tN total simulations")
n_particles

cat("\n\t\tNormality testing (linear model)")
attr(pval_particles,"p_shapiro")
cat("\n\t\tTest statistic (F)")
attr(pval_particles,"F")
cat("\n\t\tConfidence interval for the slope coefficient between the friction coefficient and the yield strain")
attr(pval_particles,"confint")
cat("\n\t\tEffect size measure: Adjusted R2")
attr(pval_particles,"adj.r.squared")
cat("\n\t\tDegrees of freedom:")
paste(attr(pval_particles,"DF1"),attr(pval_particles,"DF2"),sep="/")
cat("\n\t\tP-value (before multiple testing adjustment")
as.numeric(pval_particles)

cat("\nOverall Reporting")
cat("\n=================")
cat("\nGrand total of simulations used")
n_overall
cat("\nP-values after Bonferroni adjustment")
pvals_Friction_coefficient



dev.off()





