library(plot.counts)

load("/data/Evaluation/Rheology/Stress Sweeps/bulk/scaffold_rheology.rda")


index_matching=match(scaffold_rheology$overview_index,overview_scaffold_rheology$overview_index)

rows = (overview_scaffold_rheology$uniaxial_compression[index_matching]<=0.4) & (overview_scaffold_rheology$solvent[index_matching]=="DI") & (scaffold_rheology$tau_Pa<=5 & scaffold_rheology$tau_Pa>=1 ) & (round(overview_scaffold_rheology$original_polymer_content[index_matching])==14)


G_agg = aggregate(scaffold_rheology[rows,c("Gprime_Pa","Gprimeprime_Pa")],by=list(overview_index=scaffold_rheology[rows,"overview_index"]),FUN=mean)


G_agg$Sample = overview_scaffold_rheology$Sample[match(G_agg$overview_index,overview_scaffold_rheology$overview_index)]

G_agg$Batch = overview_scaffold_rheology$Batch[match(G_agg$overview_index,overview_scaffold_rheology$overview_index)]

G_agg$sample_type = overview_scaffold_rheology$sample_type[match(G_agg$overview_index,overview_scaffold_rheology$overview_index)]


G_agg_per_sample = aggregate(G_agg[,c("Gprime_Pa","Gprimeprime_Pa")], by=G_agg[,c("Batch","Sample","sample_type")],FUN=mean)


G_agg_per_sample_type = aggregate(G_agg_per_sample[,c("Gprime_Pa","Gprimeprime_Pa")], by=list("sample_type"=G_agg_per_sample[,c("sample_type")]),FUN=mean)


cat(paste("G' = ",mean(G_agg_per_sample$Gprime_Pa)," +/- ",sd(G_agg$Gprime_Pa),sep="","\n"))


cat(paste("G'' = ",mean(G_agg_per_sample$Gprimeprime_Pa)," +/- ",sd(G_agg$Gprimeprime_Pa),sep="","\n"))


comparison_stacked_single_samples=aggregate(scaffold_rheology[,c("Gprime_Pa","Gprimeprime_Pa")], by=list(Sample=overview_scaffold_rheology$Sample[scaffold_rheology$overview_index],sample_type=overview_scaffold_rheology$sample_type[scaffold_rheology$overview_index],
    tau_Pa =  exp(round(log(scaffold_rheology$tau_Pa)*2)/2)),FUN=mean,na.rm=TRUE)


comparison_stacked_single=aggregate(comparison_stacked_single_samples[,c("Gprime_Pa","Gprimeprime_Pa")], by=list(sample_type=comparison_stacked_single_samples$sample_type,tau_Pa =  comparison_stacked_single_samples$tau_Pa),FUN=mean)

comparison_stacked_single_sd=aggregate(comparison_stacked_single_samples[,c("Gprime_Pa","Gprimeprime_Pa")], by=list(sample_type=comparison_stacked_single_samples$sample_type,tau_Pa =  comparison_stacked_single_samples$tau_Pa),FUN=sd)




comparison_stacked_single = comparison_stacked_single[comparison_stacked_single$tau_Pa>=1 & !is.na(comparison_stacked_single_sd$Gprime_Pa),]
comparison_stacked_single_sd = comparison_stacked_single_sd[comparison_stacked_single_sd$tau_Pa>=1 & !is.na(comparison_stacked_single_sd$Gprime_Pa),]


single = comparison_stacked_single[comparison_stacked_single$sample_type=="single_scaffold",]
single_sd = comparison_stacked_single_sd[comparison_stacked_single_sd$sample_type=="single_scaffold",]

pdf("Fig_S4b.pdf")

plot_counts(single$tau_Pa, y=single$Gprime_Pa,sd_y=single_sd$Gprime_Pa,log="xy",xlab="Shear stress",ylab="Elastic storage modulus",ylim=c(4e1,1e4),main="Bulk scaffold rheology",pch=21,bg="black",cex=1.5,yaxt="n",xlim=c(1,1000),xaxt="n")

axis(side=2,at=c((4:9)*10,(1:9)*100,(1:10)*1000),las=1,labels=c(expression(""),rep("",5),"0.1kPa",rep("",8),"1kPa",rep("",8),"10kPa"))

axis(side=1,at=c(1:9,(1:9)*10,(1:10)*100),labels=c(expression("1Pa"),rep("",8),"10Pa",rep("",8),"0.1kPa",rep("",8),"1kPa"))


plot_counts(single$tau_Pa, y=single$Gprimeprime_Pa,sd_y=single_sd$Gprimeprime_Pa,pch=21,bg="white",plot.new=FALSE,cex=1.5)

legend("topright",legend=c("G'","G''"),pch=c(21,21),pt.bg=c("black","white"),lty=c(1,1),cex=1.5)


dev.off()

