library(plot.counts)
library(rheologyEvaluation)


# Read swelling curve, take average between initial and final

# add the data acquired when completing to get the yield stress


load("/data/Evaluation/Porosity/EPI/Pore fraction/EPI_porosity.rda")

load("/data/Evaluation/Porosity/Sephacryl_S200/Pore fraction/sephacryl_S200_porosity.rda")


load("/data/Evaluation/Porosity/EPI/Pore size/pore_size_fitting_constants_EPI.rda")

load("/data/Evaluation/Porosity/Sephacryl_S200/Pore size/pore_size_fitting_constants_sephacryl_S200.rda")

pore_size_agg=aggregate(diameter ~ dry_weight_conc, EPI_pore_size, FUN=mean)
pore_size_agg_sd=aggregate(diameter ~ dry_weight_conc, EPI_pore_size, FUN=sd)

sephacryl_S200_pore_size_agg=aggregate(diameter ~ dry_weight_conc, sephacryl_S200_pore_size, FUN=mean)
sephacryl_S200_pore_size_agg_sd=aggregate(diameter ~ dry_weight_conc, sephacryl_S200_pore_size, FUN=sd)


pore_size_all = data.frame(dry_weight_conc=c(pore_size_agg$dry_weight_conc,sephacryl_S200_pore_size_agg$dry_weight_conc),sample=c(rep("EPI",length(pore_size_agg$dry_weight_conc)),rep("Sephacryl_S200",length(sephacryl_S200_pore_size_agg$dry_weight_conc))),pore_diameter=c(pore_size_agg$diameter,sephacryl_S200_pore_size_agg$diameter),
        pore_diameter_sd=c(pore_size_agg_sd$diameter,sephacryl_S200_pore_size_agg_sd$diameter))


xlim=c(0,120)

pdf("Fig_S7b.pdf")

plot_counts(pore_size_all$dry_weight_conc,pore_size_all$pore_diameter,sd_y=pore_size_all$pore_diameter_sd,ylim=c(10,200),xlim=xlim,xlab="Polymer concentration [mg/mL]",ylab="Mean pore diameter [micrometers]",type="p",groups=pore_size_all$sample,pch=c(21,21),bg=c("black","white"),col="black",cex=2,log="y",lty=c(1,2),yaxt="n")

axis(side=2,at=c((1:9)*10,100,200),labels=c(expression(10),20,rep("",2),50,rep("",4),100,200),las=2)


legend("topright",legend=c("EPI biomaterial","Sephacryl S200"),pch=c(21,21),col=rep("black",2),pt.bg=c("black","white"),cex=1.5,lty=c(1,2))



# For the theory lines






for_graph = (0:200)/200*max(xlim)


for_graph_EPI_pore_fraction = EPI_pore_fraction_gamma(for_graph)



for_graph_EPI_pore_diameter=Dwall_EPI*(for_graph_EPI_pore_fraction)^(1/n_EPI)/(1-(for_graph_EPI_pore_fraction)^(1/n_EPI))


lines(for_graph,for_graph_EPI_pore_diameter,type="l")





for_graph = (0:200)/200*max(xlim)


for_graph_sephacryl_pore_fraction = sephacryl_pore_fraction_gamma(for_graph)

for_graph_sephacryl_pore_diameter=D_sephacryl*(for_graph_sephacryl_pore_fraction)^(1/n_sephacryl)/(1-(for_graph_sephacryl_pore_fraction)^(1/n_sephacryl))


lines(for_graph,for_graph_sephacryl_pore_diameter,type="l",lty=2)



# minimal pore fraction


pore_fraction_min_EPI = (50/(50+Dwall_EPI))^n_EPI

pore_fraction_min_sephacryl = (50/(50+D_sephacryl))^n_sephacryl


cmax_EPI = EPI_wall_concentration*(1-pore_fraction_min_EPI)*(1-EPI_gamma/(1-EPI_gamma)*(1-pore_fraction_min_EPI)/pore_fraction_min_EPI)^(-3/2)


cmax_sephacryl = sephacryl_wall_concentration*(1-pore_fraction_min_sephacryl)*(1-sephacryl_gamma/(1-sephacryl_gamma)*(1-pore_fraction_min_sephacryl)/pore_fraction_min_sephacryl)^(-3/2)



dev.off()



























