library(plot.counts)
library(effsize)
library(psychometric)


load("/data/Evaluation/Porosity/EPI/inter_intra_particle_pore_space/EPI_intra_inter_particle_pore_space.rda")
load(file="/data/Evaluation/Particle Geometry/EPI/particle_size_overview_EPI.rda")


pdf("Fig_S9a.pdf")


N_Bonferroni =3  # 3 Tests for Fig. S9a: Core-shell model, domain vs. core-shell, and intraparticle pore fraction vs random expected value
graphical_shift=0.6


# The particle size is calculated in the fully hydrated state, which is 2x less concentrated. By assuming roughly
# isotropic expansion, we therefore need to get the particle size distribution

breaks=(0:10)*200

mids=(breaks[1:(length(breaks)-1)]+breaks[2:(length(breaks))])/2

frequencies_area_weighted=rep(0,length(breaks)-1)

frequencies_number_weighted=rep(0,length(breaks)-1)

for(ind in 1:length(frequencies_area_weighted))
{
   sel = particle_size_overview_EPI$diameter>=breaks[ind] & particle_size_overview_EPI$diameter<breaks[ind+1]
   
    frequencies_area_weighted[ind]=frequencies_area_weighted[ind]+sum(particle_size_overview_EPI$diameter[sel]^2)
    frequencies_number_weighted[ind]=frequencies_number_weighted[ind]+sum(sel)
    
    
}

frequencies_area_weighted=frequencies_area_weighted/sum(frequencies_area_weighted)
frequencies_number_weighted=frequencies_number_weighted/sum(frequencies_number_weighted)

# To plot the barplot and the internal pore fraction on the same graph, this is a bit tricky, we need to obtain the actual x values used in the barplot and
# transform correspondingly the particle diameters
x_pos=barplot(frequencies_area_weighted,ylim=c(0,1+graphical_shift),yaxt="n",xlab="Particle diameter [mm]",ylab="Frequency             Fraction intraparticle pore space", main="Fraction intra-particle pore space")
n=length(x_pos)

axis(side=2, at=(0:4)/5+graphical_shift,labels=c(expression(0),"",50,"",100),las=2,cex.axis=2)
axis(side=2, at=(0:2)/3*graphical_shift,labels=c(expression(0),"",graphical_shift*100*2/3),las=2,cex.axis=2)

x_pos_breaks=c(x_pos-(x_pos[2]-x_pos[1])/2,x_pos[length(x_pos)]+(x_pos[2]-x_pos[1])/2)

x_axis_labels=breaks/1000
x_axis_labels[(1:length(x_axis_labels))%%5!=1]=""

axis(side=1, at=x_pos_breaks,labels=x_axis_labels,cex.axis=2)




x0=x_pos[1]+(0-mids[1])/(mids[2]-mids[1])*(x_pos[2]-x_pos[1])
x2000=x_pos[n]+(2000-mids[n])/(mids[n]-mids[n-1])*(x_pos[n]-x_pos[n-1])

coord_transform<-function(x){x/2000*(x2000-x0)+x0}

equivalent_particle_diameters=sqrt(EPI_intra_inter_particle_pore_space$particle_area_mm2/pi)*2*1000
EPI_intra_inter_particle_pore_space$equivalent_particle_diameters=equivalent_particle_diameters

equivalent_x_values=coord_transform(equivalent_particle_diameters)



plot_counts(equivalent_x_values, EPI_intra_inter_particle_pore_space$Fraction_intraparticle+graphical_shift,type="p",cex=1,pch=rep(21,1),bg=grey(0.9),col=grey(0.8),xlab="Particle diameter [um]",ylab="Fraction intra-particle pore space",plot.new=FALSE)


# Per category statistics

fraction_intraparticle_pore_space_per_size_category = vector(mode="numeric",length=length(frequencies_area_weighted))
fraction_intraparticle_pore_space_per_size_category_minus_chance=fraction_intraparticle_pore_space_per_size_category # Remove minority fraction, for statistical testing against chance minority-minority lines

fraction_intraparticle_pore_space_per_size_category_sd = fraction_intraparticle_pore_space_per_size_category
fraction_intraparticle_pore_space_per_size_category_minus_chance_sd =fraction_intraparticle_pore_space_per_size_category

for(ind in 1:length(fraction_intraparticle_pore_space_per_size_category))
{
    fraction_intraparticle_pore_space_per_size_category[ind]=mean(EPI_intra_inter_particle_pore_space$Fraction_intraparticle[
       equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]])
    fraction_intraparticle_pore_space_per_size_category_sd[ind]=sd(EPI_intra_inter_particle_pore_space$Fraction_intraparticle[
                equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]])
                
    fraction_intraparticle_pore_space_per_size_category_minus_chance[ind]=mean(EPI_intra_inter_particle_pore_space$Fraction_intraparticle[
                   equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]]-
                   EPI_intra_inter_particle_pore_space$fraction_minority_color[
                   equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]])
                   
                   fraction_intraparticle_pore_space_per_size_category_minus_chance_sd[ind]=sd(EPI_intra_inter_particle_pore_space$Fraction_intraparticle[
    equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]]-
    EPI_intra_inter_particle_pore_space$fraction_minority_color[
    equivalent_particle_diameters>=breaks[ind] & equivalent_particle_diameters<breaks[ind+1]])
        
                
}
fraction_intraparticle_pore_space_per_size_category[is.nan(fraction_intraparticle_pore_space_per_size_category)]=NA


mean_fraction_intraparticle_pore_space_from_category_stats = sum(fraction_intraparticle_pore_space_per_size_category*frequencies_area_weighted,na.rm=TRUE)/
sum(frequencies_area_weighted)
mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats = sum(fraction_intraparticle_pore_space_per_size_category_minus_chance*frequencies_area_weighted,na.rm=TRUE)/
sum(frequencies_area_weighted)


sd_fraction_intraparticle_pore_space_from_category_stats=sqrt(sum(fraction_intraparticle_pore_space_per_size_category_sd^2*frequencies_area_weighted^2,na.rm=TRUE))
sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats=sqrt(sum(fraction_intraparticle_pore_space_per_size_category_minus_chance_sd^2*frequencies_area_weighted^2,na.rm=TRUE))


plot_counts(x_pos, fraction_intraparticle_pore_space_per_size_category+graphical_shift,sd_y=fraction_intraparticle_pore_space_per_size_category_sd,plot.new=FALSE,col="black",bg="black",pch=21,cex=2,type="p")

# Modelling: core particle, + shell around for interparticle. Limitation of
# maximal radius to 0.5x the mean particle diameter because larger particles tend to
# be very irregular, and not spherical, with "domains" about the
# this diameter, probably because they cannot subsist in a spherical shape
# during the fracture process



mean_area_weighted<-function(x)
{
    
    return(mean(x^3)/mean(x^2))
}


sd_area_weighted<-function(x)
{
    
    dx=x-mean_area_weighted(x)
    
    return (sqrt((mean(dx^2*(x^2))/mean(x^2))))
}






EPI_intra_inter_particle_pore_space_for_fit = EPI_intra_inter_particle_pore_space[EPI_intra_inter_particle_pore_space$equivalent_particle_diameters>100,] # Exclude the very small particles, these have
# different geometry without proper pore structure

equivalent_particle_radius=EPI_intra_inter_particle_pore_space_for_fit$equivalent_particle_diameters/2


weights=equivalent_particle_radius/mean(equivalent_particle_radius)


Fraction_intraparticle = EPI_intra_inter_particle_pore_space_for_fit$Fraction_intraparticle*weights




model=nls(Fraction_intraparticle ~ weights*equivalent_particle_radius^2/(equivalent_particle_radius+shell_thickness)^2,start=list(shell_thickness=50))

# Model function with both shell-core structure and limitation of effective radius (i.e. irregular shape effect)
# The upper limit to the effective size is modelled by 1/R=1/R1+1/R2 equation, with the idea that fracturing
# limits the size of the local domain in a "resistor" way, the maximum being what is squeezable alone through the needle but it
# being often diminished by other particles. For a very large particle, we assume that many domains achieve maximum size given by size_limit
intra_fraction_function<-function(r_particle,size_limit,shell_thickness){
    ((1/r_particle+1/size_limit)^(-1))^2/(((1/r_particle+1/size_limit)^(-1))+shell_thickness)^2
}

model_irregularity=nls(Fraction_intraparticle ~ weights*intra_fraction_function(equivalent_particle_radius,size_limit,shell_thickness) ,
    start=list(shell_thickness=coefficients(model)[["shell_thickness"]],size_limit=800),control=nls.control(warnOnly=TRUE))





shell_thickness_fitted = coefficients(model_irregularity)[["shell_thickness"]]
size_limit_fitted = coefficients(model_irregularity)[["size_limit"]]





for_theory=seq(from=0, to=2000,length.out=201)

lines(coord_transform(for_theory),(for_theory/2)^2/(for_theory/2+coefficients(model)[["shell_thickness"]])^2+graphical_shift,type="l",lty=2)

theory_intraparticle_fraction_nominal = intra_fraction_function(for_theory/2,size_limit_fitted,shell_thickness_fitted)


lines(coord_transform(for_theory),theory_intraparticle_fraction_nominal+graphical_shift,type="l",lty=1,lwd=1.5)



# Two parameters plus offset
dof=length(equivalent_particle_radius-3)

lower_t = qt(0.025,dof)

upper_t =qt(0.975,dof)

# Try to find to where we can go
ratios_size_shell=0




model_irregularity_offset=nls(Fraction_intraparticle ~ weights*intra_fraction_function(equivalent_particle_radius,size_limit_fitted+delta_size_limit,shell_thickness_fitted) ,
start=list(delta_size_limit=0.01),control=nls.control(warnOnly=TRUE))

prof=profile(model_irregularity_offset)

delta_size_limit_lower=approx(prof$delta_size_limit$tau,prof$delta_size_limit[,2],xout=lower_t)$y



delta_size_limit_upper=approx(prof$delta_size_limit$tau,prof$delta_size_limit[,2],xout=upper_t)$y


model_irregularity_offset=nls(Fraction_intraparticle ~ weights*intra_fraction_function(equivalent_particle_radius,size_limit_fitted,
shell_thickness_fitted+delta_shell_thickness) ,
start=list(delta_shell_thickness=0.01),control=nls.control(warnOnly=TRUE))

prof=profile(model_irregularity_offset)

delta_shell_thickness_lower=approx(prof$delta_shell_thickness$tau,prof$delta_shell_thickness[,2],xout=lower_t)$y



delta_shell_thickness_upper=approx(prof$delta_shell_thickness$tau,prof$delta_shell_thickness[,2],xout=upper_t)$y


modeloffset=nls(Fraction_intraparticle ~ weights*equivalent_particle_radius^2/(equivalent_particle_radius+coefficients(model)[["shell_thickness"]]+delta_shell_thickness_single)^2,start=list(delta_shell_thickness_single=10),control=nls.control(warnOnly=TRUE))
prof=profile(modeloffset)
delta_shell_thickness_lower_single=approx(prof$delta_shell_thickness_single$tau,prof$delta_shell_thickness_single[,2],xout=lower_t)$y
delta_shell_thickness_upper_single=approx(prof$delta_shell_thickness_single$tau,prof$delta_shell_thickness_single[,2],xout=upper_t)$y


cat("\n\n\nReporting Fig. S9a (Items 77-80)==========")
cat(paste("\nNumber of particles analyzed: n=",dim(EPI_intra_inter_particle_pore_space)[1],sep=""))
cat(paste("\nNumber of independent experiments (repetitions): N=",length(unique(EPI_intra_inter_particle_pore_space$Experiment)),sep=""))

cat("\n\nNormality testing")
shapiro.test(resid(model))
shapiro.test(resid(model_irregularity))

cat("\n\nTesting of each model")
cat("\nCore-shell model (Item 77)")
profile(model)
cat("\n\nAnova analysis of improvement in fit from core-shell to core-shell with particle size limitation (irregularity): Item 78\n")
anova(model, model_irregularity)
cat("\nAkaike Information Criterion: Core-shell model")
AIC(model)
cat("\nAkaike Information Criterion: domain(irregularity) model ")
AIC(model_irregularity)


cat("\ndomain(irregularity) model, profiling")
profile(model_irregularity)

cat("\n\nEffect size")
# Effect size: adjusted r2
cat("\nCore-shell model (Item 77): adjusted r2 = ")
cat(1-var(resid(model))/var(Fraction_intraparticle)*(length(Fraction_intraparticle))/(length(Fraction_intraparticle)-1))

cat("\nDifference core-shell to irregular: adjusted r2 on the remaining residuals of the core-shell model (Item 78)")
cat(1-var(resid(model_irregularity))/var(resid(model))*(length(Fraction_intraparticle)-1)/(length(Fraction_intraparticle)-2))

cat("\nIrregular domain model: adjusted r2 on the initial residuals (final fit of the model, Item 79) = ")
cat(1-var(resid(model_irregularity))/var(Fraction_intraparticle)*(length(Fraction_intraparticle))/(length(Fraction_intraparticle)-2))

cat("\n\nConfidence intervals")

cat("\nRegular core-shell model (Item 77) parameter core radius (in micrometers). Best fit, confidence lower, confidence upper =")
cat(paste("\nBest fit=",coefficients(model)[["shell_thickness"]], ", conf lower=", coefficients(model)[["shell_thickness"]]+delta_shell_thickness_lower_single,
  "conf upper=",coefficients(model)[["shell_thickness"]]+delta_shell_thickness_upper_single,sep=""))

cat("\nConfidence interval for r2 for model comparison (Item 78)\n")
CI.Rsq(
    1-var(resid(model_irregularity))/var(resid(model))*(length(Fraction_intraparticle)-1)/(length(Fraction_intraparticle)-2),
    length(resid(model_irregularity)),2)

cat("\nIrregular core-shell models, fits for maximum core radius rf and shell thickness s (Item 79, both in micrometers). Best fit, confidence lower, confidence upper =")
cat(paste("\nBest fit s=",coefficients(model_irregularity)[["shell_thickness"]], ", conf lower=", coefficients(model_irregularity)[["shell_thickness"]]+delta_shell_thickness_lower,
  "conf upper=",coefficients(model_irregularity)[["shell_thickness"]]+delta_shell_thickness_upper,sep=""))


cat(paste("\nBest fit rf=",coefficients(model_irregularity)[["size_limit"]], ", conf lower=", coefficients(model_irregularity)[["size_limit"]]+delta_size_limit_lower,
  "conf upper=",coefficients(model_irregularity)[["size_limit"]]+delta_size_limit_upper,sep=""))

cat("\nIrregular domain model parameter size limit (radius, in micrometers) =")
cat(paste(size_limit_fitted, "+/-", max(abs(c(delta_size_limit_lower,delta_size_limit_upper)))))
cat("\nIrregular model parameter interpenetration shell thickness (micrometers) =")
cat(paste(shell_thickness_fitted, "+/-", max(abs(c(delta_shell_thickness_lower,delta_shell_thickness_upper)))))


cat("\n\n\nMean and standard deviation of intraparticle pore fraction, from descriptive statistics (category means and sd of mean, weighted by area-weighted frequency)")
cat("\nNormality testing on data aggregated per experiment")
shapiro.test(aggregate(EPI_intra_inter_particle_pore_space$Fraction_intraparticle-EPI_intra_inter_particle_pore_space$fraction_minority_color,by=list(Experiment= EPI_intra_inter_particle_pore_space$Experiment),FUN=mean)$x)
cat("\nt-statistics: Difference to minority fraction (=theoretical value for false-positive intra-particle association), divided by associated standard deviation (Item 80) ")
t_intraparticle_pore_fraction_vs_random_theory=mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats/sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats
cat(paste("\nt=",t_intraparticle_pore_fraction_vs_random_theory))
cat(paste("\nDF=",length(unique(EPI_intra_inter_particle_pore_space$Experiment))))
pval_intraparticle_pore_fraction_vs_random_theory=(1-pt(mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats/sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats,length(unique(EPI_intra_inter_particle_pore_space$Experiment))))
cat(paste("\nP (before Bonferroni correction)=",pval_intraparticle_pore_fraction_vs_random_theory))
cat(paste("\nP (with Bonferroni correction)=",pval_intraparticle_pore_fraction_vs_random_theory*N_Bonferroni))


cat(paste("\nIntraparticle pore fraction = ",mean_fraction_intraparticle_pore_space_from_category_stats,"+/-",sd_fraction_intraparticle_pore_space_from_category_stats))
# Confidence intervals: We take as N here the number of distinct experiments since there could be non-covered experimental variation
# The standard deviation is already the one from the mean
cat(paste("\n95% confidence interval from ",mean_fraction_intraparticle_pore_space_from_category_stats+
qt(0.025,length(unique(EPI_intra_inter_particle_pore_space$Experiment)))*sd_fraction_intraparticle_pore_space_from_category_stats," to ",mean_fraction_intraparticle_pore_space_from_category_stats+
qt(0.975,length(unique(EPI_intra_inter_particle_pore_space$Experiment)))*sd_fraction_intraparticle_pore_space_from_category_stats))

cat(paste("\nIntraparticle pore fraction - random expectation = ",mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats,"+/-",sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats))
# Confidence intervals: We take as N here the number of distinct experiments since there could be non-covered experimental variation
# The standard deviation is already the one from the mean
cat(paste("\n95% confidence interval from ",mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats+
qt(0.025,length(unique(EPI_intra_inter_particle_pore_space$Experiment)))*sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats," to ",mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats+
qt(0.975,length(unique(EPI_intra_inter_particle_pore_space$Experiment)))*sd_fraction_intraparticle_pore_space_minus_chance_from_category_stats))

cat("\nEffect size")
cat(paste("\nFor the biomaterial, this is the t-value as we are interested in the averaged values : ", t_intraparticle_pore_fraction_vs_random_theory))
cat(paste("\nAt the level of the individual particles, we take the particle-level sd : ", mean_fraction_intraparticle_pore_space_minus_chance_from_category_stats/sd(EPI_intra_inter_particle_pore_space$Fraction_intraparticle-EPI_intra_inter_particle_pore_space $fraction_minority_color)))


legend("topright",lty=c(2,1),lwd=c(1,2),legend=c("Core-shell","Core-shell with irregularity"))


dev.off()



pdf("Fig_S9b.pdf")


xlim=c(0,3.3)

EPI_intra_inter_particle_pore_space$particle_diameter=sqrt(EPI_intra_inter_particle_pore_space$particle_area_mm2/pi)*2

plot_counts(sqrt(EPI_intra_inter_particle_pore_space$particle_area_mm2/pi)*2,EPI_intra_inter_particle_pore_space$Mean_pore_size_inter,type="p",
pch=21,bg=c("grey"),col="black",ylim=c(0,200),xlim=xlim,xlab="Particle diameter [mm]",ylab="Pore diameter [um]",cex=1.5,
main="Pore size vs. particle size",xaxt="n")

axis(side=1,at=c(0,0.5,1,1.5,2))

plot_counts(sqrt(EPI_intra_inter_particle_pore_space$particle_area_mm2/pi)*2,EPI_intra_inter_particle_pore_space$Mean_pore_size_intra,type="p",
pch=21,bg=c("black"),col="black",xlab="Particle diameter [mm]",ylab="Pore diameter [um]",plot.new=FALSE,cex=1.5)


lines(c(0,2),rep(50,2),lty=2,col="red")
lines(c(0,0.2),c(0,200),col="red",lty=2)

legend("topright",pch=c(21,21),pt.bg=c("black","grey"),legend=c("intra-particle","inter-particle"),cex=2)

axis(side=1,at=c(2.5,2.8),labels=c("intra","inter"),las=2)

middle=2.5
width=0.2
half=width/2

polygon(c(middle-half,middle-half,middle+half,middle+half,middle-half),c(0,mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra),mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra),0,0),col="black")
lines(c(middle,middle),mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)+c(0,sd(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)))

lines(c(middle-half/2,middle+half/2),rep(mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)+sd(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra),2))

middle=2.8
polygon(c(middle-half,middle-half,middle+half,middle+half,middle-half),c(0,mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter),mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter),0,0),col="grey")
lines(c(middle,middle),mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter)+c(0,sd(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter)))

lines(c(middle-half/2,middle+half/2),rep(mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter)+sd(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter),2))



# Testing:

N_Bonferroni =3  # 3 Tests: Each porosity against 50 minimum, and intra vs. inter


pval=t.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter,EPI_intra_inter_particle_pore_space$Mean_pore_size_intra,paired=TRUE)$p.val*N_Bonferroni

text(2.65,137,labels=significance_labels(pval),cex=2,adj=0.5)
lines(c(2.5,2.8),rep(132,2))

# For both the intra-particle and intraparticle test against 50 microns we need a robust test
pval_intra = wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra-50)$p.val*N_Bonferroni
pval_inter = wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter-50)$p.val*N_Bonferroni


lines(xlim,rep(50,2),lty=2,col="red")

lines(c(2.5-width,2.5-width-0.05),rep(50,2))
lines(rep(2.5-width-0.05,2),c(50,mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)))
lines(c(2.5-width,2.5-width-0.05),rep(mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra),2))

text(2.5-width-0.2,(50+mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra))/2,significance_labels(pval_intra),cex=2)
text(2.8+width+0.2,(50+mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter))/2,significance_labels(pval_inter),cex=2)

lines(c(2.8+width,2.8+width+0.05),rep(50,2))
lines(rep(2.8+width+0.05,2),c(50,mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter)))
lines(c(2.8+width,2.8+width+0.05),rep(mean(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter),2))


# Reporting intra-particle pore size vs. 50 microns
cat("\n\n\nReporting Fig. S9b")
cat("\nTest of intra-particle pore size against theoretical limit of 50 microns (Item 81)")
cat("\nTest of normality of the residuals")
shapiro.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra-50)
cat("\nSince test of normality gives significant deviation from normality, use robust test. Output includes confidence interval of the difference to 50 microns")
wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra-50,conf.int=TRUE)
# We are doing robust testing, get the effect size through the P-value
P_wilcox=wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra-50)$p.value
# Effect size from non-paramatric test, Fritz, C.O., P.E. Morris, and J.J. Richler, Effect size estimates: current use, calculations, and interpretation. J Exp Psychol Gen, 2012. 141(1): p. 2-18.
# First get Z value from P value (two-sided)
Z_wilcox=qnorm(0.5+(1-P_wilcox)/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/length(EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)
cat(paste("\nEffect size: r2 from P-value=",r2,sep=""))
cat(paste("\nP-value with Bonferroni adjustment = ",P_wilcox*N_Bonferroni))

# Reporting inter-particle pore size vs. 50 microns

cat("\n\nTest of inter-particle pore size against theoretical limit of 50 microns (Item 82)")
cat("\nTest of normality of the residuals")
shapiro.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter-50)
cat("\nSince test of normality gives significant deviation from normality, use robust test. Output includes confidence interval of the difference to 50 microns")
wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter-50,conf.int=TRUE)
# We are doing robust testing, get the effect size through the P-value
P_wilcox=wilcox.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter-50)$p.value
# Effect size from non-paramatric test, Fritz, C.O., P.E. Morris, and J.J. Richler, Effect size estimates: current use, calculations, and interpretation. J Exp Psychol Gen, 2012. 141(1): p. 2-18.
# First get Z value from P value (two-sided)
Z_wilcox=qnorm(0.5+(1-P_wilcox)/2)
# Then convert to R-squared using the Fritz. et al. formula
r2=Z_wilcox^2/length(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter)
cat(paste("\nEffect size: r2 from P-value=",r2,sep=""))
cat(paste("\nP-value with Bonferroni adjustment = ",P_wilcox*N_Bonferroni))

cat("\n\nTest of inter-particle pore size vs. intra-particle pore size (Item 83)")
# Inter vs. intra: Normality of residuals is OK (likely the pairing is helpful)
shapiro.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter-EPI_intra_inter_particle_pore_space$Mean_pore_size_intra)
# So do t-test
t.test(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter,EPI_intra_inter_particle_pore_space$Mean_pore_size_intra,paired=TRUE)
# Effect size
cohen.d(EPI_intra_inter_particle_pore_space$Mean_pore_size_inter,EPI_intra_inter_particle_pore_space$Mean_pore_size_intra,paired=TRUE)





dev.off()
