cat("\nDemo evaluation of the supplementary simulations. R script 03_jump_correction.R: Demo for jump correction due to particles leaving and entering the measurement area.\n") 

library(particleShearEvaluation)

# Load the overview
root_folder = "/results/Simulation demo/Supplementary_evaluation"

setwd(root_folder)

load(file="overview_supplementary_demo.rda")


# prepare the additional columns for the re-evaluation of the G' and G'' with jump correction and demodulation in R
overview_simulation_supplementaries$Gprime_Pa_surface_force_jumps_corrected=NA
overview_simulation_supplementaries$Gprimeprime_Pa_surface_force_jumps_corrected=NA

overview_simulation_supplementaries$Gprime_Pa_jumps_corrected=NA
overview_simulation_supplementaries$Gprimeprime_Pa_jumps_corrected=NA




# Also, plot the stress curves
pdf("shear_stress_curves.pdf")

# Loop through the output of the 4 supplementary simulations
for (ind in 1:(dim(overview_simulation_supplementaries)[1]))
{
    # Get the file information for the current simulation
    info = overview_simulation_supplementaries[ind,]
    
    # rda file with the stress tensor data
    stress_filename =paste("stress_",gsub(".txt",".rda",info$File),sep="")
    
    pathRead=paste(info$Folder,stress_filename,sep="/")
    
    # path to the small header file with the overall information
    path =paste(info$Folder,info$File,sep="/")
    
    theStressCurve = read_stress_curve_from_rda_file(path=pathRead)
    
    # The Python simulations have a pre-equilibration, oscillation, 
    # and re-equilibration period, label these
    theStressCurve$measurement=measurement_periods(
        theStressCurve,
        info$baseline_pre_periods,info$periods,info$Frequency)
    
# Isolate the oscillation measurement 
    osc_measurement=theStressCurve[theStressCurve$measurement=="oscillatory_measurement",]
    
    # Plot the oscillation measurement, both using the overall 
    # stress tensor and the external surface force
    # They should not be too different; if they are, inertia
    # is too important and the oscillation frequency should
    # be decreased (this takes however longer to simulate)
    plot(shear_stress_measured_at_surface ~ t, osc_measurement,type="l",main=path,ylab="Shear stress [Pa]",xlab="t [s]")
    lines(shear_stress_from_internal_stress_tensor ~ t, osc_measurement,type="l",col="red")
    
    legend("topright",lty=c(1,1),col=c("black","red"),legend=c("Overall stress tensor","External force stress tensor"))
    
    # Re-evaluate including jump correction
    # For details, type help(G_from_demodulation)
    # after having loaded particleShearSimulation via library(particleShearSimulation)
    
    # First, evaluation using the external stress tensor
    G=G_from_demodulation(t=osc_measurement$t,
                        Frequency=info$Frequency,
                        m=osc_measurement$shear_stress_measured_at_surface,
                        Strain_amplitude=info$Strain_amplitude,
                        relative_threshold=0.1)
                        
    
 # Put this data into the overview table
    overview_simulation_supplementaries$Gprime_Pa_surface_force_jumps_corrected[match(path,paste(overview_simulation_supplementaries$Folder,overview_simulation_supplementaries$File,sep="/"))]=G["Gprime"]
    
    overview_simulation_supplementaries$Gprimeprime_Pa_surface_force_jumps_corrected[match(path,paste(overview_simulation_supplementaries$Folder,overview_simulation_supplementaries$File,sep="/"))]=G["Gprimeprime"]

    # Do the demodulation also for the internal stress tensor
    G_internal=G_from_demodulation(t=osc_measurement$t,
    Frequency=info$Frequency,
    m=osc_measurement$shear_stress_from_internal_stress_tensor,
    Strain_amplitude=info$Strain_amplitude,
    relative_threshold=0.1)
    
    
# and put back into the overview data
    overview_simulation_supplementaries$Gprime_Pa_jumps_corrected[match(path,paste(overview_simulation_supplementaries$Folder,overview_simulation_supplementaries$File,sep="/"))]=G_internal["Gprime"]
    
    overview_simulation_supplementaries$Gprimeprime_Pa_jumps_corrected[match(path,paste(overview_simulation_supplementaries$Folder,overview_simulation_supplementaries$File,sep="/"))]=G_internal["Gprimeprime"]
    
    
    
    
}

# Write the amended overview

save(file="overview_simulation_supplementaries_jumps_corrected.rda",list="overview_simulation_supplementaries")

# to save the plots
dev.off()