cat("\nDemo evaluation of the supplementary simulations. R script 05_read_static_pressure.R: Adding the static pressure column\n\n")

library(particleShearEvaluation)

# Load the overview file
root_folder = "/results/Simulation demo/Supplementary_evaluation"

setwd(root_folder)

load(file="overview_simulation_supplementaries_jumps_corrected.rda")

# To hold the static pressure information (mean diagonal elements of
# the stress tensor)
overview_simulation_supplementaries$P=NA

# Loop through the 4 supplementary simulation files
for (ind in 1:(dim(overview_simulation_supplementaries)[1]))
{
    # File info for the current simulation
    info = overview_simulation_supplementaries[ind,]
    
    # Stress tensor file
    stress_filename =paste("stress_",gsub(".txt",".rda",info$File),sep="")
    
    # Full path stress tensor file
    pathRead=paste(info$Folder,stress_filename,sep="/")
    
    # Full path small text header file
    path =paste(info$Folder,info$File,sep="/")
    
    
    
# Get the stress tensor curve
    theStressCurve=read_stress_tensor_data_from_rda_file(path=pathRead)

    # distinguish pre-equilibration, oscillatory measurement, and post-equilibration in the simulation
    
theStressCurve$measurement=measurement_periods(
        theStressCurve,info$baseline_pre_periods,info$periods,info$Frequency)
        
        
# Get the pressure as the mean value of the diagonal elements (00 and 11) of the overall stress tensor, in the pre-equilibration period
    overview_simulation_supplementaries$P[ind]=mean(theStressCurve$stress_tensor_overall_00[theStressCurve$measurement=="pre"]+theStressCurve$stress_tensor_overall_11[theStressCurve$measurement=="pre"])/2
    
# to show an indication of the progress   
    cat(ind)
    cat("\n")



}

# Save the overview back into the original place, this just adds the P column
save(file="overview_simulation_supplementaries_jumps_corrected.rda",list=c("overview_simulation_supplementaries","root_folder"))








