# Operating system to rename the files systematically
from os import listdir
from os.path import isfile, isdir, join, exists
import shutil


def rename_files_for_video(root_folder,target_folder):
    """Utility function for moving and renaming the image files
    for video creation
    
    root_folder: Folder in which the python simulatoin was run. This
    folder is expected to contain exactly one sub-folder where the 
    images are located\n
    target_folder: Folder to which the files should be moved.
    This function returns the 
    image folder (a subfolder of root_folder)
    """
    
    # Get the files in the temporary directory
    storage_directory = [d for d in listdir(root_folder) if 
        isdir(join(root_folder, d))]


    # There should be only 1 directory, the images are in this 
    #directory. 
    # Get a list of the image files

    image_folder = join(root_folder,storage_directory[0])

    image_files = [f for f in listdir(image_folder) if      
        isfile(join(image_folder, f))]

    # Order them
    image_files.sort()

    # Move and rename them

    
    for file_index in range(len(image_files)):
        shutil.move(join(image_folder,image_files[file_index]),
            join(target_folder,"image"+
                 "{:02d}".format(file_index)+".jpg"))
    
    return(image_folder)
        
        
    
    
    













