echo "unittest_demo.sh: Self-testing"

echo "===========run time ca. 2min==============="





# To be able to run this file also as standalone master file
cd /code/Simulation\ demo
mkdir /results/Simulation\ demo


# Demo simulation: like in Supplementary 21, but with a smaller 
# particle assembly to be reasonably fast.
# These are partially crosslinked particles


# prepare folder to hold the results
mkdir demo_unittest

# To load the python library, needs to the lib

# Start a virtual frame buffer in the background (xvfb). This will provide the
# Python and more specifically tkinter with a graphical device needed for
# displaying the simulation

# The video buffer should be run in a non-blocking mode (background process), and
# so we start it as a child process (with & at the end of the command)
Xvfb :1 -screen 1 320x240x8&
# Get the process id, we will need to kill this independent process once we're done
pid1=$!

# Make sure Xvfb is up and running, we've had issues when going on straight to the next
# commands
sleep 1

# run the python script using this for a display
echo "Running unittests"

# This command channels the graphical out put to device 1 (the :1 in the Xvfb command above). We also have it as a child process since here, in the main process, we'll have to grab the video stills
DISPLAY=:1 python3 /code/Simulation\ demo/particleShearUnitTest.py > /results/Simulation\ demo/unittest_output.txt&
# Again, we need to be able to kill it
pid2=$!

# To allow imagemagick to write files
cp /code/configuration_files/policy.xml /etc/ImageMagick-6/policy.xml 
#cp  /etc/ImageMagick-6/policy.xml /results/Simulation\ demo

# Make sure everything is up and running before trying to do anything more
sleep 0.5

# This is a bit tricky: we need to know whether the python simulation still runs or
# is already done. We know its process id (variable pid2) and so we can specifically
# query its status with ps
x="$(ps -p $pid2 -o stat)"
# We get typically a two part string of the type "STAT R" or so back, cut it in two
# and take the second half
x="$(echo $x | cut -d" " -f2)"

# Debug in case
ps -p $pid2 -o stat
echo $x

ind=1

echo "expected: 2 failures out of 55 tests. This is due to lack of angular momentum conservation in some external models assessed in unit testing, but not used in general simulation."

# Here, we loop while the Python process is still running
while [ "$x" == "Rl" ]  || [ "$x" == "Sl" ] || [ "$x" == "R" ] || [ "$x" == "S" ] || [ "$x" == "D" ]
do
# Grab whatever is currently in the video buffer and write it as a jpeg
DISPLAY=:1 import -window root demo_unittest/unittest$ind.jpg
x="$(ps -p $pid2 -o stat)"
x="$(echo $x | cut -d" " -f2)"
let ind++ 
sleep 0.2
echo "."
done

# Kill the video frame buffer (Xvfb), using its known process ID
kill $pid1


# And finally convert the intermediate jpgs to a movie
ffmpeg -r 25 -start_number 1 -i "demo_unittest/unittest%d.jpg"  "/results/Simulation demo/unittest.mov"

